/*
 * Electric(tm) VLSI Design System
 *
 * File: config.h
 * Site-dependent definitions
 * Written by: Steven M. Rubin, Electric Editor Incorporated
 *
 * Copyright (c) 1998 Electric Editor Incorporated.
 *
 * Electric(tm) is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Electric(tm) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Electric(tm); see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, Mass 02111-1307, USA.
 *
 * Electric Editor Incorporated
 * 23470 Sunset Drive, Suite 108
 * Los Gatos, California 95033
 * support@electriceditor.com
 */

#ifndef _CONFIG_H_
#define _CONFIG_H_ 1

/********************* MACHINE DETERMINATION *********************/

/* determine if it is Macintosh OS */
#if defined(THINK_C) || defined(THINK_CPLUS) || defined(__MWERKS__)
#  define MACOS 1
#  ifdef __MWERKS__
#    if __MWERKS__ >= 0x2100
#      define NEWCODEWARRIOR    1
#      define OLDROUTINENAMES   1
#    endif
#  endif
#endif

/* determine if it is Windows NT/9x */
#if (defined(_WIN32) || defined(__WIN32__)) && !defined(WIN32)
#  define WIN32 1
#endif

/* determine if it is UNIX */
#if !defined(MACOS) && !defined(WIN32)
#  define ONUNIX 1
#endif

/********************* MACHINE-SPECIFIC DEFINES *********************/

#ifdef	MACOS						/* Macintosh */
#  include <QDOffscreen.h>
#  define STDC_HEADERS       1
#  define RETSIGTYPE         void
#  define DIRSEP             ':'
#  define MESSAGESEOFKEY     "^D"
#  define CADRCFILENAME      "cadrc"
#  define ELECTRICLOG        "electric.log"
#  define OPTIONSFILE        "electricoptions.elib"
#  define LIBDIR             ":lib:"
#  define SORTLOC            ""
#  define ESIMLOC            ""
#  define RSIMLOC            ""
#  define PRESIMLOC          ""
#  define RNLLOC             ""
#  define SPICELOC           ""
#  define FLATDRCLOC         ""
#  define SFLATDRCLOC        ""
#  ifdef NEWCODEWARRIOR
#    define SIGNALCAST __signal_func_ptr
#  else
#    define SIGNALCAST _Sigfun*
#  endif
   typedef          long   INTBIG;		/* at least 32 bits, can hold address */
   typedef          short  INTSML;		/* at least 16 bits */
   typedef unsigned long  UINTBIG;		/* at least 32 bits, can hold address */
   typedef unsigned short UINTSML;		/* at least 16 bits */
#endif

#ifdef WIN32						/* Windows */
#  include "windows.h"
#  define STDC_HEADERS       1
#  define RETSIGTYPE         void
#  define DIRSEP             '\\'
#  define MESSAGESEOFKEY     "ESC"
#  define CADRCFILENAME      "cadrc"
#  define ELECTRICLOG        "electric.log"
#  define OPTIONSFILE        "electricoptions.elib"
#  define LIBDIR             "lib\\"
#  define SORTLOC            ""
#  define ESIMLOC            ""
#  define RSIMLOC            ""
#  define PRESIMLOC          ""
#  define RNLLOC             ""
#  define SPICELOC           ""
#  define FLATDRCLOC         ""
#  define SFLATDRCLOC        ""
#  undef TECHNOLOGY
   typedef void (*SIGNALCAST)(int);
   typedef LONG            INTBIG;		/* at least 32 bits, can hold address */
   typedef SHORT           INTSML;		/* at least 16 bits */
   typedef ULONG          UINTBIG;		/* at least 32 bits, can hold address */
   typedef USHORT         UINTSML;		/* at least 16 bits */
#endif

#ifdef ONUNIX						/* UNIX */
#  include "defines.h"
#  define DIRSEP             '/'
#  define MESSAGESEOFKEY     "^D"
#  define CADRCFILENAME      ".cadrc"
#  define ELECTRICLOG        ".electric.log"
#  define OPTIONSFILE        ".electricoptions.elib"
#  define LIBDIR             "lib/"
#  define SORTLOC            "/usr/bin/sort"
#  define ESIMLOC            "/usr/local/bin/esim"
#  define RSIMLOC            "/usr/local/bin/rsim"
#  define PRESIMLOC          "/usr/local/bin/presim"
#  define RNLLOC             "/usr/local/bin/rnl"
#  define SPICELOC           "/usr/local/bin/spice"
#  define FLATDRCLOC         "/usr/local/bin/ffindshort"
#  define SFLATDRCLOC        "/usr/local/bin/findshort"
   typedef RETSIGTYPE (*SIGNALCAST)(int);
   typedef          long   INTBIG;		/* at least 32 bits, can hold address */
   typedef          short  INTSML;		/* at least 16 bits */
   typedef unsigned long  UINTBIG;		/* at least 32 bits, can hold address */
   typedef unsigned short UINTSML;		/* at least 16 bits */
#endif

/********************* DETERMINE CONFIGURATION *********************/

/*
 * There are a number of different source configurations available,
 * all defined externally when compiling Electric:
 *
 * EGNU     GNU release
 * EVE      Full system
 * ELM      Mechanical product
 * ELF      FPGA product
 * ELFD     FPGA (Dyna) product
 */
#ifdef EVE
#  undef  EVE
#  define EVE 1
#else
#  define EVE 0
#endif

#ifdef ELM
#  undef  ELM
#  define ELM 1
#else
#  define ELM 0
#endif

#ifdef ELF
#  undef  ELF
#  define ELF 1
#else
#  define ELF 0
#endif

#ifdef ELFD
#  undef ELFD
#  define ELFD 1
#else
#  define ELFD 0
#endif

/* default configuration is for GNU */
#if EVE+ELM+ELF+ELFD == 0
#define EGNU 1
#endif

#ifdef EGNU
#  undef EGNU
#  define EGNU 1
#else
#  define EGNU 0
#endif

/********************* SOURCE MODULE CONFIGURATION *********************/

/* The tools (User and I/O are always enabled) */
#define COMAID             ( EGNU | EVE |  0  |  0  |   0  )
#define COMPENAID          ( EGNU | EVE | ELM |  0  |   0  )
#define DRCAID             ( EGNU | EVE |  0  |  0  |   0  )
#define LOGEFFAID          ( EGNU | EVE |  0  |  0  |   0  )
#define MAPPERAID          (   0  |  0  |  0  |  0  |   0  )
#define PLAAID             ( EGNU | EVE |  0  |  0  |   0  )
#define PROJECTAID         (   0  | EVE |  0  |  0  |   0  | FORCEPROJECT)
#define ROUTAID            ( EGNU | EVE |  0  | ELF | ELFD )
#define SCAID              ( EGNU | EVE |  0  |  0  |   0  )
#define SIMAID             ( EGNU | EVE |  0  | ELF | ELFD )
#define VHDLAID            ( EGNU | EVE |  0  | ELF | ELFD )

/* The simulator output formats */
#define SIMMOSSIM          ( EGNU | EVE |  0  |  0  |   0  )
#define SIMPAL             ( EGNU | EVE |  0  |  0  |   0  )
#define SIMALS             ( EGNU | EVE |  0  | ELF | ELFD )
#define SIMSILOS           ( EGNU | EVE |  0  |  0  |   0  )
#define SIMSIM             ( EGNU | EVE |  0  |  0  |   0  )
#define SIMSPICE           ( EGNU | EVE |  0  |  0  |   0  )
#define SIMTEXSIM          ( EGNU | EVE |  0  |  0  |   0  )
#define SIMVERILOG         ( EGNU | EVE |  0  | ELF | ELFD )

/* The I/O modules (Binary and Text are always enabled) */
#define IOCIF              ( EGNU | EVE |  0  |  0  |   0  )
#define IODEF              (   0  | EVE |  0  |  0  |   0  | FORCELEFDEF)
#define IODXF              ( EGNU | EVE | ELM |  0  |   0  )
#define IOEDIF             ( EGNU | EVE |  0  | ELF | ELFD )
#define IOGDS              ( EGNU | EVE | ELM |  0  |   0  )
#define IOHPGL             ( EGNU | EVE | ELM | ELF | ELFD )
#define IOL                ( EGNU | EVE |  0  |  0  |   0  )
#define IOLEF              (   0  | EVE |  0  |  0  |   0  | FORCELEFDEF)
#define IOPOSTSCRIPT       ( EGNU | EVE | ELM | ELF | ELFD )
#ifdef MACOS
#  define IOQUICKDRAW      ( EGNU | EVE | ELM | ELF | ELFD )
#else
#  define IOQUICKDRAW      0
#endif
#define IOSDF              ( EGNU | EVE |  0  | ELF |   0  )
#define IOSUE              ( EGNU | EVE |  0  | ELF |   0  )

/* The technologies (Artwork, Generic and Schematic are always enabled) */
#define TECBICMOS          ( EGNU | EVE |  0  |  0  |   0  )
#define TECBIPOLAR         ( EGNU | EVE |  0  |  0  |   0  )
#define TECCMOS            ( EGNU | EVE |  0  |  0  |   0  )
#define TECCMOSDODN        ( EGNU | EVE |  0  |  0  |   0  )
#define TECDYNA            (   0  |  0  |  0  |  0  | ELFD )
#define TECEFIDO           ( EGNU | EVE |  0  |  0  |   0  )
#define TECFPGA            ( EGNU | EVE |  0  | ELF |   0  )
#define TECGEM             ( EGNU | EVE |  0  |  0  |   0  )
#define TECMOCMOS          ( EGNU | EVE |  0  |  0  |   0  )
#define TECMOCMOSSUB       ( EGNU | EVE |  0  |  0  |   0  )
#define TECMOCMOS2         ( EGNU | EVE |  0  |  0  |   0  )
#define TECNCMOS3          (   0  | EVE |  0  |  0  |   0  )
#define TECNMOS            ( EGNU | EVE |  0  |  0  |   0  )
#define TECPCB             ( EGNU | EVE |  0  |  0  |   0  )
#define TECRCMOS           ( EGNU | EVE |  0  |  0  |   0  )

/* The language interfaces */
#define LANGLISP           (   0  | EVE |  0  |  0  |   0  | FORCELISP)
#define LANGMM             (   0  |  0  |  0  |  0  |   0  | FORCEMM)
#define LANGTCL            (   0  | EVE |  0  |  0  | ELFD | FORCETCL)

#endif  /* _CONFIG_H_ - at top */
