/*
 * Electric(tm) VLSI Design Systems
 *
 * File: graphunixx11.c
 * X Window System, version 11 graphics and keyboard input manager
 * Written by: Steven M. Rubin, Electric Editor Incorporated
 *
 * Copyright (c) 1998 Electric Editor Incorporated.
 *
 * Electric(tm) is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Electric(tm) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Electric(tm); see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, Mass 02111-1307, USA.
 *
 * Electric Editor Incorporated
 * 23470 Sunset Drive, Suite 108
 * Los Gatos, California 95033
 * support@electriceditor.com
 */

#include "global.h"
#include "database.h"
#include "egraphics.h"
#include "usr.h"
#include "edialogs.h"
#include "config.h"
#include <signal.h>
#include <errno.h>
#include <pwd.h>
#include <sys/param.h>
#include <sys/stat.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xatom.h>
#include <X11/keysym.h>
#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/cursorfont.h>
#include <X11/Shell.h>
#ifdef USETIF
#  include <Xm/Xm.h>
#  include <Xm/Text.h>
#  include <Xm/RowColumn.h>
#  include <Xm/CascadeB.h>
#  include <Xm/ToggleBG.h>
#  include <Xm/PushB.h>
#  include <Xm/Separator.h>
#  include <Xm/FileSB.h>
#  include <Xm/Protocols.h>
#  include <Xm/MwmUtil.h>
#else
#  include <X11/Xaw/Box.h>
#  include <X11/Xaw/Text.h>
#  include <X11/Xaw/AsciiText.h>
#endif

#ifdef HAVE_SYS_TYPES_H
#  include <sys/types.h>
#endif

#ifdef HAVE_UNISTD_H
#  include <unistd.h>
#endif

#ifdef HAVE_FCNTL_H
#  include <fcntl.h>
#endif

#ifdef HAVE_TERMIOS_H
#  include <termios.h>
#else
#  ifdef HAVE_TERMIO_H
#    include <termio.h>
#  else
#    include <sgtty.h>
#  endif
#endif

#ifdef TIME_WITH_SYS_TIME
#  include <sys/time.h>
#  include <time.h>
#else
#  ifdef HAVE_SYS_TIME_H
#    include <sys/time.h>
#  else
#    include <time.h>
#  endif
#endif

#ifdef HAVE_SYS_TIMEB_H
#  include <sys/timeb.h>
#endif

#ifdef HAVE_SYS_WAIT_H
#  include <sys/wait.h>
#endif

#ifdef HAVE_VFORK_H
#  include <vfork.h>		/* needed by SUN optimiser */
#endif

#ifdef HAVE_DIRENT_H
#  include <dirent.h>
#  define NAMELEN(dirent) strlen((dirent)->d_name)
#else
#  define dirent direct
#  define NAMELEN(dirent) (dirent)->d_namelen
#  ifdef HAVE_SYS_NDIR_H
#    include <sys/ndir.h>
#  endif
#  ifdef HAVE_SYS_DIR_H
#    include <sys/dir.h>
#  endif
#  ifdef HAVE_NDIR_H
#    include <ndir.h>
#  endif
#endif

#if LANGTCL
#  include "tcl.h"
#  ifdef USETK
#    include "tk.h"
#    define MYEVENTS (ExposureMask | ButtonPressMask | ButtonReleaseMask | KeyPressMask | \
            EnterWindowMask | LeaveWindowMask | VisibilityChangeMask | PointerMotionMask | \
            StructureNotifyMask | FocusChangeMask)
    Tk_Window gra_tktopwindow;
    void InitializeTK(void);
    Tk_Window MakeTKWindow(short type, short left, short right, short top, short bottom,
        void (*eventproc)(ClientData, XEvent*));
#  endif
  Tcl_Interp *myTCLInterp;
  int InitializeTCL(void);
#endif

/****** windows ******/

#define MAXSTATUSLINES 1						/* number of status lines */
#define FLUSHTICKS    60						/* ticks between display flushes */
#define SBARWIDTH     15						/* size of text-edit scroll bars */

#ifdef __cplusplus
#  define VisualClass(v) v->c_class
#else
#  define VisualClass(v) v->class
#endif

       WINDOWFRAME  *el_firstwindowframe = NOWINDOWFRAME;
       WINDOWFRAME  *el_curwindowframe;			/* current window frame */ 

      XtAppContext  gra_xtapp;					/* the main XT application */
static Display      *gra_dpy;					/* the main X display */
static Display      *gra_msgdpy;				/* the messages window X display */
static Visual       *gra_visual;				/* the visual on the X display */
static Window        gra_win;					/* the main window on the X display */
static INTBIG        gra_screen_num;			/* the X screen number */
static Colormap      gra_defaultcmap;			/* display colormap (if mapped) */

#ifdef ANYDEPTH
static XImage       *gra_world;					/* the offscreen buffer that matches the visual */
static int           gra_worldwid, gra_worldhei;
static char         *gra_dataaddr;				/* the data in "gra_world" */
static char        **gra_offrowstart;			/* pointers to "gra_dataaddr" */
static char         *gra_dataaddr8;				/* the 8-bit offscreen buffer */
static char        **gra_rowstart;				/* pointers to "gra_dataaddr8" */
static UINTBIG       gra_starttime = 0;			/* time of last offscreen refresh */
static int           gra_offscreendirty = 0;	/* nonzero if offscreen changed */
static int           gra_lowredrawx;			/* low X of offscreen that changed */
static int           gra_highredrawx;			/* high X of offscreen that changed */
static int           gra_lowredrawy;			/* low Y of offscreen that changed */
static int           gra_highredrawy;			/* high Y of offscreen that changed */
static INTBIG        gra_colorvalue[256];		/* the value to use */
static INTBIG        gra_truedepth;				/* actual depth of frame buffer in bits */
void       gra_drawline(INTSML x1, INTSML y1, INTSML x2, INTSML y2, INTSML col, INTSML mask);
void       gra_drawpatline(INTSML x1, INTSML y1, INTSML x2, INTSML y2, INTSML col,
                           INTSML mask, INTSML pattern);
void       gra_setrect(INTSML lx, INTSML hx, INTSML ly, INTSML hy);
void       gra_drawdiscrow(INTBIG thisy, INTBIG startx, INTBIG endx, GRAPHICS *desc);
#else
static GC            gra_gcstip;
static Colormap      gra_colormap;				/* system color map */
static INTSML        gra_maphigh;				/* highest entry to use in color map */
void       gra_loadstipple(UINTSML raster[]);
#endif

static Display      *gra_topdpy;				/* the X display for the graphics widget */
static Window        gra_topwin;				/* the X window for the graphics widget */
static Widget        gra_toplevelwidget;		/* the outer graphics widget */
static Widget        gra_graphicswidget;		/* the inner graphics widget */
#ifdef USETIF
static Widget        gra_intermediategraphics;
#else
static Atom          gra_wm_protocols;
#endif
static INTSML        gra_status_height;			/* space for lines at bottom of screen */
       INTSML        us_dispstyle;
       INTSML        us_swid, us_shei;
static INTSML        gra_shei;					/* real height of main window */
static INTSML        gra_revy;					/* for reversing Y coordinates */
static INTBIG        gra_sdep;					/* depth of frame buffer in bits */
       INTSML        us_black, us_white;		/* the monochrome colors */
static INTSML        gra_use_backing;			/* flag if backing store used */
static Atom          gra_wm_delete_window;		/* to trap window kills */
static GC            gra_gc;					/* graphics context for normal drawing */
static GC            gra_gcinv;					/* graphics context for invert drawing */
static INTSML        gra_screenw, gra_screenh;	/* edit screen size */
static INTSML        gra_screenmw, gra_screenmh;/* messages screen size */
static INTBIG        gra_initialeditx;
static INTBIG        gra_initialedity;
static INTBIG        gra_initialmsgx;
static INTBIG        gra_initialmsgy;
#ifdef HAVE_TERMIOS_H
  struct termios us_sttybuf;					/* to get the erase and kill characters */
#else
#  ifdef HAVE_TERMIO_H
    struct termio us_sttybuf;					/* to get the erase and kill characters */
#  else
    struct sgttyb us_sttybuf;					/* to get the erase and kill characters */
#  endif
#endif
static INTSML        gra_logrecordindex = 0;	/* count for session flushing */
static INTSML        gra_playbackmultiple=0;	/* count for multi-key playback */
static int           gra_argc;					/* "argc" for display */
static char        **gra_argv;					/* "argv" for display */
static char          gra_localstring[256];
extern GRAPHICS      us_box, us_ebox, us_menutext;

int        gra_xerrors(Display *dpy, XErrorEvent *err);
void       gra_xterrors(char *msg);
void       gra_showcoords(INTSML x, INTSML y);

/****** the messages window ******/
#define MESSAGESWIDTH        97					/* magic value for gra_stringput() */
#ifndef USETIF
#  define MESSAGEBUFFERSIZE 10000				/* size of XT messages window */
#endif
#define MESLEADING            1					/* extra character spacing */

static Display      *gra_topmsgdpy;				/* the X display for the messages widget */
static Window        gra_topmsgwin;				/* the X window for the messages widget */
static Widget        gra_msgtoplevelwidget;		/* the outer messages widget */
static Widget        gra_messageswidget;		/* the inner messages widget */
static Window        gra_msgwin;				/* messages window */
static INTSML        gra_messages = 0;			/* 0 if no messages window */
static INTSML        gra_messages_obscured;		/* nonzero if messages window covered */
static INTSML        gra_messages_typingin;		/* nonzero if typing into messages window */

/****** the menus ******/
#ifdef USETIF
static INTSML        gra_popupmenuresult;
static Widget        gra_menubar;
static Widget        gra_firstmenu = 0;
static INTSML        gra_pulldownmenucount = 0;	/* number of pulldown menus */
static Widget       *gra_pulldownmenus;			/* the current pulldown menu handles */
static INTSML       *gra_pulldownmenusize;		/* the number of entries in a menu */
static Widget      **gra_pulldownmenulist;		/* the entries in a menu */
static POPUPMENU   **gra_pulldowns;				/* the current pulldown menus */

Widget gra_makepdmenu(POPUPMENU *pm, INTSML value, Widget parent, Widget *childlist);
void   gra_pulldownindex(POPUPMENU *pm, INTSML order, Widget parent);
void   gra_menucb(Widget W, int item_number, XtPointer call_data);
void   gra_menupcb(Widget w, int item_number, XtPointer call_data);
#endif

/****** the dialogs ******/
#ifdef USETIF

#define MAXDIALOGS        3   /* maximum nested dialogs */
#define DIALOGNUM        16
#define DIALOGDEN        12
#define MAXICONS         20

typedef struct
{
	Widget      window;
	Widget      windowframe;
	DIALOG     *itemdesc;
	int         defaultbutton;
	Widget      items[50];
	INTBIG      redrawitem;
	void      (*redrawroutine)(RECTAREA*);
	int         editline;
	char        lastedittext[300];
	int         opaqueitem;
	int         offx, offy;
} TDIALOG;

TDIALOG         gra_dialogs[MAXDIALOGS];
TDIALOG        *gra_curdialog;
INTBIG          gra_curdialogindex = -1;
INTBIG          gra_dialoghit;
INTBIG          gra_dialoghitchar;
char            gra_opaquefield[300];

/* dialog support routines */
void gra_flushdialog(void);
void gra_getdialogcoordinates(RECTAREA *rect, INTBIG *x, INTBIG *y, INTBIG *wid, INTBIG *hei);
void gra_dialogaction(Widget w, XtPointer client_data, XmSelectionBoxCallbackStruct *call_data);
void gra_dialogredraw(Widget w, XtPointer client_data, XmSelectionBoxCallbackStruct *call_data);
void gra_dialogredrawsep(Widget w, XtPointer client_data, XmSelectionBoxCallbackStruct *call_data);
void gra_dialogopaqueaction(Widget w, XtPointer client_data,
	XmTextVerifyCallbackStruct *call_data);
void gra_dialogdraw(Widget widget, XEvent *event, String *args, int *num_args);
Pixmap gra_makeicon(char *data, Widget widget);
#endif

/****** events ******/
/* the meaning of "gra_inputstate" */
#define CHARREAD        0177	/* character that was read */
#define ISCHAR          0200	/* set if character read */
#define ISBUTTON       01400	/* set if button pushed (or released) */
#define ISLEFT          0400	/* set if left button */
#define ISMIDDLE       01000	/* set if middle button */
#define ISRIGHT        01400	/* set if right button */
#define BUTTONUP       02000	/* set if button was released */
#define SHIFTDOWN      04000	/* set if shift key was held down */
#define CONTROLDOWN   010000	/* set if control key was held down */
#define METADOWN      020000	/* set if meta key was held down */
#define DOUBLECL      040000	/* set if double-click */
#define MOTION       0100000	/* set if mouse motion detected */
#define NOEVENT           -1	/* set if nothing happened */

#define CTRLC   03
#define CTRLD   04

struct {
	INTSML x;
	INTSML y;
	INTSML kind;
} gra_action;

typedef struct
{
	INTSML                cursorx, cursory;	/* current position of mouse */
	INTBIG                inputstate;		/* current state of device input */
} MYEVENTQUEUE;

#define	EVENTQUEUESIZE	100

static MYEVENTQUEUE  gra_eventqueue[EVENTQUEUESIZE];
static MYEVENTQUEUE *gra_eventqueuehead;	/* points to next event in queue */
static MYEVENTQUEUE *gra_eventqueuetail;	/* points to first free event in queue */

static INTBIG        gra_inputstate;			/* current state of device input */
static INTSML        gra_doublethresh;			/* threshold of double-click */
static INTSML        gra_doublethreshknown;		/* whether threshold is known */
static INTSML        gra_cursorx, gra_cursory;	/* current position of mouse */
static INTSML        gra_lstcurx, gra_lstcury;	/* former position of mouse */

#if 0
static char *eventNames[] =
{
	"",
	"",
	"KeyPress",
	"KeyRelease",
	"ButtonPress",
	"ButtonRelease",
	"MotionNotify",
	"EnterNotify",
	"LeaveNotify",
	"FocusIn",
	"FocusOut",
	"KeymapNotify",
	"Expose",
	"GraphicsExpose",
	"NoExpose",
	"VisibilityNotify",
	"CreateNotfiy",
	"DestroyNotfiy",
	"UnmapNotify",
	"MapNotify",
	"MapRequest",
	"ReparentNotfiy",
	"ConfigureNotfiy",
	"ConfigureRequest",
	"GravityNotfiy",
	"ResizeRequest",
	"CirculateNotify",
	"CirculateRequest",
	"PropertyNotfiy",
	"SelectionClear",
	"SelectionRequest",
	"SelectionNotify",
	"ColormapNotify",
	"ClientMessage",
	"MappingNotify"
};
#endif

void       gra_handlemsgevent(XEvent *event);
void       gra_handleeditevent(XEvent *event);
void       gra_nextevent(void);
void       gra_repaint(INTSML redo);
void       gra_waitforaction(void);
void       gra_addeventtoqueue(INTBIG state, INTSML x, INTSML y);
RETSIGTYPE us_noint(int sig);
void       gra_graphics_event_handler(Widget w, XtPointer data, XEvent *event, Boolean *cont);
void       gra_messages_event_handler(Widget w, XtPointer data, XEvent *event, Boolean *cont);
INTBIG     gra_translatekey(XEvent *event);
RETSIGTYPE gra_sigill_trap(void);
RETSIGTYPE gra_sigfpe_trap(void);
RETSIGTYPE gra_sigbus_trap(void);
RETSIGTYPE gra_sigsegv_trap(void);
#ifdef USETIF
Boolean    gra_dowork(caddr_t client_data);
void       gra_windowdelete(Widget w, XtPointer client_data, XtPointer *call_data);
#else
void       gra_destroygraphics(Widget w, XtPointer data, XEvent *event, Boolean *cont);
#endif

/****** mouse buttons ******/
#define BUTTONS     27		/* cannot exceed NUMBUTS in "usr.h" */
#define REALBUTS    3		/* actual number of buttons */

struct {
	char  *name;				/* button name */
	INTSML unique;				/* number of letters that make it unique */
} gra_buttonname[BUTTONS] =
{
	{"LEFT", 1},    {"MIDDLE", 2},    {"RIGHT", 1},		/* unshifted */

	{"SLEFT", 2},   {"SMIDDLE", 3},   {"SRIGHT", 2},	/* shift held down */
	{"CLEFT", 2},   {"CMIDDLE", 3},   {"CRIGHT", 2},	/* control held down */
	{"MLEFT", 2},   {"MMIDDLE", 3},   {"MRIGHT", 2},	/* meta held down */

	{"SCLEFT", 3},  {"SCMIDDLE", 4},  {"SCRIGHT", 3},	/* shift and control held down*/
	{"SMLEFT", 3},  {"SMMIDDLE", 4},  {"SMRIGHT", 3},	/* shift and meta held down */
	{"CMLEFT", 3},  {"CMMIDDLE", 4},  {"CMRIGHT", 3},	/* control and meta held down */

	{"SCMLEFT", 4}, {"SCMMIDDLE", 4}, {"SCMRIGHT", 4},	/* shift, control, and meta */

	{"DLEFT", 2},   {"DMIDDLE", 2},   {"DRIGHT", 2}		/* double-click */
};

INTSML     gra_makebutton(INTBIG);

/****** cursors and icons ******/
static Cursor        gra_realcursor;
static Cursor        gra_nomousecursor;
static Cursor        gra_drawcursor;
static Cursor        gra_nullcursor;
static Cursor        gra_menucursor;
static Cursor        gra_handcursor;
static Cursor        gra_techcursor;
static Cursor        gra_ibeamcursor;

static XColor        gra_xfc, gra_xbc;			/* cursor color structure  */

/* SWAPPED means that the bytes are MSB first */
#ifndef i386
#  define SWAPPED 1
#endif

/* the icon for Electric  */
static UINTSML gra_icon64[256] =
{
	0x0000, 0x0000, 0x0000, 0x0000, /*                                                                  */
	0x0000, 0x0000, 0x0000, 0x0000, /*                                                                  */
	0x0000, 0x0000, 0x0000, 0x0000, /*                                                                  */
	0x0000, 0x0000, 0x0000, 0x0000, /*                                                                  */
	0xF800, 0xFFFF, 0xFFFF, 0x001F, /*            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX            */
	0x0400, 0x0000, 0x0000, 0x0020, /*           X                                          X           */
	0x0200, 0x0000, 0x0000, 0x0040, /*          X                                            X          */
	0x0100, 0x0000, 0x0000, 0x0080, /*         X                                              X         */
	0x0080, 0x0000, 0x0000, 0x0100, /*        X                                                X        */
	0x0080, 0x0000, 0x0000, 0x0100, /*        X                                                X        */
	0x0040, 0x0000, 0x0000, 0x0200, /*       X                                                  X       */
	0x0040, 0x0000, 0x0000, 0x0200, /*       X                                                  X       */
	0x0020, 0x0000, 0x0000, 0x0400, /*      X                                                    X      */
	0x0020, 0x0000, 0x0000, 0x0400, /*      X                                                    X      */
	0x8010, 0x001F, 0xFC00, 0x0800, /*     X          XXXXXX                     XXXXXX           X     */
	0x8010, 0x001F, 0xFC00, 0x0800, /*     X          XXXXXX                     XXXXXX           X     */
	0x8008, 0x001F, 0xFC00, 0x1000, /*    X           XXXXXX                     XXXXXX            X    */
	0x8008, 0x001F, 0xFC00, 0x1000, /*    X           XXXXXX                     XXXXXX            X    */
	0x8004, 0x001F, 0xFC00, 0x2000, /*   X            XXXXXX                     XXXXXX             X   */
	0x8004, 0x001F, 0xFC00, 0x2000, /*   X            XXXXXX                     XXXXXX             X   */
	0x8004, 0x001F, 0xFC00, 0x2000, /*   X            XXXXXX                     XXXXXX             X   */
	0x8002, 0x001F, 0xFC00, 0x4000, /*  X             XXXXXX                     XXXXXX              X  */
	0x8002, 0x001F, 0xFC00, 0x4000, /*  X             XXXXXX                     XXXXXX              X  */
	0x8002, 0x001F, 0xFC00, 0x4000, /*  X             XXXXXX                     XXXXXX              X  */
	0x8002, 0x001F, 0xFC00, 0x4000, /*  X             XXXXXX                     XXXXXX              X  */
	0x8002, 0x001F, 0xFC00, 0x4000, /*  X             XXXXXX                     XXXXXX              X  */
	0x8001, 0x001F, 0xFC00, 0x8000, /* X              XXXXXX                     XXXXXX               X */
	0x8001, 0x001F, 0xFC00, 0x8000, /* X              XXXXXX                     XXXXXX               X */
	0x8001, 0x001F, 0xFC00, 0x8000, /* X              XXXXXX                     XXXXXX               X */
	0x8001, 0x001F, 0xFC00, 0x8000, /* X              XXXXXX                     XXXXXX               X */
	0x8001, 0x001F, 0xFC00, 0x8000, /* X              XXXXXX                     XXXXXX               X */
	0x8001, 0x001F, 0xFC00, 0x8000, /* X              XXXXXX                     XXXXXX               X */
	0x0001, 0x0000, 0x0000, 0x8000, /* X                                                              X */
	0x0001, 0x0000, 0x0000, 0x8000, /* X                                                              X */
	0x0001, 0x0000, 0x0000, 0x8000, /* X                                                              X */
	0x0001, 0x0000, 0x0000, 0x8000, /* X                                                              X */
	0x0001, 0x0000, 0x0000, 0x8000, /* X                                                              X */
	0x0001, 0xF000, 0x0007, 0x8000, /* X                           XXXXXXX                            X */
	0x0002, 0xF800, 0x000F, 0x4000, /*  X                         XXXXXXXXX                          X  */
	0x0002, 0xFC00, 0x001F, 0x4000, /*  X                        XXXXXXXXXXX                         X  */
	0x0002, 0xFE00, 0x003F, 0x4000, /*  X                       XXXXXXXXXXXXX                        X  */
	0x0002, 0xFE00, 0x003F, 0x4000, /*  X                       XXXXXXXXXXXXX                        X  */
	0x0002, 0xFE00, 0x003F, 0x4000, /*  X                       XXXXXXXXXXXXX                        X  */
	0x0004, 0xFE00, 0x003F, 0x2000, /*   X                      XXXXXXXXXXXXX                       X   */
	0x0004, 0xFE00, 0x003F, 0x2000, /*   X                      XXXXXXXXXXXXX                       X   */
	0x0004, 0xFE00, 0x003F, 0x2000, /*   X                      XXXXXXXXXXXXX                       X   */
	0x0008, 0xFE00, 0x003F, 0x1000, /*    X                     XXXXXXXXXXXXX                      X    */
	0x0008, 0xFE00, 0x003F, 0x1000, /*    X                     XXXXXXXXXXXXX                      X    */
	0x0010, 0xFE00, 0x003F, 0x0800, /*     X                    XXXXXXXXXXXXX                     X     */
	0x0010, 0xFE00, 0x003F, 0x0800, /*     X                    XXXXXXXXXXXXX                     X     */
	0x0020, 0xFE00, 0x003F, 0x0400, /*      X                   XXXXXXXXXXXXX                    X      */
	0x0020, 0x0000, 0x0000, 0x0400, /*      X                                                    X      */
	0x0040, 0x0000, 0x0000, 0x0200, /*       X                                                  X       */
	0x0040, 0x0000, 0x0000, 0x0200, /*       X                                                  X       */
	0x0080, 0x0000, 0x0000, 0x0100, /*        X                                                X        */
	0x0080, 0x0000, 0x0000, 0x0100, /*        X                                                X        */
	0x0100, 0x0000, 0x0000, 0x0080, /*         X                                              X         */
	0x0200, 0x0000, 0x0000, 0x0040, /*          X                                            X          */
	0x0400, 0x0000, 0x0000, 0x0020, /*           X                                          X           */
	0xF800, 0xFFFF, 0xFFFF, 0x001F, /*            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX            */
	0x0000, 0x0000, 0x0000, 0x0000, /*                                                                  */
	0x0000, 0x0000, 0x0000, 0x0000, /*                                                                  */
	0x0000, 0x0000, 0x0000, 0x0000, /*                                                                  */
	0x0000, 0x0000, 0x0000, 0x0000  /*                                                                  */
};

static UINTSML gra_icon32[64] =
{
	0x0000, 0x0000, /*                                  */
	0x0000, 0x0000, /*                                  */
	0xFF80, 0x01FF, /*        XXXXXXXXXXXXXXXXXX        */
	0x0040, 0x0200, /*       X                  X       */
	0x0020, 0x0400, /*      X                    X      */
	0x0010, 0x0800, /*     X                      X     */
	0x0008, 0x1000, /*    X                        X    */
	0x0008, 0x1000, /*    X                        X    */
	0x0004, 0x2000, /*   X                          X   */
	0x0784, 0x21E0, /*   X    XXXX          XXXX    X   */
	0x0782, 0x41E0, /*  X     XXXX          XXXX     X  */
	0x0782, 0x41E0, /*  X     XXXX          XXXX     X  */
	0x0781, 0x81E0, /* X      XXXX          XXXX      X */
	0x0781, 0x81E0, /* X      XXXX          XXXX      X */
	0x0781, 0x81E0, /* X      XXXX          XXXX      X */
	0x0781, 0x81E0, /* X      XXXX          XXXX      X */
	0x0781, 0x81E0, /* X      XXXX          XXXX      X */
	0x0781, 0x81E0, /* X      XXXX          XXXX      X */
	0x0781, 0x8000, /* X      XXXX                    X */
	0x0001, 0x8000, /* X                              X */
	0x8002, 0x4001, /*  X             XX             X  */
	0xC002, 0x4003, /*  X            XXXX            X  */
	0xE004, 0x2007, /*   X          XXXXXX          X   */
	0xE004, 0x2007, /*   X          XXXXXX          X   */
	0xE008, 0x1007, /*    X         XXXXXX         X    */
	0xE008, 0x1007, /*    X         XXXXXX         X    */
	0x0010, 0x0800, /*     X                      X     */
	0x0020, 0x0400, /*      X                    X      */
	0x0040, 0x0200, /*       X                  X       */
	0xFF80, 0x01FF, /*        XXXXXXXXXXXXXXXXXX        */
	0x0000, 0x0000, /*                                  */
	0x0000, 0x0000  /*                                  */
};

/* the normal cursor (NORMALCURSOR, an "X") */
static UINTSML gra_realcursordata[16] = {
	0xC003, /* XX            XX */
	0xE007, /* XXX          XXX */
	0x700E, /*  XXX        XXX  */
	0x381C, /*   XXX      XXX   */
	0x1C38, /*    XXX    XXX    */
	0x0E70, /*     XXX  XXX     */
	0x07E0, /*      XXXXXX      */
	0x0240, /*       X  X       */
	0x0240, /*       X  X       */
	0x07E0, /*      XXXXXX      */
	0x0E70, /*     XXX  XXX     */
	0x1C38, /*    XXX    XXX    */
	0x381C, /*   XXX      XXX   */
	0x700E, /*  XXX        XXX  */
	0xE007, /* XXX          XXX */
	0xC003  /* XX            XX */
};

/* the "use the TTY" cursor (WANTTTYCURSOR, the word "tty" above keyboard) */
static UINTSML gra_nomousecursordata[16] = {
	0x7757, /* XXX X X XXX XXX  */
	0x1552, /*  X  X X X X X    */
	0x3772, /*  X  XXX XXX XX   */
	0x1122, /*  X   X  X   X    */
	0x7122, /*  X   X  X   XXX  */
	0x0000, /*                  */
	0xFFFF, /* XXXXXXXXXXXXXXXX */
	0x8001, /* X              X */
	0x8AA9, /* X  X X X X X   X */
	0x9551, /* X   X X X X X  X */
	0x8AA9, /* X  X X X X X   X */
	0x9551, /* X   X X X X X  X */
	0x8001, /* X              X */
	0x9FF9, /* X  XXXXXXXXXX  X */
	0x8001, /* X              X */
	0xFFFF  /* XXXXXXXXXXXXXXXX */
};

/* the "draw with pen" cursor (PENCURSOR, a pen) */
static UINTSML gra_drawcursordata[16] = {
	0x3000, /*             XX   */
	0x7800, /*            XXXX  */
	0xF400, /*           X XXXX */
	0xE200, /*          X   XXX */
	0x4100, /*         X     X  */
	0x2080, /*        X     X   */
	0x1040, /*       X     X    */
	0x0820, /*      X     X     */
	0x0410, /*     X     X      */
	0x0208, /*    X     X       */
	0x010C, /*   XX    X        */
	0x008C, /*   XX   X         */
	0x007E, /*  XXXXXX          */
	0x003E, /*  XXXXX           */
	0x000F, /* XXXX             */
	0x0003  /* XX               */
};

/* the null cursor (NULLCURSOR, an egg timer) */
static UINTSML gra_nullcursordata[16] = {
	0x1FF8, /*    XXXXXXXXXX    */
	0x2004, /*   X          X   */
	0x2004, /*   X          X   */
	0x2004, /*   X          X   */
	0x1AA8, /*    X X X X XX    */
	0x0FF0, /*     XXXXXXXX     */
	0x07E0, /*      XXXXXX      */
	0x03C0, /*       XXXX       */
	0x0240, /*       X  X       */
	0x0420, /*      X    X      */
	0x0810, /*     X      X     */
	0x1008, /*    X        X    */
	0x2AA4, /*   X  X X X X X   */
	0x3FFC, /*   XXXXXXXXXXXX   */
	0x3FFC, /*   XXXXXXXXXXXX   */
	0x1FF8  /*    XXXXXXXXXX    */
};

/* the menu selection cursor (MENUCURSOR, a sideways arrow) */
static UINTSML gra_menucursordata[16] = {
	0x0000, /*                  */
	0x0000, /*                  */
	0x0400, /*           X      */
	0x0C00, /*           XX     */
	0x1C00, /*           XXX    */
	0x3C00, /*           XXXX   */
	0x7FFF, /* XXXXXXXXXXXXXXX  */
	0xFFFF, /* XXXXXXXXXXXXXXXX */
	0x7FFF, /* XXXXXXXXXXXXXXX  */
	0x3C00, /*           XXXX   */
	0x1C00, /*           XXX    */
	0x0C00, /*           XX     */
	0x0400, /*           X      */
	0x0000, /*                  */
	0x0000, /*                  */
	0x0000  /*                  */
};

/* the "move" command dragging cursor (HANDCURSOR, a dragging hand) */
static UINTSML gra_handcursordata[16] = {
	0x0000, /*                  */
	0x3F80, /*        XXXXXXX   */
	0xC040, /*       X       XX */
	0x0380, /*        XXX       */
	0x0040, /*       X          */
	0x0020, /*      X           */
	0x01C0, /*       XXX        */
	0x0020, /*      X           */
	0x0010, /*     X            */
	0x03FE, /*  XXXXXXXXX       */
	0x0001, /* X                */
	0x0001, /* X                */
	0x1FFE, /*  XXXXXXXXXXXX    */
	0x8080, /*        X       X */
	0x4100, /*         X     X  */
	0x3E00  /*          XXXXX   */
};

/* the "technology" command dragging cursor (TECHCURSOR, a "T") */
static UINTSML gra_techcursordata[16] = {
	0x0100, /*         X        */
	0x0380, /*        XXX       */
	0x0540, /*       X X X      */
	0x0100, /*         X        */
	0x0100, /*         X        */
	0x3FF8, /*    XXXXXXXXXXX   */
	0x3FF8, /*    XXXXXXXXXXX   */
	0x2388, /*    X   XXX   X   */
	0x0380, /*        XXX       */
	0x0380, /*        XXX       */
	0x0380, /*        XXX       */
	0x0380, /*        XXX       */
	0x0380, /*        XXX       */
	0x0380, /*        XXX       */
	0x07C0, /*       XXXXX      */
	0x0000  /*                  */
};

/* the "ibeam" text selection cursor (IBEAMCURSOR, an "I") */
static UINTSML gra_ibeamcursordata[16] = {
	0x0360, /*      XX XX       */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0080, /*        X         */
	0x0360  /*      XX XX       */
};

void       gra_recolorcursor(XColor *fg, XColor *bg);

/****** fonts ******/
#define FONTLISTSIZE 10

typedef struct
{
	XFontStruct *font;
	char        *fontname;
#ifdef ANYDEPTH
	INTSML       width[128];
	INTSML       height[128];
	char        *data[128];
#endif
} FontRec;

#ifdef ANYDEPTH
#define FONTINIT , {0}, {0}, {0}
#else
#define FONTINIT
#endif

static FontRec       gra_messages_font = {(XFontStruct *)0, "fixed" FONTINIT};

/*
 * Default font - this font MUST exist, or Electric will die.  Best to choose a
 * font that is commonly used, so the X server is likely to have it loaded.
 */
#define DEFAULTFONTNAME "fixed"

static FontRec       gra_defaultFont;
static XFontStruct  *gra_curfont;				/* current writing font */
static INTSML        gra_curfontnumber;

static char *gra_resource_fontname[] =
{
	"font0", "font1", "font2", "font3", "font4", "font5",
	"font6", "font7", "font8", "fontmenu", "fontedit", "fontstatus"
};

static FontRec gra_font[] =
{
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-8-*-*-*-*" FONTINIT},	/* TXT4P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-10-*-*-*-*" FONTINIT},	/* TXT6P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-12-*-*-*-*" FONTINIT},	/* TXT8P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-14-*-*-*-*" FONTINIT},	/* TXT10P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-17-*-*-*-*" FONTINIT},	/* TXT12P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-18-*-*-*-*" FONTINIT},	/* TXT14P */
	{(XFontStruct *)0, "-*-helvetica-bold-r-normal-*-20-*-*-*-*" FONTINIT},		/* TXT16P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-24-*-*-*-*" FONTINIT},	/* TXT18P */
	{(XFontStruct *)0, "-*-helvetica-bold-r-normal-*-25-*-*-*-*" FONTINIT},		/* TXT20P */
	{(XFontStruct *)0, "-*-helvetica-bold-r-normal-*-*-120-*-*-*" FONTINIT},	/* MENU */
	{(XFontStruct *)0, "-*-fixed-*-*-normal-*-*-120-*-*-*" FONTINIT},			/* EDIT */
	{(XFontStruct *)0, "fixed" FONTINIT},										/* STATUS */
#if 0
	{(XFontStruct *)0, "-*-*-medium-r-normal-*-9-*-*-*-*" FONTINIT},			/* TXT4P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-10-*-*-*-*" FONTINIT},	/* TXT6P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-12-*-*-*-*" FONTINIT},	/* TXT8P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-14-*-*-*-*" FONTINIT},	/* TXT10P */
	{(XFontStruct *)0, "-*-clean-medium-r-normal-*-16-*-*-*-*" FONTINIT},		/* TXT12P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-18-*-*-*-*" FONTINIT},	/* TXT14P */
	{(XFontStruct *)0, "-*-*-medium-r-normal-*-20-*-*-*-*" FONTINIT},			/* TXT16P */
	{(XFontStruct *)0, "-*-helvetica-medium-r-normal-*-24-*-*-*-*" FONTINIT},	/* TXT18P */
	{(XFontStruct *)0, "-*-helvetica-bold-r-normal-*-24-*-*-*-*" FONTINIT},		/* TXT20P */
	{(XFontStruct *)0, "-*-helvetica-bold-r-normal-*-*-120-*-*-*" FONTINIT},	/* MENU */
	{(XFontStruct *)0, "*fixed-*-normal-*-*-120-*" FONTINIT},					/* EDIT */
	{(XFontStruct *)0, "fixed" FONTINIT},										/* STATUS */
#endif
	 {(XFontStruct *)0, NULL FONTINIT}  /* terminator */
};

/* X Font Selection */
DIALOGITEM gra_xfontdialogitems[] =
{
 /*  1 */ {0, {312,592,336,652}, BUTTON, "OK"},
 /*  2 */ {0, {312,312,336,372}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,8,24,88}, MESSAGE, "Foundry"},
 /*  4 */ {0, {8,96,24,296}, POPUP, ""},
 /*  5 */ {0, {32,8,48,88}, MESSAGE, "Family"},
 /*  6 */ {0, {32,96,48,296}, POPUP, ""},
 /*  7 */ {0, {56,8,72,88}, MESSAGE, "Weight"},
 /*  8 */ {0, {56,96,72,296}, POPUP, ""},
 /*  9 */ {0, {80,8,96,88}, MESSAGE, "Slant"},
 /* 10 */ {0, {80,96,96,296}, POPUP, ""},
 /* 11 */ {0, {104,8,120,88}, MESSAGE, "S Width"},
 /* 12 */ {0, {104,96,120,296}, POPUP, ""},
 /* 13 */ {0, {128,8,144,88}, MESSAGE, "Ad Style"},
 /* 14 */ {0, {128,96,144,296}, POPUP, ""},
 /* 15 */ {0, {152,8,168,88}, MESSAGE, "Pixel Size"},
 /* 16 */ {0, {152,96,168,296}, POPUP, ""},
 /* 17 */ {0, {176,8,192,88}, MESSAGE, "Point Size"},
 /* 18 */ {0, {176,96,192,296}, POPUP, ""},
 /* 19 */ {0, {200,8,216,88}, MESSAGE, "X Resolution"},
 /* 20 */ {0, {200,96,216,296}, POPUP, ""},
 /* 21 */ {0, {224,8,240,88}, MESSAGE, "Y Resolution"},
 /* 22 */ {0, {224,96,240,296}, POPUP, ""},
 /* 23 */ {0, {248,8,264,88}, MESSAGE, "Spacing"},
 /* 24 */ {0, {248,96,264,296}, POPUP, ""},
 /* 25 */ {0, {272,8,288,88}, MESSAGE, "Avg Width"},
 /* 26 */ {0, {272,96,288,296}, POPUP, ""},
 /* 27 */ {0, {296,8,312,88}, MESSAGE, "Registry"},
 /* 28 */ {0, {296,96,312,296}, POPUP, ""},
 /* 29 */ {0, {320,8,336,88}, MESSAGE, "Encoding"},
 /* 30 */ {0, {320,96,336,296}, POPUP, ""},
 /* 31 */ {0, {8,304,300,656}, SCROLL, ""}
};
DIALOG gra_xfontdialog = {{75,75,421,735}, "Font Selection", 31, gra_xfontdialogitems};

void gra_makefontchoices(char **fontlist, int namecount, char *required[14],
	char ****fchoices, INTBIG **fnumchoices);

/****** rectangle saving ******/
#define NOSAVEDBOX ((SAVEDBOX *)-1)
typedef struct Isavedbox
{
#ifdef ANYDEPTH
	char   *pix;
#else
	Pixmap  pix;
#endif
	INTBIG  code;
	INTSML  lx, hx, ly, hy;
	struct Isavedbox *nextsavedbox;
} SAVEDBOX;

static SAVEDBOX     *gra_firstsavedbox = NOSAVEDBOX;
#ifndef ANYDEPTH
static INTSML        gra_savedboxcodes = 0;
#endif

/****** polygon decomposition ******/
#ifdef ANYDEPTH
#define NOPOLYSEG ((POLYSEG *)-1)

typedef struct Isegment
{
	INTBIG fx,fy, tx,ty, direction, increment, index;
	struct Isegment *nextedge;
	struct Isegment *nextactive;
} POLYSEG;

static POLYSEG      *gra_polysegs;
static INTSML        gra_polysegcount = 0;
#endif

/****** curve drawing ******/
#ifdef ANYDEPTH
#define MODM(x) ((x<1) ? x+8 : x)
#define MODP(x) ((x>8) ? x-8 : x)
#define ODD(x)  (x&1)

static INTSML        gra_arcocttable[] = {0,0,0,0,0,0,0,0,0};
static INTBIG        gra_arccenterx, gra_arccentery;
static INTBIG        gra_arcradius, gra_curvemaxx, gra_curvemaxy;
static INTBIG        gra_arclx, gra_archx, gra_arcly, gra_archy;
static INTSML        gra_curvecol, gra_curvemask, gra_curvestyle, gra_arcfirst;

INTSML gra_arcfindoctant(INTBIG x, INTBIG y);
void gra_arcxformoctant(INTBIG x, INTBIG y, INTBIG oct, INTBIG *ox, INTBIG *oy);
void gra_arcdopixel(INTBIG x, INTBIG y);
void gra_arcoutxform(INTBIG x, INTBIG y);
void gra_arcbrescw(INTBIG x, INTBIG y, INTBIG x1, INTBIG y1);
void gra_arcbresmidcw(INTBIG x, INTBIG y);
void gra_arcbresmidccw(INTBIG x, INTBIG y);
void gra_arcbresccw(INTBIG x, INTBIG y, INTBIG x1, INTBIG y1);
#endif

/****** time ******/
static time_t        gra_timebasesec;
static INTBIG        gra_timebasems;
static Time          gra_lasttime = 0;			/* time of last click */

/****** files ******/
static void         *gra_fileliststringarray = 0;
static char          gra_curpath[255] = {0};
static char          gra_requiredextension[20];
#ifdef USETIF
static INTSML        gra_fileselectdone;
static char         *gra_fileselectresult;
#else
DIALOGITEM us_fileindialogitems[] =   /* File Input */
{
 /*  1 */ {0, {128,256,152,336}, BUTTON, "Open"},
 /*  2 */ {0, {176,256,200,336}, BUTTON, "Cancel"},
 /*  3 */ {0, {40,8,216,240}, SCROLL, ""},
 /*  4 */ {0, {8,8,40,336}, MESSAGE, ""},
 /*  5 */ {0, {80,256,104,336}, BUTTON, "Up"}
};
DIALOG us_fileindialog = {{50,75,278,421}, 0, 5, us_fileindialogitems};

DIALOGITEM us_fileoutdialogitems[] =   /* File Output */
{
 /*  1 */ {0, {146,256,170,336}, BUTTON, "OK"},
 /*  2 */ {0, {194,256,218,336}, BUTTON, "Cancel"},
 /*  3 */ {0, {50,8,218,240}, SCROLL, ""},
 /*  4 */ {0, {8,8,40,336}, MESSAGE, ""},
 /*  5 */ {0, {50,256,74,336}, BUTTON, "Up"},
 /*  6 */ {0, {98,256,122,336}, BUTTON, "Down"},
 /*  7 */ {0, {226,8,242,336}, EDITTEXT, ""}
};
DIALOG us_fileoutdialog = {{50,75,300,421}, 0, 7, us_fileoutdialogitems};
#endif

#ifdef HPUX
#  define DIRENTCONST const
#else
#  define DIRENTCONST
#endif
int    gra_fileselectall(DIRENTCONST struct dirent *a);
INTSML gra_addfiletolist(char *file);
void   gra_initfilelist(void);
#ifdef USETIF
void gra_fileselectcancel(Widget w, XtPointer client_data,
	XmSelectionBoxCallbackStruct *call_data);
void gra_fileselectok(Widget w, XtPointer client_data,
	XmSelectionBoxCallbackStruct *call_data);
#endif

/******************** INITIALIZATION ********************/

int main(int argc, char *argv[])
{
	/* on A/UX machines, simulate Berkeley signal catching */
#ifdef aux
	set42sig();
#endif

	/* catch signals if Electric trys to bomb out */
	(void)signal(SIGILL, (SIGNALCAST)gra_sigill_trap);
	(void)signal(SIGFPE, (SIGNALCAST)gra_sigfpe_trap);
	(void)signal(SIGBUS, (SIGNALCAST)gra_sigbus_trap);
	(void)signal(SIGSEGV, (SIGNALCAST)gra_sigsegv_trap);

	/* primary initialization of Electric */
	el_primaryinit();

#if LANGTCL
	/* initialize TCL here */
	if (InitializeTCL() == TCL_ERROR)
		error("InitializeTCL failed: %s\n", myTCLInterp->result);

#  ifdef USETK
	/* initialize TK here */
	InitializeTK();
#  endif
#endif

	/* secondary initialization of Electric */
	el_secondaryinit(argc, argv);

	/* now run Electric */
#ifdef USETIF
	(void)XtAppAddWorkProc(gra_xtapp, (XtWorkProc)gra_dowork, 0);
	XtAppMainLoop(gra_xtapp);
#else
	for(;;)
	{
		el_slice();
	}
#endif
}

/*
 * Routine to establish the default display define tty codes.
 */
void us_setdisplay(char *name, INTBIG *argc, char **argv)
{
	INTBIG ttydevice;

	/* save command arguments */
	gra_argc = *argc;
	gra_argv = argv;

	/* initialize keyboard input */
	ttydevice = fileno(stdin);
#ifdef HAVE_TERMIOS_H
	tcgetattr(ttydevice, &us_sttybuf);
	us_erasech = us_sttybuf.c_cc[VERASE];
	us_killch = us_sttybuf.c_cc[VKILL];
#else
#  ifdef HAVE_TERMIO_H
	(void)ioctl(ttydevice, TCGETA, &us_sttybuf);
	us_erasech = us_sttybuf.c_cc[VERASE];
	us_killch = us_sttybuf.c_cc[VKILL];
#  else
	(void)gtty(ttydevice, &us_sttybuf);
	us_erasech = us_sttybuf.sg_erase;
	us_killch = us_sttybuf.sg_kill;
#  endif
#endif

	us_noint(0);
	return;
}

/* dummy interrupt handler to use during initialization*/
RETSIGTYPE us_noint(int sig)
{
	static INTSML start = 0;

#ifndef __SVR4
	(void)signal(SIGINT, us_noint);
#endif
	if (start) fprintf(stderr, "Interrupted during initialization");
	start = 1;
}

/*
 * Routine to initialize the display device.
 */
INTSML us_initgraphics(INTSML messages)
{
	REGISTER INTBIG i, j, bg, bd, ac, pixels, bestpixels, secondbestpixels;
	INTBIG bitmask, graphicsheight, graphicswidth, msgwidth, msgheight, scr;
	INTSML full_screen, numfiles, maxdispnum, dep, togglefullscreen, wantmultiscreen;
	int namecount, argc;
	unsigned long valuemask, messagesvaluemask;
	char *buffer, *title, *ptr, **fontlist, **filelist, displayname[200],
		editdisplayname[200], msgdisplayname[200];
	char *geomSpec;
	char *iconname = "Electric";
	char *sswinname = "Electric Messages";
	char *ssiconname = "Messages";
	Arg arg[10];
	Cursor gra_ibeam;
	Pixmap pixm;
	XEvent event;
	XGCValues gcv;
	XSetWindowAttributes xswa, xswa_messages;
	XSizeHints *xsh, *xsh_messages;
	XTextProperty swintitle, sicontitle, icontitle, wintitle;
	XWindowAttributes xwa;
	XWMHints *xwmh, *xwmh_messages;
	Display *dpy;
	WINDOWFRAME *wf;
#ifdef ANYDEPTH
	XImage *image;
	XFontStruct *thefont;
	XCharStruct xcs;
	short *ptr16;
	long *ptr32;
	int direction, asc, des;
	char *dptr;
	REGISTER INTBIG amt, k;
	INTSML width, height, x, y, slop;
	Pixmap textmap;
#else
	XVisualInfo vinfo;
	INTBIG planes[8], pixelarray[256];
#endif

	/* initialize X and the toolkit */
	(void)XSetErrorHandler(gra_xerrors);
#ifdef USETIF
	XtToolkitInitialize();
	gra_xtapp = XtCreateApplicationContext();
#endif

	/* double-click threshold (in milliseconds) */
	gra_doublethresh = 500;
	gra_doublethreshknown = 0;

#ifdef SWAPPED
	/* on machines with reverse byte ordering, fix the icon and the cursors */
	for(i=0; i<256; i++)
		gra_icon64[i] = ((gra_icon64[i] >> 8) & 0xFF) | ((gra_icon64[i] << 8) & 0xFF00);
	for(i=0; i<64; i++)
		gra_icon32[i] = ((gra_icon32[i] >> 8) & 0xFF) | ((gra_icon32[i] << 8) & 0xFF00);
	for(i=0; i<16; i++)
	{
		gra_realcursordata[i] = ((gra_realcursordata[i] >> 8) & 0xFF) |
			((gra_realcursordata[i] << 8) & 0xFF00);
		gra_nomousecursordata[i] = ((gra_nomousecursordata[i] >> 8) & 0xFF) |
			((gra_nomousecursordata[i] << 8) & 0xFF00);
		gra_drawcursordata[i] = ((gra_drawcursordata[i] >> 8) & 0xFF) |
			((gra_drawcursordata[i] << 8) & 0xFF00);
		gra_nullcursordata[i] = ((gra_nullcursordata[i] >> 8) & 0xFF) |
			((gra_nullcursordata[i] << 8) & 0xFF00);
		gra_menucursordata[i] = ((gra_menucursordata[i] >> 8) & 0xFF) |
			((gra_menucursordata[i] << 8) & 0xFF00);
		gra_handcursordata[i] = ((gra_handcursordata[i] >> 8) & 0xFF) |
			((gra_handcursordata[i] << 8) & 0xFF00);
		gra_techcursordata[i] = ((gra_techcursordata[i] >> 8) & 0xFF) |
			((gra_techcursordata[i] << 8) & 0xFF00);
		gra_ibeamcursordata[i] = ((gra_ibeamcursordata[i] >> 8) & 0xFF) |
			((gra_ibeamcursordata[i] << 8) & 0xFF00);
	}
#endif

	/* get switch settings */
	togglefullscreen = 0;
	wantmultiscreen = 0;
	geomSpec = NULL;
	for(i=1; i < gra_argc; i++)
	{
		if (gra_argv[i][0] == '-')
		{
			switch (gra_argv[i][1])
			{
				case 'f':
					togglefullscreen = 1;
					continue;

				case 'm':
					wantmultiscreen = 1;
					continue;

				case 'g':       /* Geometry */
					if (++i >= gra_argc) continue;
					geomSpec = gra_argv[i];
					continue;
			}
		}
	}

	/* set default displays for edit and messages windows */
	strcpy(displayname, XDisplayName(NULL));
	strcpy(editdisplayname, displayname);
	strcpy(msgdisplayname, displayname);

	/* if multiple screens requested, search for them */
	maxdispnum = 0;
	if (wantmultiscreen != 0)
	{
		/* count the number of displays (look for files named "/dev/fb*") */
		numfiles = filesindirectory("/dev", &filelist);
		for(i=0; i<numfiles; i++)
		{
			if (filelist[i][0] == 'f' && filelist[i][1] == 'b')
			{
				j = atoi(&filelist[i][2]);
				if (j > maxdispnum) maxdispnum = j;
			}
		}

		/* if there are multiple displays, select the best for edit and messages */
		if (maxdispnum > 0)
		{
			bestpixels = 0;
			secondbestpixels = 0;
			for(i=0; i<=maxdispnum; i++)
			{
				displayname[strlen(displayname)-1] = '0'+i;
				dpy = XOpenDisplay(NULL);
				scr = DefaultScreen(dpy);
				dep = DefaultDepth(dpy, scr);
				graphicsheight = XHeightOfScreen(XDefaultScreenOfDisplay(dpy));
				graphicswidth = XWidthOfScreen(XDefaultScreenOfDisplay(dpy));
				pixels = graphicsheight * graphicswidth * dep;
				if (pixels > bestpixels)
				{
					bestpixels = pixels;
					strcpy(editdisplayname, displayname);
				} else if (pixels > secondbestpixels)
				{
					secondbestpixels = pixels;
					strcpy(msgdisplayname, displayname);
				}
				XCloseDisplay(dpy);
			}
		}
	}

	/* open the display for the edit window */
#ifdef USETIF
	argc = 0;
	gra_dpy = XtOpenDisplay(gra_xtapp, editdisplayname, NULL, "Electric", NULL,
		0, &argc, NULL);
	if (gra_dpy == NULL)
	{
		fprintf(stderr, "Cannot open edit window display %s\n", editdisplayname);
		exitprogram();
	}

	/* open the display for the messages window */
	if (strcmp(editdisplayname, msgdisplayname) == 0) gra_msgdpy = gra_dpy; else
	{
		gra_msgdpy = XtOpenDisplay(gra_xtapp, msgdisplayname, NULL, "Electric", NULL,
			0, &argc, NULL);
		if (gra_msgdpy == NULL)
		{
			fprintf(stderr, "Cannot open messages window display %s\n", msgdisplayname);
			exitprogram();
		}
	}
#else
	gra_dpy = XOpenDisplay(NULL);
	if (gra_dpy == NULL)
	{
		fprintf(stderr, "Cannot open edit window display %s\n", editdisplayname);
		exitprogram();
	}
	gra_msgdpy = gra_dpy;
#endif

	/* get the information about the display */
	gra_screen_num = DefaultScreen(gra_dpy);
	gra_visual = DefaultVisual(gra_dpy, gra_screen_num);
	gra_sdep = DefaultDepth(gra_dpy, gra_screen_num);
	us_black = BlackPixel(gra_dpy, gra_screen_num);
	us_white = WhitePixel(gra_dpy, gra_screen_num);

#ifdef ANYDEPTH
	gra_truedepth = gra_sdep;
	if (gra_truedepth == 24) gra_truedepth = 32;
	if (VisualClass(gra_visual) == PseudoColor || VisualClass(gra_visual) == StaticColor)
		gra_defaultcmap = DefaultColormap(gra_dpy, gra_screen_num);
#else
	/* Some servers change the default screen to StaticColor class, so that
	 * Electric cannot change the color map.  Try to find one that can be used.
	 */
	if (gra_sdep > 1)
	{
		if (VisualClass(gra_visual) != PseudoColor)
		{
			/* look for pseudo color only for now */
			if (XMatchVisualInfo(gra_dpy, gra_screen_num, gra_sdep, PseudoColor, &vinfo))
				gra_visual = vinfo.visual; else
					ttyputerr("Cannot find desired visual, carrying on anyhow.");
		}
	}
#endif

	/* get fonts */
	gra_defaultFont.fontname = XGetDefault(gra_dpy, "Electric", "font");
	if (gra_defaultFont.fontname == NULL) gra_defaultFont.fontname = DEFAULTFONTNAME;
	gra_defaultFont.font = XLoadQueryFont(gra_dpy, gra_defaultFont.fontname);
	if (gra_defaultFont.font == NULL)
		fprintf(stderr, "Cannot open default font \"%s\"\n", gra_defaultFont.fontname);
	for(i=0; gra_font[i].fontname != 0; i++)
	{
		/*
		 * Check the .Xdefaults or .Xresources file for a value for each of the
		 * requested fonts; they will have resource names .Font4, .Font6,...
		 * .FontStatus. Look for a matching font, if found, use it; otherwise look
		 * for the font that is hard-coded.
		 */
		ptr = XGetDefault(gra_dpy, "Electric", gra_resource_fontname[i]);
		if (ptr != NULL)
		{
			fontlist = XListFonts(gra_dpy, ptr, 10, &namecount);
			if (namecount == 0)
			{
				/* server could not find a match */
				fprintf(stderr, "Cannot find font '%s', using '%s'\n",
					ptr, gra_font[i].fontname);
			} else
			{
				/* replace the default (this is for debugging only) */
				(void)allocstring(&gra_font[i].fontname, fontlist[0], db_cluster);
			}
		} else
		{
			fontlist = XListFonts(gra_dpy, gra_font[i].fontname, 1, &namecount);
		}

		if (namecount != 0)
		{
			/* at least one version should have worked */
			gra_font[i].font = XLoadQueryFont(gra_dpy, fontlist[0]);
			XFreeFontNames(fontlist);
		}

		if (gra_font[i].font == NULL)
		{
			fprintf(stderr, "Cannot find font '%s', using default\n",
				gra_font[i].fontname);
			fprintf(stderr, "  To avoid this message, add the following line to your .Xdefaults file:\n");
			fprintf(stderr, "    Electric.%s: CORRECT-FONT-NAME\n", gra_resource_fontname[i]);
			gra_font[i].font = gra_defaultFont.font;
		}
	}
	if (gra_font[11].font != NULL)
	{
		gra_messages_font.font = gra_font[11].font;
		gra_messages_font.fontname = gra_font[11].fontname;
	}

	/* Determine initial position and size of edit window */
	if (strcmp(editdisplayname, msgdisplayname) == 0) full_screen = 0; else
		full_screen = 1;
	if (togglefullscreen != 0)
		full_screen = 1 - full_screen;
	gra_screenh = XHeightOfScreen(XDefaultScreenOfDisplay(gra_dpy));
	gra_screenw = XWidthOfScreen(XDefaultScreenOfDisplay(gra_dpy));
	xsh = XAllocSizeHints();
	if (geomSpec == NULL) geomSpec = XGetDefault(gra_dpy, "Electric", "geometry");
	if (geomSpec == NULL || full_screen != 0)
	{
		/* nothing in defaults database (or full screen was requested) */
		xsh->flags = PPosition | PSize;
		xsh->height = gra_screenh - 2;   /* room for window manager border */
		xsh->width = gra_screenw - 8;    /* room for openlook window manager */
		if (full_screen == 0)
		{
			xsh->height = xsh->height / 8 * 6;
		} else
		{
			xsh->height = gra_screenh - 24; /* room for a border */
		}
		xsh->x = xsh->y = 0;
	} else
	{
		/* use defaults from database */
		bitmask = XWMGeometry(gra_dpy, gra_screen_num, geomSpec, NULL, 1, xsh,
			&xsh->x, &xsh->y, &xsh->width, &xsh->height, &xsh->win_gravity);
		if (bitmask & (XValue | YValue)) xsh->flags |= USPosition;
		if (bitmask & (WidthValue | HeightValue)) xsh->flags |= USSize;
	}
	graphicswidth = xsh->width;
	graphicsheight = xsh->height;

	/* Determine initial position and size of messages window */
	gra_screenmh = XHeightOfScreen(XDefaultScreenOfDisplay(gra_msgdpy));
	gra_screenmw = XWidthOfScreen(XDefaultScreenOfDisplay(gra_msgdpy));
	xsh_messages = XAllocSizeHints();
	i = gra_messages_font.font->max_bounds.width;
	j = gra_messages_font.font->descent + gra_messages_font.font->ascent + MESLEADING;
	gra_status_height = MAXSTATUSLINES * j + 4;
	xsh_messages->width = i * MESSAGESWIDTH;
	if (full_screen != 0)
	{
		xsh_messages->height = 15 * j;
		xsh_messages->y = gra_screenmh - xsh_messages->height - 50;
	} else
	{
		xsh_messages->height = gra_screenmh - xsh->height - 80;
		xsh_messages->y = gra_screenmh - xsh_messages->height - 52;
	}
	xsh_messages->min_width = 0;
	xsh_messages->min_height = 0;
	xsh_messages->x = xsh->x;  /* under the other window */
	xsh_messages->flags = (PPosition | PSize | PMinSize);
	msgwidth = xsh_messages->width;
	msgheight = xsh_messages->height;

	/*
	 * See if there are enought X-Server resources for backing store.
	 * To request this, declare the X resource "Electric.retained:True"
	 * in the .Xdefaults or equivalent file before starting.
	 */
	gra_use_backing = 0;
	ptr = XGetDefault(gra_dpy, "Electric", "retained");
	if (ptr != NULL)
	{
		if (namesamen(ptr, "True", 4) == 0)
		{
			if (DoesBackingStore(DefaultScreenOfDisplay(gra_dpy)))
				gra_use_backing = 1; else
			{
				fprintf(stderr, "Backing Store is not available.\n");
				fprintf(stderr, "  To avoid this message, remove this line from your .Xdefaults file:\n");
				fprintf(stderr, "    Electric.retained:True\n");
			}
		}
	}

	/* setup to create the graphics window */
	if (gra_sdep > 1)
	{
		bd = 1;  /* window border */
		bg = 0;  /* start with default background on a color screen */
	} else
	{
		bg = us_white;   /* others have 1 for black */
		bd = us_black;   /* white background on monochrome */;
	}
	xswa.background_pixel = bg;
	xswa.border_pixel = bd;
#ifdef ANYDEPTH
	valuemask = CWBackPixel | CWBorderPixel;
#else
	valuemask = CWBackPixel | CWBorderPixel | CWColormap;
#endif
	if (gra_use_backing)
	{
		xswa.backing_store = WhenMapped;
		xswa.backing_pixel = bg;
		xswa.backing_planes = AllPlanes;
		valuemask |= CWBackingStore | CWBackingPixel | CWBackingPlanes;
	}

	/* setup to create the messages window */
	xswa_messages.background_pixel = bg;
	xswa_messages.border_pixel = bd;
	xswa_messages.bit_gravity = NorthWestGravity;
	messagesvaluemask = CWBackPixel | CWBorderPixel | CWBitGravity;
	if (gra_use_backing)
	{
		xswa_messages.backing_store = Always;
		xswa_messages.backing_pixel = bg;
		xswa_messages.backing_planes = AllPlanes;
		messagesvaluemask |= CWBackingStore | CWBackingPixel | CWBackingPlanes;
	}

	/* try to save under the messages window... may not always work */
	if (DoesSaveUnders(DefaultScreenOfDisplay(gra_msgdpy)))
	{
		xswa_messages.save_under = True;
		messagesvaluemask |= CWSaveUnder;
	}

	/* make top-level graphics widget */
#ifdef USETIF
	/*
	 * this call may generate warnings like this:
	 *   Warning: Cannot convert string "<Key>Escape,_Key_Cancel" to type VirtualBinding
	 */
	gra_toplevelwidget = XtAppCreateShell("electric", "electric", applicationShellWidgetClass,
		gra_dpy, NULL, 0);
	if (gra_toplevelwidget == 0)
	{
		fprintf(stderr, "Could not create top-level window\n");
		exitprogram();
	}
	(void)XtAppSetErrorHandler(gra_xtapp, gra_xterrors);
	ac = 0;
	XtSetArg(arg[ac], XtNx, 1);   ac++;
	XtSetArg(arg[ac], XtNy, 2);   ac++;
	XtSetArg(arg[ac], XtNwidth, graphicswidth);   ac++;
	XtSetArg(arg[ac], XtNheight, graphicsheight);   ac++;
	XtSetValues(gra_toplevelwidget, arg, ac);
	gra_initialeditx = 1;
	gra_initialedity = 0;

	/* make graphics widget frame */
	ac = 0;
	XtSetArg(arg[ac], XmNwidth, graphicswidth);   ac++;
	XtSetArg(arg[ac], XmNheight, graphicsheight);   ac++;
	gra_intermediategraphics = (Widget)XmCreateMainWindow(gra_toplevelwidget,
		"graphics", arg, ac);
	if (gra_intermediategraphics == 0)
	{
		fprintf(stderr, "Could not create main window\n");
		exitprogram();
	}
	XtManageChild(gra_intermediategraphics);

	/* make graphics widget drawing area */
	ac = 0;
	XtSetArg(arg[ac], XmNresizePolicy, XmRESIZE_ANY);   ac++;
	gra_graphicswidget = (Widget)XmCreateDrawingArea(gra_intermediategraphics,
		"drawing_area", arg, ac);
	if (gra_graphicswidget == 0)
	{
		fprintf(stderr, "Could not create main widget\n");
		exitprogram();
	}
	XtManageChild(gra_graphicswidget);

	/* make menus */
	gra_menubar = (Widget)XmCreateMenuBar(gra_intermediategraphics, "MainWin", NULL, 0);
	XtManageChild(gra_menubar);

	/* create a dummy menu to define the size of the pulldown menubar */
	gra_firstmenu = XtVaCreateManagedWidget("File", xmCascadeButtonWidgetClass, gra_menubar, NULL);
	XmMainWindowSetAreas(gra_intermediategraphics, gra_menubar, NULL,
		NULL, NULL, gra_graphicswidget);

	XtAddEventHandler(gra_graphicswidget, ButtonPressMask | ButtonReleaseMask |
		KeyPressMask | PointerMotionMask | ExposureMask | StructureNotifyMask, FALSE,
		gra_graphics_event_handler, NULL);
#else
	gra_toplevelwidget = XtInitialize("electric", "Electric", NULL, 0,
		&gra_argc, gra_argv);
	ac = 0;
	XtSetArg(arg[ac], XtNx, 1);   ac++;
	XtSetArg(arg[ac], XtNy, 0);   ac++;
	XtSetValues(gra_toplevelwidget, arg, ac);

	/* make graphics widget */
	gra_graphicswidget = XtVaCreateManagedWidget("graphics", boxWidgetClass,
		gra_toplevelwidget,
		XtNwidth,    graphicswidth,
		XtNheight,   graphicsheight,
		NULL);
	XtAddEventHandler(gra_graphicswidget, ButtonPressMask | ButtonReleaseMask |
		KeyPressMask | PointerMotionMask | ExposureMask, FALSE,
		gra_graphics_event_handler, NULL);
#endif
	XtRealizeWidget(gra_toplevelwidget);

	/* get info about this widget */
	gra_topdpy = XtDisplay(gra_toplevelwidget);
	gra_topwin = XtWindow(gra_toplevelwidget);
	gra_dpy = XtDisplay(gra_graphicswidget);
	gra_win = XtWindow(gra_graphicswidget);

	/* get window size and depth after creation */
	XGetWindowAttributes(gra_dpy, gra_win, &xwa);
	us_swid = xwa.width;
	gra_shei = xwa.height;  /* we keep the true height locally */
	us_shei = gra_shei - gra_status_height;
	gra_revy = us_shei - 1;
	gcv.foreground = us_black;
	gcv.background = us_white;
	gcv.graphics_exposures = False;

#ifdef ANYDEPTH
	/* allocate space for the 8-bit deep buffer */
	amt = us_swid * gra_shei;
	gra_dataaddr8 = (char *)emalloc(amt, us_aid->cluster);
	gra_rowstart = (char **)emalloc(gra_shei * SIZEOFINTBIG, us_aid->cluster);
	for(i=0; i<gra_shei; i++)
		gra_rowstart[i] = gra_dataaddr8 + i * us_swid;

	/* allocate space for the full-depth buffer */
   	gra_worldwid = gra_screenw;   gra_worldhei = gra_screenh;
	amt = gra_worldwid * gra_worldhei * gra_truedepth / 8;
	gra_dataaddr = (char *)emalloc(amt, us_aid->cluster);
	gra_world = XCreateImage(gra_dpy, gra_visual, gra_sdep, ZPixmap,
		0, gra_dataaddr, gra_worldwid, gra_worldhei, gra_truedepth, 0);
	if (gra_world == 0)
	{
		fprintf(stderr, "Error allocating %dx%d image array\n", gra_worldwid, gra_worldhei);
		exitprogram();
	}
	gra_offrowstart = (char **)emalloc(gra_worldhei * SIZEOFINTBIG, us_aid->cluster);
	for(i=0; i<gra_worldhei; i++)
		gra_offrowstart[i] = gra_dataaddr + i * gra_world->bytes_per_line;
#endif

	/* load window manager information */
	(void)strcpy(gra_localstring, "Electric");
	ptr = gra_localstring;
	XStringListToTextProperty(&ptr, 1, &wintitle);
	XStringListToTextProperty(&iconname, 1, &icontitle);
	xwmh = XAllocWMHints();
	xwmh->input = True;
	xwmh->initial_state = NormalState;
#ifdef sun
	xwmh->icon_pixmap = xwmh->icon_mask = XCreateBitmapFromData(gra_topdpy, gra_topwin,
		(const char *)gra_icon32, 32, 32);
#else
	xwmh->icon_pixmap = xwmh->icon_mask = XCreateBitmapFromData(gra_topdpy, gra_topwin,
		(const char *)gra_icon64, 64, 64);
#endif
	xwmh->flags = InputHint | StateHint | IconPixmapHint;
	XSetWMProperties(gra_topdpy, gra_topwin, &wintitle, &icontitle,
		gra_argv, gra_argc, xsh, xwmh, NULL);

#ifndef ANYDEPTH
	gra_colormap = XCreateColormap(gra_topdpy, RootWindow(gra_topdpy, gra_screen_num),
		gra_visual, AllocNone);
	xswa.colormap = gra_colormap;
	XChangeWindowAttributes(gra_topdpy, gra_topwin, CWColormap, &xswa);
#endif

	/* create the messages window */
	gra_messages = messages;
	if (gra_messages != 0)
	{
		/* make second top-level shell for messages */
#ifdef USETIF
		gra_msgtoplevelwidget = XtAppCreateShell("Electric", "electric",
			applicationShellWidgetClass, gra_msgdpy, NULL, 0);
#else
		gra_msgtoplevelwidget = XtCreateApplicationShell(NULL, topLevelShellWidgetClass,
			0, 0);
#endif
		gra_initialmsgx = 100;
		gra_initialmsgy = graphicsheight+36;
		gra_initialmsgy = xsh_messages->y;
		ac = 0;
		XtSetArg(arg[ac], XtNx, gra_initialmsgx);   ac++;
		XtSetArg(arg[ac], XtNy, gra_initialmsgy+2);   ac++;
		XtSetArg(arg[ac], XtNwidth, msgwidth);   ac++;
		XtSetArg(arg[ac], XtNheight, msgheight);   ac++;
#ifdef ANYDEPTH
		XtSetArg(arg[ac], XtNbackground, WHITE);   ac++;
		XtSetArg(arg[ac], XtNforeground, BLACK);   ac++;
#endif
		XtSetValues(gra_msgtoplevelwidget, arg, ac);

		/* make text widget for messages */
#ifdef USETIF
		ac = 0;
		XtSetArg(arg[ac], XmNeditable,   True);   ac++;
		XtSetArg(arg[ac], XmNeditMode,   XmMULTI_LINE_EDIT);   ac++;
		XtSetArg(arg[ac], XmNcolumns,    80);   ac++;
		XtSetArg(arg[ac], XmNrows,       10);   ac++;
		gra_messageswidget = (Widget)XmCreateScrolledText(gra_msgtoplevelwidget,
			"messages", arg, ac);
		XtManageChild(gra_messageswidget);
		XtAddEventHandler(gra_messageswidget, ButtonPressMask | KeyPressMask |
			VisibilityChangeMask | ExposureMask, FALSE, gra_messages_event_handler, NULL);
#else
		buffer = (char *)emalloc(MESSAGEBUFFERSIZE, db_cluster);
		buffer[0] = 0;
		gra_messageswidget = XtVaCreateManagedWidget("messages", asciiTextWidgetClass,
			gra_msgtoplevelwidget,
			XtNstring,           buffer,
#  ifndef ANYDEPTH
			XtNbackground,       WHITE,
			XtNborderColor,      BLACK,
			XtNforeground,       BLACK,
#  endif
			XtNlength,           MESSAGEBUFFERSIZE,
			XtNeditType,         XawtextEdit,
			XtNscrollHorizontal, XawtextScrollAlways,
			XtNscrollVertical,   XawtextScrollAlways,
			NULL);
		XtAddEventHandler(gra_messageswidget, ButtonPressMask | KeyPressMask |
			VisibilityChangeMask, FALSE, gra_messages_event_handler, NULL);
#endif
		XtRealizeWidget(gra_msgtoplevelwidget);
		gra_msgwin = XtWindow(gra_messageswidget);
		gra_messages_obscured = 0;
		gra_messages_typingin = 0;

		/* label the messages widget */
		gra_topmsgwin = XtWindow(gra_msgtoplevelwidget);
		gra_topmsgdpy = XtDisplay(gra_msgtoplevelwidget);
		title = "Electric Messages";
		XStringListToTextProperty(&title, 1, &wintitle);
		XSetWMName(gra_topmsgdpy, gra_topmsgwin, &wintitle);
#ifndef ANYDEPTH
		XChangeWindowAttributes(gra_topmsgdpy, gra_topmsgwin, CWColormap, &xswa);
#endif

		/* set I-beam cursor */
		gra_ibeam = XCreateFontCursor(gra_topmsgdpy, XC_xterm);
		XDefineCursor(gra_topmsgdpy, gra_topmsgwin, gra_ibeam);

		/* load window manager information */
		XStringListToTextProperty(&sswinname, 1, &swintitle);
		XStringListToTextProperty(&ssiconname, 1, &sicontitle);
		xwmh_messages = XAllocWMHints();
		xwmh_messages->input = True;
		xwmh_messages->initial_state = NormalState;
		xwmh_messages->icon_pixmap = xwmh->icon_mask = xwmh->icon_pixmap;
		xwmh_messages->icon_x = xsh_messages->x;
		xwmh_messages->icon_y = xsh_messages->y;
		xwmh_messages->flags = InputHint | StateHint | IconPixmapHint | IconPositionHint;
		XSetWMProperties(gra_topmsgdpy, gra_topmsgwin, &swintitle, &sicontitle,
			gra_argv, gra_argc, xsh_messages, xwmh_messages, NULL);
	}

	/* set up to trap window kills */
#ifdef USETIF
	gra_wm_delete_window = XmInternAtom(gra_topdpy, "WM_DELETE_WINDOW", False);
	XmAddWMProtocolCallback(gra_toplevelwidget, gra_wm_delete_window,
		(XtCallbackProc)gra_windowdelete, gra_intermediategraphics);
	if (gra_messages != 0)
		XmAddWMProtocolCallback(gra_msgtoplevelwidget, gra_wm_delete_window,
			(XtCallbackProc)gra_windowdelete, gra_messageswidget);
#else
	gra_wm_delete_window = XInternAtom(gra_topdpy, "WM_DELETE_WINDOW", False);
	gra_wm_protocols = XInternAtom(gra_topdpy, "WM_PROTOCOLS", False);
	XtAddEventHandler(gra_toplevelwidget, NoEventMask, TRUE, gra_destroygraphics, NULL);
	XSetWMProtocols(gra_topdpy, gra_topwin, &gra_wm_delete_window, 1);
	if (gra_messages != 0)
	{
		XtAddEventHandler(gra_msgtoplevelwidget, NoEventMask, TRUE, gra_destroygraphics,
			NULL);
		XSetWMProtocols(gra_topmsgdpy, gra_topmsgwin, &gra_wm_delete_window, 1);
	}
#endif

	/* create the cursors */
	gra_xfc.flags = gra_xbc.flags = DoRed | DoGreen | DoBlue;
	XQueryColor(gra_dpy, XDefaultColormapOfScreen(XDefaultScreenOfDisplay(gra_dpy)),
		&gra_xfc);
	XQueryColor(gra_dpy, XDefaultColormapOfScreen(XDefaultScreenOfDisplay(gra_dpy)),
		&gra_xbc);
	pixm = XCreateBitmapFromData(gra_dpy, gra_win, (const char *)gra_realcursordata, 16, 16);
	gra_realcursor = XCreatePixmapCursor(gra_dpy, pixm, pixm, &gra_xfc, &gra_xbc, 8, 8);
	pixm = XCreateBitmapFromData(gra_dpy, gra_win, (const char *)gra_nomousecursordata, 16, 16);
	gra_nomousecursor = XCreatePixmapCursor(gra_dpy, pixm, pixm, &gra_xfc, &gra_xbc, 8, 8);
	pixm = XCreateBitmapFromData(gra_dpy, gra_win, (const char *)gra_drawcursordata, 16, 16);
	gra_drawcursor = XCreatePixmapCursor(gra_dpy, pixm, pixm, &gra_xfc,  &gra_xbc, 0, 16);
	pixm = XCreateBitmapFromData(gra_dpy, gra_win, (const char *)gra_nullcursordata, 16, 16);
	gra_nullcursor = XCreatePixmapCursor(gra_dpy, pixm, pixm, &gra_xfc, &gra_xbc, 8, 8);
	pixm = XCreateBitmapFromData(gra_dpy, gra_win, (const char *)gra_menucursordata, 16, 16);
	gra_menucursor = XCreatePixmapCursor(gra_dpy, pixm, pixm, &gra_xfc, &gra_xbc, 16, 8);
	pixm = XCreateBitmapFromData(gra_dpy, gra_win, (const char *)gra_handcursordata, 16, 16);
	gra_handcursor = XCreatePixmapCursor(gra_dpy, pixm, pixm, &gra_xfc, &gra_xbc, 0, 10);
	pixm = XCreateBitmapFromData(gra_dpy, gra_win, (const char *)gra_techcursordata, 16, 16);
	gra_techcursor = XCreatePixmapCursor(gra_dpy, pixm, pixm, &gra_xfc, &gra_xbc, 8, 0);
	pixm = XCreateBitmapFromData(gra_dpy, gra_win, (const char *)gra_ibeamcursordata, 16, 16);
	gra_ibeamcursor = XCreatePixmapCursor(gra_dpy, pixm, pixm, &gra_xfc, &gra_xbc, 8, 8);

	/* build graphics contexts */
#ifdef USETIF
	gcv.foreground = bd;
	gcv.graphics_exposures = False;     /* no event after XCopyArea */
	gra_gc = XtGetGC(gra_graphicswidget, GCForeground | GCGraphicsExposures, &gcv);
	gcv.function = GXinvert;
	gra_gcinv = XtGetGC(gra_graphicswidget, GCFunction | GCGraphicsExposures, &gcv);
#  ifndef ANYDEPTH
	gcv.fill_style = FillStippled;
	gra_gcstip = XtGetGC(gra_graphicswidget, GCFillStyle | GCGraphicsExposures, &gcv);
#  endif
#else
	gcv.foreground = bd;
	gcv.graphics_exposures = False;     /* no event after XCopyArea */
	gra_gc = XCreateGC(gra_dpy, gra_win, GCForeground | GCGraphicsExposures, &gcv);
	gcv.function = GXinvert;
	gra_gcinv = XCreateGC(gra_dpy, gra_win, GCFunction | GCGraphicsExposures, &gcv);
#  ifndef ANYDEPTH
	gcv.fill_style = FillStippled;
	gra_gcstip = XCreateGC(gra_dpy, gra_win, GCFillStyle | GCGraphicsExposures, &gcv);
#  endif
#endif

#ifdef ANYDEPTH
	/* precache font bits */
	textmap = XCreatePixmap(gra_dpy, gra_win, 100, 100, gra_sdep);
	if (textmap == 0)
	{
		fprintf(stderr, "Error allocating initial text pixmap\n");
		exitprogram();
	}
	for(i=0; gra_font[i].fontname != 0; i++)
	{
		thefont = gra_font[i].font;
		XSetFont(gra_dpy, gra_gc, thefont->fid);
		for(j=0; j<128; j++)
		{
			gra_localstring[0] = (j < ' ' ? ' ' : j);
			gra_localstring[1] = 0;
			XTextExtents(thefont, gra_localstring, 1, &direction, &asc, &des, &xcs);
			width = xcs.width;
			height = thefont->ascent + thefont->descent;
			gra_font[i].width[j] = width;
			gra_font[i].height[j] = height;
			amt = width * height;
			if (amt == 0) continue;
			gra_font[i].data[j] = (char *)emalloc(amt, us_aid->cluster);
			if (gra_font[i].data[j] == 0)
			{
				fprintf(stderr, "Error allocating %d bytes for font data\n", amt);
				exitprogram();
			}
			for(k=0; k<amt; k++) gra_font[i].data[j][k] = 0;
			XSetForeground(gra_dpy, gra_gc, 0);
			XFillRectangle(gra_dpy, textmap, gra_gc, 0, 0, 100, 100);
			XSetForeground(gra_dpy, gra_gc, 0xFFFFFF);
			XDrawString(gra_dpy, textmap, gra_gc, 0,
				height-thefont->descent, gra_localstring, 1);
			image = XGetImage(gra_dpy, textmap, 0, 0, width, height,
				AllPlanes, ZPixmap);
			if (image == 0)
			{
				fprintf(stderr, "Error allocating %dx%d image for fonts\n",
					width, height);
				exitprogram();
			}

			dptr = gra_font[i].data[j];
			switch (gra_sdep)
			{
				case 8:
					ptr = image->data;
					slop = image->bytes_per_line - image->width;
					for(y=0; y<height; y++)
					{
						for(x=0; x<width; x++)
						{
							if (*ptr++ == 0) *dptr++ = 0; else
								*dptr++ = 1;
						}
						ptr += slop;
					}
					break;
				case 16:
					ptr16 = (short *)image->data;
					slop = image->bytes_per_line - image->width*2;
					for(y=0; y<height; y++)
					{
						for(x=0; x<width; x++)
						{
							if (*ptr16++ == 0) *dptr++ = 0; else
								*dptr++ = 1;
						}
						ptr16 = (short *)(((char *)ptr16) + slop);
					}
					break;
				case 24:
				case 32:
					ptr32 = (long *)image->data;
					slop = image->bytes_per_line - image->width*4;
					for(y=0; y<height; y++)
					{
						for(x=0; x<width; x++)
						{
							if (*ptr32++ == 0) *dptr++ = 0; else
								*dptr++ = 1;
						}
						ptr32 = (long *)(((char *)ptr32) + slop);
					}
					break;
			}
			XDestroyImage(image);
		}
	}
#endif

	/* fill the color map  */
	if (gra_sdep == 1) us_dispstyle = BWRASTER; else
	{
		us_dispstyle = COLORMAP;
  		el_colcursor = CURSOR;	/* also done in usr.c later */
	}
#ifdef ANYDEPTH
	el_maplength = 256;
	if (gra_sdep != 1) us_getcolormap(el_curtech, COLORSDEFAULT, 0);
#else
	el_maplength = (INTSML)DisplayCells(gra_dpy, gra_screen_num);
	gra_maphigh = el_maplength - 1;
	if (gra_sdep != 1)
	{
		if (XAllocColorCells(gra_dpy, gra_colormap, 1, (unsigned long *)planes, 0,
			(unsigned long *)pixelarray, el_maplength) == 0)
				fprintf(stderr, "XAllocColorCells failed\n");

		/* load any map the first time to establish the map segment length */
		us_getcolormap(el_curtech, COLORSDEFAULT, 0);
		gra_xfc.pixel = el_colcursor;
		XQueryColor(gra_dpy, gra_colormap, &gra_xfc);
		gra_xbc.pixel = 0;
		XQueryColor(gra_dpy, gra_colormap, &gra_xbc);
		gra_recolorcursor(&gra_xfc, &gra_xbc);
	}
#endif

	/* initialize the mouse */
	us_cursorstate = -1;
	us_normalcursor = NORMALCURSOR;
	setdefaultcursortype(us_normalcursor);
	gra_inputstate = NOEVENT;
	gra_eventqueuehead = gra_eventqueuetail = gra_eventqueue;

	/* initialize the window frames */
	wf = (WINDOWFRAME *)emalloc((sizeof (WINDOWFRAME)), us_aid->cluster);
	if (wf == 0) error("Cannot create frame window info structure");
	el_firstwindowframe = el_curwindowframe = wf;
	el_firstwindowframe->nextwindowframe = NOWINDOWFRAME;

#ifndef USETIF
	if (gra_use_backing == 0)
	{
		/* avoid double repaint at startup */
		while (XCheckTypedWindowEvent(gra_dpy, gra_win, Expose, &event) == False);
	} else
	{
		while (XCheckTypedWindowEvent(gra_dpy, gra_win, MapNotify, &event) == False);
	}
#endif
	return(0);
}

#if LANGTCL
int InitializeTCL(void)
{
	int err;
	char *newArgv[2];

	/* set the program name/path */
	newArgv[0] = "Electric";
	newArgv[1] = NULL;
	(void)Tcl_FindExecutable(newArgv[0]);

	myTCLInterp = Tcl_CreateInterp();
	if (myTCLInterp == 0) error("from Tcl_CreateInterp");

	/* tell Electric the TCL interpreter handle */
	el_tclinterpreter(myTCLInterp);

	/* Make command-line arguments available in the Tcl variables "argc" and "argv" */
	Tcl_SetVar(myTCLInterp, "argv", "", TCL_GLOBAL_ONLY);
	Tcl_SetVar(myTCLInterp, "argc", "0", TCL_GLOBAL_ONLY);
	Tcl_SetVar(myTCLInterp, "argv0", "electric", TCL_GLOBAL_ONLY);

	/* Set the "tcl_interactive" variable */
	Tcl_SetVar(myTCLInterp, "tcl_interactive", "1", TCL_GLOBAL_ONLY);

	/* initialize the interpreter */
	err = Tcl_Init(myTCLInterp);
	if (err != TCL_OK) error("(from Tcl_Init) %s", myTCLInterp->result);
	return(err);
}

#  ifdef USETK
void InitializeTK(void)
{
	int code;

	if (Tk_Init(myTCLInterp) == TCL_ERROR)
	{
		ttyputerr("Tk_Init failed: %s", tcl_interp->result);
		return;
	}

	/* get the top Tk window handle */
	gra_tktopwindow = Tk_MainWindow(myTCLInterp);
	if (gra_tktopwindow == NULL)
		error("(from Tk_MainWindow) %s\n", myTCLInterp->result);

	/* withdraw the top window */
	if (Tcl_VarEval(myTCLInterp, "wm withdraw .", (char *)NULL) == TCL_ERROR)
		error("(from Tcl_VarEval) %s\n", myTCLInterp->result);

	(void)Tk_SetClass(gra_tktopwindow, "Electric");
	(void)Tcl_ResetResult(myTCLInterp);

	/* initialize tk package */
	if (Tcl_PkgRequire(myTCLInterp, "Tcl", TCL_VERSION, 1) == NULL)
		error("(from Tcl_PkgRequire) %s", myTCLInterp->result);
	code = Tcl_PkgProvide(myTCLInterp, "Tk", TK_VERSION);
	if (code != TCL_OK) error("(from Tcl_PkgProvide) %s", myTCLInterp->result);
}

/*
 * Routine to create a TK window of type "type":
 *  1  Scrolling text window
 *  2  Graphic edit window
 *  3  Dialog window with title banner
 *  4  Dialog windiw with no title banner
 * The window runs from "left" to "right" and from "top" to "bottom".
 * The event proc to use for this window is in "eventproc"
 */
Tk_Window MakeTKWindow(short type, short left, short right, short top, short bottom,
		void (*eventproc)(ClientData, XEvent*))
{
	Tk_Window win;
	char windowname[100], unsupportedcmd[200], *argv[3];
	static INTSML windowcount = 1;

	switch (type)
	{
		case 1:
			sprintf(windowname, ".status");
			break;
		case 2:
			sprintf(windowname, ".graphics");
			break;
		case 3:
		case 4:
			sprintf(windowname, ".electric%d", windowcount);
			windowcount++;
			break;
	}

#if 0
	win = Tk_CreateWindowFromPath(myTCLInterp, gra_tktopwindow, windowname, "");
	if (win == NULL)
	{
		ttyputerr("ERROR from Tk_CreateWindowFromPath: %s", myTCLInterp->result);
		Tcl_ResetResult(myTCLInterp);
		return(0);
	}
#else
	sprintf(unsupportedcmd, "etoplevel %s", windowname);
	if (Tcl_VarEval(myTCLInterp, unsupportedcmd, 0) == TCL_ERROR)
		ttyputerr("Tcl_VarEval returned %s", myTCLInterp->result);
	win = Tk_NameToWindow(myTCLInterp, windowname, gra_tktopwindow);
#endif

	(void)Tk_CreateEventHandler(win, MYEVENTS, eventproc, (ClientData)NULL);
	(void)Tk_GeometryRequest(win, right-left, bottom-top);
	(void)Tk_MoveToplevelWindow(win, left, top);
	(void)Tk_MakeWindowExist(win);

	if (type == 3 || type == 4)
	{
		argv[0] = "grab";
		argv[1] = "-global";
		argv[2] = windowname;
		if (Tk_GrabCmd((ClientData)gra_tktopwindow, myTCLInterp, 3, argv) != TCL_OK)
		{
				ttyputmsg("ERROR from Tk_GrabCmd: %s", myTCLInterp->result);
				Tcl_ResetResult(myTCLInterp);
		}
	}
	return(win);
}

#  endif

#endif

/*
 * Routine to establish the library directories from the environment.
 */
void setupenvironment(void)
{
	REGISTER char *pt, *buf;

	pt = getenv("ELECTRIC_LIBDIR");
	if (pt == NULL)
	{
		(void)allocstring(&el_libdir, LIBDIR, db_cluster);
	} else
	{
		buf = (char *)emalloc(strlen(pt)+5, el_tempcluster);
		strcpy(buf, pt);
		if (buf[strlen(buf)-1] != '/') strcat(buf, "/");
		(void)allocstring(&el_libdir, buf, db_cluster);
		efree(buf);
	}

	/* set machine name */
	nextvarchangequiet();
	(void)setvalkey((INTBIG)us_aid, VAID, makekey("USER_machine"),
		(INTBIG)"UNIX", VSTRING|VDONTSAVE);
}

void setlibdir(char *libdir)
{
	(void)initinfstr();
	(void)addstringtoinfstr(libdir);
	if (libdir[strlen(libdir)-1] != DIRSEP) (void)addtoinfstr(DIRSEP);
	(void)reallocstring(&el_libdir, returninfstr(), db_cluster);
}

/******************** TERMINATION ********************/

void us_unsetdisplay(void) {}

void us_termgraphics(INTSML final)
{
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;
	XCloseDisplay(gra_dpy);
#ifdef USETIF
/*	XtDestroyApplicationContext(gra_xtapp); ...causes a segmentation fault for some reason */
#endif
}

void exitprogram(void)
{
	exit(0);
}

/******************** WINDOW CONTROL ********************/

/*
 * These routines implement multiple windows on the display (each display window
 * is called a "windowframe".  Currently these routines are unimplemented.
 */

WINDOWFRAME *us_newwindowframe(INTSML floating)
{
	return(NOWINDOWFRAME);
}

void us_killwindowframe(WINDOWFRAME *frame)
{
}

WINDOWFRAME *us_getwindowframe(void)
{
	return(el_firstwindowframe);
}

/*
 * routine to return size of window "win" in "wid" and "hei"
 */
void us_getwindowsize(WINDOWFRAME *frame, INTSML *wid, INTSML *hei)
{
	*wid = us_swid;
	*hei = us_shei;
}

void us_sizewindowframe(WINDOWFRAME *frame, INTSML wid, INTSML hei)
{
}

void us_movewindowframe(WINDOWFRAME *frame, INTSML top, INTSML left)
{
}

/*
 * Routine to close the messages window if it is in front.  Returns nonzero if the
 * window was closed.
 */
INTSML closefrontmostmessages(void)
{
	return(0);
}

/*
 * Routine to bring window "win" to the front.
 */
void us_bringwindowtofront(WINDOWFRAME *frame)
{
}

void us_getpaletteparameters(INTSML *wid, INTSML *hei, INTSML *palettewidth)
{
	*hei = us_shei;
	*wid = us_swid;
	*palettewidth = 70;
}

/******************** MISCELLANEOUS EXTERNAL ROUTINES ********************/

/*
 * routine to return display style of window "win"
 */
short us_getdispstyle(WINDOWPART *win)
{
	return(us_dispstyle);
}

void us_startbatching(void) {}

void us_endbatching(void)
{
#ifdef ANYDEPTH
	flushscreen();
#endif
}

/*
 * return nonzero if the capabilities in "want" are present
 */
INTSML us_graphicshas(INTSML want)
{
	/* capability not there if no graphics being used */
	if (us_dispstyle < 0) return(0);
	if ((want & CANUSEFRAMES) != 0) return(0);
#ifndef USETIF
	if ((want & CANSHOWPOPUP) != 0) return(0);
#endif

	return(1);
}

void ttybeep(void)
{
	if (us_aid->aidstate & TERMBEEP)
	{
		XBell(gra_dpy, 100);
	}
}

void error(char *s, ...)
{
	va_list ap;
	char line[256], *pars[10], fullmsg[300];
	REGISTER INTSML count;
	extern COMCOMP us_noyesp;

	us_ttyclose();
	var_start(ap, s);
	(void)vsprintf(line, s, ap);
	va_end(ap);
	sprintf(fullmsg, "Error: %s.  Exit? [y] ", line);
	count = ttygetparam(fullmsg, &us_noyesp, 2, pars);
	if (count <= 0 || namesamen(pars[0], "yes", (INTSML)strlen(pars[0])) != 0)
		exitprogram();
}

/*
 * Routine to get the environment variable "name" and return its value.
 */
char *egetenv(char *name)
{
	return(getenv(name));
}

/*
 * Routine to fork a new process.  Returns the child process number if this is the
 * parent thread.  Returns 0 if this is the child thread.
 * Returns 1 if forking is not possible (process 1 is INIT on UNIX and can't possibly
 * be assigned to a normal process).
 */
INTBIG efork(void)
{
	return(fork());
}

/*
 * Routine to execute the program "program" with the arguments "args"
 */
void eexec(char *program, char *args[])
{
	execvp(program, args);
}

/*
 * routine to kill process "process".
 */
INTBIG ekill(INTBIG process)
{
	return(kill(process, SIGKILL));
}

/*
 * routine to wait for the completion of child process "process"
 */
void ewait(INTBIG process)
{
	REGISTER INTBIG pid;

	for(;;)
	{
		pid = wait((int *)0);
		if (pid == process) return;
		if (pid == -1)
		{
			perror("Waiting");
			return;
		}
	}
}

/******************** STATUS BAR ROUTINES ********************/

/*
 * Routine to return the number of status lines on the display.
 */
INTSML ttynumstatuslines(void)
{
	return(MAXSTATUSLINES);
}

/*
 * Routine to free status field object "sf".
 */
void ttyfreestatusfield(STATUSFIELD *sf)
{
	efree(sf->label);
	efree((char *)sf);
}

/*
 * Routine to display "message" in the status "field" of window "frame" (uses all windows
 * if "frame" is zero).  If "cancrop" is zero, field cannot be cropped and should be
 * replaced with "*" if there isn't room.
 */
void ttysetstatusfield(WINDOWFRAME *frame, STATUSFIELD *field, char *message, INTSML cancrop)
{
	INTSML len, lx, ly, hx, hy;
	XFontStruct *oldfont;
	INTSML sizey, sizex;
	char *ptr;
	XTextProperty wintitle;

	/* draw the separator line between drawing and status areas */
	us_box.col = BLACK;
	us_drawline(NULL, 1, -2, us_swid - 1, -2, &us_box, 0);

	if (field == 0) return;
	if (field->line == 0)
	{
		/* should set title bar here */
		(void)strcpy(gra_localstring, "Electric");
		if (strlen(message) > 0)
		{
			(void)strcat(gra_localstring, " (");
			(void)strcat(gra_localstring, field->label);
			(void)strcat(gra_localstring, message);
			(void)strcat(gra_localstring, ")");
		}
		len = strlen(gra_localstring);
		while (len > 0 && gra_localstring[len-1] == ' ') gra_localstring[--len] = 0;
		ptr = gra_localstring;
		XStringListToTextProperty(&ptr, 1, &wintitle);
		XSetWMName(gra_topdpy, gra_topwin, &wintitle);
		return;
	}

	/* construct the status line */
	(void)strcpy(gra_localstring, field->label);
	(void)strcat(gra_localstring, message);
	len = strlen(gra_localstring);
	while (len > 0 && gra_localstring[len-1] == ' ') gra_localstring[--len] = 0;

	oldfont = gra_curfont;
	us_settextsize(NULL, TXT6P);
	sizey = gra_curfont->ascent + gra_curfont->descent;
	sizex = gra_curfont->max_bounds.rbearing - gra_curfont->max_bounds.lbearing;

	lx = us_swid * field->startper / 100;
	hx = us_swid * field->endper / 100;
	ly = - (gra_status_height / field->line);

	hy = ly + sizey;
	us_drawbox(NULL, lx, hx - 1, ly, hy, &us_ebox);
	us_puttext(el_curwindowpart, lx, ly, gra_localstring, &us_menutext);

	gra_curfont = oldfont;
}

/******************** MESSAGES WINDOW ROUTINES ********************/

/*
 * internal routine to print one line onto the scrolling area
 */
void putmessagesstring(char *line)
{
#ifdef USETIF
	XmTextPosition tp;

#if 0
	/* make sure the window isn't iconified */
	Arg arg[1];
	int isiconic;
/*	XtSetArg(arg[0], XmNiconic, False); */
/*	XtSetValues(gra_msgtoplevelwidget, arg, 1); */
/*	XRaiseWindow(gra_topmsgdpy, gra_topmsgwin); */
	XtPopup(gra_msgtoplevelwidget, XtGrabNone);
	/* or XtGrabNonexclusive or XtGrabExclusive */
#endif

	tp = XmTextGetLastPosition(gra_messageswidget);
	XmTextInsert(gra_messageswidget, tp, line);
	tp = XmTextGetLastPosition(gra_messageswidget);
	XmTextInsert(gra_messageswidget, tp, "\n");
	tp = XmTextGetLastPosition(gra_messageswidget);
	XmTextSetSelection(gra_messageswidget, tp, tp, 0);
	XmTextSetInsertionPosition(gra_messageswidget, tp);   /* new!!! */
	XmTextShowPosition(gra_messageswidget, tp);   /* new!!! */
#else
	XawTextBlock tb;
	char endline[2];
	XWindowAttributes xwa;
	XawTextPosition ip;

	/* bring window to top if not */
	if (XGetWindowAttributes(gra_topmsgdpy, gra_topmsgwin, &xwa) == 0) return;
	if (xwa.map_state != IsViewable || gra_messages_obscured != 0)
		XMapRaised(gra_topmsgdpy, gra_topmsgwin);

	ip = XawTextGetInsertionPoint(gra_messageswidget);
	if (ip + 1000 > MESSAGEBUFFERSIZE)
	{
		tb.firstPos = 0;
		tb.length = 0;
		tb.ptr = line;
		tb.format = FMT8BIT;
		XawTextReplace(gra_messageswidget, 0, 1000, &tb);
	}
	tb.firstPos = 0;
	tb.length = strlen(line);
	tb.ptr = line;
	tb.format = FMT8BIT;
	XawTextReplace(gra_messageswidget, MESSAGEBUFFERSIZE, MESSAGEBUFFERSIZE, &tb);
	endline[0] = '\n';   endline[1] = 0;
	tb.length = 1;
	tb.ptr = endline;
	XawTextReplace(gra_messageswidget, MESSAGEBUFFERSIZE, MESSAGEBUFFERSIZE, &tb);
	XawTextSetInsertionPoint(gra_messageswidget, MESSAGEBUFFERSIZE);
#endif
}

char *getmessagesstring(char *prompt)
{
#ifdef USETIF
	XmTextPosition tp, starttp;
	char ch[2], *block;
	int c, total;

	/* show the prompt */
	tp = XmTextGetLastPosition(gra_messageswidget);
	XmTextInsert(gra_messageswidget, tp, prompt);

	/* get initial text position */
	starttp = XmTextGetLastPosition(gra_messageswidget);
	XmTextSetSelection(gra_messageswidget, starttp, starttp, 0);
	XmTextSetInsertionPosition(gra_messageswidget, starttp);   /* new!!! */

	/* loop while typing is done */
	total = 0;
	gra_messages_typingin = 1;
	for(;;)
	{
		c = us_getnxtchar();
		if (c == '\n' || c == '\r' || c == CTRLD) break;
		if (c == 0177 || c == 010)
		{
			tp = XmTextGetLastPosition(gra_messageswidget);
			XmTextSetSelection(gra_messageswidget, tp-1, tp, 0);
			XmTextRemove(gra_messageswidget);
			total--;
			continue;
		}
		if (c == us_killch)
		{
			tp = XmTextGetLastPosition(gra_messageswidget);
			XmTextSetSelection(gra_messageswidget, starttp, tp, 0);
			XmTextRemove(gra_messageswidget);
			total = 0;
			continue;
		}
		tp = XmTextGetLastPosition(gra_messageswidget);
		ch[0] = c;
		ch[1] = 0;
		XmTextInsert(gra_messageswidget, tp, ch);
		tp = XmTextGetLastPosition(gra_messageswidget);
		XmTextSetSelection(gra_messageswidget, tp, tp, 0);
		total++;
	}
	gra_messages_typingin = 0;

	block = (char *)emalloc(total+2, el_tempcluster);
	XmTextGetSubstring(gra_messageswidget, starttp, total+1, total+2, block);
	block[total] = 0;
	(void)initinfstr();
	(void)addstringtoinfstr(block);
	efree((char *)block);
	block = returninfstr();

	/* add in final carriage return */
	tp = XmTextGetLastPosition(gra_messageswidget);
	XmTextInsert(gra_messageswidget, tp, "\n");

	/* return the string (0 on EOF or null) */
	if (*block == 0 && c == 4) return(0);
	return(block);
#else
	char c;
	int i;
	XawTextPosition posstart, posend;
	Arg arg;
	char *str, ch[3];
	XawTextBlock tb;

	/* show the prompt */
	tb.firstPos = 0;
	tb.length = strlen(prompt);
	tb.ptr = prompt;
	tb.format = FMT8BIT;
	XawTextReplace(gra_messageswidget, MESSAGEBUFFERSIZE, MESSAGEBUFFERSIZE, &tb);

	/* get initial text position */
	XawTextSetInsertionPoint(gra_messageswidget, MESSAGEBUFFERSIZE);
	posstart = XawTextGetInsertionPoint(gra_messageswidget);

	/* loop while typing is done */
	tb.ptr = ch;
	gra_messages_typingin = 1;
	for(;;)
	{
		c = us_getnxtchar();
		if (c == '\n' || c == '\r' || c == CTRLD) break;
		if (c == 0177 || c == 010)
		{
			posend = XawTextGetInsertionPoint(gra_messageswidget);
			if (posend > posstart)
			{
				tb.length = 0;
				XawTextReplace(gra_messageswidget, posend-1, posend, &tb);
				XawTextSetInsertionPoint(gra_messageswidget, MESSAGEBUFFERSIZE);
			}
			continue;
		}
		if (c == us_killch)
		{
			posend = XawTextGetInsertionPoint(gra_messageswidget);
			if (posend > posstart)
			{
				tb.length = 0;
				XawTextReplace(gra_messageswidget, posstart, posend, &tb);
				XawTextSetInsertionPoint(gra_messageswidget, MESSAGEBUFFERSIZE);
			}
			continue;
		}
		tb.length = 1;
		ch[0] = c;
		XawTextReplace(gra_messageswidget, MESSAGEBUFFERSIZE, MESSAGEBUFFERSIZE, &tb);
		XawTextSetInsertionPoint(gra_messageswidget, MESSAGEBUFFERSIZE);
	}
	gra_messages_typingin = 0;

	/* get current text position */
	XawTextSetInsertionPoint(gra_messageswidget, MESSAGEBUFFERSIZE);
	posend = XawTextGetInsertionPoint(gra_messageswidget);

	/* get typed string */
	XtSetArg(arg, XtNstring, &str);
	XtGetValues(gra_messageswidget, &arg, 1);
	(void)initinfstr();
	for(i=posstart; i<posend; i++) (void)addtoinfstr(str[i]);
	str = returninfstr();

	/* add in final carriage return */
	ch[0] = '\n';
	tb.length = 1;
	XawTextReplace(gra_messageswidget, MESSAGEBUFFERSIZE, MESSAGEBUFFERSIZE, &tb);
	if (*str == 0 && c == 4) return(0);
	return(str);
#endif
}

/*
 * routine to select fonts in the messages window
 */
void setmessagesfont(void)
{
	char **fontlist, *required[14], ***choices;
	int namecount;
	INTBIG i, j, k, *numchoices;
	INTSML itemHit;
#ifdef USETIF
	Arg arg[1];
	XmFontListEntry entry;
	XmFontList xfontlist;
#endif

	/* get the list of available fonts */
	fontlist = XListFonts(gra_msgdpy, "-*-*-*-*-*-*-*-*-*-*-*-*-*-*",
		2000, &namecount);

	/* show the dialog */
	if (DiaInitDialog(&gra_xfontdialog) != 0) return;
	DiaInitTextDialog(31, us_nulldloglist, us_nulldlogitem, us_nulldlogdone,
		-1, SCDOUBLEQUIT|SCSELMOUSE|SCSMALLFONT|SCFIXEDWIDTH|SCHORIZBAR);

	/* setup so that all fields are possible */
	for(j=0; j<14; j++)
	{
		required[j] = (char *)emalloc(200, el_tempcluster);
		strcpy(required[j], "*");
	}

	/* examine all of the fonts and make a lists of choices for each position */
	gra_makefontchoices(fontlist, namecount, required, &choices, &numchoices);
	for(j=0; j<14; j++)
	{
		DiaSetPopup(j*2+4, numchoices[j], choices[j]);
		DiaSetPopupEntry(j*2+4, 0);
	}

	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;
		if (itemHit >= 4 && itemHit <= 30 && (itemHit / 2) * 2 == itemHit)
		{
			/* popup changed */
			for(j=0; j<14; j++)
			{
				i = DiaGetPopupEntry(j*2+4);
				strcpy(required[j], choices[j][i]);
			}
			gra_makefontchoices(fontlist, namecount, required, &choices, &numchoices);
			for(j=0; j<14; j++)
			{
				DiaSetPopup(j*2+4, numchoices[j], choices[j]);
				for(i=0; i<numchoices[j]; i++)
					if (namesame(choices[j][i], required[j]) == 0) break;
				DiaSetPopupEntry(j*2+4, i);
			}
			continue;
		}
	}
	if (itemHit == OK)
	{
		i = DiaGetCurLine(31);
		strcpy(required[0], DiaGetScrollLine(31, i));
#ifdef USETIF
		entry = XmFontListEntryLoad(gra_msgdpy, required[0],
			XmFONT_IS_FONT, "TAG");
		xfontlist = XmFontListAppendEntry(NULL, entry);
		XmFontListEntryFree(&entry);
		XtSetArg(arg[0], XmNfontList, xfontlist);
		XtSetValues(gra_messageswidget, arg, 1);
		XmFontListFree(xfontlist);
#endif
	}
	DiaDoneDialog();
	XFreeFontPath(fontlist);

	/* free the memory */
	for(j=0; j<14; j++)
	{
		for(k=0; k<numchoices[j]; k++)
			efree((char *)choices[j][k]);
		efree((char *)required[j]);
	}
}

void gra_makefontchoices(char **fontlist, int namecount, char *required[14],
	char ****fchoices, INTBIG **fnumchoices)
{
	char *pt, *start, save, **newchoices;
	INTBIG i, j, k, newsize;
	INTSML sorted;
	static INTBIG totalchoices[14], numchoices[14];
	static char **choices[14], *current[14];
	static INTSML inited = 0;

	/* load the return parameters */
	*fchoices = (char ***)choices;
	*fnumchoices = (INTBIG *)numchoices;

	/* one-time memory allocation and initialization */
	if (inited == 0)
	{
		inited = 1;
		for(j=0; j<14; j++)
		{
			totalchoices[j] = 5;
			choices[j] = (char **)emalloc(5 * (sizeof (char *)),
				el_tempcluster);
			numchoices[j] = 0;
			current[j] = (char *)emalloc(200, el_tempcluster);
		}
	}

	/* initialize the popup choices */
	for(j=0; j<14; j++)
	{
		/* free former memory */
		for(k=0; k<numchoices[j]; k++)
			efree((char *)choices[j][k]);
		numchoices[j] = 1;
		choices[j][0] = (char *)emalloc(2, el_tempcluster);
		strcpy(choices[j][0], "*");
	}

	/* initialize the scroll area */
	DiaLoadTextDialog(31, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);

	/* examine each font and build the choice list */
	for(i=0; i<namecount; i++)
	{
		/* break the font name into fields, make sure it matches filter */
		pt = fontlist[i];
		for(j=0; j<14; j++)
		{
			if (*pt == '-') pt++;
			start = pt;
			while (*pt != 0 && *pt != '-') pt++;
			save = *pt;
			*pt = 0;
			if (*start == 0) strcpy(current[j], "(nil)"); else
				strcpy(current[j], start);
			*pt = save;
			if (required[j][0] == '*') continue;
			if (namesame(required[j], current[j]) != 0) break;
		}
		if (j < 14) continue;
		DiaStuffLine(31, fontlist[i]);

		/* add this to the list of choices */
		for(j=0; j<14; j++)
		{
			for(k=0; k<numchoices[j]; k++)
				if (namesame(current[j], choices[j][k]) == 0) break;
			if (k < numchoices[j]) continue;

			/* add this choice */
			if (numchoices[j] >= totalchoices[j])
			{
				newsize = totalchoices[j] * 2;
				newchoices = (char **)emalloc(newsize * (sizeof (char *)),
					el_tempcluster);
				for(k=0; k<numchoices[j]; k++)
					newchoices[k] = choices[j][k];
				efree((char *)choices[j]);
				choices[j] = newchoices;
				totalchoices[j] = newsize;
			}
			choices[j][numchoices[j]] = (char *)emalloc(strlen(current[j])+1,
				el_tempcluster);
			strcpy(choices[j][numchoices[j]], current[j]);
			numchoices[j]++;
		}
	}

	/* sort the choice lists */
	for(j=0; j<14; j++)
	{
		sorted = 0;
		while (sorted == 0)
		{
			sorted = 1;
			for(k=2; k<numchoices[j]; k++)
			{
				switch (j)
				{
					case 6:
					case 7:
					case 8:
					case 9:
					case 11:
						i = atoi(choices[j][k-1]) - atoi(choices[j][k]);
						break;
					default:
						i = namesame(choices[j][k-1], choices[j][k]);
						break;
				}
				if (i > 0)
				{
					pt = choices[j][k-1];
					choices[j][k-1] = choices[j][k];
					choices[j][k] = pt;
					sorted = 0;
				}
			}
		}
	}
	DiaSelectLine(31, -1);
}

/*
 * routine to cut text from the messages window if it is current.  Returns nonzero
 * if sucessful.
 */
INTSML cutfrommessages(void)
{
#ifdef USETIF
	XmTextCut(gra_messageswidget, 0);
#else
	Window win;
	int revert, length, i;
	XawTextPosition pos1, pos2;
	unsigned char *str;
	Arg arg;
	XawTextBlock tb;

	/* stop now if messages window is not on top */
	XGetInputFocus(gra_topmsgdpy, &win, &revert);
	if (win != gra_topmsgwin) return(0);

	/* store selection in cut buffer */
	XawTextGetSelectionPos(gra_messageswidget, &pos1, &pos2);
	length = pos2 - pos1;
	if (length <= 0) return(0);
	XtSetArg(arg, XtNstring, &str);
	XtGetValues(gra_messageswidget, &arg, 1);
	(void)initinfstr();
	for(i=pos1; i<pos2; i++) (void)addtoinfstr(str[i]);
	setcutbuffer(returninfstr());

	/* remove selected text */
	tb.firstPos = 0;
	tb.length = 0;
	tb.ptr = 0;
	tb.format = FMT8BIT;
	XawTextReplace(gra_messageswidget, pos1, pos2, &tb);
#endif
	return(1);
}

/*
 * routine to copy text from the messages window if it is current.  Returns nonzero
 * if sucessful.
 */
INTSML copyfrommessages(void)
{
#ifdef USETIF
	XmTextCopy(gra_messageswidget, 0);
#else
	Window win;
	int revert, length, i;
	XawTextPosition pos1, pos2;
	unsigned char *str;
	Arg arg;

	/* stop now if messages window is not on top */
	XGetInputFocus(gra_topmsgdpy, &win, &revert);
	if (win != gra_topmsgwin) return(0);

	/* store selection in cut buffer */
	XawTextGetSelectionPos(gra_messageswidget, &pos1, &pos2);
	length = pos2 - pos1;
	if (length <= 0) return(0);
	XtSetArg(arg, XtNstring, &str);
	XtGetValues(gra_messageswidget, &arg, 1);
	(void)initinfstr();
	for(i=pos1; i<pos2; i++) (void)addtoinfstr(str[i]);
	setcutbuffer(returninfstr());
#endif
	return(1);
}

/*
 * routine to paste text to the messages window if it is current.  Returns nonzero
 * if sucessful.
 */
INTSML pastetomessages(void)
{
#ifdef USETIF
	XmTextPaste(gra_messageswidget);
#else
	Window win;
	char *string;
	int revert;
	XawTextBlock tb;
	XawTextPosition pos1, pos2;

	/* stop now if messages window is not on top */
	XGetInputFocus(gra_topmsgdpy, &win, &revert);
	if (win != gra_topmsgwin) return(0);

	/* get cut buffer */
	string = getcutbuffer();

	/* insert cut buffer into messages window */
	tb.firstPos = 0;
	tb.length = strlen(string);
	tb.ptr = string;
	tb.format = FMT8BIT;
	XawTextGetSelectionPos(gra_messageswidget, &pos1, &pos2);
	XawTextReplace(gra_messageswidget, pos1, pos2, &tb);
	XawTextSetInsertionPoint(gra_messageswidget, pos1+tb.length);
#endif
	return(1);
}

/*
 * routine to get the contents of the system cut buffer
 */
char *getcutbuffer(void)
{
	int returned;
	char *string;

	/* get cut buffer */
	string = XFetchBuffer(gra_topmsgdpy, &returned, 0);
	(void)initinfstr();
	if (*string != 0) (void)addstringtoinfstr(string);
	XFree(string);
	return(returninfstr());
}

/*
 * routine to set the contents of the system cut buffer to "msg"
 */
void setcutbuffer(char *msg)
{
	XStoreBuffer(gra_topmsgdpy, msg, strlen(msg), 0);
}

/******************** GRAPHICS CONTROL ROUTINES ********************/

void flushscreen(void)
{
#ifdef ANYDEPTH
	int x, y, *drow32;
	short *drow16;
	unsigned char *srow, *drow;

	/* nothing to do if no changes have been made to offscreen buffer */
	if (gra_offscreendirty == 0) return;
	gra_offscreendirty = 0;

	/* get bounds of display update */
	if (gra_lowredrawx < 0) gra_lowredrawx = 0;
	if (gra_highredrawx > us_swid) gra_highredrawx = us_swid;
	if (gra_lowredrawy < 0) gra_lowredrawy = 0;
	if (gra_highredrawy > gra_shei) gra_highredrawy = gra_shei;

	/* copy from offscreen buffer to Ximage while doing color mapping */
	switch (gra_sdep)
	{
		case 8:
			for(y=gra_lowredrawy; y<gra_highredrawy; y++)
			{
				srow = (unsigned char *)(gra_rowstart[y] + gra_lowredrawx);
				drow = (unsigned char *)(gra_offrowstart[y] + gra_lowredrawx);
				for(x=gra_lowredrawx; x<gra_highredrawx; x++)
					*drow++ = gra_colorvalue[*srow++];
			}
			break;

		case 16:
			for(y=gra_lowredrawy; y<gra_highredrawy; y++)
			{
				srow = (unsigned char *)(gra_rowstart[y] + gra_lowredrawx);
				drow16 = (short *)(gra_offrowstart[y] + (gra_lowredrawx << 1));
				for(x=gra_lowredrawx; x<gra_highredrawx; x++)
					*drow16++ = gra_colorvalue[*srow++];
			}
			break;

		case 24:
		case 32:
			for(y=gra_lowredrawy; y<gra_highredrawy; y++)
			{
				srow = (unsigned char *)(gra_rowstart[y] + gra_lowredrawx);
				drow32 = (int *)(gra_offrowstart[y] + (gra_lowredrawx << 2));
				for(x=gra_lowredrawx; x<gra_highredrawx; x++)
					*drow32++ = gra_colorvalue[*srow++];
			}
			break;
	}

	/* copy XImage to the screen */
	XPutImage(gra_dpy, gra_win, gra_gc, gra_world, gra_lowredrawx,
		gra_lowredrawy, gra_lowredrawx, gra_lowredrawy,
		gra_highredrawx-gra_lowredrawx, gra_highredrawy-gra_lowredrawy);
	XFlush(gra_dpy);
#endif
}

#ifdef ANYDEPTH
/*
 * Routine to mark an area of the offscreen buffer as "changed".
 */
void gra_setrect(INTSML lx, INTSML hx, INTSML ly, INTSML hy)
{
	UINTBIG thistime;

	thistime = ticktime();
	if (gra_offscreendirty == 0)
	{
		gra_lowredrawx = lx;   gra_highredrawx = hx;
		gra_lowredrawy = ly;   gra_highredrawy = hy;
		gra_offscreendirty = 1;
		gra_starttime = thistime;
	} else
	{
		if (lx < gra_lowredrawx) gra_lowredrawx = lx;
		if (hx > gra_highredrawx) gra_highredrawx = hx;
		if (ly < gra_lowredrawy) gra_lowredrawy = ly;
		if (hy > gra_highredrawy) gra_highredrawy = hy;
	}

	/* flush the screen every two seconds */
	if (thistime - gra_starttime > FLUSHTICKS) flushscreen();
}
#endif

/*
 * Routine to change the default cursor (to indicate modes).
 */
void us_setnormalcursor(INTSML curs)
{
	us_normalcursor = curs;
	setdefaultcursortype(us_normalcursor);
}

void us_loadmap(INTBIG *red, INTBIG *green, INTBIG *blue, INTSML low, INTSML high)
{
#ifdef ANYDEPTH
	REGISTER INTSML i;
	REGISTER INTBIG r, g, b;
	XColor xc;

	if (us_dispstyle != COLORMAP) return;

	/* clip to the number of map entries requested */
	if (high >= el_maplength) high = el_maplength - 1;

	for(i=low; i<=high; i++)
	{
		xc.flags = DoRed | DoGreen | DoBlue;
		r = red[i-low];
		g = green[i-low];
		b = blue[i-low];

		/* always complement the highest color */
		if (low < 255 && i == 255)
		{
			r = 255 - red[i-low];
			g = 255 - green[i-low];
			b = 255 - blue[i-low];
		}

		/* for 16bpp, crop values to 5 bits */
		xc.red   = r << 8;
		xc.green = g << 8;
		xc.blue  = b << 8;

		/* if this is color-mapped, get closest entry in that map */
		if (VisualClass(gra_visual) == PseudoColor ||
			VisualClass(gra_visual) == StaticColor)
		{
			XAllocColor(gra_dpy, gra_defaultcmap, &xc);
			gra_colorvalue[i] = xc.pixel;
		} else
		{
			if (gra_sdep == 16)
			{
				gra_colorvalue[i] = ((r & 0xF8) << 8) |
					((g & 0xF8) << 3) | ((b & 0xF8) >> 3);
			} else
			{
				gra_colorvalue[i] = (b << 16) | (g << 8) | r;
			}
		}
	}

	/* mark the entire screen for redrawing */
	if (low == 0 && high == 255)
		gra_setrect(0, us_swid, 0, gra_shei);

	/* set the cursor color */
	if (low == 0 || (low <= el_colcursor && high >= el_colcursor))
	{
		gra_xfc.flags = gra_xbc.flags = DoRed | DoGreen | DoBlue;
		gra_xbc.red = red[0] << 8;
		gra_xbc.green = green[0] << 8;
		gra_xbc.blue = blue[0] << 8;
		gra_xfc.red = red[el_colcursor] << 8;
		gra_xfc.green = green[el_colcursor] << 8;
		gra_xfc.blue = blue[el_colcursor] << 8;
		gra_recolorcursor(&gra_xfc, &gra_xbc);
	}
#else
	REGISTER INTSML i;
	XColor xc[256];

	if (us_dispstyle != COLORMAP) return;

	/* clip to the number of map entries requested */
	if (high > gra_maphigh) high = gra_maphigh;

	for(i=low; i<=high; i++)
	{
		xc[i-low].flags = DoRed | DoGreen | DoBlue;
		xc[i-low].pixel = i;
		xc[i-low].red   =   red[i-low] << 8;
		xc[i-low].green = green[i-low] << 8;
		xc[i-low].blue  =  blue[i-low] << 8;

		/* always complement the highest color */
		if (low < 255 && i == 255)
		{
			xc[i-low].red   = (255 -   red[i-low]) << 8;
			xc[i-low].green = (255 - green[i-low]) << 8;
			xc[i-low].blue  = (255 -  blue[i-low]) << 8;
		}
	}

	XStoreColors(gra_dpy, gra_colormap, xc, high-low + 1);

	if (low == 0 || (low <= el_colcursor && high >= el_colcursor))
	{
		gra_xfc.pixel = el_colcursor;
		XQueryColor(gra_dpy, gra_colormap, &gra_xfc);
		gra_xbc.pixel = 0;
		XQueryColor(gra_dpy, gra_colormap, &gra_xbc);
		gra_recolorcursor(&gra_xfc, &gra_xbc);
	}
#endif
}

/*
 * Helper routine to change the cursor color.
 * fg and bg are the XColor structures to be used. We will look up the current
 * values for the cursor and the background from the installed color map, and
 * copy them into bg and fg.
 */
void gra_recolorcursor(XColor *fg, XColor *bg)
{
	XRecolorCursor(gra_dpy, gra_realcursor, fg, bg);
	XRecolorCursor(gra_dpy, gra_nomousecursor, fg, bg);
	XRecolorCursor(gra_dpy, gra_drawcursor, fg, bg);
	XRecolorCursor(gra_dpy, gra_nullcursor, fg, bg);
	XRecolorCursor(gra_dpy, gra_menucursor, fg, bg);
	XRecolorCursor(gra_dpy, gra_handcursor, fg, bg);
	XRecolorCursor(gra_dpy, gra_techcursor, fg, bg);
	XRecolorCursor(gra_dpy, gra_ibeamcursor, fg, bg);
}

#ifndef ANYDEPTH
/*
 * routine to load the global Graphic Context "gra_gcstip" with the
 * stipple pattern in "raster"
 */
void gra_loadstipple(UINTSML raster[])
{
	static Pixmap buildup = (Pixmap)NULL;
	static XImage ximage;
	static INTBIG data[8];
	static GC pgc;
	XGCValues gcv;
	REGISTER INTBIG y, pattern;
	static INTSML reverse = 0;   /* for debugging and testing */

	/* initialize raster structure for patterned write */
	if (buildup == (Pixmap)NULL)
	{
		buildup = XCreatePixmap(gra_dpy, gra_win, 32, 8, 1);
		if (gra_sdep != 1)
		{
			/* choose polarity of stipples */
#ifdef i386
			gcv.background = BlackPixel(gra_dpy, DefaultScreen(gra_dpy));
			gcv.foreground = WhitePixel(gra_dpy, DefaultScreen(gra_dpy));
#else
			gcv.foreground = BlackPixel(gra_dpy, DefaultScreen(gra_dpy));
			gcv.background = WhitePixel(gra_dpy, DefaultScreen(gra_dpy));
#endif
		} else
		{
			/* monochrome */
			gcv.foreground = us_black;
			gcv.background = us_white;
		}
		if (reverse)
		{
			y = gcv.foreground;
			gcv.foreground = gcv.background;
			gcv.background = y;
		}
		gcv.fill_style = FillStippled;
		pgc = XCreateGC(gra_dpy, buildup, GCForeground | GCBackground | GCFillStyle, &gcv);
		ximage.width = 32;
		ximage.height = 8;
		ximage.xoffset = 0;
		ximage.format = XYBitmap;
		ximage.data = (char *)data;
		ximage.byte_order = XImageByteOrder(gra_dpy);
		ximage.bitmap_unit = XBitmapUnit(gra_dpy);
		ximage.bitmap_bit_order = XBitmapBitOrder(gra_dpy);
		ximage.bitmap_pad = XBitmapPad(gra_dpy);
		ximage.depth = 1;
		ximage.bytes_per_line = 4;
	}

	for(y=0; y<8; y++)
	{
		pattern = raster[y] & 0xFFFF;
		data[y] = pattern | (pattern << 16);
	}

	XPutImage(gra_dpy, buildup, pgc, &ximage, 0, 0, 0, 0, 32, 8);
	XSetStipple(gra_dpy, gra_gcstip, buildup);
}
#endif

/*
 * Helper routine to set the cursor shape to "state".
 */
void setdefaultcursortype(INTSML state)
{
	if (us_cursorstate == state) return;

	switch (state)
	{
		case NORMALCURSOR:
			XDefineCursor(gra_topdpy, gra_topwin, gra_realcursor);
			break;
		case WANTTTYCURSOR:
			XDefineCursor(gra_topdpy, gra_topwin, gra_nomousecursor);
			break;
		case PENCURSOR:
			XDefineCursor(gra_topdpy, gra_topwin, gra_drawcursor);
			break;
		case NULLCURSOR:
			XDefineCursor(gra_topdpy, gra_topwin, gra_nullcursor);
			break;
		case MENUCURSOR:
			XDefineCursor(gra_topdpy, gra_topwin, gra_menucursor);
			break;
		case HANDCURSOR:
			XDefineCursor(gra_topdpy, gra_topwin, gra_handcursor);
			break;
		case TECHCURSOR:
			XDefineCursor(gra_topdpy, gra_topwin, gra_techcursor);
			break;
		case IBEAMCURSOR:
			XDefineCursor(gra_topdpy, gra_topwin, gra_ibeamcursor);
			break;
	}

	us_cursorstate = state;
}

/******************** GRAPHICS LINES ********************/

void us_drawline(WINDOWPART *win, INTSML x1, INTSML y1, INTSML x2, INTSML y2, GRAPHICS *desc,
	INTSML texture)
{
#ifdef ANYDEPTH
	REGISTER INTSML col, mask, lx, hx, ly, hy;
	static INTSML pat[] = {0xFF, 0x88, 0xE7, 0x80};

	/* get line type parameters */
	col = desc->col;         mask = ~desc->bits;
	y1 = gra_revy - y1;   y2 = gra_revy - y2;

	if (texture != 0) gra_drawpatline(x1, y1, x2, y2, col, mask, pat[texture]); else
		gra_drawline(x1, y1, x2, y2, col, mask);
	if (x1 < x2) { lx = x1;   hx = x2; } else { lx = x2;   hx = x1; }
	if (y1 < y2) { ly = y1;   hy = y2; } else { ly = y2;   hy = y1; }
	gra_setrect(lx, hx+1, ly, hy+1);
#else
	static INTSML on[] =  {0, 1, 6, 1};
	static INTSML off[] = {0, 3, 2, 7};
	static INTBIG linestyle[] = {LineSolid, LineOnOffDash, LineOnOffDash, LineOnOffDash};
	char dashes[2];

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	/* adjust the co-ordinates for display mapping */
	y1 = gra_revy - y1;
	y2 = gra_revy - y2;

	if (us_dispstyle == COLORMAP)
	{
		XSetPlaneMask(gra_dpy, gra_gc, desc->bits & gra_maphigh);
#ifdef sun
		/*
		 * strange OpenWindows bug requires that the width change in order to
		 * also change the line style
		 */
		XSetLineAttributes(gra_dpy, gra_gc, 1, linestyle[texture], CapButt, JoinMiter);
#endif
		XSetLineAttributes(gra_dpy, gra_gc, 0, linestyle[texture], CapButt, JoinMiter);

		if (texture != 0)
		{
			dashes[0] = on[texture];
			dashes[1] = off[texture];
			XSetDashes(gra_dpy, gra_gc, 0, dashes, 2);
		}

		XSetForeground(gra_dpy, gra_gc, desc->col);
		XDrawLine(gra_dpy, gra_win, gra_gc, x1, y1, x2, y2);
		return;
	}

	/* the rest is for monochrome */
	if ((desc->style[us_dispstyle] & NATURE) == PATTERNED)
	{
		gra_loadstipple(desc->raster);
		XSetForeground(gra_dpy, gra_gcstip, (desc->col) ? us_black : us_white);
		XDrawLine(gra_dpy, gra_win, gra_gcstip, x1, y1, x2, y2);
		return;
	}

	if (desc->bits == LAYERH)
	{
		XSetLineAttributes(gra_dpy, gra_gcinv, 0, linestyle[texture], CapButt, JoinMiter);
		if (texture != 0)
		{
			dashes[0] = on[texture];
			dashes[1] = off[texture];
			XSetDashes(gra_dpy, gra_gcinv, 0, dashes, 2);
		}
		XSetForeground(gra_dpy, gra_gcinv, (desc->col) ? us_black : us_white);
		XDrawLine(gra_dpy, gra_win, gra_gcinv, x1, y1, x2, y2);
		return;
	}

	XSetLineAttributes(gra_dpy, gra_gc, 0, linestyle[texture], CapButt, JoinMiter);
	if (texture != 0)
	{
		dashes[0] = on[texture];
		dashes[1] = off[texture];
		XSetDashes(gra_dpy, gra_gc, 0, dashes, 2);
	}
	XSetForeground(gra_dpy, gra_gc, (desc->col) ? us_black : us_white);
	XDrawLine(gra_dpy, gra_win, gra_gc, x1, y1, x2, y2);
#endif
}

#ifdef ANYDEPTH
void gra_drawpatline(INTSML x1, INTSML y1, INTSML x2, INTSML y2, INTSML col,
	INTSML mask, INTSML pattern)
{
	INTSML dx, dy, d, incr1, incr2, x, y, xend, yend, yincr, xincr, i;

	/* initialize counter for line style */
	i = 0;

	/* initialize the Bresenham algorithm */
	dx = abs(x2-x1);
	dy = abs(y2-y1);
	if (dx > dy)
	{
		/* initialize for lines that increment along X */
		incr1 = 2 * dy;
		d = incr2 = 2 * (dy - dx);
		if (x1 > x2)
		{
			x = x2;   y = y2;   xend = x1;   yend = y1;
		} else
		{
			x = x1;   y = y1;   xend = x2;   yend = y2;
		}
		if (yend < y) yincr = -1; else yincr = 1;
		gra_rowstart[y][x] = (gra_rowstart[y][x]&mask) | col;

		/* draw line that increments along X */
		while (x < xend)
		{
			x++;
			if (d < 0) d += incr1; else
			{
				y += yincr;   d += incr2;
			}
			if (i == 7) i = 0; else i++;
			if ((pattern & (1 << i)) == 0) continue;
			gra_rowstart[y][x] = (gra_rowstart[y][x]&mask) | col;
		}
	} else
	{
		/* initialize for lines that increment along Y */
		incr1 = 2 * dx;
		d = incr2 = 2 * (dx - dy);
		if (y1 > y2)
		{
			x = x2;   y = y2;   xend = x1;   yend = y1;
		} else
		{
			x = x1;   y = y1;   xend = x2;   yend = y2;
		}
		if (xend < x) xincr = -1; else xincr = 1;
		gra_rowstart[y][x] = (gra_rowstart[y][x]&mask) | col;

		/* draw line that increments along X */
		while (y < yend)
		{
			y++;
			if (d < 0) d += incr1; else
			{
				x += xincr;   d += incr2;
			}
			if (i == 7) i = 0; else i++;
			if ((pattern & (1 << i)) == 0) continue;
			gra_rowstart[y][x] = (gra_rowstart[y][x]&mask) | col;
		}
	}
}

void gra_drawline(INTSML x1, INTSML y1, INTSML x2, INTSML y2, INTSML col, INTSML mask)
{
	INTSML dx, dy, d, incr1, incr2, x, y, xend, yend, yincr, xincr;

	/* initialize the Bresenham algorithm */
	dx = abs(x2-x1);
	dy = abs(y2-y1);
	if (dx > dy)
	{
		/* initialize for lines that increment along X */
		incr1 = 2 * dy;
		d = incr2 = 2 * (dy - dx);
		if (x1 > x2)
		{
			x = x2;   y = y2;   xend = x1;   yend = y1;
		} else
		{
			x = x1;   y = y1;   xend = x2;   yend = y2;
		}
		if (yend < y) yincr = -1; else yincr = 1;
		gra_rowstart[y][x] = (gra_rowstart[y][x]&mask) | col;

		/* draw line that increments along X */
		while (x < xend)
		{
			x++;
			if (d < 0) d += incr1; else
			{
				y += yincr;   d += incr2;
			}
			gra_rowstart[y][x] = (gra_rowstart[y][x]&mask) | col;
		}
	} else
	{
		/* initialize for lines that increment along Y */
		incr1 = 2 * dx;
		d = incr2 = 2 * (dx - dy);
		if (y1 > y2)
		{
			x = x2;   y = y2;   xend = x1;   yend = y1;
		} else
		{
			x = x1;   y = y1;   xend = x2;   yend = y2;
		}
		if (xend < x) xincr = -1; else xincr = 1;
		gra_rowstart[y][x] = (gra_rowstart[y][x]&mask) | col;

		/* draw line that increments along X */
		while (y < yend)
		{
			y++;
			if (d < 0) d += incr1; else
			{
				x += xincr;   d += incr2;
			}
			gra_rowstart[y][x] = (gra_rowstart[y][x]&mask) | col;
		}
	}
}
#endif

void us_invertline(WINDOWPART *win, INTSML x1, INTSML y1, INTSML x2, INTSML y2)
{
#ifdef ANYDEPTH
	REGISTER INTSML lx, hx, ly, hy, dx, dy, d, incr1, incr2, x, y, xend, yend, yincr, xincr;

	/* get line type parameters */
	y1 = gra_revy - y1;   y2 = gra_revy - y2;

	/* initialize the Bresenham algorithm */
	dx = abs(x2-x1);
	dy = abs(y2-y1);
	if (dx > dy)
	{
		/* initialize for lines that increment along X */
		incr1 = 2 * dy;
		d = incr2 = 2 * (dy - dx);
		if (x1 > x2)
		{
			x = x2;   y = y2;   xend = x1;   yend = y1;
		} else
		{
			x = x1;   y = y1;   xend = x2;   yend = y2;
		}
		if (yend < y) yincr = -1; else yincr = 1;
		gra_rowstart[y][x] = ~gra_rowstart[y][x];

		/* draw line that increments along X */
		while (x < xend)
		{
			x++;
			if (d < 0) d += incr1; else
			{
				y += yincr;   d += incr2;
			}
			gra_rowstart[y][x] = ~gra_rowstart[y][x];
		}
	} else
	{
		/* initialize for lines that increment along Y */
		incr1 = 2 * dx;
		d = incr2 = 2 * (dx - dy);
		if (y1 > y2)
		{
			x = x2;   y = y2;   xend = x1;   yend = y1;
		} else
		{
			x = x1;   y = y1;   xend = x2;   yend = y2;
		}
		if (xend < x) xincr = -1; else xincr = 1;
		gra_rowstart[y][x] = ~gra_rowstart[y][x];

		/* draw line that increments along X */
		while (y < yend)
		{
			y++;
			if (d < 0) d += incr1; else
			{
				x += xincr;   d += incr2;
			}
			gra_rowstart[y][x] = ~gra_rowstart[y][x];
		}
	}
	if (x1 < x2) { lx = x1;   hx = x2; } else { lx = x2;   hx = x1; }
	if (y1 < y2) { ly = y1;   hy = y2; } else { ly = y2;   hy = y1; }
	gra_setrect(lx, (INTSML)(hx+1), ly, (INTSML)(hy+1));
#else
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	/* adjust the co-ordinates for display mapping */
	y1 = gra_revy - y1;
	y2 = gra_revy - y2;

	XSetPlaneMask(gra_dpy, gra_gcinv, LAYERH & gra_maphigh);
	XSetLineAttributes(gra_dpy, gra_gcinv, 0, LineSolid, CapButt, JoinMiter);
	XSetForeground(gra_dpy, gra_gcinv, HIGHLIT);
	XDrawLine(gra_dpy, gra_win, gra_gcinv, x1, y1, x2, y2);
#endif
}

/******************** GRAPHICS POLYGONS ********************/

void us_drawpolygon(WINDOWPART *win, INTBIG *x, INTBIG *y, INTSML count, GRAPHICS *desc)
{
#ifdef ANYDEPTH
	REGISTER INTBIG i, j, k, l, ycur, yrev, wrap, lx, hx, ly, hy;
	REGISTER char *row;
	REGISTER INTSML col, mask, style, pat;
	REGISTER POLYSEG *a, *active, *edge, *lastedge, *left, *edgelist;

	/* get parameters */
	col = desc->col;   mask = ~desc->bits;
	style = desc->style[COLORMAP] & NATURE;

	/* set redraw area */
	for(i=0; i<count; i++)
	{
		if (i == 0)
		{
			lx = hx = x[i];
			ly = hy = y[i];
		} else
		{
			lx = mini(lx, x[i]);
			hx = maxi(hx, x[i]);
			ly = mini(ly, y[i]);
			hy = maxi(hy, y[i]);
		}
	}
	gra_setrect((INTSML)lx, (INTSML)(hx + 1), (INTSML)(gra_revy-hy),
		(INTSML)(gra_revy-ly + 1));

	/* make sure there is room in internal structures */
	if (count > gra_polysegcount)
	{
		if (gra_polysegcount > 0) efree((char *)gra_polysegs);
		gra_polysegcount = 0;
		gra_polysegs = (POLYSEG *)emalloc(count * (sizeof (POLYSEG)), us_aid->cluster);
		if (gra_polysegs == 0) return;
		gra_polysegcount = count;
	}

	/* fill in internal structures */
	edgelist = NOPOLYSEG;
	for(i=0; i<count; i++)
	{
		if (i == 0)
		{
			gra_polysegs[i].fx = x[count-1];
			gra_polysegs[i].fy = y[count-1];
		} else
		{
			gra_polysegs[i].fx = x[i-1];
			gra_polysegs[i].fy = y[i-1];
		}
		gra_polysegs[i].tx = x[i];   gra_polysegs[i].ty = y[i];
		gra_polysegs[i].index = i;

		/* compute the direction of this edge */
		j = gra_polysegs[i].ty - gra_polysegs[i].fy;
		if (j > 0) gra_polysegs[i].direction = 1; else
			if (j < 0) gra_polysegs[i].direction = -1; else
				gra_polysegs[i].direction = 0;

		/* compute the X increment of this edge */
		if (j == 0) gra_polysegs[i].increment = 0; else
		{
			gra_polysegs[i].increment = gra_polysegs[i].tx - gra_polysegs[i].fx;
			if (gra_polysegs[i].increment != 0) gra_polysegs[i].increment =
				(gra_polysegs[i].increment * 65536 - j + 1) / j;
		}
		gra_polysegs[i].tx <<= 16;   gra_polysegs[i].fx <<= 16;

		/* make sure "from" is above "to" */
		if (gra_polysegs[i].fy > gra_polysegs[i].ty)
		{
			j = gra_polysegs[i].tx;
			gra_polysegs[i].tx = gra_polysegs[i].fx;
			gra_polysegs[i].fx = j;
			j = gra_polysegs[i].ty;
			gra_polysegs[i].ty = gra_polysegs[i].fy;
			gra_polysegs[i].fy = j;
		}

		/* insert this edge into the edgelist, sorted by ascending "fy" */
		if (edgelist == NOPOLYSEG)
		{
			edgelist = &gra_polysegs[i];
			gra_polysegs[i].nextedge = NOPOLYSEG;
		} else
		{
			/* insert by ascending "fy" */
			if (edgelist->fy > gra_polysegs[i].fy)
			{
				gra_polysegs[i].nextedge = edgelist;
				edgelist = &gra_polysegs[i];
			} else for(a = edgelist; a != NOPOLYSEG; a = a->nextedge)
			{
				if (a->nextedge == NOPOLYSEG ||
					a->nextedge->fy > gra_polysegs[i].fy)
				{
					/* insert after this */
					gra_polysegs[i].nextedge = a->nextedge;
					a->nextedge = &gra_polysegs[i];
					break;
				}
			}
		}
	}

	/* scan polygon and render */
	active = NOPOLYSEG;
	while (active != NOPOLYSEG || edgelist != NOPOLYSEG)
	{
		if (active == NOPOLYSEG)
		{
			active = edgelist;
			active->nextactive = NOPOLYSEG;
			edgelist = edgelist->nextedge;
			ycur = active->fy;
		}

		/* introduce edges from edge list into active list */
		while (edgelist != NOPOLYSEG && edgelist->fy <= ycur)
		{
			/* insert "edgelist" into active list, sorted by "fx" coordinate */
			if (active->fx > edgelist->fx ||
				(active->fx == edgelist->fx && active->increment > edgelist->increment))
			{
				edgelist->nextactive = active;
				active = edgelist;
				edgelist = edgelist->nextedge;
			} else for(a = active; a != NOPOLYSEG; a = a->nextactive)
			{
				if (a->nextactive == NOPOLYSEG ||
					a->nextactive->fx > edgelist->fx ||
						(a->nextactive->fx == edgelist->fx &&
							a->nextactive->increment > edgelist->increment))
				{
					/* insert after this */
					edgelist->nextactive = a->nextactive;
					a->nextactive = edgelist;
					edgelist = edgelist->nextedge;
					break;
				}
			}
		}

		/* generate regions to be filled in on current scan line */
		wrap = 0;
		left = active;
		for(edge = active; edge != NOPOLYSEG; edge = edge->nextactive)
		{
			wrap = wrap + edge->direction;
			if (wrap == 0)
			{
				j = (left->fx + 32768) >> 16;
				k = (edge->fx + 32768) >> 16;
				yrev = gra_revy - ycur;
				row = gra_rowstart[yrev];
				if (style == PATTERNED)
				{
					/* patterned fill */
					pat = desc->raster[yrev&7];
					if (pat != 0)
					{
						for(l=j; l<=k; l++)
						{
							if ((pat & (1 << (15-(l&15)))) != 0)
								row[l] = (row[l] & mask) | col;
						}
					}
				} else
				{
					/* solid fill */
					for(l=j; l<=k; l++)
						row[l] = (row[l] & mask) | col;
				}
				left = edge->nextactive;
			}
		}
		ycur++;

		/* update edges in active list */
		lastedge = NOPOLYSEG;
		for(edge = active; edge != NOPOLYSEG; edge = edge->nextactive)
		{
			if (ycur >= edge->ty)
			{
				if (lastedge == NOPOLYSEG) active = edge->nextactive;
					else lastedge->nextactive = edge->nextactive;
			} else
			{
				edge->fx += edge->increment;
				lastedge = edge;
			}
		}
	}
#else
	static XPoint *pointlist;
	static INTSML pointcount = 0;
	REGISTER INTSML i;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	if (count > pointcount)
	{
		if (pointcount != 0) efree((char *)pointlist);
		pointcount = 0;
		pointlist = (XPoint *)emalloc(count * (sizeof (XPoint)), us_aid->cluster);
		if (pointlist == 0) return;
		pointcount = count;
	}

	for(i=0; i<count; i++)
	{
		pointlist[i].x = x[i];
		pointlist[i].y = gra_revy - y[i];
	}

	if ((desc->style[us_dispstyle] & NATURE) == PATTERNED && desc->col != 0)
	{
		gra_loadstipple(desc->raster);
		if (us_dispstyle == COLORMAP)
		{
			XSetPlaneMask(gra_dpy, gra_gcstip, desc->bits & gra_maphigh);
			XSetForeground(gra_dpy, gra_gcstip, desc->col);
		} else
		{
			XSetForeground(gra_dpy, gra_gcstip, (desc->col) ? us_black : us_white);
		}
		XFillPolygon(gra_dpy, gra_win, gra_gcstip, pointlist, count, Complex,
			CoordModeOrigin);
	} else
	{
		if (us_dispstyle == COLORMAP)
		{
			XSetPlaneMask(gra_dpy, gra_gc, desc->bits & gra_maphigh);
			XSetForeground(gra_dpy, gra_gc, desc->col);
		} else
		{
			XSetForeground(gra_dpy, gra_gc, (desc->col) ? us_black : us_white);
		}
		XFillPolygon(gra_dpy, gra_win, gra_gc, pointlist, count, Complex, CoordModeOrigin);
	}
#endif
}

/******************** GRAPHICS BOXES ********************/

void us_drawbox(WINDOWPART *win, INTSML lowx, INTSML highx, INTSML lowy, INTSML highy,
	GRAPHICS *desc)
{
#ifdef ANYDEPTH
	INTSML col, mask, style, x, y, left, right, bottom, top, pat;
	char *thisrow;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	/* get graphics parameters */
	col = desc->col;   mask = ~desc->bits;
	style = desc->style[COLORMAP] & NATURE;
	left = lowx;                  right = highx + 1;
	bottom = gra_revy-lowy + 1;   top = gra_revy-highy;

	/* handle color drawing */
	if (style == PATTERNED)
	{
		/* special case the patterned fill */
		for(y=top; y<bottom; y++)
		{
			pat = desc->raster[y&7];
			if (pat == 0) continue;
			thisrow = gra_rowstart[y];
			for(x=left; x<right; x++)
			{
				if ((pat & (1 << (15-(x&15)))) != 0)
					thisrow[x] = (thisrow[x] & mask) | col;
			}
		}
	} else
	{
		for(y=top; y<bottom; y++)
		{
			thisrow = gra_rowstart[y];
			for(x=left; x<right; x++)
				thisrow[x] = (thisrow[x] & mask) | col;
		}
	}
	gra_setrect(left, right, top, bottom);
#else
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	/* special code for patterned writes */
	if ((desc->style[us_dispstyle] & NATURE) == PATTERNED && desc->col != 0)
	{
		gra_loadstipple(desc->raster);
		if (us_dispstyle == COLORMAP)
		{
			XSetPlaneMask(gra_dpy, gra_gcstip, desc->bits & gra_maphigh);
			XSetForeground(gra_dpy, gra_gcstip, desc->col);
		} else
		{
			XSetForeground(gra_dpy, gra_gcstip, (desc->col) ? us_black : us_white);
		}
		XFillRectangle(gra_dpy, gra_win, gra_gcstip, lowx, gra_revy - highy,
			highx - lowx + 1, highy-lowy + 1);
#ifdef sun
		/*
		 * there seems to be a bug in OpenWindows: the right edge of stipple
		 * patterns goes haywire if the pattern is more than 32 pixels wide
		 */
		if (highx - lowx + 1 > 32)
		{
			XFillRectangle(gra_dpy, gra_win, gra_gcstip, highx - 31,
				gra_revy - highy, 32, highy - lowy + 1);
		}
#endif
	} else
	{
		if (us_dispstyle == COLORMAP)
		{
			XSetPlaneMask(gra_dpy, gra_gc, desc->bits & gra_maphigh);
			XSetForeground(gra_dpy, gra_gc, desc->col);
		} else
		{
			XSetForeground(gra_dpy, gra_gc, (desc->col) ? us_black : us_white);
		}
		XFillRectangle(gra_dpy, gra_win, gra_gc, lowx, gra_revy - highy,
			highx - lowx + 1, highy - lowy + 1);
	}
#endif
}

/*
 * routine to invert the bits in the box from (lowx, lowy) to (highx, highy)
 */
void us_invertbox(WINDOWPART *win, INTSML lowx, INTSML highx, INTSML lowy, INTSML highy)
{
#ifdef ANYDEPTH
	REGISTER INTSML top, bottom, left, right, x, y;
	REGISTER char *thisrow;

	left = lowx;
	right = highx + 1;
	bottom = gra_revy - lowy + 1;
	top = gra_revy - highy;
	if (top < 0) top = 0;

	for(y=top; y<bottom; y++)
	{
		thisrow = gra_rowstart[y];
		for(x=left; x<right; x++) thisrow[x] = ~thisrow[x];
	}

	gra_setrect(left, right, top, bottom);
#else
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	XSetPlaneMask(gra_dpy, gra_gcinv, AllPlanes);
	XFillRectangle(gra_dpy, gra_win, gra_gcinv, lowx, gra_revy - highy,
		highx - lowx + 1, highy - lowy + 1);
#endif
}

/*
 * routine to move bits on the display starting with the area at
 * (sx,sy) and ending at (dx,dy).  The size of the area to be
 * moved is "wid" by "hei".
 */
void us_movebox(WINDOWPART *win, INTSML sx, INTSML sy, INTSML wid, INTSML hei,
	INTSML dx, INTSML dy)
{
#ifdef ANYDEPTH
	INTSML fleft, fright, ftop, fbottom, tleft, tright, ttop, tbottom;
	INTSML xsize, ysize, x, y, dir, fromstart, frominc, tostart, toinc;
	REGISTER char *frombase, *tobase;

	/* setup source rectangle */
	fleft = sx;
	fright = fleft + wid;
	ftop = gra_revy + 1 - sy - hei;
	fbottom = ftop + hei;

	/* setup destination rectangle */
	tleft = dx;
	tright = tleft + wid;
	ttop = gra_revy + 1 - dy - hei;
	tbottom = ttop + hei;

	/* determine size of bits to move */
	xsize = wid;   ysize = hei;

	/* determine direction of bit copy */
	if (fleft < tleft) dir = 1; else dir = 0;
	if (ftop < ttop)
	{
		fromstart = fbottom-1;   frominc = -1;
		tostart = tbottom-1;       toinc = -1;
	} else
	{
		fromstart = ftop;   frominc = 1;
		tostart = ttop;       toinc = 1;
	}

	/* move the bits */
	if (dir == 0)
	{
		/* normal forward copy in X */
		for(y = 0; y < ysize; y++)
		{
			frombase = gra_rowstart[fromstart] + fleft;
			fromstart += frominc;
			tobase = gra_rowstart[tostart] + tleft;
			tostart += toinc;
			for(x = 0; x < xsize; x++) *tobase++ = *frombase++;
		}
	} else
	{
		/* reverse copy in X */
		for(y = 0; y < ysize; y++)
		{
			frombase = gra_rowstart[fromstart] + fright;
			fromstart += frominc;
			tobase = gra_rowstart[tostart] + tright;
			tostart += toinc;
			for(x = 0; x < xsize; x++) *tobase-- = *frombase--;
		}
	}
	gra_setrect(tleft, tright, ttop, tbottom);
#else
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	/* make sure all bit planes are copied */
	if (us_dispstyle == COLORMAP) XSetPlaneMask(gra_dpy, gra_gc, AllPlanes);

	XCopyArea(gra_dpy, gra_win, gra_win, gra_gc, sx, gra_revy + 1 - sy - hei,
			  wid, hei, dx, gra_revy + 1 - dy - hei);
#endif
}

/*
 * routine to save the contents of the box from "lx" to "hx" in X and from
 * "ly" to "hy" in Y.  A code is returned that identifies this box for
 * overwriting and restoring.  The routine returns negative if there is a error.
 */
INTBIG us_savebox(WINDOWPART *win, INTSML lx, INTSML hx, INTSML ly, INTSML hy)
{
#ifdef ANYDEPTH
	SAVEDBOX *box;
	REGISTER INTSML i, x, y;
	REGISTER INTBIG xsize, ysize, toindex;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return(-1);

	i = ly;   ly = gra_revy-hy;   hy = gra_revy-i;
	xsize = hx-lx+1;
	ysize = hy-ly+1;

	box = (SAVEDBOX *)emalloc((sizeof (SAVEDBOX)), us_aid->cluster);
	if (box == 0) return(-1);
	box->pix = (char *)emalloc(xsize * ysize, us_aid->cluster);
	if (box->pix == 0) return(-1);
	box->nextsavedbox = gra_firstsavedbox;
	gra_firstsavedbox = box;
	box->lx = lx;           box->hx = hx;
	box->ly = ly;           box->hy = hy;

	/* move the bits */
	toindex = 0;
	for(y = ly; y <= hy; y++)
	{
		for(x = lx; x <= hx; x++)
			box->pix[toindex++] = gra_rowstart[y][x];
	}

	return((INTBIG)box);
#else
	SAVEDBOX *box;
	REGISTER INTSML i;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return(-1);

	i = ly;
	ly = gra_revy - hy;
	hy = gra_revy - i;

	box = (SAVEDBOX *)emalloc((sizeof (SAVEDBOX)), us_aid->cluster);
	if (box == 0) return(-1);

	box->pix = XCreatePixmap(gra_dpy, gra_win, hx - lx + 1, hy - ly + 1, gra_sdep);
	if (box->pix == 0) return(-1);

	box->nextsavedbox = gra_firstsavedbox;
	gra_firstsavedbox = box;
	gra_savedboxcodes++;
	box->code = gra_savedboxcodes;
	box->lx = lx;
	box->hx = hx;
	box->ly = ly;
	box->hy = hy;

	/* make sure the whole buffer is accessable */
	if (us_dispstyle == COLORMAP) XSetPlaneMask(gra_dpy, gra_gc, AllPlanes);

	XCopyArea(gra_dpy, gra_win, box->pix, gra_gc, lx, ly, hx - lx + 1, hy - ly + 1, 0, 0);

	return(box->code);
#endif
}

/*
 * routine to shift the saved box "code" so that it is restored in a different
 * lcoation, offset by (dx,dy)
 */
void us_movesavedbox(INTBIG code, INTSML dx, INTSML dy)
{
	REGISTER SAVEDBOX *box;

#ifdef ANYDEPTH
	box = (SAVEDBOX *)code;
#else
	for(box = gra_firstsavedbox; box != NOSAVEDBOX; box = box->nextsavedbox)
		if (box->code == code) break;
	if (box == NOSAVEDBOX) return;
#endif
	box->lx += dx;       box->hx += dx;
	box->ly -= dy;       box->hy -= dy;
}

/*
 * routine to restore saved box "code" to the screen.  "destroy" is:
 *  0   restore box, do not free memory
 *  1   restore box, free memory
 * -1   free memory
 * Returns nonzero if there is an error.
 */
INTSML us_restorebox(INTBIG code, INTSML destroy)
{
#ifdef ANYDEPTH
	REGISTER SAVEDBOX *box, *lbox, *tbox;
	REGISTER INTBIG fromindex;
	REGISTER INTSML x, y;

	/* get the box */
	if (code == -1) return(1);
	box = (SAVEDBOX *)code;

	/* move the bits */
	if (destroy >= 0)
	{
		fromindex = 0;
		for(y = box->ly; y <= box->hy; y++)
			for(x = box->lx; x <= box->hx; x++)
				gra_rowstart[y][x] = box->pix[fromindex++];
		gra_setrect(box->lx, box->hx+1, box->ly, box->hy+1);
	}

	/* destroy this box's memory if requested */
	if (destroy != 0)
	{
		lbox = NOSAVEDBOX;
		for(tbox = gra_firstsavedbox; tbox != NOSAVEDBOX; tbox = tbox->nextsavedbox)
		{
			if (tbox == box) break;
			lbox = tbox;
		}
		if (lbox == NOSAVEDBOX) gra_firstsavedbox = box->nextsavedbox; else
			lbox->nextsavedbox = box->nextsavedbox;
		efree((char *)box->pix);
		efree((char *)box);
	}
	return(0);
#else
	REGISTER SAVEDBOX *box, *lbox;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return(1);

	/* find the box corresponding to the "code" */
	lbox = NOSAVEDBOX;
	for(box = gra_firstsavedbox; box != NOSAVEDBOX; box = box->nextsavedbox)
	{
		if (box->code == code) break;
		lbox = box;
	}
	if (box == NOSAVEDBOX) return(1);

	if (destroy >= 0)
	{
		/* make sure the whole buffer is accessable */
		if (us_dispstyle == COLORMAP) XSetPlaneMask(gra_dpy, gra_gc, AllPlanes);

		/* restore the bits in the box */
		XCopyArea(gra_dpy, box->pix, gra_win, gra_gc, 0, 0, box->hx - box->lx + 1,
			box->hy - box->ly + 1, box->lx, box->ly);
	}

	/* destroy this box's memory if requested */
	if (destroy != 0)
	{
		if (lbox == NOSAVEDBOX)
		{
			gra_firstsavedbox = box->nextsavedbox;
		} else
		{
			lbox->nextsavedbox = box->nextsavedbox;
		}
		XFreePixmap(gra_dpy, box->pix);
		efree((char *)box);
	}
	return(0);
#endif
}

/******************** GRAPHICS TEXT ********************/

void us_settextsize(WINDOWPART *win, INTSML fnt)
{
	if (us_dispstyle < 0) return;

	if (fnt > TXT20P)
	{
		switch (fnt)
		{
			case TXTSMALL:  gra_curfontnumber = 1;   break;
			case TXTMEDIUM: gra_curfontnumber = 4;   break;
			case TXTLARGE:  gra_curfontnumber = 7;   break;
			case TXTMENU:   gra_curfontnumber = 9;   break;
			case TXTEDITOR: gra_curfontnumber = 10;  break;
			case TXTSTATUS: gra_curfontnumber = 11;  break;
			default:        gra_curfontnumber = 0;   break;
		}
	} else
	{
		gra_curfontnumber = fnt;
	}
	gra_curfont = gra_font[gra_curfontnumber].font;
}

void us_textsize(WINDOWPART *win, char *str, INTSML *x, INTSML *y)
{
#ifdef ANYDEPTH
	INTSML thechar, i, width, len;

	if (us_dispstyle < 0) return;

	len = strlen(str);
	if (len == 0)
	{
		*x = *y = 0;
		return;
	}

	width = 0;
	for(i=0; i<len; i++)
	{
		thechar = str[i] & 0177;
		if (thechar < ' ') thechar = ' ';
		width += gra_font[gra_curfontnumber].width[thechar];
	}
	*x = width;
	*y = gra_font[gra_curfontnumber].height[thechar];
#else
	int direction, asc, desc, len;
	XCharStruct xcs;

	if (us_dispstyle < 0) return;

	len = strlen(str);
	XTextExtents(gra_curfont, str, len, &direction, &asc, &desc, &xcs);
	*x = xcs.width;
	*y = gra_curfont->ascent + gra_curfont->descent;
#endif
}

void us_puttext(WINDOWPART *win, INTSML atx, INTSML aty, char *s, GRAPHICS *desc)
{
#ifdef ANYDEPTH
	REGISTER INTSML i, len, col, top, bottom, left, right, mask, hei, pos,
		x, y, thechar, height, width;
	REGISTER char *ptr, *dest;

	/* quit if string is null */
	len = strlen(s);
	if (len == 0) return;

	/* get parameters */
	col = desc->col;   mask = ~desc->bits;
	aty = gra_revy - aty;

	/* see if text is too high */
	thechar = s[0] & 0177;
	if (thechar < ' ') thechar = ' ';
	hei = gra_font[gra_curfontnumber].height[thechar];
	if (aty-hei <= 0) return;

	/* write the text */
	left = atx;
	pos = aty - hei;
	for(i=0; i<len; i++)
	{
		thechar = s[i] & 0177;
		if (thechar < ' ') thechar = ' ';
		width = gra_font[gra_curfontnumber].width[thechar];
		height = gra_font[gra_curfontnumber].height[thechar];
		ptr = gra_font[gra_curfontnumber].data[thechar];
		for(y=0; y<height; y++)
		{
			dest = gra_rowstart[pos+y];
			for(x=0; x<width; x++)
			{
				if (*ptr++ == 0) continue;
				dest[atx + x] = (dest[atx + x] & mask) | col;
			}
		}
		atx += width;
	}

	/* set redraw area */
	right = atx;
	bottom = aty;   top = bottom - hei;
	gra_setrect(left, right, top, bottom);
#else
	INTSML i, l;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	l = strlen(s);
	for(i=0; i<l; i++)
	{
		gra_localstring[i] = s[i] & 0177;
		if (gra_localstring[i] < ' ') gra_localstring[i] = ' ';
	}

	/* we have to wait for the window to be visible */

	/* special case for highlight layer: always complement the data */
	if (desc->bits == LAYERH)
	{
		XSetPlaneMask(gra_dpy, gra_gc, AllPlanes);
		XSetFont(gra_dpy, gra_gcinv, gra_curfont->fid);
		XDrawString(gra_dpy, gra_win, gra_gcinv, atx,
			gra_revy - aty - gra_curfont->descent, gra_localstring, l);
		return;
	}

	if (us_dispstyle == COLORMAP)
	{
		XSetPlaneMask(gra_dpy, gra_gc, desc->bits & gra_maphigh);
		XSetForeground(gra_dpy, gra_gc, desc->col);
	} else
	{
		XSetForeground(gra_dpy, gra_gc, (desc->col) ? us_black : us_white);
	}
	XSetFont(gra_dpy, gra_gc, gra_curfont->fid);
	XDrawString(gra_dpy, gra_win, gra_gc, atx,
		gra_revy - aty - gra_curfont->descent, gra_localstring, l);
#endif
}

/******************** CIRCLES ********************/

void us_drawcircle(WINDOWPART *win, INTBIG atx, INTBIG aty, INTBIG radius, GRAPHICS *desc)
{
#ifdef ANYDEPTH
	REGISTER INTSML col, mask, top, bottom, left, right;
	REGISTER INTBIG x, y, d, maxx, maxy, thisx, thisy;
	REGISTER char *thisrow;

	/* get parameters */
	col = desc->col;   mask = ~desc->bits;
	aty = gra_revy - aty;

	/* set redraw area */
	left = (INTSML)(atx - radius);
	right = (INTSML)(atx + radius + 1);
	top = (INTSML)(aty - radius);
	bottom = (INTSML)(aty + radius + 1);
	gra_setrect(left, right, top, bottom);

	maxx = us_swid;
	maxy = us_shei;
	x = 0;   y = radius;
	d = 3 - 2 * radius;
	if (left >= 0 && right < maxx && top >= 0 && bottom < maxy)
	{
		/* no clip version is faster */
		while (x <= y)
		{
			thisrow = gra_rowstart[aty + y];
			thisrow[atx + x] = (thisrow[atx + x] & mask) | col;
			thisrow[atx - x] = (thisrow[atx - x] & mask) | col;

			thisrow = gra_rowstart[aty - y];
			thisrow[atx + x] = (thisrow[atx + x] & mask) | col;
			thisrow[atx - x] = (thisrow[atx - x] & mask) | col;

			thisrow = gra_rowstart[aty + x];
			thisrow[atx + y] = (thisrow[atx + y] & mask) | col;
			thisrow[atx - y] = (thisrow[atx - y] & mask) | col;

			thisrow = gra_rowstart[aty - x];
			thisrow[atx + y] = (thisrow[atx + y] & mask) | col;
			thisrow[atx - y] = (thisrow[atx - y] & mask) | col;

			if (d < 0) d += 4*x + 6; else
			{
				d += 4 * (x-y) + 10;
				y--;
			}
			x++;
		}
	} else
	{
		/* clip version */
		while (x <= y)
		{
			thisy = aty + y;
			if (thisy >= 0 && thisy < maxy)
			{
				thisrow = gra_rowstart[thisy];
				thisx = atx + x;
				if (thisx >= 0 && thisx < maxx)
					thisrow[thisx] = (thisrow[thisx] & mask) | col;
				thisx = atx - x;
				if (thisx >= 0 && thisx < maxx)
					thisrow[thisx] = (thisrow[thisx] & mask) | col;
			}

			thisy = aty - y;
			if (thisy >= 0 && thisy < maxy)
			{
				thisrow = gra_rowstart[thisy];
				thisx = atx + x;
				if (thisx >= 0 && thisx < maxx)
					thisrow[thisx] = (thisrow[thisx] & mask) | col;
				thisx = atx - x;
				if (thisx >= 0 && thisx < maxx)
					thisrow[thisx] = (thisrow[thisx] & mask) | col;
			}

			thisy = aty + x;
			if (thisy >= 0 && thisy < maxy)
			{
				thisrow = gra_rowstart[thisy];
				thisx = atx + y;
				if (thisx >= 0 && thisx < maxx)
					thisrow[thisx] = (thisrow[thisx] & mask) | col;
				thisx = atx - y;
				if (thisx >= 0 && thisx < maxx)
					thisrow[thisx] = (thisrow[thisx] & mask) | col;
			}

			thisy = aty - x;
			if (thisy >= 0 && thisy < maxy)
			{
				thisrow = gra_rowstart[thisy];
				thisx = atx + y;
				if (thisx >= 0 && thisx < maxx)
					thisrow[thisx] = (thisrow[thisx] & mask) | col;
				thisx = atx - y;
				if (thisx >= 0 && thisx < maxx)
					thisrow[thisx] = (thisrow[thisx] & mask) | col;
			}

			if (d < 0) d += 4*x + 6; else
			{
				d += 4 * (x-y) + 10;
				y--;
			}
			x++;
		}
	}
#else
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	if (us_dispstyle == COLORMAP)
	{
		XSetPlaneMask(gra_dpy, gra_gc, desc->bits & gra_maphigh);
		XSetForeground(gra_dpy, gra_gc, desc->col);
	} else
	{
		XSetForeground(gra_dpy, gra_gc, (desc->col) ? us_black : us_white);
	}
	XDrawArc(gra_dpy, gra_win, gra_gc, atx - radius, gra_revy - aty - radius,
			 radius*2, radius*2, 0, 360*64);
#endif
}

#ifdef ANYDEPTH
/*
 * routine to draw a filled-in circle of radius "radius"
 */
void gra_drawdiscrow(INTBIG thisy, INTBIG startx, INTBIG endx, GRAPHICS *desc)
{
	REGISTER char *thisrow;
	REGISTER INTBIG x;
	REGISTER INTSML pat;

	if (thisy < 0 || thisy >= gra_curvemaxy) return;
	thisrow = gra_rowstart[thisy];
	if (startx < 0) startx = 0;
	if (endx >= gra_curvemaxx) endx = gra_curvemaxy - 1;
	if (gra_curvestyle == PATTERNED)
	{
		pat = desc->raster[thisy&7];
		if (pat != 0)
		{
			for(x=startx; x<=endx; x++)
				if ((pat & (1 << (15-(x&15)))) != 0)
					thisrow[x] = (thisrow[x] & gra_curvemask) | gra_curvecol;
		}
	} else
	{
		for(x=startx; x<=endx; x++)
			thisrow[x] = (thisrow[x] & gra_curvemask) | gra_curvecol;
	}
}
#endif

/*
 * routine to draw a filled-in circle of radius "radius"
 */
void us_drawdisc(WINDOWPART *win, INTBIG atx, INTBIG aty, INTBIG radius, GRAPHICS *desc)
{
#ifdef ANYDEPTH
	REGISTER INTBIG x, y, d;
	REGISTER INTSML top, bottom, left, right;

	/* get parameters */
	gra_curvestyle = desc->style[COLORMAP] & NATURE;
	gra_curvecol = desc->col;   gra_curvemask = ~desc->bits;

	/* set redraw area */
	aty = gra_revy - aty;
	left = (INTSML)(atx - radius);
	right = (INTSML)(atx + radius + 1);
	top = (INTSML)(aty - radius);
	bottom = (INTSML)(aty + radius + 1);
	gra_setrect(left, right, top, bottom);

	gra_curvemaxx = us_swid;
	gra_curvemaxy = us_shei;
	x = 0;   y = radius;
	d = 3 - 2 * radius;
	while (x <= y)
	{
		gra_drawdiscrow(aty+y, atx-x, atx+x, desc);
		gra_drawdiscrow(aty-y, atx-x, atx+x, desc);
		gra_drawdiscrow(aty+x, atx-y, atx+y, desc);
		gra_drawdiscrow(aty-x, atx-y, atx+y, desc);

		if (d < 0) d += 4*x + 6; else
		{
			d += 4 * (x-y) + 10;
			y--;
		}
		x++;
	}
#else
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	if ((desc->style[us_dispstyle] & NATURE) == PATTERNED && desc->col != 0)
	{
		gra_loadstipple(desc->raster);
		if (us_dispstyle == COLORMAP)
		{
			XSetPlaneMask(gra_dpy, gra_gcstip, desc->bits & gra_maphigh);
			XSetForeground(gra_dpy, gra_gcstip, desc->col);
		} else
		{
			XSetForeground(gra_dpy, gra_gcstip, (desc->col) ? us_black : us_white);
		}
		XFillArc(gra_dpy, gra_win, gra_gcstip, atx - radius,
			gra_revy - aty - radius, radius*2, radius*2, 0, 360*64);
	} else
	{
		if (us_dispstyle == COLORMAP)
		{
			XSetPlaneMask(gra_dpy, gra_gc, desc->bits & gra_maphigh);
			XSetForeground(gra_dpy, gra_gc, desc->col);
		} else
		{
			XSetForeground(gra_dpy, gra_gc, (desc->col) ? us_black : us_white);
		}
		XFillArc(gra_dpy, gra_win, gra_gc, atx - radius, gra_revy - aty - radius,
			radius*2, radius*2, 0, 360*64);
	}
#endif
}

/******************** ARC DRAWING ********************/

#ifdef ANYDEPTH
INTSML gra_arcfindoctant(INTBIG x, INTBIG y)
{
	if (x > 0)
		if (y >= 0)
			if (y >= x)	 return 7;
			else         return 8;
		else
			if (x >= -y) return 1;
			else         return 2;
	else
		if (y > 0)
			if (y > -x)  return 6;
			else         return 5;
		else
			if (y > x)   return 4;
			else         return 3;
}

void gra_arcxformoctant(INTBIG x, INTBIG y, INTBIG oct, INTBIG *ox, INTBIG *oy)
{
	switch (oct)
	{
		case 1 : *ox = -y;   *oy = x;   break;
		case 2 : *ox = x;    *oy = -y;  break;
		case 3 : *ox = -x;   *oy = -y;  break;
		case 4 : *ox = -y;   *oy = -x;  break;
		case 5 : *ox = y;    *oy = -x;  break;
		case 6 : *ox = -x;   *oy = y;   break;
		case 7 : *ox = x;    *oy = y;   break;
		case 8 : *ox = y;    *oy = x;   break;
	}
}

void gra_arcdopixel(INTBIG x, INTBIG y)
{
	if (x < 0 || x >= gra_curvemaxx || y < 0 || y >= gra_curvemaxy) return;
	if (gra_arcfirst != 0)
	{
		gra_arcfirst = 0;
		gra_arclx = gra_archx = x;
		gra_arcly = gra_archy = y;
	} else
	{
		if (x < gra_arclx) gra_arclx = x;
		if (x > gra_archx) gra_archx = x;
		if (y < gra_arcly) gra_arcly = y;
		if (y > gra_archy) gra_archy = y;
	}
	gra_rowstart[y][x] = (gra_rowstart[y][x] & gra_curvemask) | gra_curvecol;
}

void gra_arcoutxform(INTBIG x, INTBIG y)
{
	if (gra_arcocttable[1]) gra_arcdopixel( y + gra_arccenterx, -x + gra_arccentery);
	if (gra_arcocttable[2]) gra_arcdopixel( x + gra_arccenterx, -y + gra_arccentery);
	if (gra_arcocttable[3]) gra_arcdopixel(-x + gra_arccenterx, -y + gra_arccentery);
	if (gra_arcocttable[4]) gra_arcdopixel(-y + gra_arccenterx, -x + gra_arccentery);
	if (gra_arcocttable[5]) gra_arcdopixel(-y + gra_arccenterx,  x + gra_arccentery);
	if (gra_arcocttable[6]) gra_arcdopixel(-x + gra_arccenterx,  y + gra_arccentery);
	if (gra_arcocttable[7]) gra_arcdopixel( x + gra_arccenterx,  y + gra_arccentery);
	if (gra_arcocttable[8]) gra_arcdopixel( y + gra_arccenterx,  x + gra_arccentery);
}

void gra_arcbrescw(INTBIG x, INTBIG y, INTBIG x1, INTBIG y1)
{
	REGISTER INTBIG d;

	d = 3 - 2 * y + 4 * x;
	while (x < x1 && y > y1)
	{
		gra_arcoutxform(x, y);
		if (d < 0) d += 4*x+6; else
		{
			d += 4*(x-y)+10;
			y--;
		}
		x++;
	}

	/* get to the end */
	for ( ; x < x1; x++) gra_arcoutxform(x, y);
	for ( ; y > y1; y--) gra_arcoutxform(x, y);
   gra_arcoutxform(x1, y1);
}

void gra_arcbresmidcw(INTBIG x, INTBIG y)
{
	REGISTER INTBIG d;

	d = 3 - 2 * y + 4 * x;
	while (x < y)
	{
		gra_arcoutxform(x, y);
		if (d < 0) d += 4*x+6; else
		{
			d += 4*(x-y)+10;
			y--;
		}
		x++;
   }
   if (x == y) gra_arcoutxform(x, y);
}

void gra_arcbresmidccw(INTBIG x, INTBIG y)
{
	REGISTER INTBIG d;

	d = 3 + 2 * y - 4 * x;
	while (x > 0)
	{
		gra_arcoutxform(x, y);
		if (d > 0) d += 6-4*x; else
		{
			d += 4*(y-x)+10;
			y++;
		}
		x--;
   }
   gra_arcoutxform(0, gra_arcradius);
}

void gra_arcbresccw(INTBIG x, INTBIG y, INTBIG x1, INTBIG y1)
{
	REGISTER INTBIG d;

	d = 3 + 2 * y + 4 * x;
	while(x > x1 && y < y1)
	{
		/* not always correct */
		gra_arcoutxform(x, y);
		if (d > 0) d += 6 - 4*x; else
		{
			d += 4*(y-x)+10;
			y++;
		}
		x--;
	}

	/* get to the end */
	for ( ; x > x1; x--) gra_arcoutxform(x, y);
	for ( ; y < y1; y++) gra_arcoutxform(x, y);
	gra_arcoutxform(x1, y1);
}
#endif

/*
 * draws an arc centered at (centerx, centery), clockwise, passing by (x1,y1) and (x2,y2)
 */
void us_drawcirclearc(WINDOWPART *win, INTBIG centerx, INTBIG centery, INTBIG x1, INTBIG y1,
	INTBIG x2, INTBIG y2, GRAPHICS *desc)
{
#ifdef ANYDEPTH
	REGISTER INTBIG alternate, pa_x, pa_y, pb_x, pb_y, i, diff;
	INTBIG x, y;
	REGISTER INTSML start_oct, end_oct;

	/* ignore tiny arcs */
	if (x1 == x2 && y1 == y2) return;

	/* get parameters */
	gra_curvecol = desc->col;   gra_curvemask = ~desc->bits;
	gra_curvemaxx = us_swid;
	gra_curvemaxy = us_shei;
	y1 = gra_revy - y1;
	y2 = gra_revy - y2;
	gra_arccentery = gra_revy - centery;
	gra_arccenterx = centerx;
	pa_x = x2 - gra_arccenterx;
	pa_y = y2 - gra_arccentery;
	pb_x = x1 - gra_arccenterx;
	pb_y = y1 - gra_arccentery;
	gra_arcradius = computedistance(gra_arccenterx, gra_arccentery, x2, y2);
	alternate = computedistance(gra_arccenterx, gra_arccentery, x1, y1);
	start_oct = gra_arcfindoctant(pa_x, pa_y);
	end_oct   = gra_arcfindoctant(pb_x, pb_y);
	gra_arcfirst = 1;

	/* move the point */
	if (gra_arcradius != alternate)
	{
		diff = gra_arcradius-alternate;
		switch (end_oct)
		{
			case 6:
			case 7: /*  y >  x */ pb_y += diff;  break;
			case 8: /*  x >  y */
			case 1: /*  x > -y */ pb_x += diff;  break;
			case 2: /* -y >  x */
			case 3: /* -y > -x */ pb_y -= diff;  break;
			case 4: /* -y < -x */
			case 5: /*  y < -x */ pb_x -= diff;  break;
		}
	}

	for(i=1; i<9; i++) gra_arcocttable[i] = 0;

	if (start_oct == end_oct)
	{
		INTBIG x1, y1, x2, y2;

		gra_arcocttable[start_oct] = 1;
		gra_arcxformoctant(pa_x, pa_y, start_oct, &x1, &y1);
		gra_arcxformoctant(pb_x, pb_y, start_oct, &x2 ,&y2);

		if (ODD(start_oct)) gra_arcbrescw(x1, y1, x2, y2);
		else				gra_arcbresccw(x1 ,y1, x2, y2);
		gra_arcocttable[start_oct] = 0;
	} else
	{
		gra_arcocttable[start_oct] = 1;
		gra_arcxformoctant(pa_x, pa_y, start_oct, &x, &y);
		if (ODD(start_oct)) gra_arcbresmidcw(x, y);
		else				gra_arcbresmidccw(x, y);
		gra_arcocttable[start_oct] = 0;

		gra_arcocttable[end_oct] = 1;
		gra_arcxformoctant(pb_x, pb_y, end_oct, &x, &y);
		if (ODD(end_oct)) gra_arcbresmidccw(x, y);
		else			  gra_arcbresmidcw(x, y);
		gra_arcocttable[end_oct] = 0;

		if (MODP(start_oct+1) != end_oct)
		{
			if (MODP(start_oct+1) == MODM(end_oct-1))
				gra_arcocttable[MODP(start_oct+1)] = 1; else
					for(i = MODP(start_oct+1); i != end_oct; i = MODP(i+1))
						gra_arcocttable[i] = 1;
			gra_arcbresmidcw(0, gra_arcradius);
		}
	}

	/* set redraw area */
	if (gra_arcfirst == 0)
		gra_setrect((INTSML)(gra_arclx), (INTSML)(gra_archx+1), (INTSML)(gra_arcly),
			(INTSML)(gra_archy+1));
#else
	REGISTER INTSML radius, startangle, endangle;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	if (us_dispstyle == COLORMAP)
	{
		XSetPlaneMask(gra_dpy, gra_gc, desc->bits & gra_maphigh);
		XSetForeground(gra_dpy, gra_gc, desc->col);
	} else
	{
		XSetForeground(gra_dpy, gra_gc, (desc->col) ? us_black : us_white);
	}

	radius = computedistance(centerx, gra_revy - centery, x1,
		gra_revy - y1);
	startangle = figureangle(centerx, centery, x1, y1);
	endangle = figureangle(centerx, centery, x2, y2);
	if (startangle < endangle) startangle += 3600;
	XDrawArc(gra_dpy, gra_win, gra_gc, centerx - radius,
		gra_revy - centery - radius, radius*2, radius*2, (endangle*64 + 5) / 10,
		((startangle - endangle)*64 + 5) / 10);
#endif
}

/******************** GRID CONTROL ********************/

/*
 * fast grid drawing routine
 */
void us_drawgrid(WINDOWPART *win, POLYGON *obj)
{
#ifdef ANYDEPTH
	REGISTER INTBIG i, j, xnum, xden, ynum, yden, x0,y0, x1,y1, x2,y2, x3,y3,
		x4,y4, x5,y5, x10, y10, y10mod, spacing, y1base, x1base;
	REGISTER INTSML x, y;
	REGISTER VARIABLE *var;

	x0 = obj->xv[0];   y0 = obj->yv[0];		/* screen space grid spacing */
	x1 = obj->xv[1];   y1 = obj->yv[1];		/* screen space grid start */
	x2 = obj->xv[2];   y2 = obj->yv[2];		/* display space low */
	x3 = obj->xv[3];   y3 = obj->yv[3];		/* display space high */
	x4 = obj->xv[4];   y4 = obj->yv[4];		/* screen space low */
	x5 = obj->xv[5];   y5 = obj->yv[5];		/* screen space high */

	var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_gridboldspacing);
	if (var == NOVARIABLE) spacing = 10; else
		spacing = var->addr;

	xnum = x3 - x2;
	xden = x5 - x4;
	ynum = y3 - y2;
	yden = y5 - y4;
	x10 = x0*spacing;       y10 = y0*spacing;
	y1base = y1 - (y1 / y0 * y0);
	x1base = x1 - (x1 / x0 * x0);

	/* draw the grid to the offscreen buffer */
	for(i = y1; i < y5; i += y0)
	{
		y = (INTSML)(muldiv(i-y4, ynum, yden) + y2);
		if (y < y2 || y > y3) continue;
		y = gra_revy - y;
		y10mod = (i-y1base) % y10;
		for(j = x1; j < x5; j += x0)
		{
			x = (INTSML)(muldiv(j-x4, xnum, xden) + x2);
			if (x >= x2 && x <= x3) gra_rowstart[y][x] |= GRID;

			/* special case every 10 grid points in each direction */
			if (((j-x1base)%x10) == 0 && y10mod == 0)
			{
				if (x > x2) gra_rowstart[y][x-1] |= GRID;
				if (x < x3) gra_rowstart[y][x+1] |= GRID;
				if (y > y2) gra_rowstart[y-1][x] |= GRID;
				if (y < y3) gra_rowstart[y+1][x] |= GRID;
			}
		}
	}

	/* copy it back to the screen */
	gra_setrect((INTSML)x2, (INTSML)x3, (INTSML)(gra_revy-y3), (INTSML)(gra_revy-y2));
#else
	REGISTER INTBIG i, gridsize;
	REGISTER INTSML x, y;
	static Pixmap grid_pix;
	static GC grid_gc;
	XGCValues gcv;
	static INTBIG bestsize = 0;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	/* grid pixrect */
	gridsize = obj->xv[3] - obj->xv[2];

	/* for some reason, must always reallocate SEEMS OK NOW: SRP */
	if (us_swid > bestsize)
	{
		if (bestsize != 0)
		{
			XFreePixmap(gra_dpy, grid_pix);
			XFreeGC(gra_dpy, grid_gc);
		}
		grid_pix = XCreatePixmap(gra_dpy, gra_win, bestsize = us_swid, 1, 1);
		gcv.background = 0;
		gcv.foreground = 0;
		grid_gc = XCreateGC(gra_dpy, (Drawable)grid_pix, GCBackground | GCForeground, &gcv);
	}

	XSetForeground(gra_dpy, grid_gc, 0);
	XFillRectangle(gra_dpy, (Drawable)grid_pix, grid_gc, 0, 0, bestsize, 1);

	/* calculate the horizontal dots position */
	XSetForeground(gra_dpy, grid_gc, 1);
	for(i = obj->xv[1]; i < obj->xv[5]; i += obj->xv[0])
	{
		x = muldiv(i - obj->xv[4], gridsize, obj->xv[5] - obj->xv[4]) + obj->xv[2];
		XDrawPoint(gra_dpy, (Drawable)grid_pix, grid_gc, x, 0);
	}

	/* draw the vertical columns */
	XSetStipple(gra_dpy, gra_gcstip, grid_pix);
	if (us_dispstyle == COLORMAP)
	{
		XSetPlaneMask(gra_dpy, gra_gcstip, obj->desc->bits & gra_maphigh);
		XSetForeground(gra_dpy, gra_gcstip, obj->desc->col);
	} else
	{
		XSetForeground(gra_dpy, gra_gcstip, (obj->desc->col) ? us_black : us_white);
	}

	for(i = obj->yv[1]; i < obj->yv[5]; i += obj->yv[0])
	{
		y = muldiv(i - obj->yv[4], obj->yv[3] - obj->yv[2], obj->yv[5] - obj->yv[4]) +
			obj->yv[2];
		XFillRectangle(gra_dpy, gra_win, gra_gcstip, obj->xv[2],
			gra_revy - y, gridsize, 1);
	}
#endif
}

/******************** MOUSE CONTROL ********************/

/*
 * routine to return the number of buttons on the mouse
 */
INTSML buttoncount(void)
{
	if (us_dispstyle < 0) return(0);
	return(mini(BUTTONS, NUMBUTS));
}

/*
 * routine to tell whether button "but" is a double-click
 */
INTSML doublebutton(INTSML b)
{
	if (b >= BUTTONS - REALBUTS) return(1);
	return(0);
}

/*
 * routine to tell whether button "but" has the "shift" key held
 */
INTSML shiftbutton(INTSML b)
{
	REGISTER INTSML index;

	index = b / REALBUTS;
	if (index == 1 || index == 4 || index == 5 || index == 7) return(1);
	return(0);
}

/*
 * routine to return the name of button "b" (from 0 to "buttoncount()").
 * The number of letters unique to the button is placed in "important".
 */
char *buttonname(INTSML b, INTSML *important)
{
	*important = gra_buttonname[b].unique;
	return(gra_buttonname[b].name);
}

/*
 * routine to convert from "gra_inputstate" (the typical input parameter)
 * to button numbers (the table "gra_buttonname")
 */
INTSML gra_makebutton(INTBIG state)
{
	REGISTER INTSML base;

	base = 0;
	if ((state & DOUBLECL) != 0)
	{
		base += REALBUTS*8;
	} else
	{
		if ((state & SHIFTDOWN) != 0)
		{
			/* shift down */
			if ((state & CONTROLDOWN) != 0)
			{
				/* shift and control down */
				if ((state & METADOWN) != 0) base += REALBUTS*7; else
					base += REALBUTS*4;
			} else
			{
				/* shift down, control up */
				if ((state & METADOWN) != 0) base += REALBUTS*5; else
					base += REALBUTS;
			}
		} else
		{
			/* shift up */
			if ((state & CONTROLDOWN) != 0)
			{
				/* shift up, control down */
				if ((state & METADOWN) != 0) base += REALBUTS*6; else
					base += REALBUTS*2;
			} else
			{
				/* shift and control up */
				if ((state & METADOWN) != 0) base += REALBUTS*3;
			}
		}
	}

	switch (state & ISBUTTON)
	{
		case ISLEFT:                break;
		case ISMIDDLE: base++;      break;
		case ISRIGHT:  base += 2;   break;
	}
	return(base);
}

/*
 * routine to wait for a button push and return its index (0 based) in "*but".
 * The coordinates of the cursor are placed in "*x" and "*y".  If there is no
 * button push, the value of "*but" is negative.
 */
void waitforbutton(INTSML *x, INTSML *y, INTSML *but)
{
	/* quit if no graphics being used */
	if (us_dispstyle < 0)
	{
		*but = -1;
		return;
	}

	/* if there is a button push pending, return it */
	if ((gra_inputstate != NOEVENT) && ((gra_inputstate & ISBUTTON) != 0) &&
		((gra_inputstate & BUTTONUP) == 0))
	{
		*but = gra_makebutton(gra_inputstate);
		*x = gra_cursorx;
		*y = gra_cursory;
		gra_inputstate = NOEVENT;
		if (us_cursorstate != IBEAMCURSOR) setdefaultcursortype(us_normalcursor);
		return;
	}

	/* get some input (keyboard or mouse) */
	gra_waitforaction();

	/* if a button push was read, return it */
	if ((gra_inputstate != NOEVENT) && ((gra_inputstate & ISBUTTON) != 0) &&
		((gra_inputstate & BUTTONUP) == 0))
	{
		*but = gra_makebutton(gra_inputstate);
		*x = gra_cursorx;
		*y = gra_cursory;
		gra_inputstate = NOEVENT;
		if (us_cursorstate != IBEAMCURSOR) setdefaultcursortype(us_normalcursor);
		return;
	}

	/* no button input yet */
	*but = -1;
}

/*
 * routine to track the cursor until a button is released, calling "whileup" for
 * each co-ordinate when the mouse moves before the first button push, calling
 * "whendown" once when the button goes down, calling "eachdown" for each
 * co-ordinate when the mouse moves after the button is pushed, calling
 * "eachchar" for each key that is typed at any time, and calling "done" once
 * when done.  The "whendown" and "done" routines are called with no parameters;
 * "whileup" and "eachdown" are called with the X and Y coordinates of the
 * cursor; and "eachchar" is called with the X, Y, and character value that was
 * typed.  The "whileup", "eachdown", and "eachchar" routines return nonzero to
 * abort tracking.
 * If "waitforpush" is nonzero then the routine will wait for a button to
 * actually be pushed before tracking (otherwise it will begin tracking
 * immediately).  The value of "purpose" determines what the cursor will look
 * like during dragging: 0 for normal (the X cursor), 1 for drawing (a pen),
 * 2 for dragging (a hand), 3 for popup menu selection (a horizontal arrow), 4 for
 * hierarchical popup menu selection (arrow, stays at end).
 */
void trackcursor(INTSML waitforpush, INTSML (*whileup)(INTBIG, INTBIG),
	void (*whendown)(void), INTSML (*eachdown)(INTBIG, INTBIG),
	INTSML (*eachchar)(INTBIG, INTBIG, INTSML), void (*done)(void), INTSML purpose)
{
	REGISTER INTSML keepon, chr, oldcursor;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	/* change the cursor to an appropriate icon */
	oldcursor = us_normalcursor;
	switch (purpose)
	{
		case TRACKDRAWING:    us_normalcursor = PENCURSOR;    break;
		case TRACKDRAGGING:   us_normalcursor = HANDCURSOR;   break;
		case TRACKSELECTING:
		case TRACKHSELECTING: us_normalcursor = MENUCURSOR;   break;
	}
	setdefaultcursortype(us_normalcursor);

	/* now wait for a button to go down, if requested */
	keepon = 0;
	if (waitforpush != 0)
	{
		while (keepon == 0)
		{
			gra_waitforaction();
			if (gra_inputstate == NOEVENT) continue;

			/* if button just went down, stop this loop */
			if ((gra_inputstate & ISBUTTON) != 0 && (gra_inputstate & BUTTONUP) == 0)
				break;

			if ((gra_inputstate & MOTION) != 0)
			{
				keepon = (*whileup)(gra_cursorx, gra_cursory);
			} else if ((gra_inputstate & ISCHAR) != 0)
			{
				chr = gra_inputstate & CHARREAD;
				if ((gra_inputstate & METADOWN) != 0) chr |= 0200;
				keepon = (*eachchar)(gra_cursorx, gra_cursory, chr);
			}
		}
	}

	/* button is now down, real tracking begins */
	if (keepon == 0)
	{
		(*whendown)();
		keepon = (*eachdown)(gra_cursorx, gra_cursory);
	}

	/* now track while the button is down */
	while (keepon == 0)
	{
		gra_waitforaction();

		/* for each motion, report the coordinates */
		if (gra_inputstate == NOEVENT) continue;

		if ((gra_inputstate & ISBUTTON) != 0 && (gra_inputstate & BUTTONUP) != 0) break;
		if ((gra_inputstate & MOTION) != 0)
		{
			keepon = (*eachdown)(gra_cursorx, gra_cursory);
		} else if ((gra_inputstate & ISCHAR) != 0)
		{
			chr = gra_inputstate & CHARREAD;
			if ((gra_inputstate & METADOWN) != 0) chr |= 0200;
			keepon = (*eachchar)(gra_cursorx, gra_cursory, chr);
		}
		if (el_pleasestop != 0) keepon = 1;
	}
	gra_inputstate = NOEVENT;

	/* inform the user that all is done */
	(*done)();

	/* restore the state of the world */
	us_normalcursor = oldcursor;
	setdefaultcursortype(us_normalcursor);
}

/*
 * routine to read the current co-ordinates of the tablet and return them in "*x" and "*y"
 */
void readtablet(INTSML *x, INTSML *y)
{
	*x = gra_cursorx;
	*y = gra_cursory;
}

/*
 * routine to turn off the cursor tracking if it is on
 */
void stoptablet(void)
{
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return;

	if (us_cursorstate != IBEAMCURSOR) setdefaultcursortype(us_normalcursor);
}

/******************** KEYBOARD CONTROL ********************/

/*
 * routine to get the next character from the keyboard
 */
INTSML us_getnxtchar(void)
{
	REGISTER INTSML i;

	/* quit if no graphics being used */
	if (us_dispstyle < 0) return(getchar());

	if ((gra_inputstate != NOEVENT) && ((gra_inputstate & ISCHAR) == ISCHAR))
	{
		i = gra_inputstate & CHARREAD;
		if ((gra_inputstate & METADOWN) != 0) i |= 0200;
		gra_inputstate = NOEVENT;
		return(i);
	}
	if (us_cursorstate != IBEAMCURSOR) setdefaultcursortype(WANTTTYCURSOR);

	for(;;)
	{
		gra_waitforaction();
		if ((gra_inputstate != NOEVENT) && ((gra_inputstate & ISCHAR) == ISCHAR)) break;
	}

	i = gra_inputstate & CHARREAD;
	if ((gra_inputstate & METADOWN) != 0) i |= 0200;

	gra_inputstate = NOEVENT;
	if (us_cursorstate != IBEAMCURSOR) setdefaultcursortype(us_normalcursor);

	return(i);
}

/* not required with X11 */
void checkforinterrupt(void) {}

/*
 * routine to tell whether data is waiting at the terminal.  Returns nonzero
 * if data is ready.
 */
INTSML ttydataready(void)
{
	/* quit if no graphics being used */
	if (us_dispstyle < 0) return(1);

	/* see if something is already pending */
	if (gra_inputstate != NOEVENT)
	{
		if ((gra_inputstate & ISCHAR) == ISCHAR) return(1);
		return(0);
	}

	/* wait for something and analyze it */
	if (us_cursorstate != IBEAMCURSOR) setdefaultcursortype(us_normalcursor);
	gra_waitforaction();
	if ((gra_inputstate != NOEVENT) && ((gra_inputstate & ISCHAR) == ISCHAR)) return(1);
	return(0);
}

/****************************** FILES ******************************/

INTSML gra_topoffile(char **a)
{
	char *b, **c;
	INTSML retval;

	b = gra_curpath;
	c = &b;
	retval = topoffile(c);
	requiredextension(gra_requiredextension);
	return(retval);
}

#ifdef USETIF
void gra_fileselectcancel(Widget w, XtPointer client_data,
	XmSelectionBoxCallbackStruct *call_data)
{
	gra_curpath[0] = 0;
	gra_fileselectdone = 1;
}

void gra_fileselectok(Widget w, XtPointer client_data,
	XmSelectionBoxCallbackStruct *call_data)
{
	char *filename;

	gra_curpath[0] = 0;
	if (XmStringGetLtoR(call_data->value, XmSTRING_DEFAULT_CHARSET,
		&filename))
	{
		strcpy(gra_curpath, filename);
		XtFree(filename);
	}
	gra_fileselectdone = 1;
}
#endif

/*
 * Routine to display a standard file prompt dialog and return the selected file.
 * The prompt message is in "msg" and the kind of file is in "filetype".  The default
 * output file name is in "defofile" (only used if "filetype" is for output files).
 */
char *fileselect(char *msg, INTSML filetype, char *defofile)
{
	INTSML itemHit, i, l, oldlen, count;
	char *ths, sep[2], *extension, *filter, *shortname, *longname, banner[200],
		fullmsg[300], *pars[5];
	extern COMCOMP us_yesnop;

	if ((filetype&FILETYPEWRITE) == 0)
	{
		/* input file selection: display the file input dialog box */
#ifdef USETIF
		XmString mprompt, mfilter, mtitle;
		Widget w;
		char temp[256];
		INTBIG wid, hei, ac;
		Arg arg[10];
		XEvent event;

		describefiletype(filetype, &extension, &filter, &shortname, &longname);
		sprintf(temp, "%s Selection", msg);
		mtitle = XmStringCreateLocalized(temp);
		mprompt = XmStringCreateLocalized(msg);
		strcpy(temp, filter);
		for(i=0; temp[i] != 0; i++) if (temp[i] == ';') break;
		temp[i] = 0;
		mfilter = XmStringCreateLocalized(temp);
		wid = 400;   if (wid > us_swid) wid = us_swid;
		hei = 480;   if (hei > us_shei) hei = us_shei;
		ac = 0;
		XtSetArg(arg[ac], XmNdirMask, mfilter);   ac++;
		XtSetArg(arg[ac], XmNselectionLabelString, mprompt);   ac++;
		XtSetArg(arg[ac], XmNwidth, 400);   ac++;
		XtSetArg(arg[ac], XmNheight, 480);   ac++;
		XtSetArg(arg[ac], XmNdialogTitle, mtitle);   ac++;
		w = XmCreateFileSelectionDialog(gra_graphicswidget, "File Selection", arg, ac);
		XtAddCallback(w, XmNcancelCallback, (XtCallbackProc)gra_fileselectcancel, NULL);
		XtAddCallback(w, XmNokCallback, (XtCallbackProc)gra_fileselectok, NULL);
		XtManageChild(w);
		XmStringFree(mprompt);
		XmStringFree(mfilter);
		XmStringFree(mtitle);

		gra_fileselectdone = 0;
		while (gra_fileselectdone == 0)
		{
			XmUpdateDisplay(gra_toplevelwidget);
			XtAppNextEvent(gra_xtapp, &event);
			XtDispatchEvent(&event);
		}
		XtUnmanageChild(w);
		XtDestroyWidget(w);
		return(gra_curpath);
#else
		describefiletype(filetype, &extension, &filter, &shortname, &longname);
		strcpy(gra_requiredextension, extension);
		us_fileindialog.movable = msg;
		if (DiaInitDialog(&us_fileindialog) != 0) return(0);
		(void)strcpy(gra_curpath, currentdirectory());
		if (gra_curpath[strlen(gra_curpath)-1] != DIRSEP)
		{
			sep[0] = DIRSEP;   sep[1] = 0;
			(void)strcat(gra_curpath, sep);
		}
		DiaInitTextDialog(3, gra_topoffile, nextfile, us_nulldlogdone, 0,
			SCSELKEY|SCSELMOUSE|SCDOUBLEQUIT);
		DiaSetText(4, gra_curpath);

		/* loop until done */
		for(;;)
		{
			itemHit = DiaNextHit();
			if (itemHit == CANCEL) break;
			if (itemHit == OK)
			{
				oldlen = strlen(gra_curpath);
				ths = DiaGetScrollLine(3, DiaGetCurLine(3));
				(void)strcat(gra_curpath, ths);
				if (fileexistence(gra_curpath) != 2) break;
				DiaSetText(4, gra_curpath);
				DiaLoadTextDialog(3, gra_topoffile, nextfile, us_nulldlogdone, 0);
				continue;
			}
			if (itemHit == 5)
			{
				l = strlen(gra_curpath);
				if (l > 0 && gra_curpath[l-1] == DIRSEP) l--;
				if (l <= 0) continue;
				for(l--; l>=0; l--) if (gra_curpath[l] == DIRSEP) break;
				gra_curpath[l+1] = 0;
				DiaSetText(4, gra_curpath);
				DiaLoadTextDialog(3, gra_topoffile, nextfile, us_nulldlogdone, 0);
				continue;
			}
		}

		setdefaultcursortype(WAITCURSOR);
		DiaDoneDialog();
		if (itemHit == CANCEL) return((char *)NULL);
		return(gra_curpath);
#endif
	} else
	{
#ifdef USETIF
		XmString mprompt, mpattern, mdirectory, mtitle;
		Widget w, child;
		INTBIG wid, hei, ac;
		Arg arg[10];
		char directory[256], filename[256], temp[256], *childmsg;
		XEvent event;

		/* determine the default directory and file name */
		directory[0] = filename[0] = 0;
		if (defofile[0] != 0)
		{
			l = strlen(defofile);
			for(i=l-1; i>0; i--) if (defofile[i] == DIRSEP) break;
			if (i > 0)
			{
				i++;
				(void)strcpy(directory, defofile);
				directory[i] = 0;
			}
			strcpy(filename, &defofile[i]);
		}

		describefiletype(filetype, &extension, &filter, &shortname, &longname);
		wid = 400;   if (wid > us_swid) wid = us_swid;
		hei = 480;   if (hei > us_shei) hei = us_shei;
		mprompt = XmStringCreateLocalized(msg);
		mdirectory = XmStringCreateLocalized(directory);
		strcpy(temp, filter);
		for(i=0; temp[i] != 0; i++) if (temp[i] == ';') break;
		temp[i] = 0;
		mpattern = XmStringCreateLocalized(temp);
		sprintf(temp, "%s Creation", msg);
		mtitle = XmStringCreateLocalized(temp);
		ac = 0;
		XtSetArg(arg[ac], XmNwidth, 400);   ac++;
		XtSetArg(arg[ac], XmNheight, 480);   ac++;
		XtSetArg(arg[ac], XmNselectionLabelString, mprompt);   ac++;
		XtSetArg(arg[ac], XmNdirectory, mdirectory);   ac++;
		XtSetArg(arg[ac], XmNpattern, mpattern);   ac++;
		XtSetArg(arg[ac], XmNdialogTitle, mtitle);   ac++;
		w = XmCreateFileSelectionDialog(gra_graphicswidget, "", arg, ac);
		XtAddCallback(w, XmNcancelCallback, (XtCallbackProc)gra_fileselectcancel, NULL);
		XtAddCallback(w, XmNokCallback, (XtCallbackProc)gra_fileselectok, NULL);
		XtManageChild(w);
		XmStringFree(mprompt);
		XmStringFree(mdirectory);
		XmStringFree(mpattern);
		XmStringFree(mtitle);

		/* append the default output file name to the selection path */
		child = XmFileSelectionBoxGetChild(w, XmDIALOG_TEXT);
		childmsg = XmTextGetString(child);
		sprintf(temp, "%s%s", childmsg, filename);
		XmTextSetString(child, temp);

		gra_fileselectdone = 0;
		while (gra_fileselectdone == 0)
		{
			XmUpdateDisplay(gra_toplevelwidget);
			XtAppNextEvent(gra_xtapp, &event);
			XtDispatchEvent(&event);
		}
		XtUnmanageChild(w);
		XtDestroyWidget(w);
#else
		/* input file selection: display the file input dialog box */
		sprintf(banner, "Write %s", msg);
		us_fileoutdialog.movable = banner;
		if (DiaInitDialog(&us_fileoutdialog) != 0) return(0);
		(void)strcpy(gra_curpath, currentdirectory());
		if (gra_curpath[strlen(gra_curpath)-1] != DIRSEP)
		{
			sep[0] = DIRSEP;   sep[1] = 0;
			(void)strcat(gra_curpath, sep);
		}
		if (defofile[0] != 0)
		{
			l = strlen(defofile);
			for(i=l-1; i>0; i--) if (defofile[i] == DIRSEP) break;
			if (i > 0)
			{
				i++;
				(void)strcpy(gra_curpath, defofile);
				gra_curpath[i] = 0;
			}
			DiaSetText(-7, &defofile[i]);
		}
		gra_requiredextension[0] = 0;
		DiaInitTextDialog(3, gra_topoffile, nextfile, us_nulldlogdone, 0,
			SCSELKEY|SCREPORT|SCSELMOUSE);
		DiaSetText(4, gra_curpath);

		/* loop until done */
		for(;;)
		{
			itemHit = DiaNextHit();
			if (itemHit == CANCEL) break;
			if (itemHit == OK)
			{
				ths = DiaGetText(7);
				(void)strcat(gra_curpath, ths);
				break;
			}
			if (itemHit == 3)
			{
				/* handle selection in the directory list */
				oldlen = strlen(gra_curpath);
				ths = DiaGetScrollLine(3, DiaGetCurLine(3));
				(void)strcat(gra_curpath, ths);
				if (fileexistence(gra_curpath) != 2) DiaSetText(7, ths);
				gra_curpath[oldlen] = 0;
				continue;
			}
			if (itemHit == 6)
			{
				/* go down the directory */
				oldlen = strlen(gra_curpath);
				ths = DiaGetScrollLine(3, DiaGetCurLine(3));
				(void)strcat(gra_curpath, ths);
				if (fileexistence(gra_curpath) != 2) gra_curpath[oldlen] = 0; else
				{
					DiaSetText(4, gra_curpath);
					DiaLoadTextDialog(3, gra_topoffile, nextfile, us_nulldlogdone, 0);
				}
				continue;
			}
			if (itemHit == 5)
			{
				/* go up the directory */
				l = strlen(gra_curpath);
				if (l > 0 && gra_curpath[l-1] == DIRSEP) l--;
				if (l <= 0) continue;
				for(l--; l>=0; l--) if (gra_curpath[l] == DIRSEP) break;
				gra_curpath[l+1] = 0;
				DiaSetText(4, gra_curpath);
				DiaLoadTextDialog(3, gra_topoffile, nextfile, us_nulldlogdone, 0);
				continue;
			}
		}

		setdefaultcursortype(WAITCURSOR);
		DiaDoneDialog();
		if (itemHit == CANCEL) return((char *)NULL);
#endif

		/* give warning if creating file that already exists */
		if (fileexistence(gra_curpath) != 0)
		{
			sprintf(fullmsg, "File '%s' exists.  Overwrite? ", gra_curpath);
			count = ttygetparam(fullmsg, &us_yesnop, 2, pars);
			if (count > 0 && namesamen(pars[0], "no", (INTSML)strlen(pars[0])) == 0)
				return(0);
		}
		return(gra_curpath);
	}
}

/*
 * Helper routine to initialize the list of files in a directory.
 */
void gra_initfilelist(void)
{
	if (gra_fileliststringarray == 0)
	{
		gra_fileliststringarray = newstringarray(db_cluster);
		if (gra_fileliststringarray == 0) return;
	}
	clearstrings(gra_fileliststringarray);
}

/*
 * Helper routine to add "file" to the list of files in a directory.
 * Returns nonzero on error.
 */
INTSML gra_addfiletolist(char *file)
{
	addtostringarray(gra_fileliststringarray, file);
	return(0);
}

int gra_fileselectall(DIRENTCONST struct dirent *a)
{
	REGISTER DIRENTCONST char *pt;

	pt = a->d_name;
	if (strcmp(pt, "..") == 0) return(0);
	if (strcmp(pt, ".") == 0) return(0);
	return(1);
}

/*
 * Routine to search for all of the files/directories in directory "directory" and
 * return them in the array of strings "filelist".  Returns the number of files found.
 */
INTSML filesindirectory(char *directory, char ***filelist)
{
	INTBIG len;
	char localname[256];
	struct dirent **filenamelist;
	struct dirent *dir;
	INTSML total, i;
#ifndef HAVE_SCANDIR
#  define DIRFILECOUNT 2048  /* max number of entries in a directory */
#  ifndef _POSIX_PATH_MAX
#    define _POSIX_PATH_MAX 255
#  endif
	DIR *dirp;
	register int tdirsize;
#endif

	/* make sure there is no ending "/" */
	strcpy(localname, directory);
	i = strlen(localname) - 1;
	if (i > 0 && localname[i] == '/') localname[i] = 0;
	if (i == -1) sprintf(localname, ".");

	/* scan the directory */
#ifdef HAVE_SCANDIR
	/*
	 * On BSD, last arg is: "(int (*)(const void *, const void *))0"
	 * On non-BSD, last arg is: "(int (*)(const __ptr_t, const __ptr_t))0"
	 */
	total = scandir(localname, &filenamelist, gra_fileselectall, NULL);
#else
	/* get space for directory */
	filenamelist = (struct dirent **)calloc(DIRFILECOUNT,
		sizeof(struct dirent *));
	if (filenamelist == 0) return(0);
	tdirsize = sizeof (struct dirent);
	dir = (struct dirent *)emalloc(tdirsize + _POSIX_PATH_MAX, us_aid->cluster);
	if (dir == 0) return(0);

	/* get the directory */
	dirp = opendir(localname);
	if (dirp == NULL) return(-1);

	/* construct the list */
	total = 0;
	while ((struct dirent *)readdir_r(dirp, dir) != NULL)
	{
		if (gra_fileselectall(dir))
		{
			filenamelist[total] = (struct dirent *)emalloc(tdirsize + _POSIX_PATH_MAX,
				us_aid->cluster);
			if (filenamelist[total] == NULL) { closedir(dirp);   return(0); }
			memcpy(filenamelist[total], dir, sizeof(dir)+_POSIX_PATH_MAX);
			total++;
		}
	}
	closedir(dirp);
#endif

	gra_initfilelist();
	for(i=0; i<total; i++)
	{
		dir = filenamelist[i];
		if (gra_addfiletolist(dir->d_name) != 0) return(0);
		free((char *)dir);
	}
	free((char *)filenamelist);
	*filelist = getstringarray(gra_fileliststringarray, &len);
	return(len);
}

/* routine to convert a path name with "~" to a real path */
char *truepath(char *line)
{
	static char outline[100], home[50];
	REGISTER char save, *ch;
	static INTSML gothome = 0;
	struct passwd *tmp;

	if (line[0] != '~') return(line);

	/* if it is the form "~username", figure it out */
	if (line[1] != '/')
	{
		for(ch = &line[1]; *ch != 0 && *ch != '/'; ch++);
		save = *ch;   *ch = 0;
		tmp = getpwnam(&line[1]);
		if (tmp == 0) return(line);
		*ch = save;
		(void)strcpy(outline, tmp->pw_dir);
		(void)strcat(outline, ch);
		return(outline);
	}

	/* get the user's home directory once only */
	if (gothome == 0)
	{
		/* get name of user */
		tmp = getpwuid(getuid());
		if (tmp == 0) return(line);
		(void)strcpy(home, tmp->pw_dir);
		gothome++;
	}

	/* substitute home directory for the "~" */
	(void)strcpy(outline, home);
	(void)strcat(outline, &line[1]);
	return(outline);
}

/*
 * Routine to turn the file name "file" into a unique one by changing the
 * "XXX" part to a number that makes the file unique.
 */
void emaketemp(char *file)
{
	mktemp(file);
}

/*
 * routine to rename file "file" to "newfile"
 * returns nonzero on error
 */
INTBIG erename(char *file, char *newfile)
{
	if (link(file, newfile) < 0) return(1);
	if (unlink(file) < 0) return(1);
	return(0);
}

/*
 * routine to delete file "file"
 */
INTBIG eunlink(char *file)
{
	return(unlink(file));
}

/*
 * Routine to return information about the file or directory "name":
 *  0: does not exist
 *  1: is a file
 *  2: is a directory
 */
INTSML fileexistence(char *name)
{
	struct stat buf;

	if (stat(name, &buf) < 0) return(0);
	if ((buf.st_mode & S_IFMT) == S_IFDIR) return(2);
	return(1);
}

/*
 * Routine to create a directory.
 * Returns nonzero on error.
 */
INTSML createdirectory(char *dirname)
{
	char cmd[256];

	sprintf(cmd, "mkdir %s", dirname);
	if (system(cmd) == 0) return(0);
	return(1);
}

/*
 * Routine to return the current directory name
 */
char *currentdirectory(void)
{
	char line[MAXPATHLEN];
#ifdef HAVE_GETCWD
	(void)getcwd(line, MAXPATHLEN);
#else
#  ifdef HAVE_GETWD
	(void)getwd(line);
#  else
	line[0] = 0;
#  endif
#endif
	(void)initinfstr();
	(void)addstringtoinfstr(line);
	return(returninfstr());
}

/*
 * Routine to return the home directory (returns 0 if it doesn't exist)
 */
char *hashomedir(void)
{
	return("~/");
}

/*
 * routine to return the date of the last modification to file "filename"
 */
UINTBIG filedate(char *filename)
{
	struct stat buf;

	stat(filename, &buf);
	buf.st_mtime -= machinetimeoffset();
	return(buf.st_mtime);
}

/*
 * Routine to lock a resource called "lockfilename" by creating such a file
 * if it doesn't exist.  Returns nonzero if successful, zero if unable to
 * lock the file.
 */
INTSML lockfile(char *lockfilename)
{
	int fd;

	fd = creat(lockfilename, 0);
	if (fd == -1 && errno == EACCES) return(0);
	if (fd == -1 || close(fd) == -1) return(0);
	return(1);
}

/*
 * Routine to unlock a resource called "lockfilename" by deleting such a file.
 */
void unlockfile(char *lockfilename)
{
	if (unlink(lockfilename) == -1)
		ttyputerr("Error unlocking %s", lockfilename);
}

/****************************** CHANNELS ******************************/

/*
 * routine to create a pipe connection between the channels in "channels"
 */
INTBIG epipe(int channels[2])
{
	return(pipe(channels));
}

/*
 * Routine to set channel "channel" into an appropriate mode for single-character
 * interaction (i.e. break mode).
 */
void setinteractivemode(int channel)
{
#ifdef HAVE_TERMIOS_H
	struct termios sbuf;

	tcgetattr(channel, &sbuf);
	sbuf.c_iflag |= (BRKINT|IGNPAR|ISTRIP|IXON);
	sbuf.c_oflag |= OPOST;
	sbuf.c_lflag |= (ICANON|ISIG|ECHO);
	sbuf.c_cc[VMIN] = 1;	/* Input should wait for at least one char */
	sbuf.c_cc[VTIME] = 0;	/* no matter how long that takes. */
	tcsetattr(channel, TCSANOW, &sbuf);
#else
#  ifdef HAVE_TERMIO_H
	struct termio sbuf;

	(void)ioctl(channel, TCGETA, &sbuf);
	sbuf.c_iflag |= (BRKINT|IGNPAR|ISTRIP|IXON);
	sbuf.c_oflag |= OPOST;

	/* bogus hp baud rate sanity */
	sbuf.c_cflag = (sbuf.c_cflag & ~CBAUD) | B9600;
	sbuf.c_lflag |= (ICANON|ISIG|ECHO);
	sbuf.c_cc[VMIN] = 1;	/* Input should wait for at least one char */
	sbuf.c_cc[VTIME] = 0;	/* no matter how long that takes. */
	(void)ioctl(channel, TCSETA, &sbuf);
#  else
	struct sgttyb sbuf;

	(void)gtty(channel, &sbuf);
	sbuf.sg_flags |= CBREAK;
	(void)stty(channel, &sbuf);
#  endif
#endif
}

/*
 * Routine to replace channel "channel" with a pointer to file "file".
 * Returns a pointer to the original channel.
 */
INTBIG channelreplacewithfile(int channel, char *file)
{
	INTBIG save;

	save = dup(channel);
	(void)close(channel);
	(void)open(file, 1);
	return(save);
}

/*
 * Routine to replace channel "channel" with new channel "newchannel".
 * Returns a pointer to the original channel.
 */
INTBIG channelreplacewithchannel(int channel, int newchannel)
{
	INTBIG save;

	save = dup(channel);
	(void)close(channel);
	(void)dup(newchannel);
	return(save);
}

/*
 * Routine to restore channel "channel" to the pointer that was returned
 * by "channelreplacewithfile" or "channelreplacewithchannel" (and is in "saved").
 */
void channelrestore(int channel, INTBIG saved)
{
	(void)close(channel);
	(void)dup(saved);
}

/*
 * Routine to read "count" bytes from channel "channel" into "addr".
 * Returns the number of bytes read.
 */
INTBIG eread(int channel, char *addr, INTBIG count)
{
	return(read(channel, addr, count));
}

/*
 * Routine to write "count" bytes to channel "channel" from "addr".
 * Returns the number of bytes written.
 */
INTBIG ewrite(int channel, char *addr, INTBIG count)
{
	return(write(channel, addr, count));
}

/*
 * routine to close a channel in "channel"
 */
INTBIG eclose(int channel)
{
	return(close(channel));
}

/******************** TIME ROUTINES ********************/

/*
 * This routine returns the amount to add to the operating-system time
 * to adjust for a common time format.
 */
UINTBIG machinetimeoffset(void)
{
	return(0);
}

UINTBIG ticktime(void)
{
#ifdef HAVE_FTIME
	struct timeb tp;
	static INTBIG basesecs = 0;
	INTBIG ticks;

	ftime(&tp);
	if (basesecs == 0) basesecs = tp.time;
	ticks = (tp.time-basesecs) * 60 + (tp.millitm * 6 / 100);
	return(ticks);
#else
#  ifdef HAVE_GETTIMEOFDAY
	struct timeval tp;
	struct timezone tzp;

	gettimeofday(&tp, &tzp);
	return(tp.tv_sec * 60 + tp.tv_usec * 6 / 100000);
#  else
	static UINTBIG theTime = 0;

	return(theTime++);
#  endif
#endif
}

/*
 * Routine to start counting time.
 */
void starttimer(void)
{
#ifdef HAVE_FTIME
	struct timeb tp;

	ftime(&tp);
	gra_timebasesec = tp.time;
	gra_timebasems = tp.millitm;
#else
	gra_timebasesec = time(0);
	gra_timebasems = 0;
#endif
}

/*
 * Routine to stop counting time and return the number of elapsed seconds
 * since the last call to "starttimer()".
 */
float endtimer(void)
{
	float seconds;
#ifdef HAVE_FTIME
	INTBIG milliseconds;
	struct timeb timeptr;

	ftime(&timeptr);
	milliseconds = (timeptr.time - gra_timebasesec) * 1000 +
		(timeptr.millitm-gra_timebasems);
	seconds = ((float)milliseconds) / 1000.0;
#else
	seconds = time(0) - gra_timebasesec;
#endif
	return(seconds);
}

/*
 * Routine to wait "ticks" sixtieths of a second and then return.
 */
void gotosleep(INTBIG ticks)
{
	sleep(ticks);
}

/*************************** EVENT ROUTINES ***************************/

#ifdef USETIF
/*
 * Routine to handle window deletion
 */
void gra_windowdelete(Widget w, XtPointer client_data, XtPointer *call_data)
{
	char *par[MAXPARS];

	XmAnyCallbackStruct *cbs = (XmAnyCallbackStruct *)call_data;

	if (cbs->reason != XmCR_PROTOCOLS) return;
	if (us_preventloss(0, par, NOLIBRARY, "Quit", 0)) return;
	bringdown();
}
#else
/*
 * helper routine to wait for some keyboard or mouse input
 */
void gra_destroygraphics(Widget w, XtPointer data, XEvent *event, Boolean *cont)
{
	char *par[MAXPARS];

	if (event->type == ClientMessage &&
		event->xclient.message_type == gra_wm_protocols)
	{
		if (event->xclient.data.l[0] == gra_wm_delete_window)
		{
			if (w == gra_msgtoplevelwidget)
			{
				/* iconify the messages window */
				XIconifyWindow(gra_topmsgdpy, gra_topmsgwin, gra_screen_num);
			} else
			{
				if (us_preventloss(0, par, NOLIBRARY, "Quit", 1)) return;
				bringdown();
			}
		}
	}
}
#endif

void gra_graphics_event_handler(Widget w, XtPointer data, XEvent *event, Boolean *cont)
{
	gra_handleeditevent(event);
}

void gra_messages_event_handler(Widget w, XtPointer data, XEvent *event, Boolean *cont)
{
	gra_handlemsgevent(event);
}

#ifdef USETIF
Boolean gra_dowork(caddr_t client_data)
{
	el_slice();
	return(False);
}
#endif

void gra_addeventtoqueue(INTBIG state, INTSML x, INTSML y)
{
	MYEVENTQUEUE *next;

	next = gra_eventqueuetail + 1;
	if (next >= &gra_eventqueue[EVENTQUEUESIZE])
		next = gra_eventqueue;
	if (next == gra_eventqueuehead)
	{
		/* queue is full */
		XBell(gra_dpy, 100);
		return;
	}

	gra_eventqueuetail->inputstate = state;
	gra_eventqueuetail->cursorx = x;
	gra_eventqueuetail->cursory = y;
	gra_eventqueuetail = next;
}

void gra_nextevent(void)
{
	XEvent event;

	/* get any event on the queue */
	if (gra_eventqueuehead != gra_eventqueuetail)
	{
		gra_inputstate = gra_eventqueuehead->inputstate;
		gra_cursorx = gra_eventqueuehead->cursorx;
		gra_cursory = gra_eventqueuehead->cursory;
		gra_eventqueuehead++;
		if (gra_eventqueuehead >= &gra_eventqueue[EVENTQUEUESIZE])
			gra_eventqueuehead = gra_eventqueue;
		return;
	}

#ifdef USETIF
	XmUpdateDisplay(gra_toplevelwidget);
	XtAppNextEvent(gra_xtapp, &event);
#else
	XtNextEvent(&event);
#endif
	XtDispatchEvent(&event);

	/* get any event on the queue */
	if (gra_eventqueuehead != gra_eventqueuetail)
	{
		gra_inputstate = gra_eventqueuehead->inputstate;
		gra_cursorx = gra_eventqueuehead->cursorx;
		gra_cursory = gra_eventqueuehead->cursory;
		gra_eventqueuehead++;
		if (gra_eventqueuehead >= &gra_eventqueue[EVENTQUEUESIZE])
			gra_eventqueuehead = gra_eventqueue;
	}
}

void gra_handlemsgevent(XEvent *event)
{
	char buffer[2];
	REGISTER INTBIG ret, state;
	void us_onint(void);
	static INTSML firstexposure = 1;
	KeySym key;

	switch (event->type)
	{
#ifdef USETIF
		case Expose:
			if (firstexposure == 0) break;
			firstexposure = 0;
			XtMoveWidget(gra_msgtoplevelwidget, gra_initialmsgx, gra_initialmsgy);
			break;
#endif
		case VisibilityNotify:
			if (event->xvisibility.state == VisibilityUnobscured)
				gra_messages_obscured = 0; else
					gra_messages_obscured = 1;
			break;

		case KeyPress:
			(void)XLookupString((XKeyEvent *)event, buffer, 2, &key, NULL);
			if ((key == 'c' || key == 'C') && (event->xbutton.state & ControlMask) != 0)
			{
				/* we have to do interrupts here */
				us_onint();
				state = 0;
			} else state = gra_translatekey(event);
			if (state != 0)
			{
				us_state |= DIDINPUT;
				gra_addeventtoqueue(state, 0, 0);
			}
			event->type = 0;     /* disable this event so key doesn't go into window */
			break;

#if 0
		default:
			fprintf(stderr, "Unhandled event %s in messages window\n",
				eventNames[event->type]);
			break;
#endif
	}
}

void gra_handleeditevent(XEvent *event)
{
	INTSML setibeam, inmenu;
	char *str;
	REGISTER INTBIG ret, wid, hei, x, y, state;
	REGISTER WINDOWPART *w;
	REGISTER EDITOR *e;
	REGISTER VARIABLE *var;
	XWindowAttributes xwa;
	void us_onint(void);
	COMMANDBINDING commandbinding;
	static INTSML firstexposure = 1;
	static INTSML overrodestatus = 0;

	switch (event->type)
	{
#if 0
		case ConfigureNotify:
#  ifdef USETIF
			if (XGetWindowAttributes(gra_dpy, gra_win, &xwa) == 0) break;
			if (xwa.width != us_swid || xwa.height != us_shei + gra_status_height)
			{
				gra_repaint(1);
			} else
			{
#    ifdef ANYDEPTH
				XPutImage(gra_dpy, gra_win, gra_gc, gra_world, 0,
					0, 0, 0, us_swid, gra_shei);
				XFlush(gra_dpy);
#    else
				gra_repaint(0);
#    endif
			}
#  endif
			break;
#endif

		case Expose:
			/* ignore partial events */
			if (event->xexpose.count != 0) break;
#ifdef USETIF
			if (firstexposure != 0)
			{
				firstexposure = 0;
				XtMoveWidget(gra_toplevelwidget, gra_initialeditx, gra_initialedity);
			}
			if (XGetWindowAttributes(gra_dpy, gra_win, &xwa) == 0) break;
#else
			if (XGetWindowAttributes(gra_topdpy, gra_topwin, &xwa) == 0) break;
#endif
			if (xwa.width != us_swid || xwa.height != us_shei + gra_status_height)
			{
				gra_repaint(1);
			} else
			{
#ifdef ANYDEPTH
				XPutImage(gra_dpy, gra_win, gra_gc, gra_world, 0,
					0, 0, 0, us_swid, gra_shei);
				XFlush(gra_dpy);
#else
				gra_repaint(0);
#endif
			}
			break;

#ifndef USETIF
		case ClientMessage:
			/* watch for deletes of our windows */
			if (event->xclient.message_type == gra_wm_protocols)
			{
				if (event->xclient.data.l[0] == gra_wm_delete_window)
				{
					ttybeep();
					ttyputerr("WARNING! An attempt was made to kill your graphics window.");
					ttyputmsg("Always exit from within Electric to prevent loss of data.");
				}
			}
			break;
#endif

		case KeyPress:
			state = gra_translatekey(event);
			if (state == 0) break;
			us_state |= DIDINPUT;

			/* don't track in the status window */
			gra_cursorx = event->xkey.x;
			gra_cursory = maxi(gra_revy - event->xkey.y, 0);
			gra_addeventtoqueue(state, gra_cursorx, gra_cursory);
			break;

		case ButtonPress:  /* these are ignored in the messages window */
			switch (event->xbutton.button)
			{
				case 1: state = ISLEFT;   break;
				case 2: state = ISMIDDLE; break;
				case 3: state = ISRIGHT;  break;
			}
			if ((event->xbutton.state & ShiftMask) != 0) state |= SHIFTDOWN;
			if ((event->xbutton.state & LockMask) != 0) state |= SHIFTDOWN;
			if ((event->xbutton.state & ControlMask) != 0) state |= CONTROLDOWN;
			if ((event->xbutton.state & (Mod1Mask|Mod4Mask)) != 0) state |= METADOWN;
			gra_cursorx = event->xbutton.x;
			gra_cursory = maxi(gra_revy - event->xbutton.y, 0);
			if ((event->xbutton.time - gra_lasttime) <= gra_doublethresh &&
				(state & (SHIFTDOWN|CONTROLDOWN|METADOWN)) == 0 &&
				gra_cursorx == gra_lstcurx && gra_cursory == gra_lstcury)
			{
				state |= DOUBLECL;
				gra_lasttime = event->xbutton.time - gra_doublethresh - 1;
			} else
			{
				gra_lasttime = event->xbutton.time;
			}
			gra_addeventtoqueue(state, gra_cursorx, gra_cursory);
			gra_lstcurx = gra_cursorx;
			gra_lstcury = gra_cursory;
			us_state |= DIDINPUT;
			break;

		case ButtonRelease:
			switch (event->xbutton.button)
			{
				case 1: state = ISLEFT | BUTTONUP;   break;
				case 2: state = ISMIDDLE | BUTTONUP; break;
				case 3: state = ISRIGHT | BUTTONUP;  break;
			}
			if ((event->xbutton.state & ShiftMask) != 0) state |= SHIFTDOWN;
			if ((event->xbutton.state & LockMask) != 0) state |= SHIFTDOWN;
			if ((event->xbutton.state & ControlMask) != 0) state |= CONTROLDOWN;
			if ((event->xbutton.state & (Mod1Mask|Mod4Mask)) != 0) state |= METADOWN;
			gra_cursorx = event->xbutton.x;
			gra_cursory = maxi(gra_revy - event->xbutton.y, 0);
			gra_addeventtoqueue(state, gra_cursorx, gra_cursory);
			us_state |= DIDINPUT;
			break;

		case MotionNotify:
			gra_showcoords(event->xmotion.x, gra_revy - event->xmotion.y);
			gra_cursorx = event->xmotion.x;
			gra_cursory = gra_revy - event->xmotion.y;
			if (gra_cursory < 0) gra_cursory = 0;

			/* report the menu if over one */
			if ((event->xmotion.state & (Button1Mask | Button2Mask | Button3Mask)) == 0)
			{
				inmenu = 0;
				if ((us_aid->aidstate&MENUON) != 0 && gra_cursory >= us_menuly &&
					gra_cursory <= us_menuhy && gra_cursorx >= us_menulx && gra_cursorx <= us_menuhx)
				{
					x = (gra_cursorx-us_menulx) / us_menuxsz;
					y = (gra_cursory-us_menuly) / us_menuysz;
					if (x >= 0 && y >= 0 && x < us_menux && y < us_menuy)
					{
						inmenu = 1;
						var = getvalkey((INTBIG)us_aid, VAID, VSTRING|VISARRAY, us_binding_menu);
						if (var != NOVARIABLE)
						{
							if (us_menupos <= 1) str = ((char **)var->addr)[y * us_menux + x]; else
								str = ((char **)var->addr)[x * us_menuy + y];
							us_parsebinding(str, &commandbinding);
							if (*commandbinding.command != 0)
							{
								if (commandbinding.nodeglyph != NONODEPROTO)
								{
									ttysetstatusfield(NOWINDOWFRAME, us_statusarc,
										describearcproto(us_curarcproto), 1);
									ttysetstatusfield(NOWINDOWFRAME, us_statusnode,
										us_describemenunode(&commandbinding), 1);
									overrodestatus = 1;
								}
								if (commandbinding.arcglyph != NOARCPROTO)
								{
									ttysetstatusfield(NOWINDOWFRAME, us_statusarc,
										describearcproto(commandbinding.arcglyph), 1);
									if (us_curnodeproto == NONODEPROTO) str = ""; else
										str = describenodeproto(us_curnodeproto);
									ttysetstatusfield(NOWINDOWFRAME, us_statusnode, str, 1);
									overrodestatus = 1;
								}
							}
							us_freebindingparse(&commandbinding);
						}
					}
				}
				if (inmenu == 0 && overrodestatus != 0)
				{
					ttysetstatusfield(NOWINDOWFRAME, us_statusarc,
						describearcproto(us_curarcproto), 1);
					if (us_curnodeproto == NONODEPROTO) str = ""; else
						str = describenodeproto(us_curnodeproto);
					ttysetstatusfield(NOWINDOWFRAME, us_statusnode, str, 1);
					overrodestatus = 0;
				}
			}

			setibeam = 0;
			for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
			{
				if (gra_cursorx < w->uselx || gra_cursorx > w->usehx ||
				    gra_cursory < w->usely || gra_cursory > w->usehy) continue;
				if ((w->state&WINDOWTYPE) == POPTEXTWINDOW ||
				    (w->state&WINDOWTYPE) == TEXTWINDOW)
				{
					e = w->editor;
					if ((e->state&EDITORTYPE) == PACEDITOR)
					{
						if (gra_cursorx <= w->usehx - SBARWIDTH &&
							gra_cursory >= w->usely + SBARWIDTH &&
							gra_cursory < e->revy)
						{
							setdefaultcursortype(IBEAMCURSOR);
							setibeam = 1;
						}
					}
				}
				break;
			}
			if (setibeam == 0) setdefaultcursortype(us_normalcursor);

			state = MOTION;
			if ((event->xmotion.state & (Button1Mask | Button2Mask | Button3Mask)) == 0)
				state |= BUTTONUP;
			gra_addeventtoqueue(state, gra_cursorx, gra_cursory);
			break;

		case ReparentNotify:
			break;

#if 0
		default:
			fprintf(stderr, "Unhandled event %s in graphics window.\n",
				eventNames[event->type]);
			break;
#endif
	}
}

/*
 * Routine to translate key symbols to electric state.
 * Returns 0 if the key is unknown.
 */
INTBIG gra_translatekey(XEvent *event)
{
	char buffer[2];
	KeySym key;
	INTBIG state;

	(void)XLookupString((XKeyEvent *)event, buffer, 2, &key, NULL);
	if (key > 0 && key < 0200) state = key; else
	{
		switch (key)
		{
			case XK_KP_0:      state = '0';   break;
			case XK_KP_1:      state = '1';   break;
			case XK_KP_2:      state = '2';   break;
			case XK_KP_3:      state = '3';   break;
			case XK_KP_4:      state = '4';   break;
			case XK_KP_5:      state = '5';   break;
			case XK_KP_6:      state = '6';   break;
			case XK_KP_7:      state = '7';   break;
			case XK_KP_8:      state = '8';   break;
			case XK_KP_9:      state = '9';   break;
			case XK_Left:
			case XK_KP_Left:   state = 034;   break;
			case XK_Right:
			case XK_KP_Right:  state = 035;   break;
			case XK_Up:
			case XK_KP_Up:     state = 036;   break;
			case XK_Down:
			case XK_KP_Down:   state = 037;   break;
			case XK_BackSpace: state = 010;   break;
			case XK_Tab:       state = 011;   break;
			case XK_Linefeed:  state = 012;   break;
			case XK_Return:    state = 015;   break;
			case XK_Escape:    state = 033;   break;
			case XK_Delete:    state = 0177;  break;
			case XK_KP_Enter:  state = 015;   break;
			default:           state = 0;     break;
		}
	}
	if (state == 0) return(0);
	if ((event->xbutton.state & ControlMask) != 0)
	{
		if (gra_messages_typingin == 0)
		{
			state |= METADOWN;
		} else
		{
			if (state >= 'a' && state <= 'z') state -= 'a' - 1; else
				if (state >= 'A' && state <= 'Z') state -= 'A' - 1;
		}
	}
	state |= ISCHAR;
	return(state);
}

/*
 * Function to show the cursor coordinate in the current window
 * enter with cursor coordinates in x, y, display in current lambda.
 */
void gra_showcoords(INTSML x, INTSML y)
{
#if 0
	INTBIG icx = x, icy = y;
	WINDOWPART *w;
	char temp[30];
	INTSML lx, ly, hx, hy;
	static POLYGON  *poly = NOPOLYGON;
	INTSML wid, hei;
	static INTSML maxwid = 0;
	XFontStruct *oldfont;

	if (poly == NOPOLYGON) poly = allocpolygon(4, us_aid->cluster);

	us_settextsize(NULL, TXTMENU);
	us_textsize(NULL, "X", &wid, &hei);
	hx = us_swid - 5; lx = hx - maxwid;
	hy = us_shei - 5; ly = hy - hei;
	us_drawbox(NULL, lx, hx, ly, hy, &us_ebox);  /* erase old value */

	for (w = el_topwindowpart; w!= NOWINDOWPART; w = w->nextwindowpart)
	{
		if ((w->state&WINDOWTYPE) != DISPWINDOW) continue;
		if (x >= w->uselx && x <= w->usehx && y >= w->usely && y <= w->usehy)
		{
			us_scaletowindow(&icx, &icy, w);
			if (us_alignment != 0) gridalign(&icx, &icy, us_alignment);
			sprintf(temp, "(%s, %s)", latoa(icx), latoa(icy));
			oldfont = gra_curfont;  /* save current environment */
			us_textsize(NULL, temp, &wid, &hei);
			maxwid = maxi(wid, maxwid);
			us_puttext(w, hx-wid, ly, temp, &us_menutext);
			gra_curfont = oldfont;
			break;
		}
	}
#endif
}

void gra_repaint(INTSML redo)
{
	XWindowAttributes xwa;
#ifdef ANYDEPTH
	INTSML newwid, newhei, i, j;
	XImage *newworld;
	char *newdataaddr8, **newrowstart, *newdataaddr, **newoffrowstart;

	/* we could use a global xwa */
#  ifdef USETIF
	XGetWindowAttributes(gra_dpy, gra_win, &xwa);
#  else
	XGetWindowAttributes(gra_topdpy, gra_topwin, &xwa);
#  endif
	newwid = xwa.width;
	newhei = xwa.height;

	if (newwid != us_swid || newhei != gra_shei)
	{
		/* allocate space for the 8-bit deep buffer */
		newdataaddr8 = (char *)emalloc(newwid * newhei, us_aid->cluster);
		newrowstart = (char **)emalloc(newhei * SIZEOFINTBIG, us_aid->cluster);
		if (newdataaddr8 == 0 || newrowstart == 0) return;
		for(i=0; i<newhei; i++)
		{
			newrowstart[i] = newdataaddr8 + i * newwid;
			for(j=0; j<newwid; j++)
				newrowstart[i][j] = 0;
		}

		/* deallocate old buffers and fill in new */
		efree((char *)gra_dataaddr8);
		efree((char *)gra_rowstart);
		gra_dataaddr8 = newdataaddr8;
		gra_rowstart = newrowstart;

		/* allocate space for the full-depth buffer */
		if (newwid > gra_worldwid || newhei > gra_worldhei)
		{
			newdataaddr = (char *)emalloc(newwid * newhei *
				gra_truedepth / 8, us_aid->cluster);
			newoffrowstart = (char **)emalloc(newhei * SIZEOFINTBIG, us_aid->cluster);
			if (newdataaddr == 0 || newoffrowstart == 0) return;
			newworld = XCreateImage(gra_dpy, gra_visual, gra_truedepth,
				ZPixmap, 0, newdataaddr, newwid, newhei, gra_sdep, 0);
			if (newworld == 0)
			{
				fprintf(stderr, "Error allocating new image array that is %dx%d\n",
					newwid, newhei);
				return;
			}
			for(i=0; i<newhei; i++)
				newoffrowstart[i] = newdataaddr + i * newworld->bytes_per_line;

			/* deallocate old data and set new */
			efree((char *)gra_dataaddr);
			efree((char *)gra_offrowstart);
			XFree(gra_world);
			gra_dataaddr = newdataaddr;
			gra_offrowstart = newoffrowstart;
			gra_world = newworld;
			gra_worldwid = newwid;   gra_worldhei = newhei;
		}
		us_swid = newwid;
		gra_shei = newhei;
		us_shei = gra_shei - gra_status_height;
		gra_revy = us_shei - 1;
	}
#else
	/* we could use a global xwa */
	XGetWindowAttributes(gra_topdpy, gra_topwin, &xwa);

	us_swid = xwa.width;
	gra_shei = xwa.height;
	us_shei = gra_shei - gra_status_height;
	gra_revy = us_shei - 1;

	XClearWindow(gra_dpy, gra_win);
#endif
	if (el_topwindowpart == NOWINDOWPART) return;

	/* mark start of redisplay */
	us_startbatch(NOAID, 0);

	/* save and clear highlighting */
	us_pushhighlight();
	us_clearhighlightcount();

	/* rewrite status area */
	us_redostatus(NOWINDOWFRAME);

	/* draw the separator line between drawing and status areas */
	us_box.col = BLACK;
	us_drawline(NULL, 1, -2, us_swid - 1, -2, &us_box, 0);

	if (redo != 0) us_drawmenu(1, NOWINDOWFRAME); else
		us_drawmenu(-1, NOWINDOWFRAME);

	/* restore highlighting */
	(void)us_pophighlight(0);

	/* finish drawing */
	us_endbatch();

	/* redraw any dialogs */
/*	Dredrawdialogwindow(); */

	/* describe this change */
	setactivity("Window Resize");
}

/*
 * helper routine to wait for some keyboard or mouse input
 */
void gra_waitforaction(void)
{
	REGISTER INTBIG err;

	if (us_logplay != NULL)
	{
		err = fread((char *)&gra_action, sizeof(gra_action), 1, us_logplay);
		if (stopping("Playback") != 0) err = 0;
		if (err != 0)
		{
			if (gra_playbackmultiple <= 0)
			{
				gra_playbackmultiple = 0;
				for(;;)
				{
					gra_nextevent();
					if (gra_inputstate == NOEVENT) continue;
					if ((gra_inputstate & ISCHAR) != ISCHAR) break;
					if ((gra_inputstate & CHARREAD) < '0' ||
						(gra_inputstate & CHARREAD) > '9') break;
					gra_playbackmultiple = gra_playbackmultiple * 10 +
						(gra_inputstate & CHARREAD) - '0';
				}
				if ((gra_inputstate != NOEVENT) &&
					((gra_inputstate & (ISCHAR | CHARREAD)) == (ISCHAR | 'q'))) err = 0;
			}
			gra_playbackmultiple--;
			gra_inputstate = gra_action.kind & 0xFFFF;
			gra_cursorx = gra_action.x;
			gra_cursory = gra_action.y;
			if (gra_cursory < 0) gra_cursory = 0;
		}
		if (err == 0)
		{
			ttyputmsg("End of session playback file");
			(void)fclose(us_logplay);
			us_logplay = NULL;
			return;
		}
	} else
	{
		flushscreen();
		gra_nextevent();
	}

	if ((us_logrecord != NULL) && (gra_inputstate != NOEVENT))
	{
		gra_action.kind = gra_inputstate;
		gra_action.x = gra_cursorx;
		gra_action.y = gra_cursory;
		if (fwrite((char *)&gra_action, sizeof (gra_action), 1, us_logrecord) == 0)
		{
			ttyputerr("Error writing session log file: recording disabled");
			us_logfinishrecord();
		}
		gra_logrecordindex++;
		if (gra_logrecordindex >= us_logflushfreq)
		{
			/* flush the session log file */
			gra_logrecordindex = 0;
			(void)fflush(us_logrecord);
		}
	}
}

/*
 * support routine to print any internal errors
 */
int gra_xerrors(Display *dpy, XErrorEvent *err)
{
	char buffer[100];

	XGetErrorText(dpy, err->error_code, buffer, 100);
	/* buffer is now in the "encoding of the current locale" */
	ttyputerr("ERROR: X Window System routine %d has %s", err->request_code, buffer);
	return(0);
}
void gra_xterrors(char *msg)
{
	ttyputerr("ERROR: X Toolkit: %s", msg);
}

/* error events */
RETSIGTYPE gra_sigill_trap(void)
{
	(void)signal(SIGILL, (SIGNALCAST)gra_sigill_trap);
	db_severeerror("FATAL ERROR: An illegal instruction has been trapped");
}

RETSIGTYPE gra_sigfpe_trap(void)
{
	(void)signal(SIGFPE, (SIGNALCAST)gra_sigfpe_trap);
	db_severeerror("FATAL ERROR: A numerical error has occurred");
}

RETSIGTYPE gra_sigbus_trap(void)
{
	(void)signal(SIGBUS, (SIGNALCAST)gra_sigbus_trap);
	db_severeerror("FATAL ERROR: A bus error has occurred");
}

RETSIGTYPE gra_sigsegv_trap(void)
{
	(void)signal(SIGSEGV, (SIGNALCAST)gra_sigsegv_trap);
	db_severeerror("FATAL ERROR: A segmentation violation has occurred");
}

/*************************** SESSION LOGGING ROUTINES ***************************/

/*
 * routine to begin playback of session logging file "file".  The routine
 * returns nonzero if there is an error.  If "all" is nonzero, playback
 * the entire file with no prompt.
 */
INTSML us_logplayback(char *file, INTSML all)
{
	struct stat buf;
	REGISTER INTSML comcount;

	us_logplay = fopen(truepath(file), "r");
	if (us_logplay == NULL) return(1);

	ttyputmsg("Type any key to playback the next command in the log file");
	ttyputmsg("Type a number followed by 'x' to execute that many commands");
	ttyputmsg("Type 'q' to terminate playback");

	if (stat(file, &buf) >= 0)
	{
		comcount = buf.st_size / (sizeof(gra_action));
		ttyputmsg(" (there are %d commands to playback)", comcount);
	} else
	{
		comcount = 0;
	}

	if (all != 0) gra_playbackmultiple = comcount;
	return(0);
}

/*
 * routine to create a session logging file
 */
void us_logstartrecord(void)
{
#if 0
	us_logrecord = xcreate(ELECTRICLOG, FILETYPELOG, 0, 0);
#else
	us_logrecord = NULL;
#endif
}

/*
 * routine to terminate session logging
 */
void us_logfinishrecord(void)
{
	if (us_logrecord != NULL) xclose(us_logrecord);
	us_logrecord = NULL;
}

/****************************** MENUS ******************************/

void getacceleratorstrings(char **acceleratorstring, char **acceleratorprefix)
{
	*acceleratorstring = "Ctrl";
	*acceleratorprefix = "Ctrl-";
}

INTSML nativepopupmenu(POPUPMENU *menu, INTSML header, INTSML left, INTSML top)
{
#ifdef USETIF
	Widget popmenu, child;
	Arg arg[10];
	INTBIG ac, j;
	POPUPMENUITEM *mi;
	XEvent event;

	if (left < 0 || top < 0)
	{
		left = gra_cursorx;
		top = gra_revy - gra_cursory;
	}
	ac = 0;
	XtSetArg(arg[ac], XmNx, left);   ac++;
	XtSetArg(arg[ac], XmNy, top);   ac++;
	popmenu = (Widget)XmCreatePopupMenu(gra_toplevelwidget, "menu", arg, ac);
	if (header != 0)
	{
		child = (Widget)XmCreatePushButton(popmenu, menu->header, NULL, 0);
		XtManageChild(child);
		XtAddCallback(child, XmNactivateCallback,
			(XtCallbackProc)gra_menupcb, (XtPointer)-2);
		XtVaCreateManagedWidget("sep", xmSeparatorWidgetClass, popmenu, NULL);
	}
	for(j=0; j<menu->total; j++)
	{
		mi = &menu->list[j];
		mi->changed = 0;
		child = (Widget)XmCreatePushButton(popmenu, mi->attribute, NULL, 0);
		XtManageChild(child);
		XtAddCallback(child, XmNactivateCallback,
			(XtCallbackProc)gra_menupcb, (XtPointer)j);
	}
	XtAddCallback(popmenu, XmNunmapCallback,
		(XtCallbackProc)gra_menupcb, (XtPointer)-2);
	XtManageChild(popmenu);

	gra_popupmenuresult = -1;
	gra_inputstate = NOEVENT;
	while (gra_popupmenuresult == -1)
	{
		gra_nextevent();
		if (gra_inputstate == NOEVENT) continue;
		if ((gra_inputstate & ISBUTTON) != 0 && (gra_inputstate & BUTTONUP) != 0)
		{
			gra_inputstate = NOEVENT;
			break;
		}
	}
	XtDestroyWidget(popmenu);
	if (gra_popupmenuresult < 0) return(-1);
	return(gra_popupmenuresult);
#else
	return(-1);
#endif
}

#ifdef USETIF
void gra_menupcb(Widget w, int item_number, XtPointer call_data)
{
	gra_popupmenuresult = (INTSML)item_number;
}
#endif

void gra_nativemenudoone(INTSML low, INTSML high)
{
#ifdef USETIF
	POPUPMENU *pm;

	if (low >= 0 && low < gra_pulldownmenucount)
	{
		pm = gra_pulldowns[low];
		if (high >= 0 && high < pm->total)
		{
			us_state |= DIDINPUT;
			us_state &= ~GOTXY;
			setdefaultcursortype(NULLCURSOR);
			us_forceeditchanges();
			us_execute(pm->list[high].response, us_aid->aidstate&ECHOBIND, 1, 1);
			db_setcurrenttool(us_aid);
			setactivity(pm->list[high].attribute);
		}
	}
#endif
}

INTSML nativemenuload(INTSML count, char *par[])
{
#ifdef USETIF
	REGISTER INTSML i, j;
	char myline[256], *pt, mstring[2];
	REGISTER POPUPMENU *pm;
	Widget thismenu, child;

	/* delete any dummy menu created during initialization */
	if (gra_firstmenu != 0)
	{
		XtUnmanageChild(gra_firstmenu);
		XtDestroyWidget(gra_firstmenu);
		gra_firstmenu = 0;
	}

	/* build the pulldown menu bar */
	mstring[1] = 0;
	for(i=0; i<count; i++)
	{
		pm = us_getpopupmenu(par[i]);
		if (pm == NOPOPUPMENU) continue;

		/* see if there is a mnemonic */
		mstring[0] = 0;
		pt = myline;
		for(j=0; pm->header[j] != 0; j++)
		{
			if (pm->header[j] == '&') mstring[0] = pm->header[j+1]; else
				*pt++ = pm->header[j];
		}
		*pt = 0;

		child = XtVaCreateManagedWidget(myline, xmCascadeButtonWidgetClass, gra_menubar, NULL);
		if (mstring[0] != 0)
			XtVaSetValues(child, XmNmnemonic, XStringToKeysym(mstring), NULL);
		thismenu = XmVaCreateSimplePulldownMenu(gra_menubar, "menu", i,
			(XtCallbackProc)gra_menucb, NULL);
		if (thismenu == 0) return(1);
		gra_pulldownindex(pm, i, thismenu);
	}
	return(0);
#else
	return(1);
#endif
}

void nativemenurename(POPUPMENU *pm, INTSML index)
{
#ifdef USETIF
	INTSML i, j, len;
	char line[100], *pt, mstring[2];
	Widget w;
	Arg arg[5];
	XmString label;

	for(i=0; i<gra_pulldownmenucount; i++)
		if (gra_pulldowns[i] == pm) break;
	if (i >= gra_pulldownmenucount) return;
	if (index < 0 || index > gra_pulldownmenusize[i]) return;
	w = gra_pulldownmenulist[i][index];
	if (w == 0) return;

	/* see if there is a mnemonic */
	mstring[1] = 0;
	mstring[0] = 0;
	pt = line;
	for(j=0; pm->list[index].attribute[j] != 0; j++)
	{
		if (pm->list[index].attribute[j] == '&') mstring[0] = pm->list[index].attribute[j+1]; else
			*pt++ = pm->list[index].attribute[j];
	}
	*pt = 0;

	pt = line;
	len = strlen(line);
	if (pt[len-1] != '<')
	{
		label = XmStringCreateLocalized(line);
		XtSetArg(arg[0], XmNlabelString, label);
		XtSetValues(w, arg, 1);
		XmStringFree(label);
	} else
	{
		pt[len-1] = 0;
		if (*pt == '>')
		{
			pt++;
			label = XmStringCreateLocalized(pt);
			XtSetArg(arg[0], XmNlabelString, label);
			XtSetValues(w, arg, 1);
			XmStringFree(label);
			XmToggleButtonSetState(w, True, 0);
		} else
		{
			label = XmStringCreateLocalized(pt);
			XtSetArg(arg[0], XmNlabelString, label);
			XtSetValues(w, arg, 1);
			XmStringFree(label);
			XmToggleButtonSetState(w, False, 0);
		}
	}
#endif
}

#ifdef USETIF
/*
 * Routine to create a pulldown menu from popup menu "pm".
 * Returns an index to the table of pulldown menus (-1 on error).
 */
void gra_pulldownindex(POPUPMENU *pm, INTSML order, Widget parent)
{
	REGISTER INTSML i, index, *newpulldownmenucount;
	Widget *newpulldownmenus, **newpulldownmenulist;
	POPUPMENU **newpulldowns;

	/* see if it is in the list already */
	for(i=0; i<gra_pulldownmenucount; i++)
		if (gra_pulldowns[i] == pm) return;

	/* allocate new space with one more */
	newpulldownmenus = (Widget *)emalloc((gra_pulldownmenucount+1) *
		(sizeof (Widget)), us_aid->cluster);
	if (newpulldownmenus == 0) return;
	newpulldowns = (POPUPMENU **)emalloc((gra_pulldownmenucount+1) *
		(sizeof (POPUPMENU *)), us_aid->cluster);
	if (newpulldowns == 0) return;
	newpulldownmenucount = (INTSML *)emalloc((gra_pulldownmenucount+1) *
		SIZEOFINTSML, us_aid->cluster);
	if (newpulldownmenucount == 0) return;
	newpulldownmenulist = (Widget **)emalloc((gra_pulldownmenucount+1) *
		(sizeof (Widget *)), us_aid->cluster);
	if (newpulldownmenulist == 0) return;

	/* copy former arrays then delete them */
	for(i=0; i<gra_pulldownmenucount; i++)
	{
		newpulldownmenus[i] = gra_pulldownmenus[i];
		newpulldowns[i] = gra_pulldowns[i];
		newpulldownmenucount[i] = gra_pulldownmenusize[i];
		newpulldownmenulist[i] = gra_pulldownmenulist[i];
	}
	if (gra_pulldownmenucount != 0)
	{
		efree((char *)gra_pulldownmenus);
		efree((char *)gra_pulldowns);
		efree((char *)gra_pulldownmenusize);
		efree((char *)gra_pulldownmenulist);
	}
	gra_pulldownmenus = newpulldownmenus;
	gra_pulldowns = newpulldowns;
	gra_pulldownmenusize = newpulldownmenucount;
	gra_pulldownmenulist = newpulldownmenulist;

	index = gra_pulldownmenucount++;
	gra_pulldownmenus[index] = parent;
	gra_pulldowns[index] = pm;
	gra_pulldownmenusize[index] = pm->total;
	gra_pulldownmenulist[index] = (Widget *)emalloc(pm->total * (sizeof (Widget)),
		us_aid->cluster);
	if (newpulldownmenulist[index] == 0) return;
	gra_makepdmenu(pm, order, parent, newpulldownmenulist[index]);
}

/*
 * Routine to create pulldown menu number "value" from the popup menu in "pm" and return
 * the menu handle.
 */
Widget gra_makepdmenu(POPUPMENU *pm, INTSML value, Widget thismenu, Widget *childlist)
{
	REGISTER INTBIG i, j;
	char myline[256], metaline[50], *pt, mstring[2];
	REGISTER USERCOM *uc;
	REGISTER POPUPMENUITEM *mi;
	Widget submenu;
	REGISTER INTSML len;
	Arg arg[5];
	XmString acctext;

	/* build the actual menu */
	mstring[1] = 0;
	for(i=0; i<pm->total; i++)
	{
		childlist[i] = 0;
		mi = &pm->list[i];

		/* see if there is a mnemonic */
		mstring[0] = 0;
		pt = myline;
		for(j=0; mi->attribute[j] != 0; j++)
		{
			if (mi->attribute[j] == '&') mstring[0] = mi->attribute[j+1]; else
				*pt++ = mi->attribute[j];
		}
		*pt = 0;

		uc = mi->response;
		if (uc->active < 0)
		{
			if (*mi->attribute == 0)
			{
				/* separator */
				XtVaCreateManagedWidget("sep", xmSeparatorWidgetClass, thismenu, NULL);
			} else
			{
				/* dimmed item (DIM IT!!!) */
				childlist[i] = (Widget)XmCreatePushButton(thismenu, myline, NULL, 0);
			}
			continue;
		}

		/* see if this command is another menu */
		if (uc->menu != NOPOPUPMENU)
		{
			submenu = (Widget)XmVaCreateSimplePulldownMenu(thismenu, "menu", i,
				(XtCallbackProc)gra_menucb, NULL);
			if (submenu == 0) return(0);
			XtSetArg(arg[0], XmNsubMenuId, submenu);
			childlist[i] = XmCreateCascadeButton(thismenu, myline, arg, 1);
			if (mstring[0] != 0)
				XtVaSetValues(childlist[i], XmNmnemonic, XStringToKeysym(mstring), NULL);
			XtManageChild(childlist[i]);
			gra_pulldownindex(uc->menu, i, submenu);
			continue;
		}

		/* insert command title */
		len = strlen(myline);
		if (myline[len-1] == '<')
		{
			pt = myline;
			myline[len-1] = 0;
			if (pt[0] == '>') pt++;
			childlist[i] = (Widget)XmCreateToggleButton(thismenu, pt, NULL, 0);
			if (mstring[0] != 0)
				XtVaSetValues(childlist[i], XmNmnemonic, XStringToKeysym(mstring), NULL);
			XtManageChild(childlist[i]);
			if (myline[0] == '>')
				XmToggleButtonSetState(childlist[i], True, 0); else
					XmToggleButtonSetState(childlist[i], False, 0);
			XtAddCallback(childlist[i], XmNvalueChangedCallback,
				(XtCallbackProc)gra_menucb, (XtPointer)i);
		} else
		{
			if (myline[len-2] == '/')
			{
				myline[len-2] = 0;
				sprintf(metaline, "Ctrl-%s", &myline[len-1]);
				acctext = XmStringCreateLocalized(metaline);
				childlist[i] = (Widget)XmCreatePushButton(thismenu, myline, NULL, 0);
				if (mstring[0] != 0)
					XtVaSetValues(childlist[i], XmNmnemonic, XStringToKeysym(mstring), NULL);
				XtManageChild(childlist[i]);
				XtVaSetValues(childlist[i], XmNacceleratorText, acctext, NULL);
				XmStringFree(acctext);
			} else
			{
				childlist[i] = (Widget)XmCreatePushButton(thismenu, myline, NULL, 0);
				if (mstring[0] != 0)
					XtVaSetValues(childlist[i], XmNmnemonic, XStringToKeysym(mstring), NULL);
				XtManageChild(childlist[i]);
			}
			XtAddCallback(childlist[i], XmNactivateCallback,
				(XtCallbackProc)gra_menucb, (XtPointer)i);
		}
	}
	return(thismenu);
}

void gra_menucb(Widget w, int item_number, XtPointer call_data)
{
	Widget parent;
	INTBIG i;

	parent = XtParent(w);
	for(i=0; i<gra_pulldownmenucount; i++)
		if (gra_pulldownmenus[i] == parent) break;
	if (i >= gra_pulldownmenucount) return;

	gra_nativemenudoone(i, item_number);
}
#endif


#ifdef USETIF

/* #define DIALOGFRAME 1 */

/****************************** MOTIF/LESSTIF DIALOGS ******************************/

/*
 * Routine to initialize a dialog described by "dialog".
 * Returns nonzero if dialog cannot be initialized.
 */
INTSML DiaInitDialog(DIALOG *dialog)
{
	Widget temp, menu, focus;
	Arg arg[20];
	char *title, *pt;
	INTBIG i, j, len, itemtype, ac, x, y, wid, hei;
	short inix, iniy;
	XmString str;
	Display *dpy;
	Window win;
	Pixmap map;
	String translation;
	XtActionsRec actions;
	static INTSML actionsset = 0;

	/* get the current dialog structure */
	gra_curdialogindex++;
	gra_curdialog = &gra_dialogs[gra_curdialogindex];

	/* create the dialog */
	title = dialog->movable;
	if (title == 0 || *title == 0) title = " ";
	gra_getdialogcoordinates(&dialog->windowRect, &x, &y, &wid, &hei);

#ifdef DIALOGFRAME
	/* make dialog frame */
	gra_curdialog->windowframe = (Widget)XtAppCreateShell(NULL, NULL,
		applicationShellWidgetClass, gra_dpy, NULL, 0);
	ac = 0;
	XtSetArg(arg[ac], XmNx,               x);   ac++;
	XtSetArg(arg[ac], XmNy,               y);   ac++;
	XtSetArg(arg[ac], XmNwidth,           wid);   ac++;
	XtSetArg(arg[ac], XmNheight,          hei);   ac++;
	XtSetArg(arg[ac], XmNtitle,           title);   ac++;
/*	XtSetArg(arg[ac], XmNmwmFunctions,    MWM_FUNC_MOVE);   ac++; */
	XtSetValues(gra_curdialog->windowframe, arg, 5);
#endif

	ac = 0;
	XtSetArg(arg[ac], XmNdialogStyle,     XmDIALOG_PRIMARY_APPLICATION_MODAL);   ac++;
	XtSetArg(arg[ac], XmNx,               x);   ac++;
	XtSetArg(arg[ac], XmNy,               y);   ac++;
	XtSetArg(arg[ac], XmNwidth,           wid);   ac++;
	XtSetArg(arg[ac], XmNheight,          hei);   ac++;
#ifndef DIALOGFRAME
	str = XmStringCreateLocalized(title);
	XtSetArg(arg[ac], XmNdialogTitle,     str);   ac++;
#endif
	XtSetArg(arg[ac], XmNautoUnmanage,    False);   ac++;
	XtSetArg(arg[ac], XmNmarginWidth,     0);   ac++;
	XtSetArg(arg[ac], XmNmarginHeight,    0);   ac++;
	XtSetArg(arg[ac], XmNallowOverlap,    True);   ac++;
	XtSetArg(arg[ac], XmNresizePolicy,    XmRESIZE_NONE);   ac++;
/*	XtSetArg(arg[ac], XmNdeleteResponse,  XmDO_NOTHING);   ac++; */
	XtSetArg(arg[ac], XmNmwmFunctions,    MWM_FUNC_MOVE);   ac++;
	XtSetArg(arg[ac], XmNdefaultPosition, False);   ac++;
	
#ifdef DIALOGFRAME
	gra_curdialog->window = (Widget)XmCreateBulletinBoard(gra_curdialog->windowframe, 
		"dialog", arg, ac);
	XmAddWMProtocolCallback(gra_curdialog->windowframe, gra_wm_delete_window,
		(XtCallbackProc)gra_windowdelete, gra_curdialog->window);
#else
	gra_curdialog->window = (Widget)XmCreateBulletinBoardDialog(gra_toplevelwidget,
		"dialog", arg, ac);
#endif
	gra_curdialog->redrawroutine = 0;
	gra_curdialog->itemdesc = dialog;
	gra_curdialog->editline = -1;
	gra_curdialog->lastedittext[0] = 0;
	gra_curdialog->opaqueitem = -1;
	gra_curdialog->offx = gra_curdialog->offy = -1;
	XtManageChild(gra_curdialog->window);

	/* determine the default button */
	gra_curdialog->defaultbutton = 1;
	for(i=0; i<dialog->items; i++)
	{
		itemtype = dialog->list[i].type;
		if ((itemtype&ITEMTYPE) == DEFBUTTON)
			gra_curdialog->defaultbutton = i+1;
	}

	/* load the items */
	focus = 0;
	for(i=0; i<dialog->items; i++)
	{
		gra_getdialogcoordinates(&dialog->list[i].r, &x, &y, &wid, &hei);
		itemtype = dialog->list[i].type;
		switch (itemtype&ITEMTYPE)
		{
			case RADIO:				/* radio buttons seem too low, so raise them */
				y -= 5;
				break;
			case EDITTEXT:			/* raise text and force it to minimum height */
				y -= 4;
				if (hei < 30) hei = 30;
				break;
			case SCROLL:			/* shrink to make room for vertical scrollbar */
				wid -= 20;
				break;
			case POPUP:				/* popups seem too low, so raise them */
				y -= 7;
				break;
			case ICON:				/* icons must be a multiple of 2 in size */
				x = (x+1) / 2 * 2;
				y = (y+1) / 2 * 2;
				break;
		}
		ac = 0;
		XtSetArg(arg[ac], XmNx, x);   ac++;
		XtSetArg(arg[ac], XmNy, y);   ac++;
		XtSetArg(arg[ac], XmNwidth, wid);   ac++;
		XtSetArg(arg[ac], XmNheight, hei);   ac++;
		switch (itemtype&ITEMTYPE)
		{
			case BUTTON:
			case DEFBUTTON:
				gra_curdialog->items[i] = (Widget)XmCreatePushButton(gra_curdialog->window,
					dialog->list[i].msg, arg, ac);
				XtManageChild(gra_curdialog->items[i]);
				XtAddCallback(gra_curdialog->items[i], XmNactivateCallback,
					(XtCallbackProc)gra_dialogaction, (XtPointer)i);
				break;
			case CHECK:
				XtSetArg(arg[ac], XmNalignment, XmALIGNMENT_BEGINNING);   ac++;
				gra_curdialog->items[i] = (Widget)XmCreateToggleButton(gra_curdialog->window,
					dialog->list[i].msg, arg, ac);
				XtManageChild(gra_curdialog->items[i]);
				XtAddCallback(gra_curdialog->items[i], XmNvalueChangedCallback,
					(XtCallbackProc)gra_dialogaction, (XtPointer)i);
				break;
			case RADIO:
				temp = (Widget)XmCreateRadioBox(gra_curdialog->window, "radio", arg, ac);
				XtManageChild(temp);
				gra_curdialog->items[i] = XtVaCreateManagedWidget(dialog->list[i].msg,
					xmToggleButtonGadgetClass, temp, XmNindicatorSize, hei-8, NULL);
				XtAddCallback(gra_curdialog->items[i], XmNvalueChangedCallback,
					(XtCallbackProc)gra_dialogaction, (XtPointer)i);
				break;
			case EDITTEXT:
				gra_curdialog->items[i] = (Widget)XmCreateText(gra_curdialog->window, "text",
					arg, ac);
				XtManageChild(gra_curdialog->items[i]);
				XtAddCallback(gra_curdialog->items[i], XmNvalueChangedCallback,
					(XtCallbackProc)gra_dialogaction, (XtPointer)i);
				if (focus == 0) focus = gra_curdialog->items[i];
				break;
			case MESSAGE:
				XtSetArg(arg[ac], XmNalignment, XmALIGNMENT_BEGINNING);   ac++;
				gra_curdialog->items[i] = (Widget)XmCreateLabel(gra_curdialog->window,
					dialog->list[i].msg, arg, ac);
				XtManageChild(gra_curdialog->items[i]);
				break;
			case PROGRESS:
				gra_curdialog->items[i] = (Widget)XmCreateDrawingArea(gra_curdialog->window,
					"user", arg, ac);
				XtManageChild(gra_curdialog->items[i]);
				break;
			case DIVIDELINE:
				gra_curdialog->items[i] = (Widget)XmCreateDrawingArea(gra_curdialog->window,
					"user", arg, ac);
				XtManageChild(gra_curdialog->items[i]);
				XtAddCallback(gra_curdialog->items[i], XmNexposeCallback,
					(XtCallbackProc)gra_dialogredrawsep, (XtPointer)i);
				dpy = XtDisplay(gra_curdialog->items[i]);
				win = XtWindow(gra_curdialog->items[i]);
				XSetForeground(dpy, gra_gc, BlackPixelOfScreen(XtScreen(gra_curdialog->items[i])));
				XFillRectangle(dpy, win, gra_gc, 0, 0, wid, hei);
				break;
			case USERDRAWN:
				if (actionsset == 0)
				{
					actions.string = "draw";
					actions.proc = (XtActionProc)gra_dialogdraw;
					XtAppAddActions(gra_xtapp, &actions, 1);
					actionsset = 1;
				}
				translation =
					"<BtnDown>:   draw(down)   ManagerGadgetArm() \n\
					 <BtnUp>:     draw(up)     ManagerGadgetActivate() \n\
					 <BtnMotion>: draw(motion) ManagerGadgetButtonMotion()";
				XtSetArg(arg[ac], XmNtranslations, XtParseTranslationTable(translation));   ac++;
				gra_curdialog->items[i] = (Widget)XmCreateDrawingArea(gra_curdialog->window,
					"user", arg, ac);
				XtManageChild(gra_curdialog->items[i]);
				XtAddCallback(gra_curdialog->items[i], XmNexposeCallback,
					(XtCallbackProc)gra_dialogredraw, (XtPointer)i);
				break;
			case POPUP:
				gra_curdialog->items[i] = (Widget)XmCreateOptionMenu(gra_curdialog->window,
					"menu", arg, ac);
				dialog->list[i].data = 0;
				break;
			case ICON:
				map = gra_makeicon(dialog->list[i].msg, gra_curdialog->window);
				if (map == 0) break;
				if ((itemtype&INACTIVE) != 0)
				{
					/* inactive: make it a label */
					XtSetArg(arg[ac], XmNlabelType, XmPIXMAP);   ac++;
					XtSetArg(arg[ac], XmNlabelPixmap, map);   ac++;
					gra_curdialog->items[i] = (Widget)XmCreateLabel(gra_curdialog->window,
						dialog->list[i].msg, arg, ac);
				} else
				{
					/* active: make it a pushbutton */
					XtSetArg(arg[ac], XmNlabelType, XmPIXMAP);   ac++;
					XtSetArg(arg[ac], XmNlabelPixmap, map);   ac++;
					XtSetArg(arg[ac], XmNhighlightThickness, 0);   ac++;
					XtSetArg(arg[ac], XmNshadowThickness, 0);   ac++;
					XtSetArg(arg[ac], XmNborderWidth, 0);   ac++;
					gra_curdialog->items[i] = (Widget)XmCreatePushButton(gra_curdialog->window,
						dialog->list[i].msg, arg, ac);
					XtManageChild(gra_curdialog->items[i]);
					XtAddCallback(gra_curdialog->items[i], XmNactivateCallback,
						(XtCallbackProc)gra_dialogaction, (XtPointer)i);
				}
				XtManageChild(gra_curdialog->items[i]);
				break;
			case SCROLL:
				XtSetArg(arg[ac], XmNselectionPolicy, XmBROWSE_SELECT);   ac++;
				XtSetArg(arg[ac], XmNresizePolicy, XmRESIZE_NONE);   ac++;
				XtSetArg(arg[ac], XmNlistSizePolicy, XmCONSTANT);   ac++;
				gra_curdialog->items[i] = (Widget)XmCreateScrolledList(gra_curdialog->window,
					"scroll", arg, ac);
				XtManageChild(gra_curdialog->items[i]);
				if (gra_doublethreshknown == 0)
				{
					gra_doublethreshknown = 1;
					XtSetArg(arg[0], XmNdoubleClickInterval, &j);
					XtGetValues(gra_curdialog->items[i], arg, 1);
					gra_doublethresh = j;
				}
				break;
			default:
				break;
		}
	}

	/* set focus to first edit text field */
	if (focus != 0)
	{
		XtSetArg(arg[0], XmNinitialFocus, focus);
		XtSetValues(gra_curdialog->window, arg, 1);
	}

	/* set default button if appropriate */
	itemtype = dialog->list[gra_curdialog->defaultbutton-1].type;
	if ((itemtype&ITEMTYPE) == BUTTON || (itemtype&ITEMTYPE) == DEFBUTTON)
	{
		temp = gra_curdialog->items[gra_curdialog->defaultbutton-1];
		if (focus == 0)
		{
			XtSetArg(arg[0], XmNinitialFocus, temp);
			XtSetValues(gra_curdialog->window, arg, 1);
		}
		XtSetArg(arg[0], XmNdefaultButton, temp);
		XtSetValues(gra_curdialog->window, arg, 1);
		XtSetArg(arg[0], XmNshowAsDefault, 1);
		XtSetValues(temp, arg, 1);
	}

	gra_dialoghit = -1;
#ifdef DIALOGFRAME
	XtRealizeWidget(gra_curdialog->windowframe);
#endif
	gra_flushdialog();
	return(0);
}

/*
 * Routine to handle actions and return the next item hit.
 */
INTSML DiaNextHit(void)
{
	INTSML item;
	Arg arg[2];
	INTBIG x, y, wid, hei;
	short inix, iniy;

	for(;;)
	{
		gra_nextevent();

		/*
		 * What a hack!  Have to obtain offset between specified dialog position and
		 * actual position (to account for the dialog title size and border width).
		 * But the only way to get it reliably is to wait until it is fully mapped,
		 * and that only happens here in the event loop.
		 */
		if (gra_curdialog->offx == -1 && gra_curdialog->offy == -1)
		{
			/* determine offset between specified dialog position and actual */
			gra_getdialogcoordinates(&gra_curdialog->itemdesc->windowRect,
				&x, &y, &wid, &hei);
			XtSetArg(arg[0], XtNx, &inix);
			XtSetArg(arg[1], XtNy, &iniy);
			XtGetValues(gra_curdialog->window, arg, 2);
			if (inix != x || iniy != y)
			{
				gra_curdialog->offx = inix * DIALOGDEN / DIALOGNUM -
					gra_curdialog->itemdesc->windowRect.left;
				gra_curdialog->offy = iniy * DIALOGDEN / DIALOGNUM -
					gra_curdialog->itemdesc->windowRect.top;
			}
		}

		if (gra_dialoghit != -1)
		{
			item = gra_dialoghit;
			gra_dialoghit = -1;
			return(item);
		}
	}
}

/*
 * Routine to parse the next input event and return the next character typed.
 * If the routine returns -1, nothing has happened.  If the
 * routine returns -2, an item has been hit (and is in "itemHit").
 */
INTSML DiaGetNextCharacter(INTSML *itemHit)
{
	INTSML chr;

	gra_nextevent();
	if (gra_dialoghit == -1) return(-1);
	*itemHit = gra_dialoghit;
	if (gra_dialoghitchar == 0) return(-2);
	chr = gra_dialoghitchar;
	gra_dialoghitchar = 0;
	return(chr);
}

void DiaDoneDialog(void)
{
	Arg arg[3];
	INTBIG origleft, origtop, dx, dy;
	short newx, newy;

	/* adjust the dialog position if it was moved */
	if (gra_curdialog->offx != -1 && gra_curdialog->offy != -1)
	{
		XtSetArg(arg[0], XtNx, &newx);
		XtSetArg(arg[1], XtNy, &newy);
		XtGetValues(gra_curdialog->window, arg, 2);
		origleft = newx * DIALOGDEN / DIALOGNUM - gra_curdialog->offx;
		origtop = newy * DIALOGDEN / DIALOGNUM - gra_curdialog->offy;
		dx = origleft - gra_curdialog->itemdesc->windowRect.left;
		dy = origtop - gra_curdialog->itemdesc->windowRect.top;
		gra_curdialog->itemdesc->windowRect.left += dx;
		gra_curdialog->itemdesc->windowRect.right += dx;
		gra_curdialog->itemdesc->windowRect.top += dy;
		gra_curdialog->itemdesc->windowRect.bottom += dy;
	}

	XtUnmanageChild(gra_curdialog->window);
	XtDestroyWidget(gra_curdialog->window);
#ifdef DIALOGFRAME
	XtDestroyWidget(gra_curdialog->windowframe);
#endif
	gra_curdialogindex--;
	if (gra_curdialogindex >= 0)
		gra_curdialog = &gra_dialogs[gra_curdialogindex];
}

/*
 * Routine to set the text in item "item" to "msg"
 */
void DiaSetText(INTSML item, char *msg)
{
	Arg arg[5];
	INTSML type, highlight;
	XmString str;
	Widget w;
	INTBIG bigitem, count, i, textwid, x, y, itemwid, itemhei, len;
	int direction, asc, desc;
	XmFontList fontlist;
	XmFontListEntry fontentry;
	XmFontContext fontlistcontext;
	XmFontType entrytype;
	XFontStruct *font;
	XFontSet fontset;
	XtPointer retval;
	char **fontnamelist, *pt;
	XFontStruct **fontstructlist;
	XCharStruct xcs;
	static XFontStruct *theFont = 0;
	static char *brokenbuf;
	static INTBIG brokenbufsize = 0;

	highlight = 0;
	if (item < 0)
	{
		item = -item;
		highlight = 1;
	}
	item--;
	w = gra_curdialog->items[item];
	type = gra_curdialog->itemdesc->list[item].type;
	if ((type&ITEMTYPE) == EDITTEXT)
	{
		bigitem = (INTBIG)item;
		XtRemoveCallback(w, XmNvalueChangedCallback,
			(XtCallbackProc)gra_dialogaction, (XtPointer)bigitem);
		XmTextSetString(w, msg);
		count = XmTextGetLastPosition(w);
		if (highlight != 0)
		{
			XmTextSetSelection(w, 0, count, 0);
			XtSetArg(arg[0], XmNinitialFocus, w);
			XtSetValues(gra_curdialog->window, arg, 1);
		} else
		{
			XmTextSetSelection(w, count, count, 0);
		}
		XtAddCallback(w, XmNvalueChangedCallback,
			(XtCallbackProc)gra_dialogaction, (XtPointer)bigitem);
		if (item == gra_curdialog->editline)
			strcpy(gra_curdialog->lastedittext, msg);
	} else
	{
		/* cache the font used to draw messages (once only) */
		if (theFont == 0)
		{
			XtSetArg(arg[0], XmNfontList, &fontlist);
			XtGetValues(w, arg, 1);
			if (XmFontListInitFontContext(&fontlistcontext, fontlist))
			{
				fontentry = XmFontListNextEntry(fontlistcontext);
				if (fontentry != 0)
				{
					retval = XmFontListEntryGetFont(fontentry, &entrytype);
					if (entrytype == XmFONT_IS_FONT)
					{
						theFont = (XFontStruct *)retval;
					} else if (entrytype == XmFONT_IS_FONTSET)
					{
						fontset = (XFontSet)retval;
						count = XFontsOfFontSet(fontset, &fontstructlist, &fontnamelist);
						if (count > 0)
							theFont = fontstructlist[0];
					}
				}
				XmFontListFreeFontContext(fontlistcontext);
			}
		}

		/* see if the text fits */
		if (theFont == 0) textwid = itemwid = 10; else
		{
			XTextExtents(theFont, msg, strlen(msg), &direction, &asc, &desc, &xcs);
			textwid = xcs.width;
			gra_getdialogcoordinates(&gra_curdialog->itemdesc->list[item].r, &x, &y, &itemwid, &itemhei);
		}
		if (textwid > itemwid)
		{
			/* break up the text */
			if (strlen(msg)*2 > brokenbufsize)
			{
				if (brokenbufsize > 0) efree(brokenbuf);
				brokenbufsize = strlen(msg)*2;
				brokenbuf = (char *)emalloc(brokenbufsize, us_aid->cluster);
			}
			strcpy(brokenbuf, msg);
			pt = brokenbuf;
			for(;;)
			{
				/* look backwards for blank space that fits */
				for(len = strlen(pt); len > 0; len--)
				{
					if (pt[len] != ' ' && pt[len] != 0) continue;
					XTextExtents(theFont, msg, len, &direction, &asc, &desc, &xcs);
					if (xcs.width <= itemwid) break;
				}
				if (len == 0)
				{
					/* no place to break in blank space: break where possible */
					for(len = strlen(pt)-1; len > 0; len--)
					{
						XTextExtents(theFont, msg, len, &direction, &asc, &desc, &xcs);
						if (xcs.width <= itemwid) break;
					}
					for(i=strlen(pt)+1; i>len; i--)
						pt[i] = pt[i-1];
				}
				if (len == strlen(pt)) break;
				pt[len] = '\n';
				pt = &pt[len+1];
			}
			str = XmStringCreateLocalized(brokenbuf);
			XtSetArg(arg[0], XmNlabelString, str);
			XtSetValues(w, arg, 1);
			XmStringFree(str);
		} else
		{
			str = XmStringCreateLocalized(msg);
			XtSetArg(arg[0], XmNlabelString, str);
			XtSetValues(w, arg, 1);
			XmStringFree(str);
		}
	}
	gra_flushdialog();
}

/*
 * Routine to return the text in item "item"
 */
char *DiaGetText(INTSML item)
{
	Arg arg;
	INTSML type;
	XmString str;
	char *text, *retstring;

	item--;
	if (gra_curdialog->opaqueitem == item)
		return(gra_opaquefield);

	type = gra_curdialog->itemdesc->list[item].type;
	if ((type&ITEMTYPE) == EDITTEXT)
		return(XmTextGetString(gra_curdialog->items[item]));

	if ((type&ITEMTYPE) == MESSAGE)
	{
		XtSetArg(arg, XmNlabelString, &str);
		XtGetValues(gra_curdialog->items[item], &arg, 1);
		XmStringGetLtoR(str, XmFONTLIST_DEFAULT_TAG, &text);
		(void)initinfstr();
		(void)addstringtoinfstr(text);
		retstring = returninfstr();
		XtFree(text);
		return(retstring);
	}
	return("");
}

/*
 * Routine to set the value in item "item" to "value"
 */
void DiaSetControl(INTSML item, INTSML value)
{
	item--;
	XmToggleButtonSetState(gra_curdialog->items[item], value, False);
	gra_flushdialog();
}

/*
 * Routine to return the value in item "item"
 */
INTSML DiaGetControl(INTSML item)
{
	INTSML value;

	item--;
	value = XmToggleButtonGetState(gra_curdialog->items[item]);
	return(value);
}

/*
 * Routine to check item "item" to make sure that there is
 * text in it.  If so, it returns nonzero.  Otherwise it beeps and returns zero.
 */
INTSML DiaValidEntry(INTSML item)
{
	char *msg;

	msg = DiaGetText(item);
	while (*msg == ' ') msg++;
	if (*msg != 0) return(1);
	ttybeep();
	return(0);
}

/*
 * Routine to dim item "item"
 */
void DiaDimItem(INTSML item)
{
	item--;
	XtSetSensitive(gra_curdialog->items[item], False);
	gra_flushdialog();
}

/*
 * Routine to un-dim item "item"
 */
void DiaUnDimItem(INTSML item)
{
	item--;
	XtSetSensitive(gra_curdialog->items[item], True);
	gra_flushdialog();
}

/*
 * Routine to change item "item" to be a message rather
 * than editable text
 */
void DiaNoEditControl(INTSML item)
{
	DiaDimItem(item);
}

/*
 * Routine to change item "item" to be editable text rather
 * than a message
 */
void DiaEditControl(INTSML item)
{
	DiaUnDimItem(item);
}

void DiaOpaqueEdit(INTSML item)
{
	Widget w;

	item--;
	gra_curdialog->opaqueitem = item;

	w = gra_curdialog->items[item];
	gra_opaquefield[0] = 0;
	XtAddCallback(w, XmNmodifyVerifyCallback, (XtCallbackProc)gra_dialogopaqueaction, 0);
}

/*
 * Routine to cause item "item" to report character hits
 */
void DiaCharacterEdit(INTSML item)
{
	item--;
	gra_curdialog->editline = item;
}

/*
 * Routine to change item "item" into a popup with "count" entries
 * in "names".
 */
void DiaSetPopup(INTSML item, INTSML count, char **names)
{
	Widget child, menu;
	Arg arg[1];
	INTSML i;
	INTBIG bigitem;

	item--;
	menu = (Widget)XmCreatePulldownMenu(gra_curdialog->window, "menu", NULL, 0);
	bigitem = (INTBIG)item;
	for(i=0; i<count; i++)
	{
		child = (Widget)XmCreatePushButton(menu, names[i], NULL, 0);
		XtManageChild(child);
		XtAddCallback(child, XmNactivateCallback,
			(XtCallbackProc)gra_dialogaction, (XtPointer)bigitem);
	}
	XtSetArg(arg[0], XmNsubMenuId, menu);
	XtSetValues(gra_curdialog->items[item], arg, 1);
	if (gra_curdialog->itemdesc->list[item].data == 0)
	{
		gra_curdialog->itemdesc->list[item].data = 1;
		XtManageChild(gra_curdialog->items[item]);
	}
	gra_flushdialog();
}

/*
 * Routine to change popup item "item" so that the current entry is "entry".
 */
void DiaSetPopupEntry(INTSML item, INTSML entry)
{
	Widget w, child, *kids;
	Arg arg[1];

	item--;
	w = gra_curdialog->items[item];
	XtVaGetValues(w, XmNsubMenuId, &child, NULL);
	XtVaGetValues(child, XmNchildren, &kids, NULL);
	XtSetArg(arg[0], XmNmenuHistory, kids[entry]);
	XtSetValues(w, arg, 1);
	gra_flushdialog();
}

/*
 * Routine to return the current item in popup menu item "item".
 */
INTSML DiaGetPopupEntry(INTSML item)
{
	Widget w, child, *kids, kid;
	INTBIG numkids, i;

	item--;
	w = gra_curdialog->items[item];
	XtVaGetValues(w, XmNsubMenuId, &child, NULL);
	XtVaGetValues(child, XmNchildren, &kids, NULL);
	XtVaGetValues(child, XmNnumChildren, &numkids, NULL);
	XtVaGetValues(w, XmNmenuHistory, &kid, NULL);
	for(i=0; i<numkids; i++)
		if (kids[i] == kid) break;
	return((INTSML)i);
}

void DiaInitTextDialog(INTSML item, INTSML (*toplist)(char **), char *(*nextinlist)(void),
	void (*donelist)(void), INTSML sortpos, INTSML flags)
{
	Widget w;
	INTBIG bigitem;
	int j;
	Arg arg[2];
	XmFontListEntry entry;
	static XmFontList fontlist;
	static INTSML havefontlist = 0;

	item--;
	w = gra_curdialog->items[item];
	if ((flags&SCDOUBLEQUIT) != 0)
	{
		XtAddCallback(w, XmNdefaultActionCallback,
			(XtCallbackProc)gra_dialogaction, (XtPointer)0);
	}
	if ((flags&SCREPORT) != 0)
	{
		bigitem = (INTBIG)item;
		XtAddCallback(w, XmNbrowseSelectionCallback,
			(XtCallbackProc)gra_dialogaction, (XtPointer)bigitem);
	}
	if ((flags&SCFIXEDWIDTH) != 0)
	{
		XtSetArg(arg[0], XmNvisibleItemCount, &j);
		XtGetValues(w, arg, 1);
		if (havefontlist == 0)
		{
			entry = XmFontListEntryLoad(gra_topdpy, gra_font[11].fontname,
				XmFONT_IS_FONT, "TAG");
			fontlist = XmFontListAppendEntry(NULL, entry);
			XmFontListEntryFree(&entry);
			havefontlist = 1;
		}
		XtSetArg(arg[0], XmNfontList, fontlist);
		XtSetArg(arg[1], XmNvisibleItemCount, j*2-1);
		XtSetValues(w, arg, 2);
	}
	gra_flushdialog();
	DiaLoadTextDialog((INTSML)(item+1), toplist, nextinlist, donelist, sortpos);
}

void DiaLoadTextDialog(INTSML item, INTSML (*toplist)(char **), char *(*nextinlist)(void),
	void (*donelist)(void), INTSML sortpos)
{
	Widget w;
	INTBIG i, j, sorted, items, sc, *order;
	char *next, **list, line[256];
	XmString str;

	item--;
	w = gra_curdialog->items[item];

	/* clear the list */
	XmListDeleteAllItems(w);

	if (sortpos < 0)
	{
		/* unsorted: load the list directly */
		line[0] = 0;
		next = line;
		(void)(*toplist)(&next);
		for(items=0; ; items++)
		{
			next = (*nextinlist)();
			if (next == 0) break;
			str = XmStringCreateLocalized(next);
			XmListAddItemUnselected(w, str, 0);
			XmStringFree(str);
		}
		(*donelist)();
	} else
	{
		/* count the number of items to be put in the text editor */
		line[0] = 0;
		next = line;
		(void)(*toplist)(&next);
		for(items=0; ; items++) if ((*nextinlist)() == 0) break;
		(*donelist)();

		/* allocate space for the strings */
		if (items > 0)
		{
			list = (char **)emalloc(items * (sizeof (char *)), el_tempcluster);
			if (list == 0) return;
			order = (INTBIG *)emalloc(items * (sizeof (INTBIG)), el_tempcluster);
			if (order == 0) return;
		}

		/* get the list */
		line[0] = 0;
		next = line;
		(void)(*toplist)(&next);
		for(i=0; i<items; i++)
		{
			next = (*nextinlist)();
			if (next == 0) next = "???";
			list[i] = (char *)emalloc(strlen(next)+1, el_tempcluster);
			if (list[i] == 0) return;
			strcpy(list[i], next);
			order[i] = i;
		}
		(*donelist)();

		/* sort the list */
		sorted = 0;
		while (sorted == 0)
		{
			sorted = 1;
			for(i=1; i<items; i++)
			{
				if (namesame(&list[order[i-1]][sortpos], &list[order[i]][sortpos]) <= 0)
					continue;
				j = order[i];   order[i] = order[i-1];   order[i-1] = j;
				sorted = 0;
			}
		}

		/* stuff the list into the text editor */
		for(i=0; i<items; i++)
		{
			str = XmStringCreateLocalized(list[order[i]]);
			XmListAddItemUnselected(w, str, 0);
			XmStringFree(str);
		}

		/* deallocate the list */
		if (items > 0)
		{
			for(i=0; i<items; i++) efree((char *)list[i]);
			efree((char *)(char *)list);
			efree((char *)(char *)order);
		}
	}
	if (items > 0) XmListSelectPos(w, 1, False);
	gra_flushdialog();
}

/*
 * Routine to stuff line "line" at the end of the edit buffer.
 */
void DiaStuffLine(INTSML item, char *line)
{
	Widget w;
	XmString str;

	item--;
	w = gra_curdialog->items[item];
	str = XmStringCreateLocalized(line);
	XmListAddItemUnselected(w, str, 0);
	XmStringFree(str);
	gra_flushdialog();
}

void DiaSelectLine(INTSML item, INTSML line)
{
	Widget w;

	item--;
	w = gra_curdialog->items[item];
	if (line < 0) XmListDeselectAllItems(w); else
		XmListSelectPos(w, line+1, False);
	gra_flushdialog();
}

INTSML DiaGetCurLine(INTSML item)
{
	Widget w;
	int count, *pos, selected;

	item--;
	w = gra_curdialog->items[item];
	selected = -1;
	if (XmListGetSelectedPos(w, &pos, &count))
	{
		if (count == 1) selected = pos[0]-1;
		XtFree((XtPointer)pos);
	}
	return((INTSML)selected);
}

char *DiaGetScrollLine(INTSML item, INTSML line)
{
	Widget w;
	int count, *pos;
	XmString *strlist;
	char *text, *retstring;

	item--;
	if (line < 0) return("");
	w = gra_curdialog->items[item];
	XtVaGetValues(w, XmNitemCount, &count, XmNitems, &strlist, NULL);
	if (line >= count) retstring = ""; else
	{
		XmStringGetLtoR(strlist[line], XmFONTLIST_DEFAULT_TAG, &text);
		(void)initinfstr();
		(void)addstringtoinfstr(text);
		retstring = returninfstr();
		XtFree(text);
	}
	return(retstring);
}

void DiaSetScrollLine(INTSML item, INTSML line, char *msg)
{
	Widget w;
	int *pos, count, selected;
	XmString strlist[1];

	item--;
	w = gra_curdialog->items[item];

	/* remember which line was selected */
	selected = 0;
	if (XmListGetSelectedPos(w, &pos, &count))
	{
		if (count == 1) selected = pos[0];
		XtFree((XtPointer)pos);
	}

	/* change the desired line */
	strlist[0] = XmStringCreateLocalized(msg);
	XmListReplaceItemsPosUnselected(w, strlist, 1, line+1);
	XmStringFree(strlist[0]);

	/* restore the selected line */
	if (selected == 0) XmListDeselectAllItems(w); else
		XmListSelectPos(w, selected, False);
	gra_flushdialog();
}

void DiaItemRect(INTSML item, RECTAREA *rect)
{
	item--;
	if (item < 0 || item >= gra_curdialog->itemdesc->items) return;
	*rect = gra_curdialog->itemdesc->list[item].r;
}

void DiaPercent(INTSML item, INTBIG percent)
{
	Widget w;
	Display *dpy;
	Window win;
	INTBIG x, y, wid, hei, rwid;

	item--;
	w = gra_curdialog->items[item];
	dpy = XtDisplay(w);
	win = XtWindow(w);

	/* determine size and draw interior bar */
	gra_getdialogcoordinates(&gra_curdialog->itemdesc->list[item].r, &x, &y, &wid, &hei);
	rwid = wid * percent / 100;
	XSetForeground(dpy, gra_gc, BlackPixelOfScreen(XtScreen(w)));
	XFillRectangle(dpy, win, gra_gc, 0, 0, rwid, hei);

	/* draw outline */
	XSetForeground(dpy, gra_gc, BlackPixelOfScreen(XtScreen(w)));
	XDrawLine(dpy, win, gra_gc, 0, 0, wid, 0);
	XDrawLine(dpy, win, gra_gc, wid, 0, wid, hei);
	XDrawLine(dpy, win, gra_gc, wid, hei, 0, hei);
	XDrawLine(dpy, win, gra_gc, 0, hei, 0, 0);
}

void DiaRedispRoutine(INTSML item, void (*routine)(RECTAREA*))
{
	item--;
	gra_curdialog->redrawroutine = routine;
	gra_curdialog->redrawitem = item;
}

void DiaFrameRect(INTSML item, RECTAREA *r)
{
	Widget w;
	Display *dpy;
	Window win;
	INTBIG x, y, lx, hx, ly, hy;

	w = gra_curdialog->items[item-1];
	x = gra_curdialog->itemdesc->list[item-1].r.left;
	y = gra_curdialog->itemdesc->list[item-1].r.top;

	dpy = XtDisplay(w);
	win = XtWindow(w);
	lx = (r->left-x) * DIALOGNUM / DIALOGDEN;
	hx = (r->right-x) * DIALOGNUM / DIALOGDEN;
	ly = (r->top-y) * DIALOGNUM / DIALOGDEN;
	hy = (r->bottom-y) * DIALOGNUM / DIALOGDEN;
	XSetForeground(dpy, gra_gc, WhitePixelOfScreen(XtScreen(w)));
	XFillRectangle(dpy, win, gra_gc, lx, ly, hx-lx, hy-ly);
	XSetForeground(dpy, gra_gc, BlackPixelOfScreen(XtScreen(w)));
	XDrawLine(dpy, win, gra_gc, lx, ly, hx-1, ly);
	XDrawLine(dpy, win, gra_gc, hx-1, ly, hx-1, hy-1);
	XDrawLine(dpy, win, gra_gc, hx-1, hy-1, lx, hy-1);
	XDrawLine(dpy, win, gra_gc, lx, hy-1, lx, ly);
}

void DiaDrawLine(INTSML item, INTBIG fx, INTBIG fy, INTBIG tx, INTBIG ty, INTBIG mode)
{
	Widget w;
	Display *dpy;
	Window win;
	GC gc;
	INTBIG x, y, x1, y1, x2, y2;

	w = gra_curdialog->items[item-1];
	x = gra_curdialog->itemdesc->list[item-1].r.left;
	y = gra_curdialog->itemdesc->list[item-1].r.top;

	dpy = XtDisplay(w);
	win = XtWindow(w);
	x1 = (fx-x) * DIALOGNUM / DIALOGDEN;
	y1 = (fy-y) * DIALOGNUM / DIALOGDEN;
	x2 = (tx-x) * DIALOGNUM / DIALOGDEN;
	y2 = (ty-y) * DIALOGNUM / DIALOGDEN;
	switch (mode)
	{
		case DLMODEON:
			XSetForeground(dpy, gra_gc, BlackPixelOfScreen(XtScreen(w)));
			gc = gra_gc;
			break;
		case DLMODEOFF:
			XSetForeground(dpy, gra_gc, WhitePixelOfScreen(XtScreen(w)));
			gc = gra_gc;
			break;
		case DLMODEINVERT:
			gc = gra_gcinv;
			break;
	}
	XDrawLine(dpy, win, gc, x1, y1, x2, y2);
}

void DiaFillPoly(INTSML item, INTBIG *xv, INTBIG *yv, INTBIG count, INTBIG r, INTBIG g, INTBIG b)
{
	Widget w;
	Display *dpy;
	Window win;
	INTBIG x, y, colorvalue, i;
	XPoint pointlist[20];
	XColor xc;

	w = gra_curdialog->items[item-1];
	x = gra_curdialog->itemdesc->list[item-1].r.left;
	y = gra_curdialog->itemdesc->list[item-1].r.top;

	dpy = XtDisplay(w);
	win = XtWindow(w);
	for(i=0; i<count; i++)
	{
		pointlist[i].x = (xv[i]-x) * DIALOGNUM / DIALOGDEN;
		pointlist[i].y = (yv[i]-y) * DIALOGNUM / DIALOGDEN;
	}

	/* determine color to use */
	if (VisualClass(gra_visual) == PseudoColor ||
		VisualClass(gra_visual) == StaticColor)
	{
		xc.red   = r << 8;
		xc.green = g << 8;
		xc.blue  = b << 8;
		XAllocColor(dpy, gra_defaultcmap, &xc);
		colorvalue = xc.pixel;
	} else
	{
		if (gra_sdep == 16)
		{
			colorvalue = ((r & 0xF8) << 8) |
				((g & 0xF8) << 3) | ((b & 0xF8) >> 3);
		} else
		{
			colorvalue = (b << 16) | (g << 8) | r;
		}
	}
	XSetForeground(dpy, gra_gc, colorvalue);

	XFillPolygon(dpy, win, gra_gc, pointlist, count, Complex, CoordModeOrigin);
}

void DiaDrawRect(INTSML item, RECTAREA *r, INTSML on)
{
	Widget w;
	Display *dpy;
	Window win;
	INTBIG screen, i, itemtype, x, y, lx, hx, ly, hy;

	for(i=0; i<gra_curdialog->itemdesc->items; i++)
	{
		itemtype = gra_curdialog->itemdesc->list[i].type;
		if ((itemtype&ITEMTYPE) == USERDRAWN) break;
	}
	if (i >= gra_curdialog->itemdesc->items) return;
	w = gra_curdialog->items[i];
	x = gra_curdialog->itemdesc->list[i].r.left;
	y = gra_curdialog->itemdesc->list[i].r.top;

	dpy = XtDisplay(w);
	win = XtWindow(w);
	XSetForeground(dpy, gra_gc, on ? BlackPixelOfScreen(XtScreen(w)) :
		WhitePixelOfScreen(XtScreen(w)));
	lx = (r->left-x) * DIALOGNUM / DIALOGDEN;
	hx = (r->right-x) * DIALOGNUM / DIALOGDEN;
	ly = (r->top-y) * DIALOGNUM / DIALOGDEN;
	hy = (r->bottom-y) * DIALOGNUM / DIALOGDEN;
	XFillRectangle(dpy, win, gra_gc, lx, ly, hx-lx, hy-ly);
}

void DiaGetMouse(INTSML *x, INTSML *y)
{
	*x = gra_cursorx;
	*y = gra_cursory;
}

/****************************** MOTIF/LESSTIF DIALOG SUPPORT ******************************/

/*
 * Routine to make sure that changes to the dialog are on the screen
 */
void gra_flushdialog(void)
{
	XmUpdateDisplay(gra_toplevelwidget);
}

/*
 * Routine to convert dialog coordinates
 */
void gra_getdialogcoordinates(RECTAREA *rect, INTBIG *x, INTBIG *y, INTBIG *wid, INTBIG *hei)
{
	*x = rect->left * DIALOGNUM / DIALOGDEN;
	*y = rect->top * DIALOGNUM / DIALOGDEN;
	*wid = (rect->right - rect->left) * DIALOGNUM / DIALOGDEN;
	*hei = (rect->bottom - rect->top) * DIALOGNUM / DIALOGDEN;
}

/*
 * Routine to make a Pixmap from image data
 */
Pixmap gra_makeicon(char *data, Widget widget)
{
	static Pixmap buildup[MAXICONS];
	static INTSML first = 1;
	static INTSML which = 0;
	static INTBIG foreground, background;
	static char *truedata, *rowdata;
	char *tdptr, *rptr;
	INTBIG i, j, wid, hei, bytesperrow, datasize, x, y, byte, bit,
		outx, lastoutx, outy, lastouty, sdep, pad, allocsdep;
	static GC pgc;
	static XImage *ximage;
	Arg arg[2];
	XGCValues gcv;

	/* determine sizes */
	wid = 32 * DIALOGNUM / DIALOGDEN;
	hei = 32 * DIALOGNUM / DIALOGDEN;
	sdep = DefaultDepth(gra_dpy, DefaultScreen(gra_dpy));
	allocsdep = sdep;
	if (allocsdep == 24) allocsdep = 32;
	pad = XBitmapPad(gra_dpy);
	bytesperrow = ((wid*allocsdep+pad-1) / pad) * pad / 8;
	datasize = bytesperrow * hei;

	/* initialize icon storage */
	if (first != 0)
	{
		for(i=0; i<MAXICONS; i++) buildup[i] = 0;
		truedata = (char *)emalloc(datasize, us_aid->cluster);
		rowdata = (char *)emalloc(bytesperrow, us_aid->cluster);
		first = 0;
	}

	/* choose an icon to build */
	which++;
	if (which >= MAXICONS) which = 0;

	if (buildup[which] == 0)
	{
		buildup[which] = XCreatePixmap(gra_dpy, gra_win, wid, hei, sdep);
		XtSetArg(arg[0], XtNbackground, &gcv.background);
		XtSetArg(arg[1], XtNforeground, &gcv.foreground);
		XtGetValues(widget, arg, 2);
		foreground = gcv.foreground;
		background = gcv.background;
		gcv.fill_style = FillStippled;
		pgc = XtGetGC(widget, GCForeground | GCBackground, &gcv);
		ximage = XCreateImage(gra_dpy, DefaultVisual(gra_dpy, DefaultScreen(gra_dpy)),
			sdep, ZPixmap, 0, truedata, wid, hei, pad, 0);
	}
	lastouty = 0;
	tdptr = truedata;
	for(y=0; y<32; y++)
	{
		lastoutx = 0;
		for(i=0; i<bytesperrow; i++) rowdata[i] = foreground;
		rptr = rowdata;
		for(x=0; x<32; x++)
		{
			byte = data[y*4+(x>>3)];
			bit = byte & (0200 >> (x&7));
			if (x == 31) outx = wid-1; else
				outx = x * DIALOGNUM / DIALOGDEN;
			if (bit == 0)
			{
				for(i=lastoutx; i<=outx; i++)
				{
					switch (sdep)
					{
						case 1:
							rowdata[i>>3] |= (0200 >> (i&7));
							break;
						case 8:
							rowdata[i] = background;
							break;
						case 16:
							((short *)rowdata)[i] = background;
							break;
						case 24:
						case 32:
							((long *)rowdata)[i] = background;
							break;
					}
				}
			}
			lastoutx = outx+1;
		}
		if (y == 31) outy = hei-1; else
			outy = y * DIALOGNUM / DIALOGDEN;
		for(i=lastouty; i<=outy; i++)
		{
			for(j=0; j<bytesperrow; j++)
				tdptr[j] = rowdata[j];
			tdptr += bytesperrow;
		}
		lastouty = outy+1;
	}
	XPutImage(gra_dpy, buildup[which], pgc, ximage, 0, 0, 0, 0, wid, hei);
	return(buildup[which]);
}

/*
 * Routine to handle events specific to dialog items
 */
void gra_dialogaction(Widget w, XtPointer client_data, XmSelectionBoxCallbackStruct *call_data)
{
	INTBIG item, itemtype, value, count, reportuserclick, x, y;
	char *line;
	XmDrawingAreaCallbackStruct *cbsda;
	XmPushButtonCallbackStruct *cbspb;
	XEvent *event;

	item = ((int)client_data) & 0xFFFF;
	itemtype = gra_curdialog->itemdesc->list[item].type;
	if ((itemtype&ITEMTYPE) == CHECK)
	{
		value = XmToggleButtonGetState(w);
		XmToggleButtonSetState(w, value == 0 ? True : False, 0);
	}
	if ((itemtype&ITEMTYPE) == ICON)
	{
		cbspb = (XmPushButtonCallbackStruct *)call_data;
		event = cbspb->event;
		gra_cursorx = event->xbutton.x * DIALOGDEN / DIALOGNUM +
			gra_curdialog->itemdesc->list[item].r.left;
		gra_cursory = event->xbutton.y * DIALOGDEN / DIALOGNUM +
			gra_curdialog->itemdesc->list[item].r.top;
	}
	if ((itemtype&ITEMTYPE) == EDITTEXT)
	{
		if (item == gra_curdialog->editline)
		{
			/* determine which character was typed (hack!!!) */
			line = XmTextGetString(w);
			if (strlen(line) > strlen(gra_curdialog->lastedittext))
			{
				gra_dialoghitchar = line[strlen(line)-1];
			} else if (strlen(line) < strlen(gra_curdialog->lastedittext))
			{
				gra_dialoghitchar = 010;
			}

			/* reset to previous state */
			XtRemoveCallback(w, XmNvalueChangedCallback,
				(XtCallbackProc)gra_dialogaction, (XtPointer)item);
			XmTextSetString(w, gra_curdialog->lastedittext);
			count = XmTextGetLastPosition(w);
			XmTextSetSelection(w, count, count, 0);
			XtAddCallback(w, XmNvalueChangedCallback,
				(XtCallbackProc)gra_dialogaction, (XtPointer)item);
		}
	}
	gra_dialoghit = item+1;
}

/*
 * Routine to handle clicks in user-drawn items
 */
void gra_dialogdraw(Widget widget, XEvent *event, String *args, int *num_args)
{
	int i;

	/* see which dialog item this applies to */
	for(i=0; i<gra_curdialog->itemdesc->items; i++)
		if (widget == gra_curdialog->items[i]) break;
	if (i >= gra_curdialog->itemdesc->items) return;

	/* get cursor coordinates */
	gra_cursorx = event->xbutton.x * DIALOGDEN / DIALOGNUM +
		gra_curdialog->itemdesc->list[i].r.left;
	gra_cursory = event->xbutton.y * DIALOGDEN / DIALOGNUM +
		gra_curdialog->itemdesc->list[i].r.top;

	/* determine type of action */
	if (*num_args != 1) return;
	if (strcmp(args[0], "motion") == 0)
	{
		gra_inputstate = MOTION;
		if ((event->xmotion.state & (Button1Mask | Button2Mask | Button3Mask)) == 0)
			gra_inputstate |= BUTTONUP;
	} else
	{
		switch (event->xbutton.button)
		{
			case 1: gra_inputstate = ISLEFT;   break;
			case 2: gra_inputstate = ISMIDDLE; break;
			case 3: gra_inputstate = ISRIGHT;  break;
		}
		if ((event->xbutton.state & ShiftMask) != 0)
			gra_inputstate |= SHIFTDOWN;
		if ((event->xbutton.state & LockMask) != 0)
			gra_inputstate |= SHIFTDOWN;
		if ((event->xbutton.state & ControlMask) != 0)
			gra_inputstate |= CONTROLDOWN;
		if ((event->xbutton.state & (Mod1Mask|Mod4Mask)) != 0)
			gra_inputstate |= METADOWN;
		if (strcmp(args[0], "up") == 0)
			gra_inputstate |= BUTTONUP;
	}
	if (strcmp(args[0], "down") == 0)
		gra_dialoghit = i+1;
}

/*
 * Routine to handle keystrokes in an "opaque" item
 * (replaces the text with "*")
 */
void gra_dialogopaqueaction(Widget w, XtPointer client_data,
	XmTextVerifyCallbackStruct *call_data)
{
	INTBIG i;

	if (call_data->startPos < call_data->currInsert)
	{
		call_data->endPos = strlen(gra_opaquefield);
		gra_opaquefield[call_data->startPos] = 0;
		return;
	}
	if (call_data->text->length > 1)
	{
		call_data->doit = False;
		return;
	}
	strncat(gra_opaquefield, call_data->text->ptr, call_data->text->length);
	gra_opaquefield[call_data->endPos + call_data->text->length] = 0;

	for(i=0; i<call_data->text->length; i++)
		call_data->text->ptr[i] = '*';
}

/*
 * Routine to redraw user-drawn items (calls the user's callback)
 */
void gra_dialogredraw(Widget w, XtPointer client_data, XmSelectionBoxCallbackStruct *call_data)
{
	RECTAREA ra;

	if (gra_curdialog->redrawroutine != 0)
	{
		DiaItemRect(gra_curdialog->redrawitem, &ra);
		(*gra_curdialog->redrawroutine)(&ra);
	}
}

/*
 * Routine to redraw separator lines
 */
void gra_dialogredrawsep(Widget w, XtPointer client_data, XmSelectionBoxCallbackStruct *call_data)
{
	Display *dpy;
	Window win;
	INTBIG x, y, wid, hei;

	gra_getdialogcoordinates(&gra_curdialog->itemdesc->list[(INTBIG)client_data].r, &x, &y, &wid, &hei);
	dpy = XtDisplay(w);
	win = XtWindow(w);
	XSetForeground(dpy, gra_gc, BlackPixelOfScreen(XtScreen(w)));
	XFillRectangle(dpy, win, gra_gc, 0, 0, wid, hei);
}

#else

/****************************** ATHENA DIALOGS ******************************/

#define	TAB           011		/* the TAB character */
#define	DELETEKEY     010		/* the DELETE character */
#define	BS           0177		/* the BS character */
#define	LEFTARROWKEY  034		/* the Left Arrow key */
#define	RIGHTARROWKEY 035		/* the Right Arrow key */
#define	UPARROWKEY    036		/* the Up Arrow key */
#define	DOWNARROWKEY  037		/* the Down Arrow key */

/* the four scroller arrows */
#define	UPARROW      0
#define	DOWNARROW    1
#define	LEFTARROW    2
#define	RIGHTARROW   3

#define	THUMBSIZE     16		/* width of the thumb area in scroll slider */
#define	MAXSCROLLS     2		/* maximum scroll items in a dialog */
#define	MAXDIALOGS     2		/* maximum subdialogs on screen */
#define MAXMATCH      50
#define DRAGBARHEIGHT 18

typedef void (*USERTYPE)(RECTAREA*);

/* the scroll arrow definition */
#define	ARROWLEN     7
static INTSML dia_arrowx[] = {4, 10, 10, 13, 7, 1, 4};
static INTSML dia_arrowy[] = {12, 12, 8, 8, 2, 8, 8};

typedef struct
{
	INTSML  count;
	INTSML  current;
	char **namelist;
} POPUPDATA;

typedef struct
{
	INTSML   scrollitem;		/* item number of SCROLL area (-1 if none) */
	RECTAREA userrect;			/* position of SCROLL area */
	INTSML   flags;				/* state SCROLL area */
	INTSML   vthumbpos;			/* position of vertical thumb slider  */
	INTSML   hthumbpos;			/* position of horizontal thumb slider */
	INTSML   horizfactor;		/* shift of horizontal text (0 to 100) */
	INTSML   firstline;			/* line number of top line */
	INTSML   linesinfolder;		/* number of lines displayable */
	INTSML   which;				/* currently highlighted line */
	INTSML   lineheight;		/* height of line of text */
	INTSML   lineoffset;		/* offset to baseline for text */
	char   **scrolllist;		/* list of text lines */
	INTSML   scrolllistsize;	/* size of line list */
	INTSML   scrolllistlen;		/* number of valid lines/list */
} DSCROLL;

typedef struct
{
	DIALOG   *dlgresaddr;		/* address of this dialog */
	short     onscreen;			/* nonzero if displayed */
	short     defaultbutton;	/* default button */
	INTBIG    theDialog;

	/* for the scroll item */
	INTSML     scrollcount;			/* number of scroll items */
	INTSML     curscroll;			/* current scroll item */
	DSCROLL    scroll[MAXSCROLLS];	/* data structures for the scroll item(s) */

	/* for the current edit text item */
	INTSML     curitem;				/* current edit item */
	INTSML     editstart, editend;	/* start/end selected text in edit item */
	INTSML     firstch;				/* first displayed character in edit item */
	INTSML     opaqueitem;			/* item number of opaque edit text */
} DIALOCAL;

DIALOCAL   dia_it, dia_save[MAXDIALOGS];
INTSML     dia_active = 0;
INTSML     dia_savepos = 0;
INTSML     dia_slineheight;			/* height of a line of scroll text */
INTSML     dia_slineoffset;			/* scroll text: distance up to baseline */
INTSML     dia_lineheight;			/* height of a line of other text */
INTSML     dia_lineoffset;			/* other text: distance up to baseline */
INTSML     dia_curlineoffset;		/* current distance up to baseline */
INTSML     dia_knowndialogcount = 0;/* number of resource-read dialogs */
DIALOG   **dia_knowndialogs;		/* array of resource-read dialogs */
INTSML    *dia_knowdialognumbers;	/* array of resource-read dialog numbers */
INTSML     dia_firstupdate;
INTSML     dia_wasin, dia_lbase, dia_hbase, dia_offset, dia_ddata;
RECTAREA   dia_rect;				/* the current rectangle being tracked */
char      *dia_msg;
POPUPDATA *dia_pd;					/* the current popup menu */
INTSML     dia_cnt;					/* the current entry count in the popup menu */
INTSML     dia_sta;					/* the current start point in the popup menu */
INTSML     dia_xoffset, dia_yrev;
INTSML     dia_revy;					/* for reversing Y coordinates */
POLYGON   *dia_poly = NOPOLYGON;
WINDOWPART dia_window;				/* current window in which dialog is drawn */
INTSML     dia_lastx, dia_lasty;
GRAPHICS dia_drawgray = {LAYERA, DGRAY, {SOLIDC, SOLIDC, SOLIDC, SOLIDC},
	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
GRAPHICS dia_drawdim = {LAYERA, GRAY, {SOLIDC, SOLIDC, SOLIDC, SOLIDC},
	{0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF,0xFFFF}, NOVARIABLE, 0};
extern GRAPHICS us_menufigs, us_menutext, us_ebox;

/* prototypes for local routines */
INTSML Dbuttondown(INTBIG x, INTBIG y);
INTSML Dcheckdown(INTBIG x, INTBIG y);
void Dcorrectxy(INTBIG *x, INTBIG *y);
void Ddonedialogwindow(void);
void Ddoneedit(void);
INTSML Ddownarrow(INTBIG x, INTBIG y);
INTSML Ddownpage(INTBIG x, INTBIG y);
void Ddragwindow(INTSML x, INTSML y);
void Ddrawarrow(INTSML sc, INTSML which, INTSML filled);
void Ddrawbox(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, GRAPHICS *which);
void Ddrawcircle(RECTAREA *r, INTSML dim);
void Ddrawdisc(RECTAREA *r);
void Ddrawhorizslider(INTSML sc);
void Ddrawitem(INTSML type, RECTAREA *r, char *msg, INTSML dim);
void Ddrawline(INTSML xf, INTSML yf, INTSML xt, INTSML yt);
void Ddrawmsg(INTSML sc, char *msg, INTSML which);
void Ddrawpolygon(INTBIG *xv, INTBIG *yv, INTSML count, INTSML filled);
void Ddrawpopupentries(void);
void Ddrawrectframe(RECTAREA *r, INTSML on, INTSML dim);
void Ddrawroundrectframe(RECTAREA *r, INTSML arc, INTSML dim);
void Ddrawtext(char *msg, INTSML len, INTSML x, INTSML y, INTSML dim);
void Ddrawvertslider(INTSML sc);
void Deditbox(RECTAREA *r, INTSML draw, INTSML dim);
INTSML Deditdown(INTBIG x, INTBIG y);
INTSML Dgeteditpos(RECTAREA *r, INTSML x, INTSML y, char *msg);
INTSML Dgettextsize(char *msg, INTSML len);
void Dgetwindowextent(INTSML *ly, INTSML *hy);
void Dgrayrect(RECTAREA *r);
void Dhighlight(INTSML on);
void Dhighlightrect(RECTAREA *r);
INTSML Dhscroll(INTBIG x, INTBIG y);
void Dinsertstr(char *insmsg);
void Dinsetrect(RECTAREA *r, INTSML amt);
void Dintdrawrect(RECTAREA *r, INTSML on);
void Dinvertbox(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy);
void Dinvertentry(INTSML sc, INTSML on);
void Dinvertrect(RECTAREA *r);
void Dinvertrectframe(RECTAREA *r);
INTSML Dleftarrow(INTBIG x, INTBIG y);
INTSML Dleftpage(INTBIG x, INTBIG y);
void Dnewdialogwindow(RECTAREA *r, char *movable);
void Dnewdialogwindowframe(RECTAREA *r, char *movable);
INTSML Dneweditbase(void);
INTSML Dnullchar(INTBIG x, INTBIG y, INTSML ch);
INTSML Dnullup(INTBIG x, INTBIG y);
void Dnullvoid(void);
void Dputicon(INTSML x, INTSML y, char *data);
void Dredrawdialogwindow(void);
void Dredrawscroll(INTSML sc);
void Drestorerect(INTBIG sr);
INTSML Drightarrow(INTBIG x, INTBIG y);
INTSML Drightpage(INTBIG x, INTBIG y);
INTBIG Dsaverect(RECTAREA *r);
void Dsethscroll(INTSML sc);
void Dsettextsmall(INTSML sc);
void Dsetvscroll(INTSML sc);
void Dshiftbits(RECTAREA *sr, RECTAREA *dr);
void Dstuffmessage(char *msg, RECTAREA *r, INTSML dim);
void Dstufftext(char *msg, RECTAREA *r);
void Dtextlocation(char *msg, INTSML len, RECTAREA *r, INTSML *wid, INTSML *line);
void Dtrackcursor(INTSML, INTSML, INTSML (*eachdown)(INTBIG, INTBIG));
INTSML Dtrackpopup(INTBIG x, INTBIG y);
INTSML Duparrow(INTBIG x, INTBIG y);
INTSML Duppage(INTBIG x, INTBIG y);
INTSML Dvscroll(INTBIG x, INTBIG y);
INTSML Dwaitforaction(INTSML *x, INTSML *y, INTSML *chr, UINTBIG *time);
INTSML Dwhichitem(INTSML x, INTSML y);

/*
 * Routine to initialize a dialog described by "dialog".
 * Returns nonzero if dialog cannot be initialized.
 */
INTSML DiaInitDialog(DIALOG *dialog)
{
	INTSML itemtype, i;
	RECTAREA r;
	char *save, *line;
	POPUPDATA *pd;

	/* save the current dialog if this is a subdialog */
	if (dia_savepos > 0)
	{
		if (dia_savepos > MAXDIALOGS) return(1);
		dia_save[dia_savepos-1] = dia_it;
	}
	dia_savepos++;

	/* initialize dialog data structures */
	dia_it.defaultbutton = OK;
	dia_it.dlgresaddr = dialog;
	dia_it.curitem = -1;
	dia_it.opaqueitem = -1;
	for(i=0; i<MAXSCROLLS; i++)
	{
		dia_it.scroll[i].scrollitem = -1;
		dia_it.scroll[i].horizfactor = 0;
		dia_it.scroll[i].scrolllistlen = 0;
		dia_it.scroll[i].scrolllistsize = 0;
	}
	dia_it.curscroll = 0;
	dia_it.scrollcount = 0;
	dia_it.onscreen = 1;
	dia_it.firstch = 0;

	/* make the window */
	Dnewdialogwindow(&dialog->windowRect, dialog->movable);
	Dnewdialogwindowframe(&dialog->windowRect, dialog->movable);

	/* find the default button */
	for(i=0; i<dialog->items; i++)
	{
		itemtype = dia_it.dlgresaddr->list[i].type;
		if ((itemtype&ITEMTYPE) == DEFBUTTON)
			dia_it.defaultbutton = i+1;
	}

	/* loop through all of the dialog entries, drawing them */
	for(i=0; i<dialog->items; i++)
	{
		/* draw the item */
		itemtype = dia_it.dlgresaddr->list[i].type;
		line = dia_it.dlgresaddr->list[i].msg;
		r = dia_it.dlgresaddr->list[i].r;

		if ((itemtype&ITEMTYPE) == EDITTEXT)
		{
			if (dia_it.curitem == -1) dia_it.curitem = i;
		}
		if ((itemtype&ITEMTYPE) == SCROLL)
		{
			if (dia_it.scrollcount < MAXSCROLLS)
				dia_it.scroll[dia_it.scrollcount++].scrollitem = i;
		}
		if ((itemtype&ITEMTYPE) == MESSAGE || (itemtype&ITEMTYPE) == EDITTEXT)
		{
			save = (char *)emalloc(strlen(line)+1, el_tempcluster);
			if (save == 0) return(1);
			(void)strcpy(save, line);
			dia_it.dlgresaddr->list[i].data = (INTBIG)save;
		} else if ((itemtype&ITEMTYPE) == POPUP)
		{
			pd = (POPUPDATA *)emalloc(sizeof (POPUPDATA), el_tempcluster);
			if (pd == 0) return(1);
			pd->count = 0;
			dia_it.dlgresaddr->list[i].data = (INTBIG)pd;
			line = (char *)pd;
		} else dia_it.dlgresaddr->list[i].data = 0;

		Ddrawitem(itemtype, &r, line, 0);

		/* highlight the default button */
		if (i == dia_it.defaultbutton-1 &&
			(itemtype == BUTTON || itemtype == DEFBUTTON)) Dhighlightrect(&r);
	}
	if (dia_it.curitem >= 0)
	{
		dia_it.editstart = 0;
		dia_it.editend = strlen(dia_it.dlgresaddr->list[dia_it.curitem].msg);
		Dhighlight(1);
	}
	dia_active++;
	dia_firstupdate = 1;
	return(0);
}

/*
 * Routine to handle actions and return the next item hit.
 */
INTSML DiaNextHit(void)
{
	INTSML chr, itemHit;
	char ch[2];

	for(;;)
	{
		/* if interrupted, stop dialog */
		if (el_pleasestop != 0) return(CANCEL);

		/* get the next event, ignore fluff */
		chr = DiaGetNextCharacter(&itemHit);
		if (chr == -1) continue;

		/* non-character events return immediately */
		if (chr == -2) break;

		/* handle special character events */
		if (chr == 033) return(CANCEL);
		if (chr == '\n' || chr == '\r' || chr == 03) return(dia_it.defaultbutton);

		/* handle delete/backspace key */
		if ((chr == DELETEKEY || chr == BS) && dia_it.curitem >= 0)
		{
			if (dia_it.editstart == dia_it.editend && dia_it.editstart > 0)
				dia_it.editstart--;
			chr = 0;
		}

		ch[0] = chr;   ch[1] = 0;
		Dinsertstr(ch);
		break;
	}
	return(itemHit);
}

/*
 * Routine to parse the next input event and return the next character typed into
 * the current edit item.  If the routine returns -1, nothing has happened.  If the
 * routine returns -2, an item has been hit (and is in "itemHit").
 */
INTSML DiaGetNextCharacter(INTSML *itemHit)
{
	RECTAREA r;
	char *msg;
	INTBIG sr, thumbval;
	UINTBIG time;
	static char match[MAXMATCH];
	static INTSML matchpos = 0;
	static UINTBIG lasttime = 0;
	INTSML i, chr, type, which, v, t, n, x, y, sc, oak, newfirst, ly, hy;
	DSCROLL *scr;
	POPUPDATA *pd;

	oak = Dwaitforaction(&x, &y, &chr, &time);
	if (oak == 1 || oak == 5)
	{
		/* hit in the window: find the item */
		*itemHit = Dwhichitem(x, y);
		if (*itemHit == 0) return(-1);
		type = dia_it.dlgresaddr->list[*itemHit-1].type;
		r = dia_it.dlgresaddr->list[*itemHit-1].r;

		if ((type&ITEMTYPE) == MESSAGE || (type&INACTIVE) != 0) return(-1);

		/* if the item is a popup menu, display it and track */
		if ((type&ITEMTYPE) == POPUP)
		{
			pd = (POPUPDATA *)dia_it.dlgresaddr->list[*itemHit-1].data;

			/* system can't handle popups automatically: do it by hand */
			dia_cnt = pd->count;    dia_sta = 0;
			Dgetwindowextent(&ly, &hy);
			for(;;)
			{
				i = r.top - ((pd->current-dia_sta) * dia_lineheight) + 1;
				if (i > ly) break;
				dia_sta++;
			}
			for(;;)
			{
				i = r.bottom + ((dia_cnt-pd->current-1) * dia_lineheight) + 1;
				if (i < hy) break;
				dia_cnt--;
			}
			r.top -= ((pd->current-dia_sta) * dia_lineheight) + 1;
			r.bottom += ((dia_cnt-pd->current-1) * dia_lineheight) + 1;
			r.left--;   r.right++;
			sr = Dsaverect(&r);
			dia_pd = pd;
			dia_rect = r;
			Dsettextsmall(0);
			Ddrawpopupentries();
			dia_wasin = -1;
			Dtrackcursor(x, y, Dtrackpopup);
			Drestorerect(sr);
			if (dia_wasin < 0) return(-1);
			i = dia_wasin + dia_sta;

			pd->current = i;
			Ddrawitem(POPUP, &dia_it.dlgresaddr->list[*itemHit-1].r, (char *)pd, 0);
			return(-2);
		}

		/* items under the user's control are given to the user */
		if (type == USERDRAWN) return(-2);

		/* if the item is edit text, make it the current one */
		if (type == EDITTEXT)
		{
			if (dia_it.curitem != *itemHit - 1) Ddoneedit(); else Dhighlight(0);
			dia_it.curitem = *itemHit - 1;
			msg = (char *)dia_it.dlgresaddr->list[*itemHit-1].data;
			i = Dgeteditpos(&r, x, y, msg);
			if (oak == 5)
			{
				/* look for a full word about position "base" */
				for(dia_it.editstart=i-1; dia_it.editstart>=0; dia_it.editstart--)
					if (!isalnum(msg[dia_it.editstart])) break;
				dia_it.editstart++;
				for(dia_it.editend = dia_it.editstart; msg[dia_it.editend] != 0; dia_it.editend++)
					if (!isalnum(msg[dia_it.editend])) break;
				Dhighlight(1);
			} else
			{
				dia_it.editstart = dia_it.editend = i;
				Dhighlight(1);
			}
			dia_lbase = dia_it.editstart;   dia_hbase = dia_it.editend;
			dia_rect = r;
			dia_msg = msg;
			Dtrackcursor(x, y, Deditdown);
			return(-2);
		}

		/* if the item is a button, reverse it and track */
		if (type == BUTTON || type == DEFBUTTON)
		{
			r.left++;   r.right--;
			r.top++;    r.bottom--;
			Dinvertrect(&r);
			dia_rect = r;
			dia_wasin = 1;
			Dtrackcursor(x, y, Dbuttondown);
			if (dia_wasin == 0) return(-1);
			Dinvertrect(&r);
			return(-2);
		}

		/* if the item is a check, outline it and track */
		if (type == CHECK)
		{
			dia_rect = r;
			r.right = r.left + 11;   r.left++;
			r.top = (r.top + r.bottom) / 2 - 5;
			r.bottom = r.top + 10;
			Ddrawrectframe(&r, 1, 0);
			dia_wasin = 1;
			dia_ddata = dia_it.dlgresaddr->list[*itemHit-1].data;
			Dtrackcursor(x, y, Dcheckdown);
			if (dia_wasin == 0) return(-1);
			Ddrawrectframe(&r, 0, 0);
			if (dia_ddata != 0)
			{
				Ddrawline(r.left, r.top, (INTSML)(r.right-1), (INTSML)(r.bottom-1));
				Ddrawline(r.left, (INTSML)(r.bottom-1), (INTSML)(r.right-1), r.top);
			}
			return(-2);
		}

		/* if the item is a scroll area, select a line */
		if (type == SCROLL)
		{
			for(sc=0; sc<dia_it.scrollcount; sc++)
				if (dia_it.scroll[sc].scrollitem == *itemHit - 1) break;
			if (sc >= dia_it.scrollcount) return(-1);
			scr = &dia_it.scroll[dia_it.curscroll=sc];

			if (x > scr->userrect.right)
			{
				/* cursor in vertical slider */
				if (scr->scrolllistlen <= scr->linesinfolder) return(-1);
				if (y > scr->userrect.bottom-16)
				{
					/* the down arrow */
					Ddrawarrow(sc, DOWNARROW, 1);
					Dtrackcursor(x, y, Ddownarrow);
					Ddrawarrow(sc, DOWNARROW, 0);
					return(-1);
				}
				if (y < scr->userrect.top+16)
				{
					/* the up arrow */
					Ddrawarrow(sc, UPARROW, 1);
					Dtrackcursor(x, y, Duparrow);
					Ddrawarrow(sc, UPARROW, 0);
					return(-1);
				}
				if (y > scr->vthumbpos+THUMBSIZE/2 && y <= scr->userrect.bottom-16)
				{
					/* scroll down one page */
					Dtrackcursor(x, y, Ddownpage);
					return(-1);
				}
				if (y < scr->vthumbpos-THUMBSIZE/2 && y >= scr->userrect.top+16)
				{
					/* scroll up one page */
					Dtrackcursor(x, y, Duppage);
					return(-1);
				}
				if (y >= scr->vthumbpos-THUMBSIZE/2 && y <= scr->vthumbpos+THUMBSIZE/2)
				{
					/* drag slider appropriately */
					v = y;   t = scr->vthumbpos;
					dia_rect = dia_it.dlgresaddr->list[*itemHit-1].r;
					dia_rect.left = dia_rect.right - 14;
					dia_rect.right--;
					dia_rect.top = scr->vthumbpos - THUMBSIZE/2;
					dia_rect.bottom = scr->vthumbpos + THUMBSIZE/2;
					Dinvertrectframe(&dia_rect);
					dia_offset = t-v;
					Dtrackcursor(x, y, Dvscroll);
					dia_rect.top = scr->vthumbpos - THUMBSIZE/2;
					dia_rect.bottom = scr->vthumbpos + THUMBSIZE/2;
					Dinvertrectframe(&dia_rect);
					r = scr->userrect;
					r.top += 16;   r.bottom -= 16;
					thumbval = scr->vthumbpos - r.top - THUMBSIZE/2;
					thumbval *= scr->scrolllistlen - scr->linesinfolder;
					thumbval /= r.bottom - r.top - THUMBSIZE;
					i = thumbval;
					if (i < 0) i = 0;
					if (i == scr->firstline) return(-1);
					scr->firstline = i;
					Dredrawscroll(sc);
					Dinvertentry(sc, 1);
					Dsetvscroll(sc);
					return(-1);
				}
			} else if (y > scr->userrect.bottom)
			{
				/* cursor in horizontal slider */
				if (x > scr->userrect.right-16)
				{
					/* the right arrow */
					Ddrawarrow(sc, RIGHTARROW, 1);
					Dtrackcursor(x, y, Drightarrow);
					Ddrawarrow(sc, RIGHTARROW, 0);
					return(-1);
				}
				if (x < scr->userrect.left+16)
				{
					/* the left arrow */
					Ddrawarrow(sc, LEFTARROW, 1);
					Dtrackcursor(x, y, Dleftarrow);
					Ddrawarrow(sc, LEFTARROW, 0);
					return(-1);
				}
				if (x > scr->hthumbpos+THUMBSIZE/2 && x <= scr->userrect.right-16)
				{
					/* scroll right one page */
					Dtrackcursor(x, y, Drightpage);
					return(-1);
				}
				if (x < scr->hthumbpos-THUMBSIZE/2 && x >= scr->userrect.left+16)
				{
					/* scroll left one page */
					Dtrackcursor(x, y, Dleftpage);
					return(-1);
				}
				if (x >= scr->hthumbpos-THUMBSIZE/2 && x <= scr->hthumbpos+THUMBSIZE/2)
				{
					/* drag slider appropriately */
					v = x;   t = scr->hthumbpos;
					dia_rect = dia_it.dlgresaddr->list[*itemHit-1].r;
					dia_rect.top = dia_rect.bottom - 14;
					dia_rect.bottom--;
					dia_rect.left = scr->hthumbpos - THUMBSIZE/2;
					dia_rect.right = scr->hthumbpos + THUMBSIZE/2;
					Dinvertrectframe(&dia_rect);
					dia_offset = t - v;
					Dtrackcursor(x, y, Dhscroll);
					dia_rect.left = scr->hthumbpos - THUMBSIZE/2;
					dia_rect.right = scr->hthumbpos + THUMBSIZE/2;
					Dinvertrectframe(&dia_rect);
					r = scr->userrect;
					r.left += 16;   r.right -= 16;
					thumbval = scr->hthumbpos - r.left - THUMBSIZE/2;
					thumbval *= 100;
					thumbval /= r.right - r.left - THUMBSIZE;
					i = thumbval;
					if (i < 0) i = 0;
					if (i == scr->horizfactor) return(-1);
					scr->horizfactor = i;
					Dredrawscroll(sc);
					Dinvertentry(sc, 1);
					Dsethscroll(sc);
					return(-1);
				}
			} else
			{
				/* double click in scroll selects and returns */
				if (oak == 5 && scr->scrolllistlen > 0 && (scr->flags&SCDOUBLEQUIT) != 0)
				{
					*itemHit = OK;
					return(-2);
				}

				if ((scr->flags&SCSELMOUSE) != 0)
				{
					/* cursor in list: select an entry */
					which = y - r.top;
					which /= scr->lineheight;
					which += scr->firstline;
					if (which >= scr->scrolllistlen) which = scr->scrolllistlen - 1;
					DiaSelectLine(*itemHit, which);
					if ((scr->flags&SCREPORT) == 0) return(-1);
				}
			}
		}
		return(-2);
	}

	/* get the character, return immediately if special */
	if (oak != 0) return(-1);
	if (chr == 033 || chr == '\n' || chr == '\r' || chr == 03) return(chr);

	/* handle arrow positioning */
	if (chr == LEFTARROWKEY)
	{
		if (dia_it.curitem < 0) return(-1);
		Dhighlight(0);
		dia_it.editstart--;
		if (dia_it.editstart < 0) dia_it.editstart = 0;
		dia_it.editend = dia_it.editstart;
		newfirst = Dneweditbase();
		if (dia_it.firstch != newfirst)
		{
			dia_it.firstch = newfirst;
			msg = (char *)dia_it.dlgresaddr->list[dia_it.curitem].data;
			Dstufftext(msg, &dia_it.dlgresaddr->list[dia_it.curitem].r);
		}
		Dhighlight(1);
		return(-1);
	}
	if (chr == RIGHTARROWKEY)
	{
		if (dia_it.curitem < 0) return(-1);
		Dhighlight(0);
		msg = (char *)dia_it.dlgresaddr->list[dia_it.curitem].data;
		if (msg[dia_it.editend] != 0) dia_it.editend++;
		dia_it.editstart = dia_it.editend;
		newfirst = Dneweditbase();
		if (dia_it.firstch != newfirst)
		{
			dia_it.firstch = newfirst;
			Dstufftext(msg, &dia_it.dlgresaddr->list[dia_it.curitem].r);
		}
		Dhighlight(1);
		return(-1);
	}

	/* tab to next edit text item */
	if (chr == TAB)
	{
		type = 0;
		for(i=dia_it.curitem+1; i<dia_it.dlgresaddr->items; i++)
		{
			type = dia_it.dlgresaddr->list[i].type;
			if (type == EDITTEXT) break;
		}
		if (type != EDITTEXT)
		{
			for(i=0; i<dia_it.curitem; i++)
			{
				type = dia_it.dlgresaddr->list[i].type;
				if (type == EDITTEXT) break;
			}
		}
		if (type != EDITTEXT) return(-1);
		Ddoneedit();
		dia_it.curitem = i;
		dia_it.editstart = 0;
		msg = (char *)dia_it.dlgresaddr->list[i].data;
		dia_it.editend = strlen(msg);
		dia_it.firstch = 0;
		Dhighlight(1);
		return(-1);
	}

	if (chr == DOWNARROWKEY)
	{
		if (dia_it.scrollcount <= 0) return(-1);
		scr = &dia_it.scroll[sc = dia_it.curscroll];
		if (scr->scrolllistlen <= 0) return(-1);
		if (scr->which >= scr->scrolllistlen-1) return(-1);
		*itemHit = scr->scrollitem + 1;
		DiaSelectLine(*itemHit, (INTSML)(scr->which+1));
		if ((scr->flags&SCREPORT) == 0) return(-1);
		return(-2);
	}
	if (chr == UPARROWKEY)
	{
		if (dia_it.scrollcount <= 0) return(-1);
		scr = &dia_it.scroll[sc = dia_it.curscroll];
		if (scr->scrolllistlen <= 0) return(-1);
		if (scr->which <= 0) return(-1);
		*itemHit = scr->scrollitem + 1;
		DiaSelectLine(*itemHit, (INTSML)(scr->which-1));
		if ((scr->flags&SCREPORT) == 0) return(-1);
		return(-2);
	}

	if (dia_it.curitem < 0 && dia_it.scrollcount > 0 &&
		(dia_it.scroll[dia_it.curscroll].flags&SCSELKEY) != 0)
	{
		/* use key to select line in scroll area */
		scr = &dia_it.scroll[sc=dia_it.curscroll];
		*itemHit = scr->scrollitem + 1;
		if (chr >= 'A' && chr <= 'Z') chr += 040;

		/* if it has been more than a second, reset the match string */
		if (time - lasttime > 60) matchpos = 0;
		lasttime = time;

		/* add this character to the match string */
		if (matchpos < MAXMATCH)
		{
			match[matchpos] = chr;
			matchpos++;
		}

		/* find that string */
		for(which = 0; which < scr->scrolllistlen; which++)
		{
			for(i=0; i<matchpos; i++)
			{
				n = scr->scrolllist[which][i];
				if (n >= 'A' && n <= 'Z') n += 040;
				if (match[i] != n) break;
			}
			if (i >= matchpos)
			{
				DiaSelectLine(*itemHit, which);
				break;
			}
		}
		if ((scr->flags&SCREPORT) == 0) return(-1);
		return(-2);
	}

	/* insert character into edit text */
	*itemHit = dia_it.curitem + 1;
	return(chr);
}

void DiaDoneDialog(void)
{
	INTSML i, j, type;
	POPUPDATA *oldpd;

	/* free all the edit text and message buffers */
	for(i=0; i<dia_it.dlgresaddr->items; i++)
	{
		type = dia_it.dlgresaddr->list[i].type;
		if ((type&ITEMTYPE) == POPUP)
		{
			oldpd = (POPUPDATA *)dia_it.dlgresaddr->list[i].data;
			for(j=0; j<oldpd->count; j++) efree((char *)oldpd->namelist[j]);
			efree((char *)oldpd->namelist);
		}
		if ((type&ITEMTYPE) == MESSAGE || (type&ITEMTYPE) == EDITTEXT || (type&ITEMTYPE) == POPUP)
			efree((char *)dia_it.dlgresaddr->list[i].data);
	}

	/* free all items in the scroll area */
	for(i=0; i<dia_it.scrollcount; i++)
	{
		for(j=0; j<dia_it.scroll[i].scrolllistlen; j++)
			efree((char *)dia_it.scroll[i].scrolllist[j]);
		if (dia_it.scroll[i].scrolllistsize > 0) efree((char *)dia_it.scroll[i].scrolllist);
	}
	if (dia_it.onscreen != 0)
	{
		dia_it.onscreen = 0;
		Ddonedialogwindow();
		dia_active--;
	}

	dia_savepos--;
	if (dia_savepos <= 0) return;
	dia_it = dia_save[dia_savepos-1];
	Dredrawdialogwindow();
}

/*
 * Routine to set the text in item "item" to "msg"
 */
void DiaSetText(INTSML item, char *msg)
{
	INTSML type, oldcur, highlight, dim;
	INTBIG amt;
	char *save;
	RECTAREA r;

	highlight = 0;
	if (item < 0)
	{
		item = -item;
		highlight = 1;
	}
	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	type = dia_it.dlgresaddr->list[item].type;

	/* special case when renaming buttons */
	if ((type&ITEMTYPE) == BUTTON || (type&ITEMTYPE) == DEFBUTTON ||
		(type&ITEMTYPE) == CHECK || (type&ITEMTYPE) == RADIO)
	{
		r = dia_it.dlgresaddr->list[item].r;
		if ((type&INACTIVE) != 0) dim = 1; else dim = 0;
		Dintdrawrect(&r, 0);
		Ddrawitem(type, &r, msg, dim);
		if ((type&ITEMTYPE) == RADIO && dia_it.dlgresaddr->list[item].data != 0)
		{
			/* draw the circle in a selected radio button */
			r.right = r.left + 12;
			r.top = (r.top + r.bottom) / 2 - 6;
			r.bottom = r.top + 12;
			Dinsetrect(&r, 3);
			Ddrawdisc(&r);
		}
		if ((type&ITEMTYPE) == CHECK && dia_it.dlgresaddr->list[item].data != 0)
		{
			/* draw the "X" in a selected check box */
			r.right = r.left + 12;
			r.top = (r.top + r.bottom) / 2 - 6;
			r.bottom = r.top + 12;
			Ddrawline(r.left, r.top, (INTSML)(r.right-1), (INTSML)(r.bottom-1));
			Ddrawline(r.left, (INTSML)(r.bottom-1), (INTSML)(r.right-1), r.top);
		}
		return;
	}

	/* handle messages and edit text */
	oldcur = dia_it.curitem;   Ddoneedit();
	if ((type&ITEMTYPE) == MESSAGE || (type&ITEMTYPE) == EDITTEXT)
	{
		if ((type&ITEMTYPE) == MESSAGE)
			Dstuffmessage(msg, &dia_it.dlgresaddr->list[item].r, 0); else
				Dstufftext(msg, &dia_it.dlgresaddr->list[item].r);
		amt = strlen(msg)+1;
		save = (char *)emalloc(amt, el_tempcluster);
		if (save == 0) return;
		(void)strcpy(save, msg);
		efree((char *)dia_it.dlgresaddr->list[item].data);
		dia_it.dlgresaddr->list[item].data = (INTBIG)save;
		if ((type&ITEMTYPE) == EDITTEXT)
		{
			if (highlight != 0)
			{
				Ddoneedit();
				oldcur = item;
				dia_it.editstart = 0;
				dia_it.editend = strlen(msg);
				dia_it.firstch = 0;
			} else if (oldcur == item)
			{
				dia_it.editstart = dia_it.editend = strlen(msg);
			}
		}
	}
	dia_it.curitem = oldcur;
	Dhighlight(1);
}

/*
 * Routine to return the text in item "item"
 */
char *DiaGetText(INTSML item)
{
	INTSML type;
	POPUPDATA *pd;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return("");
	type = dia_it.dlgresaddr->list[item].type;
	if ((type&ITEMTYPE) == POPUP)
	{
		pd = (POPUPDATA *)dia_it.dlgresaddr->list[item].data;
		return(pd->namelist[pd->current]);
	}
	if ((type&ITEMTYPE) == MESSAGE || (type&ITEMTYPE) == EDITTEXT)
		return((char *)dia_it.dlgresaddr->list[item].data);
	return(0);
}

/*
 * Routine to set the value in item "item" to "value"
 */
void DiaSetControl(INTSML item, INTSML value)
{
	INTSML type;
	RECTAREA r;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	type = dia_it.dlgresaddr->list[item].type;
	r = dia_it.dlgresaddr->list[item].r;
	if ((type&ITEMTYPE) == CHECK)
	{
		/* check box */
		r.right = r.left + 12;
		r.top = (r.top + r.bottom) / 2 - 6;
		r.bottom = r.top + 12;
		Dintdrawrect(&r, 0);
		Ddrawrectframe(&r, 1, 0);
		if (value != 0)
		{
			Ddrawline(r.left, r.top, (INTSML)(r.right-1), (INTSML)(r.bottom-1));
			Ddrawline(r.left, (INTSML)(r.bottom-1), (INTSML)(r.right-1), r.top);
		}
		dia_it.dlgresaddr->list[item].data = (INTBIG)value;
	} else if ((type&ITEMTYPE) == RADIO)
	{
		/* radio button */
		r.right = r.left + 12;
		r.top = (r.top + r.bottom) / 2 - 6;
		r.bottom = r.top + 12;
		Dintdrawrect(&r, 0);
		Ddrawcircle(&r, 0);
		if (value != 0)
		{
			Dinsetrect(&r, 3);
			Ddrawdisc(&r);
		}
		dia_it.dlgresaddr->list[item].data = (INTBIG)value;
	}
}

/*
 * Routine to return the value in item "item"
 */
INTSML DiaGetControl(INTSML item)
{
	INTSML type;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return(0);
	type = dia_it.dlgresaddr->list[item].type;
	if ((type&ITEMTYPE) == CHECK || (type&ITEMTYPE) == RADIO)
		return(dia_it.dlgresaddr->list[item].data);
	return(0);
}

/*
 * Routine to check item "item" to make sure that there is
 * text in it.  If so, it returns nonzero.  Otherwise it beeps and returns zero.
 */
INTSML DiaValidEntry(INTSML item)
{
	char *msg;

	msg = DiaGetText(item);
	while (*msg == ' ') msg++;
	if (*msg != 0) return(1);
	ttybeep();
	return(0);
}

/*
 * Routine to dim item "item"
 */
void DiaDimItem(INTSML item)
{
	char *msg;
	INTSML type;
	RECTAREA r;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	if (item == dia_it.curitem) Ddoneedit();
	dia_it.dlgresaddr->list[item].type |= INACTIVE;
	type = dia_it.dlgresaddr->list[item].type;
	r = dia_it.dlgresaddr->list[item].r;
	msg = (char *)dia_it.dlgresaddr->list[item].data;
	if ((type&ITEMTYPE) == BUTTON || (type&ITEMTYPE) == DEFBUTTON ||
		(type&ITEMTYPE) == CHECK || (type&ITEMTYPE) == RADIO)
			msg = dia_it.dlgresaddr->list[item].msg;
	Ddrawitem(type, &r, msg, 1);
}

/*
 * Routine to un-dim item "item"
 */
void DiaUnDimItem(INTSML item)
{
	char *msg;
	INTSML type;
	RECTAREA r;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	dia_it.dlgresaddr->list[item].type &= ~INACTIVE;
	type = dia_it.dlgresaddr->list[item].type;
	r = dia_it.dlgresaddr->list[item].r;
	msg = (char *)dia_it.dlgresaddr->list[item].data;
	if ((type&ITEMTYPE) == BUTTON || (type&ITEMTYPE) == DEFBUTTON ||
		(type&ITEMTYPE) == CHECK || (type&ITEMTYPE) == RADIO)
			msg = dia_it.dlgresaddr->list[item].msg;
	Ddrawitem(type, &r, msg, 0);

	/* if undimming selected radio button, redraw disc */
	if ((type&ITEMTYPE) == RADIO && dia_it.dlgresaddr->list[item].data != 0)
	{
		r.right = r.left + 9;
		r.left += 3;
		r.top = (r.top + r.bottom) / 2 - 3;
		r.bottom = r.top + 6;
		Ddrawdisc(&r);
	}
}

/*
 * Routine to change item "item" to be a message rather
 * than editable text
 */
void DiaNoEditControl(INTSML item)
{
	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	if (item == dia_it.curitem) Ddoneedit();
	dia_it.dlgresaddr->list[item].type = MESSAGE;
	Deditbox(&dia_it.dlgresaddr->list[item].r, 0, 0);
}

/*
 * Routine to change item "item" to be editable text rather
 * than a message
 */
void DiaEditControl(INTSML item)
{
	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	dia_it.dlgresaddr->list[item].type = EDITTEXT;
	Deditbox(&dia_it.dlgresaddr->list[item].r, 1, 0);
}

void DiaOpaqueEdit(INTSML item)
{
	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	if (dia_it.dlgresaddr->list[item].type != EDITTEXT) return;
	dia_it.opaqueitem = item;
}

/*
 * Routine to cause item "item" to report character hits
 */
void DiaCharacterEdit(INTSML item)
{
}

/*
 * Routine to change item "item" into a popup with "count" entries
 * in "names".
 */
void DiaSetPopup(INTSML item, INTSML count, char **names)
{
	POPUPDATA *pd;
	INTSML i, type;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	type = dia_it.dlgresaddr->list[item].type;
	if ((type&ITEMTYPE) != POPUP) return;

	/* copy into a POPUPDATA structure */
	pd = (POPUPDATA *)dia_it.dlgresaddr->list[item].data;
	for(i=0; i<pd->count; i++) efree((char *)pd->namelist[i]);
	if (pd->count > 0) efree((char *)pd->namelist);
	pd->count = count;
	pd->current = 0;
	pd->namelist = (char **)emalloc(count * (sizeof (char *)), el_tempcluster);
	if (pd->namelist == 0) return;
	for(i=0; i<count; i++)
	{
		pd->namelist[i] = (char *)emalloc((strlen(names[i])+1) * (sizeof (char)),
			el_tempcluster);
		if (pd->namelist[i] == 0) return;
		(void)strcpy(pd->namelist[i], names[i]);
	}

	/* display the popup */
	Ddrawitem(POPUP, &dia_it.dlgresaddr->list[item].r, (char *)pd, 0);
}

/*
 * Routine to change popup item "item" so that the current entry is "entry".
 */
void DiaSetPopupEntry(INTSML item, INTSML entry)
{
	POPUPDATA *pd;
	INTSML type;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	type = dia_it.dlgresaddr->list[item].type;
	if ((type&ITEMTYPE) != POPUP) return;
	pd = (POPUPDATA *)dia_it.dlgresaddr->list[item].data;
	if (entry < 0 || entry >= pd->count) return;
	pd->current = entry;

	Ddrawitem(POPUP, &dia_it.dlgresaddr->list[item].r, (char *)pd,
		(INTSML)(type&INACTIVE));
}

/*
 * Routine to return the current item in popup menu item "item".
 */
INTSML DiaGetPopupEntry(INTSML item)
{
	POPUPDATA *pd;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return(0);
	if ((dia_it.dlgresaddr->list[item].type&ITEMTYPE) != POPUP) return(0);
	pd = (POPUPDATA *)dia_it.dlgresaddr->list[item].data;
	return(pd->current);
}

void DiaInitTextDialog(INTSML item, INTSML (*toplist)(char **), char *(*nextinlist)(void),
	void (*donelist)(void), INTSML sortpos, INTSML flags)
{
	DSCROLL *scr;
	INTSML sc;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	for(sc=0; sc<dia_it.scrollcount; sc++) if (dia_it.scroll[sc].scrollitem == item) break;
	if (sc >= dia_it.scrollcount) return;
	scr = &dia_it.scroll[sc];

	/* save information about this scroll area */
	scr->flags = flags;
	if ((scr->flags&SCSMALLFONT) != 0)
	{
		scr->lineheight = dia_slineheight;
		scr->lineoffset = dia_slineoffset;
	} else
	{
		scr->lineheight = dia_lineheight;
		scr->lineoffset = dia_lineoffset;
	}

	/* compute size of actual area (not including scroll bars) */
	scr->userrect = dia_it.dlgresaddr->list[item].r;
	scr->userrect.right -= 14;
	if ((scr->flags&SCHORIZBAR) != 0) scr->userrect.bottom -= 14;
	scr->linesinfolder = (scr->userrect.bottom - scr->userrect.top) / scr->lineheight;

	/* draw sliders */
	Ddrawvertslider(sc);
	if ((scr->flags&SCHORIZBAR) != 0) Ddrawhorizslider(sc);

	/* load the text */
	scr->scrolllistlen = 0;
	DiaLoadTextDialog((INTSML)(item+1), toplist, nextinlist, donelist, sortpos);
}

void DiaLoadTextDialog(INTSML item, INTSML (*toplist)(char **), char *(*nextinlist)(void),
	void (*donelist)(void), INTSML sortpos)
{
	INTSML i, j, sorted, items, *order, sc;
	char *next, **list, line[256];
	DSCROLL *scr;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	for(sc=0; sc<dia_it.scrollcount; sc++) if (dia_it.scroll[sc].scrollitem == item) break;
	if (sc >= dia_it.scrollcount) return;
	scr = &dia_it.scroll[sc];

	/* deallocate all former items in the list */
	for(i=0; i<scr->scrolllistlen; i++) efree((char *)scr->scrolllist[i]);
	scr->scrolllistlen = 0;
	scr->firstline = 0;

	/* count the number of items to be put in the text editor */
	line[0] = 0;
	next = line;
	(void)(*toplist)(&next);
	for(items=0; ; items++) if ((*nextinlist)() == 0) break;
	(*donelist)();

	/* allocate space for the strings */
	if (items > 0)
	{
		list = (char **)emalloc(items * (sizeof (char *)), el_tempcluster);
		if (list == 0) return;
		order = (INTSML *)emalloc(items * (sizeof (INTSML)), el_tempcluster);
		if (order == 0) return;
	}

	/* get the list */
	line[0] = 0;
	next = line;
	(void)(*toplist)(&next);
	for(i=0; i<items; i++)
	{
		next = (*nextinlist)();
		if (next == 0) next = "???";
		list[i] = (char *)emalloc(strlen(next)+1, el_tempcluster);
		if (list[i] == 0) return;
		strcpy(list[i], next);
		order[i] = i;
	}
	(*donelist)();

	/* sort the list */
	if (sortpos >= 0)
	{
		sorted = 0;
		while (sorted == 0)
		{
			sorted = 1;
			for(i=1; i<items; i++)
			{
				if (namesame(&list[order[i-1]][sortpos], &list[order[i]][sortpos]) <= 0)
					continue;
				j = order[i];   order[i] = order[i-1];   order[i-1] = j;
				sorted = 0;
			}
		}
	}

	/* stuff the list into the text editor */
	scr->which = -1;
	Dinsetrect(&scr->userrect, 1);
	Dintdrawrect(&scr->userrect, 0);
	Dinsetrect(&scr->userrect, -1);
	for(i=0; i<items; i++) DiaStuffLine(item+1, list[order[i]]);
	Dsetvscroll(sc);
	if (scr->scrolllistlen > 0) DiaSelectLine(item+1, 0);

	/* deallocate the list */
	if (items > 0)
	{
		for(i=0; i<items; i++) efree((char *)list[i]);
		efree((char *)(char *)list);
		efree((char *)(char *)order);
	}
}

/*
 * Routine to stuff line "line" at the end of the edit buffer.
 */
void DiaStuffLine(INTSML item, char *line)
{
	char **newlist, *pt;
	INTSML i, sc;
	DSCROLL *scr;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	for(sc=0; sc<dia_it.scrollcount; sc++) if (dia_it.scroll[sc].scrollitem == item) break;
	if (sc >= dia_it.scrollcount) return;
	scr = &dia_it.scroll[sc];

	if (scr->scrolllistlen >= scr->scrolllistsize)
	{
		newlist = (char **)emalloc((scr->scrolllistsize+10) * (sizeof (char *)),
			el_tempcluster);
		if (newlist == 0) return;
		for(i=0; i<scr->scrolllistlen; i++) newlist[i] = scr->scrolllist[i];
		if (scr->scrolllistsize != 0) efree((char *)scr->scrolllist);
		scr->scrolllist = newlist;
		scr->scrolllistsize += 10;
	}
	pt = (char *)emalloc(strlen(line)+1, el_tempcluster);
	if (pt == 0) return;
	(void)strcpy(pt, line);
	if (scr->scrolllistlen < scr->firstline+scr->linesinfolder)
		Ddrawmsg(sc, line, scr->scrolllistlen);
	scr->scrolllist[scr->scrolllistlen++] = pt;
}

void DiaSelectLine(INTSML item, INTSML l)
{
	INTSML n, sc;
	DSCROLL *scr;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	for(sc=0; sc<dia_it.scrollcount; sc++) if (dia_it.scroll[sc].scrollitem == item) break;
	if (sc >= dia_it.scrollcount) return;
	scr = &dia_it.scroll[sc];

	/* if the new line is visible, simply shift the highlighting */
	if (l-scr->firstline >= 0 && l-scr->firstline < scr->linesinfolder)
	{
		Dinvertentry(sc, 0);
	} else
	{
		/* must shift the buffer */
		n = l - scr->linesinfolder/2;
		if (n > scr->scrolllistlen-scr->linesinfolder)
			n = scr->scrolllistlen-scr->linesinfolder;
		if (n < 0) n = 0;
		scr->firstline = n;
		Dredrawscroll(sc);
	}
	scr->which = l;
	Dinvertentry(sc, 1);
	Dsetvscroll(sc);
}

INTSML DiaGetCurLine(INTSML item)
{
	INTSML sc;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return(-1);
	for(sc=0; sc<dia_it.scrollcount; sc++)
		if (dia_it.scroll[sc].scrollitem == item) return(dia_it.scroll[sc].which);
	return(-1);
}

char *DiaGetScrollLine(INTSML item, INTSML l)
{
	INTSML sc;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return("");
	for(sc=0; sc<dia_it.scrollcount; sc++)
		if (dia_it.scroll[sc].scrollitem == item)
	{
		if (l < 0 || l >= dia_it.scroll[sc].scrolllistlen) break;
		return(dia_it.scroll[sc].scrolllist[l]);
	}
	return("");
}

void DiaSetScrollLine(INTSML item, INTSML l, char *msg)
{
	char *ins;
	INTSML sc;
	DSCROLL *scr;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	for(sc=0; sc<dia_it.scrollcount; sc++) if (dia_it.scroll[sc].scrollitem == item) break;
	if (sc >= dia_it.scrollcount) return;
	scr = &dia_it.scroll[sc];

	if (l >= scr->scrolllistlen) DiaStuffLine(item+1, msg); else
	{
		ins = (char *)emalloc(strlen(msg)+1, el_tempcluster);
		if (ins == 0) return;
		(void)strcpy(ins, msg);
		efree((char *)scr->scrolllist[l]);
		scr->scrolllist[l] = ins;
	}
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsetvscroll(sc);
}

void DiaItemRect(INTSML item, RECTAREA *rect)
{
	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	*rect = dia_it.dlgresaddr->list[item].r;
}

void DiaPercent(INTSML item, INTBIG p)
{
	RECTAREA r;
	INTSML type;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	type = dia_it.dlgresaddr->list[item].type;
	if ((type&ITEMTYPE) != PROGRESS) return;
	r = dia_it.dlgresaddr->list[item].r;
	if (p == 0)
	{
		Dintdrawrect(&r, 0);
		Ddrawrectframe(&r, 1, 0);
		return;
	}
	r.left++;
	r.right = r.left + (r.right-1-r.left)*p/100;
	r.top++;   r.bottom--;
	Dgrayrect(&r);
	flushscreen();
}

void DiaRedispRoutine(INTSML item, void (*routine)(RECTAREA*))
{
	INTSML type;

	item--;
	if (item < 0 || item >= dia_it.dlgresaddr->items) return;
	type = dia_it.dlgresaddr->list[item].type;
	if ((type&ITEMTYPE) != USERDRAWN) return;
	dia_it.dlgresaddr->list[item].data = (INTBIG)routine;
}

void DiaFrameRect(INTSML item, RECTAREA *r)
{
	Dintdrawrect(r, 0);
	Ddrawrectframe(r, 1, 0);
}

void DiaDrawLine(INTSML item, INTBIG xf, INTBIG yf, INTBIG xt, INTBIG yt, INTBIG mode)
{
	INTBIG fx, fy, tx, ty;

	fx = xf + dia_xoffset;   fy = dia_yrev - yf;
	tx = xt + dia_xoffset;   ty = dia_yrev - yt;
	if (clipline(&fx, &fy, &tx, &ty, dia_window.uselx, dia_window.usehx,
		dia_window.usely, dia_window.usehy) != 0) return;

	switch (mode)
	{
		case DLMODEON:
			us_drawline(&dia_window, (INTSML)fx, (INTSML)fy, (INTSML)tx, (INTSML)ty, &us_menufigs, 0);
			break;
		case DLMODEOFF:
			us_menufigs.col = 0;
			us_drawline(&dia_window, (INTSML)fx, (INTSML)fy, (INTSML)tx, (INTSML)ty, &us_menufigs, 0);
			us_menufigs.col = el_colmengly;
			break;
		case DLMODEINVERT:
			us_invertline(&dia_window, (INTSML)fx, (INTSML)fy, (INTSML)tx, (INTSML)ty);
			break;
	}
}

void DiaFillPoly(INTSML item, INTBIG *x, INTBIG *y, INTBIG count, INTBIG r, INTBIG g, INTBIG b)
{
	REGISTER INTBIG colorvalue, dist, bestdist, i;
	XColor xc;
	REGISTER VARIABLE *varred, *vargreen, *varblue;
	INTBIG *red, *green, *blue;

	/* determine color to use */
	varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
	vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
	varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
	if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE) return;
	red = (INTBIG *)varred->addr;
	green = (INTBIG *)vargreen->addr;
	blue = (INTBIG *)varblue->addr;
	bestdist = 99999;
	for(i=0; i<255; i++)
	{
		dist = abs(red[i] - r) + abs(green[i] - g) + abs(blue[i] - b);
		if (dist > bestdist) continue;
		bestdist = dist;
		colorvalue = i;
	}

	us_menufigs.col = colorvalue;
	Ddrawpolygon(x, y, count, 1);
	us_menufigs.col = el_colmengly;
}

void DiaDrawRect(INTSML item, RECTAREA *r, INTSML on)
{
	Dintdrawrect(r, on);
}

void DiaGetMouse(INTSML *x, INTSML *y)
{
	INTBIG lx, ly;

	readtablet(x, y);
	lx = *x;   ly = *y;
	Dcorrectxy(&lx, &ly);
	*x = lx;   *y = ly;
}

/****************************** ATHENA DIALOG SUPPORT ******************************/

INTSML Dbuttondown(INTBIG x, INTBIG y)
{
	INTSML in;

	Dcorrectxy(&x, &y);
	if (x < dia_rect.left || x > dia_rect.right || y < dia_rect.top || y > dia_rect.bottom)
		in = 0; else
			in = 1;
	if (in != dia_wasin)
		Dinvertrect(&dia_rect);
	dia_wasin = in;
	return(0);
}

INTSML Dtrackpopup(INTBIG x, INTBIG y)
{
	INTSML which;
	RECTAREA r;

	Dcorrectxy(&x, &y);
	if (x < dia_rect.left || x > dia_rect.right || y < dia_rect.top || y > dia_rect.bottom)
		which = -1; else
	{
		which = (y - dia_rect.top - 1) / dia_lineheight;
		if (which >= dia_cnt-dia_sta) which = dia_cnt-dia_sta-1;

	}
	if (which != dia_wasin)
	{
		r.left = dia_rect.left + 1;
		r.right = dia_rect.right - 1;
		if (dia_wasin >= 0)
		{
			r.top = dia_rect.top + (dia_wasin * dia_lineheight) + 1;
			r.bottom = r.top + dia_lineheight;
			Dinvertrect(&r);
		}

		/* special case if in the "up" arrow */
		if (which == 0 && dia_sta != 0)
		{
			dia_sta--;   dia_cnt--;
			Ddrawpopupentries();
			dia_wasin = -1;
			return(0);
		}

		/* special case if in the "down" arrow */
		if (which == dia_cnt-dia_sta-1 && dia_cnt != dia_pd->count)
		{
			dia_sta++;   dia_cnt++;
			Ddrawpopupentries();
			dia_wasin = -1;
			return(0);
		}

		if (which >= 0)
		{
			r.top = dia_rect.top + (which * dia_lineheight) + 1;
			r.bottom = r.top + dia_lineheight;
			Dinvertrect(&r);
		}

		dia_wasin = which;
	}
	return(0);
}

INTSML Dcheckdown(INTBIG x, INTBIG y)
{
	INTSML in;
	RECTAREA r;

	Dcorrectxy(&x, &y);
	if (x < dia_rect.left || x > dia_rect.right || y < dia_rect.top || y > dia_rect.bottom)
		in = 0; else
			in = 1;
	if (in != dia_wasin)
	{
		r = dia_rect;
		r.right = r.left + 11;   r.left++;
		r.top = (r.top + r.bottom) / 2 - 5;
		r.bottom = r.top + 10;
		if (in != 0) Ddrawrectframe(&r, 1, 0); else
		{
			Ddrawrectframe(&r, 0, 0);
			if (dia_ddata != 0)
			{
				Ddrawline(r.left, r.top, (INTSML)(r.right-1), (INTSML)(r.bottom-1));
				Ddrawline(r.left, (INTSML)(r.bottom-1), (INTSML)(r.right-1), r.top);
			}
		}
	}
	dia_wasin = in;
	return(0);
}

INTSML Deditdown(INTBIG x, INTBIG y)
{
	INTSML l, h, pos, wid, len, prevpos, basepos;
	char *msg;

	Dcorrectxy(&x, &y);

	/* shift the text if the cursor moves outside the field */
	if (dia_rect.bottom-dia_rect.top < dia_lineheight*2)
	{
		if (y < dia_rect.top || y > dia_rect.bottom) return(0);

		/* scroll horizontally if there is only 1 line in the edit field */
		if (x < dia_rect.left && dia_it.firstch > 0)
		{
			Dhighlight(0);
			dia_it.firstch--;
			Dstufftext(dia_msg, &dia_rect);
			Dhighlight(1);
			gotosleep(10);
			return(0);
		}
		if (x > dia_rect.right && dia_it.firstch < dia_it.editend-1)
		{
			Dhighlight(0);
			dia_it.firstch++;
			Dstufftext(dia_msg, &dia_rect);
			Dhighlight(1);
			gotosleep(10);
			return(0);
		}
	} else
	{
		if (x < dia_rect.left || x > dia_rect.right) return(0);

		/* scroll vertically if there are multiple lines in the field */
		if (y < dia_rect.top && dia_it.firstch > 0)
		{
			msg = dia_msg;
			prevpos = 0;
			basepos = 0;
			while (*msg != 0)
			{
				for(len = strlen(msg); len>0; len--)
				{
					wid = Dgettextsize(msg, len);
					if (wid < dia_rect.right-dia_rect.left-2) break;
				}
				if (len == 0) break;
				basepos += len;
				if (basepos == dia_it.firstch) break;
				prevpos += len;
				msg += len;
			}
			Dhighlight(0);
			dia_it.firstch = prevpos;
			Dstufftext(dia_msg, &dia_rect);
			Dhighlight(1);
			gotosleep(30);
			return(0);
		}
		if (y > dia_rect.bottom && dia_it.firstch < dia_it.editend-1)
		{
			msg = &dia_msg[dia_it.firstch];
			for(len = strlen(msg); len>0; len--)
			{
				wid = Dgettextsize(msg, len);
				if (wid < dia_rect.right-dia_rect.left-2) break;
			}
			if (len == strlen(msg)) return(0);
			Dhighlight(0);
			dia_it.firstch += len;
			Dstufftext(dia_msg, &dia_rect);
			Dhighlight(1);
			gotosleep(30);
			return(0);
		}
	}

	pos = Dgeteditpos(&dia_rect, (INTSML)x, (INTSML)y, dia_msg);
	l = dia_lbase;   h = dia_hbase;
	if (pos > h) h = pos;
	if (pos < l) l = pos;
	if (l != dia_it.editstart || h != dia_it.editend)
	{
		Dhighlight(0);
		dia_it.editstart = l;   dia_it.editend = h;
		Dhighlight(1);
	}
	return(0);
}

INTSML Ddownarrow(INTBIG x, INTBIG y)
{
	short sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	if (scr->scrolllistlen-scr->firstline <= scr->linesinfolder) return(1);
	scr->firstline++;
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsetvscroll(sc);
	return(0);
}

INTSML Duparrow(INTBIG x, INTBIG y)
{
	INTSML sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	if (scr->firstline <= 0) return(1);
	scr->firstline--;
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsetvscroll(sc);
	return(0);
}

INTSML Ddownpage(INTBIG x, INTBIG y)
{
	INTSML sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	Dcorrectxy(&x, &y);
	if (y <= scr->vthumbpos+THUMBSIZE/2 || y > scr->userrect.bottom-16) return(1);
	if (scr->scrolllistlen-scr->firstline <= scr->linesinfolder) return(1);
	scr->firstline += scr->linesinfolder-1;
	if (scr->scrolllistlen-scr->firstline <= scr->linesinfolder)
		scr->firstline = scr->scrolllistlen-scr->linesinfolder;
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsetvscroll(sc);
	return(0);
}

INTSML Duppage(INTBIG x, INTBIG y)
{
	INTSML sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	Dcorrectxy(&x, &y);
	if (y >= scr->vthumbpos-THUMBSIZE/2 || y < scr->userrect.top+16) return(1);
	if (scr->firstline <= 0) return(1);
	scr->firstline -= scr->linesinfolder-1;
	if (scr->firstline < 0) scr->firstline = 0;
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsetvscroll(sc);
	return(0);
}

INTSML Dvscroll(INTBIG x, INTBIG y)
{
	INTSML l, sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	Dcorrectxy(&x, &y);
	l = scr->vthumbpos;
	scr->vthumbpos = y + dia_offset;
	if (scr->vthumbpos < scr->userrect.top+16+THUMBSIZE/2)
		scr->vthumbpos = scr->userrect.top+16+THUMBSIZE/2;
	if (scr->vthumbpos > scr->userrect.bottom-16-THUMBSIZE/2)
		scr->vthumbpos = scr->userrect.bottom-16-THUMBSIZE/2;
	if (scr->vthumbpos == l) return(0);
	dia_rect.top = l - THUMBSIZE/2;
	dia_rect.bottom = l + THUMBSIZE/2;
	Dinvertrectframe(&dia_rect);
	dia_rect.top = scr->vthumbpos - THUMBSIZE/2;
	dia_rect.bottom = scr->vthumbpos + THUMBSIZE/2;
	Dinvertrectframe(&dia_rect);
	return(0);
}

INTSML Drightarrow(INTBIG x, INTBIG y)
{
	INTSML sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	if (scr->horizfactor >= 100) return(1);
	scr->horizfactor++;
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsethscroll(sc);
	return(0);
}

INTSML Dleftarrow(INTBIG x, INTBIG y)
{
	INTSML sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	if (scr->horizfactor <= 0) return(1);
	scr->horizfactor--;
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsethscroll(sc);
	return(0);
}

INTSML Drightpage(INTBIG x, INTBIG y)
{
	INTSML sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	Dcorrectxy(&x, &y);
	if (x <= scr->hthumbpos+THUMBSIZE/2 || x > scr->userrect.right-16) return(1);
	if (scr->horizfactor >= 100) return(1);
	scr->horizfactor += 10;
	if (scr->horizfactor >= 100) scr->horizfactor = 100;
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsethscroll(sc);
	return(0);
}

INTSML Dleftpage(INTBIG x, INTBIG y)
{
	INTSML sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	Dcorrectxy(&x, &y);
	if (x >= scr->hthumbpos-THUMBSIZE/2 || x < scr->userrect.left+16) return(1);
	if (scr->horizfactor <= 0) return(1);
	scr->horizfactor -= 10;
	if (scr->horizfactor <= 0) scr->horizfactor = 0;
	Dredrawscroll(sc);
	Dinvertentry(sc, 1);
	Dsethscroll(sc);
	return(0);
}

INTSML Dhscroll(INTBIG x, INTBIG y)
{
	INTSML l, sc;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc=dia_it.curscroll];
	Dcorrectxy(&x, &y);
	l = scr->hthumbpos;
	scr->hthumbpos = x + dia_offset;
	if (scr->hthumbpos < scr->userrect.left+16+THUMBSIZE/2)
		scr->hthumbpos = scr->userrect.left+16+THUMBSIZE/2;
	if (scr->hthumbpos > scr->userrect.right-16-THUMBSIZE/2)
		scr->hthumbpos = scr->userrect.right-16-THUMBSIZE/2;
	if (scr->hthumbpos == l) return(0);
	dia_rect.left = l - THUMBSIZE/2;
	dia_rect.right = l + THUMBSIZE/2;
	Dinvertrectframe(&dia_rect);
	dia_rect.left = scr->hthumbpos - THUMBSIZE/2;
	dia_rect.right = scr->hthumbpos + THUMBSIZE/2;
	Dinvertrectframe(&dia_rect);
	return(0);
}

void Dredrawscroll(INTSML sc)
{
	RECTAREA r;
	INTSML i;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc];
	r = scr->userrect;
	r.left++;        r.right--;
	r.top++;         r.bottom--;
	Dintdrawrect(&r, 0);
	for(i=scr->firstline; i<scr->scrolllistlen; i++)
	{
		if (i-scr->firstline >= scr->linesinfolder) break;
		Ddrawmsg(sc, scr->scrolllist[i], (INTSML)(i-scr->firstline));
	}
}

/*
 * Routine to set the vertical scroll bar
 */
void Dsetvscroll(INTSML sc)
{
	RECTAREA r;
	INTBIG f;
	DSCROLL *scr;

	/* first redraw the border */
	Ddrawvertslider(sc);

	/* get the area of the slider without arrows */
	scr = &dia_it.scroll[sc];
	r = scr->userrect;
	r.top += 16;
	r.bottom -= 16;
	r.left = r.right;
	r.right += 13;

	/* if there is nothing to scroll, clear this area */
	if (scr->scrolllistlen <= scr->linesinfolder)
	{
		Dintdrawrect(&r, 0);
		return;
	}

	/* gray the scroll area */
	Dgrayrect(&r);

	/* compute position of vertical thumb area */
	f = scr->firstline;   f *= r.bottom - r.top-THUMBSIZE;
	f /= scr->scrolllistlen - scr->linesinfolder;
	scr->vthumbpos = r.top + THUMBSIZE/2 + f;
	if (scr->vthumbpos > r.bottom-THUMBSIZE/2) scr->vthumbpos = r.bottom-THUMBSIZE/2;

	/* draw the thumb */
	r.top = scr->vthumbpos - THUMBSIZE/2;
	r.bottom = scr->vthumbpos + THUMBSIZE/2;
	Dintdrawrect(&r, 0);
	Ddrawrectframe(&r, 1, 0);
}

/*
 * Routine to set the horizontal scroll bar
 */
void Dsethscroll(INTSML sc)
{
	RECTAREA r;
	INTBIG f;
	DSCROLL *scr;

	/* get the area of the slider without arrows */
	scr = &dia_it.scroll[sc];
	r = scr->userrect;
	r.left += 16;
	r.right -= 16;
	r.top = r.bottom;
	r.bottom += 13;

	/* gray the scroll area */
	Dgrayrect(&r);

	/* compute position of vertical thumb area */
	f = scr->horizfactor;   f *= (INTBIG)(r.right-r.left-THUMBSIZE);   f /= 100;
	scr->hthumbpos = r.left + THUMBSIZE/2 + f;
	if (scr->hthumbpos > r.right-THUMBSIZE/2) scr->hthumbpos = r.right-THUMBSIZE/2;

	/* draw the thumb */
	r.left = scr->hthumbpos - THUMBSIZE/2;
	r.right = scr->hthumbpos + THUMBSIZE/2;
	Dintdrawrect(&r, 0);
	Ddrawrectframe(&r, 1, 0);
}

void Dinvertentry(INTSML sc, INTSML on)
{
	RECTAREA r;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc];
	if (scr->which-scr->firstline >= 0 && scr->which-scr->firstline < scr->linesinfolder)
	{
		r.left = scr->userrect.left+1;
		r.right = scr->userrect.right-1;
		r.top = scr->userrect.top + scr->lineheight*(scr->which-scr->firstline)+1;
		r.bottom = r.top + scr->lineheight;
		if (r.bottom >= scr->userrect.bottom) r.bottom = scr->userrect.bottom-1;
		Dinvertrect(&r);
	}
}

/*
 * routine to determine which item falls under the coordinates (x, y)
 */
INTSML Dwhichitem(INTSML x, INTSML y)
{
	INTSML i;
	RECTAREA r;

	for(i=0; i<dia_it.dlgresaddr->items; i++)
	{
		r = dia_it.dlgresaddr->list[i].r;
		if (x >= r.left && x <= r.right && y >= r.top && y <= r.bottom) return(i+1);
	}
	return(0);
}

void Dinsertstr(char *insmsg)
{
	INTSML i, j, newcurspos;
	char *oldmsg, *newmsg, *pt;

	if (dia_it.curitem < 0) return;
	Dhighlight(0);
	oldmsg = (char *)dia_it.dlgresaddr->list[dia_it.curitem].data;

	/* allocate space for the new message and fill it */
	newmsg = (char *)emalloc(strlen(oldmsg)+strlen(insmsg)+dia_it.editend-dia_it.editstart+1, el_tempcluster);
	if (newmsg == 0) return;
	j = 0;
	for(i=0; i<dia_it.editstart; i++) newmsg[j++] = oldmsg[i];
	for(i=0; insmsg[i] != 0; i++) newmsg[j++] = insmsg[i];
	newcurspos = j;
	for(i=dia_it.editend; oldmsg[i] != 0; i++) newmsg[j++] = oldmsg[i];
	newmsg[j] = 0;
	dia_it.editstart = dia_it.editend = newcurspos;

	/* replace the message */
	efree((char *)dia_it.dlgresaddr->list[dia_it.curitem].data);
	dia_it.dlgresaddr->list[dia_it.curitem].data = (INTBIG)newmsg;

	/* make sure the cursor is visible */
	dia_it.firstch = Dneweditbase();
	if (dia_it.opaqueitem == dia_it.curitem)
	{
		allocstring(&oldmsg, newmsg, el_tempcluster);
		for(pt = oldmsg; *pt != 0; pt++)
			*pt = '*';
		Dstufftext(oldmsg, &dia_it.dlgresaddr->list[dia_it.curitem].r);
		efree(oldmsg);
	} else
	{
		Dstufftext(newmsg, &dia_it.dlgresaddr->list[dia_it.curitem].r);
	}

	/* set new highlighting */
	Dhighlight(1);
}

INTSML Dneweditbase(void)
{
	INTSML wid, prevpos, basepos, y, firstoff, len, newfirst;
	char *newmsg, *msg;
	RECTAREA r;

	newfirst = dia_it.firstch;
	newmsg = (char *)dia_it.dlgresaddr->list[dia_it.curitem].data;
	r = dia_it.dlgresaddr->list[dia_it.curitem].r;
	if (r.bottom-r.top < dia_lineheight*2)
	{
		/* if there is only 1 line in the edit field, shift horizontally */
		if (dia_it.editend < newfirst)
		{
			newfirst = dia_it.editend-1;
			if (newfirst < 0) newfirst = 0;
		}
		while (dia_it.editend > newfirst)
		{
			wid = Dgettextsize(&newmsg[newfirst], (INTSML)(dia_it.editend-newfirst));
			if (wid <= r.right-r.left-2) break;
			newfirst++;
		}
	} else
	{
		/* multiple lines in the edit field, shift vertically */
		while (dia_it.editend < newfirst)
		{
			msg = newmsg;
			prevpos = 0;
			basepos = 0;
			while (*msg != 0)
			{
				for(len = strlen(msg); len>0; len--)
				{
					wid = Dgettextsize(msg, len);
					if (wid < r.right-r.left-2) break;
				}
				if (len == 0) break;
				basepos += len;
				if (basepos == newfirst) break;
				prevpos += len;
				msg += len;
			}
			newfirst = prevpos;
		}
		if (dia_it.editend > newfirst)
		{
			y = r.top + dia_lineheight;
			msg = &newmsg[newfirst];
			firstoff = 0;
			basepos = 0;
			while (*msg != 0)
			{
				for(len = strlen(msg); len>0; len--)
				{
					wid = Dgettextsize(msg, len);
					if (wid < r.right-r.left-2) break;
				}
				if (len == 0) break;
				if (dia_it.editend <= newfirst + basepos + len) break;
				if (firstoff == 0) firstoff = len;
				msg += len;
				basepos += len;
				y += dia_lineheight;
				if (y > r.bottom) { newfirst += firstoff;   break; }
			}
		}
	}
	return(newfirst);
}

void Dhighlight(INTSML on)
{
	INTSML i, sx, ex, sline, eline, line, dummy, es, ee;
	char *msg;
	RECTAREA r, itemrect;

	if (dia_it.curitem < 0) return;
	itemrect = dia_it.dlgresaddr->list[dia_it.curitem].r;
	msg = (char *)dia_it.dlgresaddr->list[dia_it.curitem].data;
	es = dia_it.editstart;   ee = dia_it.editend;
	if (es > ee) { i = es;   es = ee;   ee = i; }
	Dtextlocation(msg, es, &itemrect, &sx, &sline);
	Dtextlocation(msg, ee, &itemrect, &ex, &eline);
	for(i=sline; i<=eline; i++)
	{
		r.top = itemrect.top + i * dia_lineheight;
		if (r.top >= itemrect.bottom) break;
		r.bottom = r.top + dia_lineheight;
		if (r.bottom > itemrect.bottom) r.bottom = itemrect.bottom;

		r.left = itemrect.left;
		if (i == sline)
		{
			Dtextlocation(msg, (INTSML)(es+1), &itemrect, &dummy, &line);
			if (line != sline && sline != eline) continue;
			r.left += sx;
		}
		r.right = itemrect.right;
		if (i == eline)
		{
			if (ex == 0 && sline != eline) continue;
			r.right = itemrect.left + ex + 1;
		}

		Dinvertrect(&r);
	}
}

/*
 * routine to determine where the cursor is in the edit item "r" given character
 * "len" of "msg".  The horizontal offset is placed in "wid" and the line number
 * in "line".
 */
void Dtextlocation(char *msg, INTSML position, RECTAREA *r, INTSML *x, INTSML *line)
{
	INTSML basepos, len, wid;

	/* if beyond the end, any hit is the end */
	*line = *x = 0;
	if (dia_it.firstch >= strlen(msg)) return;

	/* set initial message and offset in corner of edit box */
	msg = &msg[dia_it.firstch];
	basepos = dia_it.firstch;
	while (*msg != 0)
	{
		for(len = strlen(msg); len>0; len--)
		{
			wid = Dgettextsize(msg, len);
			if (wid < r->right-r->left-2) break;
		}
		if (len <= 0) { *x = 0;   break; }

		if (position - basepos <= len)
		{
			*x = Dgettextsize(msg, (INTSML)(position - basepos));
			break;
		}
		msg += len;
		basepos += len;
		(*line)++;
	}
}

INTSML Dgeteditpos(RECTAREA *r, INTSML x, INTSML y, char *msg)
{
	INTSML pos, i, basepos, lastpos, len, wid;

	/* if beyond the end, any hit is the end */
	if (dia_it.firstch > strlen(msg)) return(strlen(msg));

	/* set initial message and offset in corner of edit box */
	msg = &msg[dia_it.firstch];
	basepos = dia_it.firstch;
	while (*msg != 0)
	{
		for(len = strlen(msg); len>0; len--)
		{
			wid = Dgettextsize(msg, len);
			if (wid < r->right-r->left-2) break;
		}
		if (len <= 0) break;

		if (y > r->top && y <= r->top+dia_lineheight)
		{
			lastpos = 0;
			for(i=0; i<len; i++)
			{
				pos = Dgettextsize(msg, (INTSML)(i+1));
				if (r->left+(lastpos+pos)/2 > x) break;
				lastpos = pos;
			}
			return(basepos+i);
		}

		msg += len;
		basepos += len;
		y -= dia_lineheight;
	}
	return(basepos);
}

void Ddoneedit(void)
{
	INTSML was;

	if (dia_it.curitem < 0) return;
	Dhighlight(0);
	was = dia_it.curitem;
	dia_it.curitem = -1;
	if (dia_it.firstch == 0) return;
	dia_it.firstch = 0;
	Dstufftext((char *)dia_it.dlgresaddr->list[was-1].data, &dia_it.dlgresaddr->list[was].r);
}

void Ddrawitem(INTSML type, RECTAREA *r, char *msg, INTSML dim)
{
	INTSML j, save;
	POPUPDATA *pd;
	RECTAREA myrect;
	INTBIG xv[3], yv[3];

	if ((type&ITEMTYPE) == POPUP)
	{
		/* popup menu item */
		pd = (POPUPDATA *)msg;
		if (pd->count <= 0) return;
		Dstuffmessage(pd->namelist[pd->current], r, dim);
		Dinsetrect(r, -1);
		Ddrawrectframe(r, 1, 0);
		Ddrawline((INTSML)(r->left+3), r->bottom, r->right, r->bottom);
		Ddrawline(r->right, (INTSML)(r->top+3), r->right, r->bottom);
		Dinsetrect(r, 1);
		xv[0] = r->right - 18;   yv[0] = r->top + 4;
		xv[1] = r->right - 12;   yv[1] = r->top + 10;
		xv[2] = r->right - 6;    yv[2] = r->top + 4;
		save = r->left;   r->left = r->right - 19;
		Dintdrawrect(r, 0);
		r->left = save;
		Ddrawpolygon(xv, yv, 3, 1);
	} else if ((type&ITEMTYPE) == BUTTON || (type&ITEMTYPE) == DEFBUTTON)
	{
		/* button */
		j = Dgettextsize(msg, (INTSML)strlen(msg));
		Ddrawroundrectframe(r, 12, dim);
		Ddrawtext(msg, (INTSML)strlen(msg), (INTSML)((r->left+r->right-j)/2),
			(INTSML)((r->top+r->bottom+dia_lineheight)/2), dim);
	} else if ((type&ITEMTYPE) == CHECK)
	{
		/* check box */
		myrect = *r;
		myrect.right = myrect.left + 12;
		myrect.top = (myrect.top + myrect.bottom) / 2 - 6;
		myrect.bottom = myrect.top + 12;
		Ddrawrectframe(&myrect, 1, dim);
		Ddrawtext(msg, (INTSML)strlen(msg), (INTSML)(myrect.right+4), (INTSML)(r->top+dia_lineheight), dim);
	} else if ((type&ITEMTYPE) == RADIO)
	{
		/* radio button */
		myrect = *r;
		myrect.right = myrect.left + 12;
		myrect.top = (myrect.top + myrect.bottom) / 2 - 6;
		myrect.bottom = myrect.top + 12;
		Ddrawcircle(&myrect, dim);
		Ddrawtext(msg, (INTSML)strlen(msg), (INTSML)(myrect.right+4), (INTSML)(myrect.top+dia_lineheight), dim);
	} else if ((type&ITEMTYPE) == MESSAGE)
	{
		/* message */
		Dstuffmessage(msg, r, dim);
	} else if ((type&ITEMTYPE) == EDITTEXT)
	{
		/* edit text */
		if (dim == 0) Dstufftext(msg, r);
		Deditbox(r, 1, dim);
	} else if ((type&ITEMTYPE) == SCROLL)
	{
		/* scrollable list */
		Ddrawrectframe(r, 1, dim);
	} else if ((type&ITEMTYPE) == ICON)
	{
		/* 32x32 icon */
		Dputicon(r->left, r->top, msg);
	} else if ((type&ITEMTYPE) == DIVIDELINE)
	{
		/* dividing line */
		DiaDrawRect(0, r, 1);
	}
}

void Ddrawpopupentries(void)
{
	INTSML i, y;
	INTBIG xv[3], yv[3];

	Dintdrawrect(&dia_rect, 0);
	Ddrawrectframe(&dia_rect, 1, 0);
	for(i=dia_sta; i<dia_cnt; i++)
	{
		if (i == dia_sta && dia_sta != 0)
		{
			y = dia_rect.top+(i-dia_sta+1)*dia_lineheight+1;
			xv[0] = dia_rect.left + 18;   yv[0] = y - 4;
			xv[1] = dia_rect.left + 12;   yv[1] = y - 10;
			xv[2] = dia_rect.left + 6;    yv[2] = y - 4;
			Ddrawpolygon(xv, yv, 3, 1);
			continue;
		}
		if (i == dia_cnt-1 && dia_cnt != dia_pd->count)
		{
			y = dia_rect.top+(i-dia_sta+1)*dia_lineheight+1;
			xv[0] = dia_rect.left + 18;   yv[0] = y - 10;
			xv[1] = dia_rect.left + 12;   yv[1] = y - 4;
			xv[2] = dia_rect.left + 6;    yv[2] = y - 10;
			Ddrawpolygon(xv, yv, 3, 1);
			continue;
		}
		Ddrawtext(dia_pd->namelist[i], (INTSML)(strlen(dia_pd->namelist[i])), (INTSML)(dia_rect.left+1),
			(INTSML)(dia_rect.top+(i-dia_sta+1)*dia_lineheight+1), 0);
	}
}

void Dstufftext(char *msg, RECTAREA *r)
{
	INTSML len, wid, vpos;

	Dintdrawrect(r, 0);

	/* display the message in multiple lines */
	vpos = r->top+dia_lineheight;
	if (dia_it.firstch > strlen(msg)) return;
	msg = &msg[dia_it.firstch];
	while (*msg != 0)
	{
		for(len = strlen(msg); len>0; len--)
		{
			wid = Dgettextsize(msg, len);
			if (wid < r->right-r->left-2) break;
		}
		if (len <= 0) break;
		Ddrawtext(msg, len, (INTSML)(r->left+1), vpos, 0);
		msg += len;
		vpos += dia_lineheight;
		if (vpos > r->bottom) break;
	}
}

void Dstuffmessage(char *msg, RECTAREA *r, INTSML dim)
{
	INTSML len, wid, truelen, vpos, mostch, i;

	Dintdrawrect(r, 0);

	/* see how much fits */
	truelen = strlen(msg);
	for(len = truelen; len > 0; len--)
	{
		wid = Dgettextsize(msg, len);
		if (wid <= r->right-r->left-2) break;
	}
	if (len <= 0) return;

	/* if it all fits or must fit (because there is just 1 line), draw it */
	vpos = r->top+dia_lineheight;
	if (len == truelen || dia_lineheight*2 > r->bottom - r->top)
	{
		if (len != truelen)
		{
			/* single line doesn't fit: put ellipsis at end */
			(void)initinfstr();
			for(i=0; i<len-3; i++) (void)addtoinfstr(msg[i]);
			(void)addstringtoinfstr("...");
			msg = returninfstr();
		}
		Ddrawtext(msg, len, (INTSML)(r->left+1), vpos, dim);
		return;
	}

	/* write the message in multiple lines */
	while (truelen > 0)
	{
		mostch = 0;
		for(len = truelen; len > 0; len--)
		{
			wid = Dgettextsize(msg, len);
			if (wid > r->right-r->left-2) continue;
			if (mostch == 0) mostch = len;
			if (msg[len] == 0 || msg[len] == ' ') break;
		}
		if (len <= 0) len = mostch;
		Ddrawtext(msg, len, (INTSML)(r->left+1), vpos, dim);
		if (msg[len] == ' ') len++;
		msg += len;
		truelen -= len;
		vpos += dia_lineheight;
		if (vpos > r->bottom) break;
	}
}

void Deditbox(RECTAREA *r, INTSML draw, INTSML dim)
{
	Dinsetrect(r, -3);
	Ddrawrectframe(r, draw, dim);
	Dinsetrect(r, 3);
}

/*
 * routine to draw line "msg" in position "which" of scroll area "sc"
 */
void Ddrawmsg(INTSML sc, char *msg, INTSML which)
{
	INTSML wid, len, firstch, offset;
	INTBIG skip;
	DSCROLL *scr;

	Dsettextsmall(sc);
	scr = &dia_it.scroll[sc];
	firstch = offset = 0;
	if (scr->horizfactor != 0)
	{
		skip = scr->userrect.right - scr->userrect.left - 6;
		skip *= (INTBIG)scr->horizfactor;   skip /= 10;
		wid = Dgettextsize(msg, (INTSML)strlen(msg));
		if (skip >= wid) return;
		for(firstch = 0; firstch < strlen(msg); firstch++)
		{
			wid = Dgettextsize(msg, firstch);
			if (wid >= skip) break;
		}
		offset = wid - skip;
	}

	for(len = strlen(&msg[firstch]); len>0; len--)
	{
		wid = Dgettextsize(&msg[firstch], len);
		if (wid+offset < scr->userrect.right-scr->userrect.left-6) break;
	}
	if (len <= 0) return;
	Ddrawtext(&msg[firstch], len, (INTSML)(scr->userrect.left+2+offset),
		(INTSML)(scr->userrect.top + scr->lineheight*(which+1)), 0);
	Dsettextsmall(-1);
}

void Dinsetrect(RECTAREA *r, INTSML amt)
{
	r->left += amt;   r->right -= amt;
	r->top += amt;    r->bottom -= amt;
}

void Ddrawvertslider(INTSML sc)
{
	RECTAREA r;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc];
	r = scr->userrect;
	r.left = r.right-1;   r.right += 14;
	Ddrawrectframe(&r, 1, 0);
	Ddrawline(r.left, (INTSML)(r.top+15), (INTSML)(r.right-1), (INTSML)(r.top+15));
	Ddrawarrow(sc, UPARROW, 0);
	Ddrawline(r.left, (INTSML)(r.bottom-16), (INTSML)(r.right-1), (INTSML)(r.bottom-16));
	Ddrawarrow(sc, DOWNARROW, 0);
}

void Ddrawhorizslider(INTSML sc)
{
	RECTAREA r;
	DSCROLL *scr;

	scr = &dia_it.scroll[sc];
	r = scr->userrect;
	r.top = r.bottom-1;   r.bottom += 14;
	Ddrawrectframe(&r, 1, 0);
	Ddrawline((INTSML)(r.left+15), r.top, (INTSML)(r.left+15), (INTSML)(r.bottom-1));
	Ddrawarrow(sc, LEFTARROW, 0);
	Ddrawline((INTSML)(r.right-16), r.top, (INTSML)(r.right-16), (INTSML)(r.bottom-1));
	Ddrawarrow(sc, RIGHTARROW, 0);
	Dsethscroll(sc);
}

void Ddrawarrow(INTSML sc, INTSML which, INTSML filled)
{
	INTSML i, left, top, bottom, right;
	INTBIG xv[ARROWLEN], yv[ARROWLEN];
	DSCROLL *scr;

	scr = &dia_it.scroll[sc];
	top = scr->userrect.top;
	bottom = scr->userrect.bottom-1;
	right = scr->userrect.right-1;
	left = scr->userrect.left;
	for(i=0; i<ARROWLEN; i++)
	{
		switch (which)
		{
			case UPARROW:
				xv[i] = right+dia_arrowx[i];
				yv[i] = top+dia_arrowy[i];
				break;
			case DOWNARROW:
				xv[i] = right+dia_arrowx[i];
				yv[i] = bottom-dia_arrowy[i];
				break;
			case LEFTARROW:
				xv[i] = left+dia_arrowy[i];
				yv[i] = bottom+dia_arrowx[i];
				break;
			case RIGHTARROW:
				xv[i] = right-dia_arrowy[i];
				yv[i] = bottom+dia_arrowx[i];
				break;
		}
	}
	Ddrawpolygon(xv, yv, ARROWLEN, filled);
}

void Dredrawdialogwindow(void)
{
	INTSML i, itemtype, dim;
	char *line;
	RECTAREA r;
	USERTYPE routine;

	if (dia_active <= 0) return;

	/* redraw the window frame */
	Dsettextsmall(-1);
	Dnewdialogwindowframe(&dia_it.dlgresaddr->windowRect, dia_it.dlgresaddr->movable);

	for(i=0; i<dia_it.dlgresaddr->items; i++)
	{
		/* draw the item */
		itemtype = dia_it.dlgresaddr->list[i].type;
		r = dia_it.dlgresaddr->list[i].r;
		if ((itemtype&ITEMTYPE) == USERDRAWN)
		{
			routine = (USERTYPE)dia_it.dlgresaddr->list[i].data;
			if (routine != 0) (*routine)(&r);
			continue;
		}
		if ((itemtype&ITEMTYPE) == MESSAGE || (itemtype&ITEMTYPE) == EDITTEXT || (itemtype&ITEMTYPE) == POPUP)
			line = (char *)dia_it.dlgresaddr->list[i].data; else
				line = dia_it.dlgresaddr->list[i].msg;
		if ((itemtype&ITEMTYPE) == CHECK || (itemtype&ITEMTYPE) == RADIO)
			DiaSetControl((INTSML)(i+1), (INTSML)dia_it.dlgresaddr->list[i].data);
		if ((itemtype&INACTIVE) != 0) dim = 1; else dim = 0;
		Ddrawitem(itemtype, &r, line, dim);

		/* highlight the default button */
		if (i == dia_it.defaultbutton-1 &&
			(itemtype == BUTTON || itemtype == DEFBUTTON)) Dhighlightrect(&r);
	}

	/* turn on anything being edited */
	if (dia_it.curitem >= 0) Dhighlight(1);
	for(i=0; i<dia_it.scrollcount; i++)
	{
		Dredrawscroll(i);
		Dinvertentry(i, 1);      /* restores previous inverted entry */
		Dsetvscroll(i);
		if ((dia_it.scroll[i].flags&SCHORIZBAR) != 0)
		{
			Ddrawhorizslider(i);
			Dsethscroll(i);
		}
	}
}

/****************************** ATHENA DIALOG PRIMITIVE GRAPHICS ******************************/

INTSML Dnullup(INTBIG x, INTBIG y) { return(0); }
void Dnullvoid(void) {}
INTSML Dnullchar(INTBIG x, INTBIG y, INTSML ch) { return(0); }

/*
 * routine to prepare a dialog in location "r", draggable if "movable" is nonzero
 */
void Dnewdialogwindow(RECTAREA *r, char *movable)
{
	INTSML x, swid, shei;
	RECTAREA lr;

	dia_window = *el_curwindowpart;
	us_getwindowsize(el_curwindowpart->frame, &swid, &shei);

	/* set drawing bounds to address the world */
	dia_window.screenlx = dia_window.screenly = dia_window.uselx = dia_window.usely = 0;
	dia_window.screenhx = dia_window.usehx = swid-1;
	dia_window.screenhy = dia_window.usehy = shei-1;
	dia_window.frame = el_curwindowpart->frame;
	computewindowscale(&dia_window);

	dia_revy = shei-1;
	setdefaultcursortype(NORMALCURSOR);
	us_menufigs.col = el_colmengly;
	us_menutext.col = el_colmentxt;

	/* set text sizes */
	us_settextsize(&dia_window, TXT8P);
	us_textsize(&dia_window, "X", &x, &dia_slineheight);
	us_settextsize(&dia_window, TXTMENU);
	us_textsize(&dia_window, "X", &x, &dia_lineheight);

	/* adjust for window borders */
	lr = *r;
	if (movable == 0) Dinsetrect(&lr, -5); else
	{
		Dinsetrect(&lr, -1);
		lr.top -= DRAGBARHEIGHT;
	}

	/* make sure the dialog fits in the edit window */
	us_getwindowsize(el_curwindowpart->frame, &swid, &shei);
	if (lr.right >= swid) { lr.left -= lr.right-swid+1;   lr.right = swid-1; }
	if (lr.bottom >= shei) { lr.top -= lr.bottom-shei+1;   lr.bottom = shei-1; }
	if (lr.left < 0) { lr.right -= lr.left;   lr.left = 0; }
	if (lr.top < 0) { lr.bottom -= lr.top;   lr.top = 0; }
	if (lr.right >= swid) lr.right = swid-1;
	if (lr.bottom >= shei) lr.bottom = shei-1;

	/* save the display under the dialog */
	dia_it.theDialog = us_savebox(&dia_window, lr.left, lr.right, (INTSML)(dia_revy-lr.bottom),
		(INTSML)(dia_revy-lr.top));

	/* compute the true offsets */
	if (movable == 0)
	{
		dia_xoffset = lr.left+5;    dia_yrev = dia_revy - (lr.top+5);
	} else
	{
		dia_xoffset = lr.left+1;    dia_yrev = dia_revy - (lr.top+DRAGBARHEIGHT+1);
	}
	dia_lineoffset = 0;
	dia_curlineoffset = dia_lineoffset;
}

/*
 * routine to draw the dialog frame in location "r", draggable if "movable" is nonzero
 */
void Dnewdialogwindowframe(RECTAREA *r, char *movable)
{
	RECTAREA lr;
	INTSML realxo, realyo, wid, swid, shei;

	lr = *r;
	if (movable == 0) Dinsetrect(&lr, -5); else
	{
		Dinsetrect(&lr, -1);
		lr.top -= DRAGBARHEIGHT;
	}

	/* make sure the dialog fits in the edit window */
	us_getwindowsize(el_curwindowpart->frame, &swid, &shei);
	if (lr.right >= swid) { lr.left -= lr.right-swid+1;   lr.right = swid-1; }
	if (lr.bottom >= shei) { lr.top -= lr.bottom-shei+1;   lr.bottom = shei-1; }
	if (lr.left < 0) { lr.right -= lr.left;   lr.left = 0; }
	if (lr.top < 0) { lr.bottom -= lr.top;   lr.top = 0; }
	if (lr.right >= swid) lr.right = swid-1;
	if (lr.bottom >= shei) lr.bottom = shei-1;

	/* compute the true offsets and set temporary ones */
	if (movable == 0)
	{
		realxo = lr.left+5;    realyo = dia_revy - (lr.top+5);
	} else
	{
		realxo = lr.left+1;    realyo = dia_revy - (lr.top+DRAGBARHEIGHT+1);
	}
	dia_xoffset = lr.left;    dia_yrev = dia_revy - lr.top;

	us_drawbox(&dia_window, lr.left, lr.right, (INTSML)(dia_revy-lr.bottom), (INTSML)(dia_revy-lr.top), &us_ebox);
	lr.right -= lr.left;   lr.left = 0;
	lr.bottom -= lr.top;   lr.top = 0;
	if (movable == 0)
	{
		Ddrawrectframe(&lr, 1, 0);
		Dinsetrect(&lr, 3);
		Ddrawrectframe(&lr, 1, 0);
		Dinsetrect(&lr, 1);
		Ddrawrectframe(&lr, 1, 0);
	} else
	{
		Ddrawrectframe(&lr, 1, 0);
		lr.bottom = lr.top + DRAGBARHEIGHT;
		lr.left++;   lr.right--;   lr.top++;
		Dgrayrect(&lr);
		Ddrawline(lr.left,lr.bottom, lr.right,lr.bottom);
		if (*movable != 0)
		{
			wid = Dgettextsize(movable, (INTSML)strlen(movable));
			lr.left = (lr.right+lr.left-wid) / 2-10;
			lr.right = lr.left + wid + 20;
			Dintdrawrect(&lr, 0);
			Ddrawtext(movable, (INTSML)strlen(movable), (INTSML)(lr.left+10), lr.bottom, 0);
		}
	}

	/* set true offsets */
	dia_xoffset = realxo;    dia_yrev = realyo;
}

/*
 * Routine to return the low and high Y coordinates of the WINDOW in dialog space.
 */
void Dgetwindowextent(INTSML *ly, INTSML *hy)
{
	INTSML swid, shei;

	us_getwindowsize(el_curwindowpart->frame, &swid, &shei);
	*ly = -dia_it.dlgresaddr->windowRect.top;
	*hy = shei-dia_it.dlgresaddr->windowRect.top;
}

/*
 * routine to terminate the current dialog
 */
void Ddonedialogwindow(void)
{
	(void)us_restorebox(dia_it.theDialog, 1);
}

/*
 * routine to wait for the next action from the dialog window.  Returns:
 *  -1  Nothing happened
 *   0  Key typed, character in "chr"
 *   1  Mouse button pushed, coordinates in (x,y), modifiers in "chr"
 *   2  Mouse button released, coordinates in (x,y)
 *   4  Mouse motion while button down, coordinates in (x,y)
 *   5  Double-click of mouse button, coordinates in (x,y), modifiers in "chr"
 */
INTSML Dwaitforaction(INTSML *x, INTSML *y, INTSML *chr, UINTBIG *time)
{
	INTSML but;
	INTBIG lx, ly;

	if (ttydataready() == 0)
	{
		waitforbutton(x, y, &but);
		if (but < 0) return(-1);
		lx = *x;   ly = *y;
		Dcorrectxy(&lx, &ly);
		*x = lx;   *y = ly;

		/* see if the drag bar was hit */
		if (dia_it.dlgresaddr->movable != 0 && *y < 0)
		{
			Ddragwindow(*x, *y);
			return(-1);
		}
		*time = ticktime();
		if (doublebutton(but) != 0) return(5);
		return(1);
	}
	*chr = us_getnxtchar();
	*time = ticktime();
	return(0);
}

/*
 * routine to track mouse movements while the button remains down, calling
 * the routine "eachdown" for each advance.  The routine is given the
 * mouse coordinates as parameters.  The initial mouse position is (fx,fy).
 */
void Dtrackcursor(INTSML fx, INTSML fy, INTSML (*eachdown)(INTBIG, INTBIG))
{
	trackcursor(0, Dnullup, Dnullvoid, eachdown, Dnullchar, Dnullvoid, TRACKNORMAL);
}

/*
 * routine to save the rectangle "r" and return a pointer that can be
 * used to restore it with "Drestorerect()".  Returns zero if this function
 * is not possible.
 */
INTBIG Dsaverect(RECTAREA *r)
{
	return(us_savebox(&dia_window, (INTSML)(r->left+dia_xoffset), (INTSML)(r->right+1+dia_xoffset),
		(INTSML)(dia_yrev-r->bottom), (INTSML)(dia_yrev-r->top)));
}

/*
 * routine to restore the rectangle "sr" (a pointer that came from "Dsaverect()")
 */
void Drestorerect(INTBIG sr)
{
	(void)us_restorebox(sr, 1);
}

/*
 * routine to move the rectangle "sr" to "dr"
 */
void Dshiftbits(RECTAREA *sr, RECTAREA *dr)
{
	us_movebox(&dia_window, sr->left, sr->top, (INTSML)(sr->right-sr->left), (INTSML)(sr->bottom-sr->top),
		dr->left, dr->top);
}

void Dcorrectxy(INTBIG *x, INTBIG *y)
{
	*x -= dia_xoffset;
	*y = dia_yrev - *y;
}

/*
 * routine to draw the 32x32 bitmap in "data" at (x,y)
 */
void Dputicon(INTSML x, INTSML y, char *data)
{
	INTSML xp, yp, v;

	for(yp=0; yp<32; yp++)
	{
		for(xp=0; xp<32; xp++)
		{
			v = data[yp*4 + (xp>>3)];
			if ((v & (0200>>(xp&7))) == 0) continue;
			Ddrawbox(x+xp, x+xp, y+yp, y+yp, &us_menufigs);
		}
	}
}

/*
 * routine to draw a line from (xf,yf) to (xt,yt) in the dialog
 */
void Ddrawline(INTSML xf, INTSML yf, INTSML xt, INTSML yt)
{
	INTBIG fx, fy, tx, ty;

	fx = xf + dia_xoffset;   fy = dia_yrev - yf;
	tx = xt + dia_xoffset;   ty = dia_yrev - yt;
	if (clipline(&fx, &fy, &tx, &ty, dia_window.uselx, dia_window.usehx,
		dia_window.usely, dia_window.usehy) != 0) return;
	us_drawline(&dia_window, (INTSML)fx, (INTSML)fy, (INTSML)tx, (INTSML)ty, &us_menufigs, 0);
}

/*
 * routine to draw a filled rectangle at "r" in the dialog.  Erases if "on" is zero
 */
void Dintdrawrect(RECTAREA *r, INTSML on)
{
	GRAPHICS *which;

	if (on == 0) which = &us_ebox; else which = &us_menufigs;
	Ddrawbox(r->left, r->right-1, r->bottom-1, r->top, which);
}

void Ddrawbox(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy, GRAPHICS *which)
{
	lx += dia_xoffset;   ly = dia_yrev - ly;
	hx += dia_xoffset;   hy = dia_yrev - hy;
	if (lx < dia_window.uselx) lx = dia_window.uselx;
	if (hx >= dia_window.usehx) hx = dia_window.usehx-1;
	if (ly < dia_window.usely) ly = dia_window.usely;
	if (hy >= dia_window.usehy) hy = dia_window.usehy-1;
	if (lx > hx || ly > hy) return;
	us_drawbox(&dia_window, (INTSML)lx, (INTSML)hx, (INTSML)ly, (INTSML)hy, which);
}

void Dinvertbox(INTBIG lx, INTBIG hx, INTBIG ly, INTBIG hy)
{
	lx += dia_xoffset;   ly = dia_yrev - ly;
	hx += dia_xoffset;   hy = dia_yrev - hy;
	if (lx < dia_window.uselx) lx = dia_window.uselx;
	if (hx >= dia_window.usehx) hx = dia_window.usehx-1;
	if (ly < dia_window.usely) ly = dia_window.usely;
	if (hy >= dia_window.usehy) hy = dia_window.usehy-1;
	if (lx >= hx || ly >= hy) return;
	us_invertbox(&dia_window, (INTSML)lx, (INTSML)hx, (INTSML)ly, (INTSML)hy);
}

/*
 * routine to draw a gray rectangle at "r" in the dialog
 */
void Dgrayrect(RECTAREA *r)
{
	Ddrawbox(r->left, r->right, r->bottom, r->top, &dia_drawgray);
}

/*
 * routine to invert a rectangle at "r" in the dialog
 */
void Dinvertrect(RECTAREA *r)
{
	Dinvertbox(r->left, r->right, r->bottom-1, r->top);
}

/*
 * routine to draw the outline of rectangle "r" in the dialog.  Erases if "on" is zero
 */
void Ddrawrectframe(RECTAREA *r, INTSML on, INTSML dim)
{
	GRAPHICS *which;

	if (on == 0) which = &us_ebox; else
	{
		if (dim == 0) which = &us_menufigs; else which = &dia_drawdim;
	}
	Ddrawline(r->left, r->top, r->left, (INTSML)(r->bottom-1));
	Ddrawline(r->left, (INTSML)(r->bottom-1), r->right, (INTSML)(r->bottom-1));
	Ddrawline(r->right, (INTSML)(r->bottom-1), r->right, r->top);
	Ddrawline(r->right, r->top, r->left, r->top);
}

/*
 * routine to highlight the outline of rectangle "r" in the dialog
 */
void Dhighlightrect(RECTAREA *r)
{
	Dinsetrect(r, -3);
	Ddrawrectframe(r, 1, 0);
	Dinsetrect(r, -1);
	Ddrawrectframe(r, 1, 0);
}

/*
 * routine to draw the outline of rounded rectangle "r" in the dialog
 */
void Ddrawroundrectframe(RECTAREA *r, INTSML arc, INTSML dim)
{
	Ddrawrectframe(r, 1, dim);
}

/*
 * routine to invert the outline of rectangle "r" in the dialog
 */
void Dinvertrectframe(RECTAREA *r)
{
	Dinvertbox(r->left, r->left+1, r->bottom-1, r->top);
	Dinvertbox(r->right-1, r->right, r->bottom-1, r->top);
	Dinvertbox(r->left+1, r->right-1, r->bottom, r->bottom-1);
	Dinvertbox(r->left+1, r->right-1, r->top+1, r->top);
}

/*
 * routine to draw the polygon in "count" points (xv,yv) and fill it if "filled" is nonzero
 */
void Ddrawpolygon(INTBIG *xv, INTBIG *yv, INTSML count, INTSML filled)
{
	INTSML i, l;

	/* adjust to edit window coordinates */
	if (dia_poly == NOPOLYGON) dia_poly = allocpolygon(count, us_aid->cluster); else
		if (dia_poly->limit < count) (void)extendpolygon(dia_poly, count);
	for(i=0; i<count; i++)
	{
		dia_poly->xv[i] = xv[i] + dia_xoffset;
		dia_poly->yv[i] = dia_yrev - yv[i];
	}
	dia_poly->count = count;
	dia_poly->style = CLOSED;

	clippoly(dia_poly, dia_window.uselx, dia_window.usehx, dia_window.usely, dia_window.usehy);
	if (dia_poly->count == 0) return;

	if (filled == 0)
	{
		us_drawpolygon(&dia_window, dia_poly->xv, dia_poly->yv, dia_poly->count, &us_ebox);
		for(i=0; i<dia_poly->count; i++)
		{
			if (i == 0) l = dia_poly->count-1; else l = i-1;
			us_drawline(&dia_window, (INTSML)dia_poly->xv[l], (INTSML)dia_poly->yv[l],
				(INTSML)dia_poly->xv[i], (INTSML)dia_poly->yv[i], &us_menufigs, 0);
		}
	} else us_drawpolygon(&dia_window, dia_poly->xv, dia_poly->yv, dia_poly->count, &us_menufigs);
}

/*
 * routine to draw a circle outline in rectangle "r" in the dialog
 */
void Ddrawcircle(RECTAREA *r, INTSML dim)
{
	GRAPHICS *which;

	if (dim == 0) which = &us_menufigs; else which = &dia_drawdim;
	if (dia_poly == NOPOLYGON) dia_poly = allocpolygon(2, us_aid->cluster); else
		if (dia_poly->limit < 2) (void)extendpolygon(dia_poly, 2);
	dia_poly->xv[0] = (r->left+r->right)/2+dia_xoffset;
	dia_poly->yv[0] = dia_yrev-(r->top+r->bottom)/2;
	dia_poly->xv[1] = dia_poly->xv[0] + (r->right-r->left)/2;
	dia_poly->yv[1] = dia_poly->yv[0];
	dia_poly->count = 2;
	dia_poly->style = CIRCLE;
	cliparc(dia_poly, dia_window.uselx, dia_window.usehx, dia_window.usely, dia_window.usehy);
	if (dia_poly->style != CIRCLE) return;

	us_drawcircle(&dia_window, dia_poly->xv[0], dia_poly->yv[0], (r->right-r->left)/2, which);
}

/*
 * routine to draw a filled circle in rectangle "r" in the dialog
 */
void Ddrawdisc(RECTAREA *r)
{
	if (dia_poly == NOPOLYGON) dia_poly = allocpolygon(2, us_aid->cluster); else
		if (dia_poly->limit < 2) (void)extendpolygon(dia_poly, 2);
	dia_poly->xv[0] = (r->left+r->right)/2+dia_xoffset;
	dia_poly->yv[0] = dia_yrev-(r->top+r->bottom)/2;
	dia_poly->xv[1] = dia_poly->xv[0] + (r->right-r->left)/2;
	dia_poly->yv[1] = dia_poly->yv[0];
	dia_poly->count = 2;
	dia_poly->style = DISC;
	cliparc(dia_poly, dia_window.uselx, dia_window.usehx, dia_window.usely, dia_window.usehy);
	if (dia_poly->style != DISC) return;

	us_drawdisc(&dia_window, dia_poly->xv[0], dia_poly->yv[0], (r->right-r->left)/2, &us_menufigs);
}

/*
 * routine to determine the width of the "len" characters at "msg"
 */
INTSML Dgettextsize(char *msg, INTSML len)
{
	INTSML wid, hei, need;
	static char *tempbuf;
	static INTSML tempbufsize = 0;

	if (len == 0) return(0);
	need = len + 1;
	if (need > tempbufsize)
	{
		if (tempbufsize > 0) efree(tempbuf);
		tempbufsize = 0;
		tempbuf = (char *)emalloc(need, us_aid->cluster);
		if (tempbuf == 0) return(0);
		tempbufsize = need;
	}
	strncpy(tempbuf, msg, len);
	tempbuf[len] = 0;
	us_textsize(&dia_window, tempbuf, &wid, &hei);
	return(wid);
}

/*
 * Routine to set the current text size to the large or small scroll text.
 */
void Dsettextsmall(INTSML sc)
{
	INTSML smallf;
	DSCROLL *scr;

	if (sc < 0) smallf = 0; else
	{
		scr = &dia_it.scroll[sc];
		smallf = scr->flags & SCSMALLFONT;
	}
	if (smallf != 0)
	{
		dia_curlineoffset = dia_slineoffset;
		us_settextsize(&dia_window, TXT8P);
	} else
	{
		dia_curlineoffset = dia_lineoffset;
		us_settextsize(&dia_window, TXTMENU);
	}
}

/*
 * routine to draw "len" characters of "msg" at (x,y)
 */
void Ddrawtext(char *msg, INTSML len, INTSML x, INTSML y, INTSML dim)
{
	INTSML need, sx, sy;
	GRAPHICS *which;
	static char *tempbuf;
	static INTSML tempbufsize = 0;

	if (dim == 0) which = &us_menutext; else which = &dia_drawdim;
	need = len + 1;
	if (need > tempbufsize)
	{
		if (tempbufsize > 0) efree(tempbuf);
		tempbufsize = 0;
		tempbuf = (char *)emalloc(need, us_aid->cluster);
		if (tempbuf == 0) return;
		tempbufsize = need;
	}
	strncpy(tempbuf, msg, len);
	tempbuf[len] = 0;
	us_textsize(&dia_window, tempbuf, &sx, &sy);
	if (x+dia_xoffset >= dia_window.uselx && x+dia_xoffset+sx < dia_window.usehx &&
		dia_yrev-y >= dia_window.usely && dia_yrev-y+sy < dia_window.usehy)
	{
		us_puttext(&dia_window, (INTSML)(x+dia_xoffset), (INTSML)(dia_yrev-y),
			tempbuf, which);
	}
}

INTSML Ddragwin(INTBIG x, INTBIG y)
{
	INTSML swid, shei;

	if (x == dia_lastx && y == dia_lasty) return(0);
	us_getwindowsize(el_curwindowpart->frame, &swid, &shei);
	if (dia_it.dlgresaddr->windowRect.left+x-dia_lastx < 0) return(0);
	if (dia_it.dlgresaddr->windowRect.right+x-dia_lastx >= swid) return(0);
	if (dia_it.dlgresaddr->windowRect.top-y+dia_lasty < 0) return(0);
	if (dia_it.dlgresaddr->windowRect.bottom-y+dia_lasty >= shei) return(0);
	Dinvertrectframe(&dia_it.dlgresaddr->windowRect);
	dia_it.dlgresaddr->windowRect.left += x-dia_lastx;
	dia_it.dlgresaddr->windowRect.right += x-dia_lastx;
	dia_it.dlgresaddr->windowRect.top -= y-dia_lasty;
	dia_it.dlgresaddr->windowRect.bottom -= y-dia_lasty;
	dia_lastx = x;   dia_lasty = y;
	Dinvertrectframe(&dia_it.dlgresaddr->windowRect);
	return(0);
}

void Ddragwindow(INTSML x, INTSML y)
{
	INTBIG save;
	INTSML swid, shei;
	REGISTER INTSML saveleft, saveright, savetop, savebottom;
	RECTAREA lr, oldr;

	if (y <= -DRAGBARHEIGHT && x >= 0 &&
		x <= dia_it.dlgresaddr->windowRect.right-dia_it.dlgresaddr->windowRect.left) return;

	dia_lastx = x + dia_xoffset;
	dia_lasty = dia_yrev - y;
	dia_xoffset = 0;         dia_yrev = dia_revy;
	oldr = dia_it.dlgresaddr->windowRect;

	/* make the window frame true to size */
	Dinsetrect(&dia_it.dlgresaddr->windowRect, -1);
	dia_it.dlgresaddr->windowRect.top -= DRAGBARHEIGHT;
	Dinvertrectframe(&dia_it.dlgresaddr->windowRect);
	trackcursor(0, Dnullup, Dnullvoid, Ddragwin, Dnullchar, Dnullvoid, TRACKNORMAL);
	Dinvertrectframe(&dia_it.dlgresaddr->windowRect);

	/* save the old dialog image */
	Dinsetrect(&oldr, -1);
	oldr.top -= DRAGBARHEIGHT;
	saveleft = oldr.left;
	saveright = oldr.right;
	savetop = dia_revy-oldr.bottom;
	savebottom = dia_revy-oldr.top;

	/* make sure the dialog fits in the edit window */
	us_getwindowsize(el_curwindowpart->frame, &swid, &shei);
	if (saveright >= swid) { saveleft -= saveright-swid+1;    saveright = swid-1; }
	if (savebottom >= shei) { savetop -= savebottom-shei+1;   savebottom = shei-1; }
	if (saveleft < 0) { saveright -= saveleft;   saveleft = 0; }
	if (savetop < 0) { lr.bottom -= savetop;   savetop = 0; }
	if (saveright >= swid) saveright = swid-1;
	if (savebottom >= shei) savebottom = shei-1;

	save = us_savebox(&dia_window, saveleft, saveright, savetop, savebottom);

	/* move the saved bits to the new location */
	us_movesavedbox(save, (INTSML)(dia_it.dlgresaddr->windowRect.left-oldr.left),
		(INTSML)(-(dia_it.dlgresaddr->windowRect.top-oldr.top)));

	/* restore the bits underneath */
	us_restorebox(dia_it.theDialog, 1);

	/* save the bits under the new dialog area */
	lr = dia_it.dlgresaddr->windowRect;
	saveleft = lr.left;
	saveright = lr.right;
	savetop = dia_revy-lr.bottom;
	savebottom = dia_revy-lr.top;
	if (saveright >= swid) { saveleft -= saveright-swid+1;    saveright = swid-1; }
	if (savebottom >= shei) { savetop -= savebottom-shei+1;   savebottom = shei-1; }
	if (saveleft < 0) { saveright -= saveleft;   saveleft = 0; }
	if (savetop < 0) { lr.bottom -= savetop;   savetop = 0; }
	if (saveright >= swid) saveright = swid-1;
	if (savebottom >= shei) savebottom = shei-1;
	dia_it.theDialog = us_savebox(&dia_window, saveleft, saveright, savetop, savebottom);

	/* restore the dialog to the new location */
	us_restorebox(save, 1);

	/* restore the moved dialog frame to its true size */
	Dinsetrect(&dia_it.dlgresaddr->windowRect, 1);
	dia_it.dlgresaddr->windowRect.top += DRAGBARHEIGHT;

	/* compute proper drawing offsets */
	dia_xoffset = dia_it.dlgresaddr->windowRect.left;
	dia_yrev = dia_revy - dia_it.dlgresaddr->windowRect.top;
}

#endif
