/*
 * Electric(tm) VLSI Design System
 *
 * File: usrdiacom1.c
 * Special command dialogs, part 1
 * Written by: Steven M. Rubin, Electric Editor Incorporated
 *
 * Copyright (c) 1998 Electric Editor Incorporated.
 *
 * Electric(tm) is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Electric(tm) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Electric(tm); see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, Mass 02111-1307, USA.
 *
 * Electric Editor Incorporated
 * 23470 Sunset Drive, Suite 108
 * Los Gatos, California 95033
 * support@electriceditor.com
 */

#include "global.h"
#include "egraphics.h"
#include "usr.h"
#include "usrdiacom.h"
#include "efunction.h"
#include "tecart.h"
#include "tecschem.h"
#include "tecgen.h"
#include "usredtec.h"
#include "sim.h"
#include "eio.h"
#include "edialogs.h"
#if SCAID
#  include "sc1.h"
#endif
#include <math.h>

/*
 * the list of contributors to Electric (not including Steven M. Rubin)
 */
char *us_castofthousands[] =
{
	"Philip Attfield",
	"Ron Bolton",
	"Mark Brinsmead",
	"Stefano Concina",
	"Peter Gallant",
	"R. Brian Gardiner",
	"T. J. Goodman",
	"D. Guptill",
	"Robert Hon",
	"Sundaravarathan Iyengar",
	"Allan Jost",
	"Wallace Kroeker",
	"Andrew Kostiuk",
	"Oliver Laumann",
	"Glen Lawson",
	"David Lewis",
	"Erwin Liu",
	"John Mohammed",
	"Mark Moraes",
	"Sid Penstone",
	"J. P. Polonovski",
	"Kevin Ryan",
	"Nora Ryan",
	"Brent Serbin",
	"Boaz Shmueli",
	"Ken Stevens",
	"Lyndon Swab",
	"Brian W. Thomson",
	"Burnie West",
	"Telle Whitney",
	"Rob Winstanley",
	"Russell Wright",
	"David J. Yurach",
	0
};

char *us_gnucopying[] =
{
	"TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION",
	"",
	"0. This License applies to any program or other work which contains a notice placed by",
	"the copyright holder saying it may be distributed under the terms of this General",
	"Public License. The 'Program', below, refers to any such program or work, and a",
	"'work based on the Program' means either the Program or any derivative work under",
	"copyright law: that is to say, a work containing the Program or a portion of it,",
	"either verbatim or with modifications and/or translated into another language.",
	"(Hereinafter, translation is included without limitation in the term 'modification'.)",
	"Each licensee is addressed as 'you'.",
	"",
	"Activities other than copying, distribution and modification are not covered by this",
	"License; they are outside its scope. The act of running the Program is not restricted,",
	"and the output from the Program is covered only if its contents constitute a work based",
	"on the Program (independent of having been made by running the Program). Whether that",
	"is true depends on what the Program does.",
	"",
	"1. You may copy and distribute verbatim copies of the Program's source code as you",
	"receive it, in any medium, provided that you conspicuously and appropriately publish",
	"on each copy an appropriate copyright notice and disclaimer of warranty; keep intact",
	"all the notices that refer to this License and to the absence of any warranty; and",
	"give any other recipients of the Program a copy of this License along with the Program.",
	"",
	"You may charge a fee for the physical act of transferring a copy, and you may at your",
	"option offer warranty protection in exchange for a fee.",
	"",
	"2. You may modify your copy or copies of the Program or any portion of it, thus forming",
	"a work based on the Program, and copy and distribute such modifications or work under",
	"the terms of Section 1 above, provided that you also meet all of these conditions:",
	"",
	"*	a) You must cause the modified files to carry prominent notices stating that you",
	"	changed the files and the date of any change.",
	"",
	"*	b) You must cause any work that you distribute or publish, that in whole or",
	"	in part contains or is derived from the Program or any part thereof, to be licensed",
	"	as a whole at no charge to all third parties under the terms of this License.",
	"",
	"*	c) If the modified program normally reads commands interactively when run, you",
	"	must cause it, when started running for such interactive use in the most ordinary",
	"	way, to print or display an announcement including an appropriate copyright notice",
	"	and a notice that there is no warranty (or else, saying that you provide a warranty)",
	"	and that users may redistribute the program under these conditions, and telling the",
	"	user how to view a copy of this License. (Exception: if the Program itself is",
	"	interactive but does not normally print such an announcement, your work based on the",
	"	Program is not required to print an announcement.)",
	"",
	"These requirements apply to the modified work as a whole. If identifiable sections",
	"of that work are not derived from the Program, and can be reasonably considered independent",
	"and separate works in themselves, then this License, and its terms, do not apply to those",
	"sections when you distribute them as separate works. But when you distribute the same",
	"sections as part of a whole which is a work based on the Program, the distribution of",
	"the whole must be on the terms of this License, whose permissions for other licensees",
	"extend to the entire whole, and thus to each and every part regardless of who wrote it.",
	"",
	"Thus, it is not the intent of this section to claim rights or contest your rights to",
	"work written entirely by you; rather, the intent is to exercise the right to control",
	"the distribution of derivative or collective works based on the Program.",
	"",
	"In addition, mere aggregation of another work not based on the Program with the Program",
	"(or with a work based on the Program) on a volume of a storage or distribution medium",
	"does not bring the other work under the scope of this License.",
	"",
	"3. You may copy and distribute the Program (or a work based on it, under Section 2)",
	"in object code or executable form under the terms of Sections 1 and 2 above provided",
	"that you also do one of the following:",
	"",
	"*	a) Accompany it with the complete corresponding machine-readable source code,",
	"which must be distributed under the terms of Sections 1 and 2 above on a medium",
	"customarily used for software interchange; or,",
	"",
	"*	b) Accompany it with a written offer, valid for at least three years, to give",
	"any third party, for a charge no more than your cost of physically performing source",
	"distribution, a complete machine-readable copy of the corresponding source code,",
	"to be distributed under the terms of Sections 1 and 2 above on a medium customarily",
	"used for software interchange; or,",
	"",
	"*	c) Accompany it with the information you received as to the offer to distribute",
	"corresponding source code. (This alternative is allowed only for noncommercial",
	"distribution and only if you received the program in object code or executable",
	"form with such an offer, in accord with Subsection b above.)",
	"",
	"The source code for a work means the preferred form of the work for making",
	"modifications to it. For an executable work, complete source code means all",
	"the source code for all modules it contains, plus any associated interface",
	"definition files, plus the scripts used to control compilation and installation",
	"of the executable. However, as a special exception, the source code distributed",
	"need not include anything that is normally distributed (in either source or binary",
	"form) with the major components (compiler, kernel, and so on) of the operating",
	"system on which the executable runs, unless that component itself accompanies the executable.",
	"",
	"If distribution of executable or object code is made by offering access to copy",
	"from a designated place, then offering equivalent access to copy the source code",
	"from the same place counts as distribution of the source code, even though third",
	"parties are not compelled to copy the source along with the object code.",
	"",
	"4. You may not copy, modify, sublicense, or distribute the Program except as",
	"expressly provided under this License. Any attempt otherwise to copy, modify,",
	"sublicense or distribute the Program is void, and will automatically terminate your",
	"rights under this License. However, parties who have received copies, or rights,",
	"from you under this License will not have their licenses terminated so long as",
	"such parties remain in full compliance.",
	"",
	"5. You are not required to accept this License, since you have not signed it.",
	"However, nothing else grants you permission to modify or distribute the Program or",
	"its derivative works. These actions are prohibited by law if you do not accept this",
	"License. Therefore, by modifying or distributing the Program (or any work based on",
	"the Program), you indicate your acceptance of this License to do so, and all its",
	"terms and conditions for copying, distributing or modifying the Program or works based on it.",
	"",
	"6. Each time you redistribute the Program (or any work based on the Program),",
	"the recipient automatically receives a license from the original licensor to copy,",
	"distribute or modify the Program subject to these terms and conditions. You may not",
	"impose any further restrictions on the recipients' exercise of the rights granted",
	"herein. You are not responsible for enforcing compliance by third parties to this License.",
	"",
	"7. If, as a consequence of a court judgment or allegation of patent infringement",
	"or for any other reason (not limited to patent issues), conditions are imposed",
	"on you (whether by court order, agreement or otherwise) that contradict the conditions",
	"of this License, they do not excuse you from the conditions of this License. If you",
	"cannot distribute so as to satisfy simultaneously your obligations under this",
	"License and any other pertinent obligations, then as a consequence you may not",
	"distribute the Program at all. For example, if a patent license would not permit",
	"royalty-free redistribution of the Program by all those who receive copies directly",
	"or indirectly through you, then the only way you could satisfy both it and this",
	"License would be to refrain entirely from distribution of the Program.",
	"",
	"If any portion of this section is held invalid or unenforceable under any",
	"particular circumstance, the balance of the section is intended to apply and",
	"the section as a whole is intended to apply in other circumstances.",
	"",
	"It is not the purpose of this section to induce you to infringe any patents",
	"or other property right claims or to contest validity of any such claims; this",
	"section has the sole purpose of protecting the integrity of the free software",
	"distribution system, which is implemented by public license practices. Many",
	"people have made generous contributions to the wide range of software distributed",
	"through that system in reliance on consistent application of that system; it is",
	"up to the author/donor to decide if he or she is willing to distribute software",
	"through any other system and a licensee cannot impose that choice.",
	"",
	"This section is intended to make thoroughly clear what is believed to be a",
	"consequence of the rest of this License.",
	"",
	"8. If the distribution and/or use of the Program is restricted in certain",
	"countries either by patents or by copyrighted interfaces, the original copyright",
	"holder who places the Program under this License may add an explicit geographical",
	"distribution limitation excluding those countries, so that distribution is permitted",
	"only in or among countries not thus excluded. In such case, this License incorporates",
	"the limitation as if written in the body of this License.",
	"",
	"9. The Free Software Foundation may publish revised and/or new versions of the",
	"General Public License from time to time. Such new versions will be similar in",
	"spirit to the present version, but may differ in detail to address new problems",
	"or concerns.",
	"",
	"Each version is given a distinguishing version number. If the Program specifies",
	"a version number of this License which applies to it and 'any later version',",
	"you have the option of following the terms and conditions either of that version",
	"or of any later version published by the Free Software Foundation. If the Program",
	"does not specify a version number of this License, you may choose any version ever",
	"published by the Free Software Foundation.",
	"",
	"10. If you wish to incorporate parts of the Program into other free programs",
	"whose distribution conditions are different, write to the author to ask for",
	"permission. For software which is copyrighted by the Free Software Foundation,",
	"write to the Free Software Foundation; we sometimes make exceptions for this.",
	"Our decision will be guided by the two goals of preserving the free status of",
	"all derivatives of our free software and of promoting the sharing and reuse of",
	"software generally.",
	0
};

char *us_gnuwarranty[] =
{
	"NO WARRANTY",
	"",
	"11. Because the program is licensed free of charge, there is no warranty for the",
	"program, to the extent permitted by applicable law. Except when otherwise stated",
	"in writing the copyright holders and/or other parties provide the program 'as is'",
	"without warranty of any kind, either expressed or implied, including, but not",
	"limited to, the implied warranties of merchantability and fitness for a particular",
	"purpose. The entire risk as to the quality and performance of the program is with you.",
	"Should the program prove defective, you assume the cost of all necessary servicing,",
	"repair or correction. ",
	"",
	"12. In no event unless required by applicable law or agreed to in writing will any",
	"copyright holder, or any other party who may modify and/or redistribute the program",
	"as permitted above, be liable to you for damages, including any general, special,",
	"incidental or consequential damages arising out of the use or inability to use the",
	"program (including but not limited to loss of data or data being rendered inaccurate",
	"or losses sustained by you or third parties or a failure of the program to operate",
	"with any other programs), even if such holder or other party has been advised of",
	"the possibility of such damages. ",
	0
};

/* icons for the "About Electric" dialog */
unsigned char us_icon130[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 03, 0377, 0377, 0, 07, 0377, 0377, 0, 014, 0, 0, 0, 030, 0, 0,
	0, 060, 0, 0, 0, 0140, 0, 0, 0, 0300, 0, 0, 01, 0200, 0, 0,
	03, 0, 0, 0, 03, 0, 0, 0, 06, 0, 0, 0, 06, 0, 0, 0,
	014, 03, 0374, 0, 014, 03, 0374, 0, 030, 03, 0374, 0, 030, 03, 0374, 0,
	060, 03, 0374, 0, 060, 03, 0374, 0, 0140, 03, 0374, 0, 0140, 03, 0374, 0,
	0300, 03, 0374, 0, 0300, 03, 0374, 0, 0300, 03, 0374, 0, 0300, 03, 0374, 0,
	0300, 03, 0374, 0, 0300, 03, 0374, 0, 0300, 03, 0374, 0, 0300, 03, 0374, 0
};
unsigned char us_icon129[] =
{
	0300, 03, 0374, 0, 0300, 03, 0374, 0, 0300, 03, 0374, 0, 0300, 03, 0374, 0,
	0300, 03, 0374, 0, 0300, 03, 0374, 0, 0300, 0, 0, 0, 0300, 0, 0, 0,
	0140, 0, 0, 03, 0140, 0, 0, 07, 060, 0, 0, 017, 060, 0, 0, 037,
	030, 0, 0, 077, 030, 0, 0, 077, 014, 0, 0, 077, 014, 0, 0, 077,
	06, 0, 0, 077, 06, 0, 0, 077, 03, 0, 0, 077, 03, 0, 0, 077,
	01, 0200, 0, 0, 0, 0300, 0, 0, 0, 0140, 0, 0, 0, 060, 0, 0,
	0, 030, 0, 0, 0, 014, 0, 0, 0, 07, 0377, 0377, 0, 03, 0377, 0377,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon131[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0377, 0377, 0300, 0, 0377, 0377, 0340, 0, 0, 0, 060, 0, 0, 0, 030, 0,
	0, 0, 014, 0, 0, 0, 06, 0, 0, 0, 03, 0, 0, 0, 01, 0200,
	0, 0, 0, 0300, 0, 0, 0, 0300, 0, 0, 0, 0140, 0, 0, 0, 0140,
	0, 077, 0300, 060, 0, 077, 0300, 060, 0, 077, 0300, 030, 0, 077, 0300, 030,
	0, 077, 0300, 014, 0, 077, 0300, 014, 0, 077, 0300, 06, 0, 077, 0300, 06,
	0, 077, 0300, 03, 0, 077, 0300, 03, 0, 077, 0300, 03, 0, 077, 0300, 03,
	0, 077, 0300, 03, 0, 077, 0300, 03, 0, 077, 0300, 03, 0, 077, 0300, 03
};
unsigned char us_icon132[] =
{
	0, 077, 0300, 03, 0, 077, 0300, 03, 0, 077, 0300, 03, 0, 077, 0300, 03,
	0, 0, 0, 03, 0, 0, 0, 03, 0, 0, 0, 03, 0, 0, 0, 03,
	0300, 0, 0, 06, 0340, 0, 0, 06, 0360, 0, 0, 014, 0370, 0, 0, 014,
	0374, 0, 0, 030, 0374, 0, 0, 030, 0374, 0, 0, 060, 0374, 0, 0, 060,
	0374, 0, 0, 0140, 0374, 0, 0, 0140, 0374, 0, 0, 0300, 0374, 0, 0, 0300,
	0, 0, 01, 0200, 0, 0, 03, 0, 0, 0, 06, 0, 0, 0, 014, 0,
	0, 0, 030, 0, 0, 0, 060, 0, 0377, 0377, 0340, 0, 0377, 0377, 0300, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};

/* About Electric */
DIALOGITEM us_aboutdialogitems[] =
{
 /*  1 */ {0, {216,24,240,104}, BUTTON, "Continue"},
 /*  2 */ {0, {88,8,104,448}, MESSAGE, "Protected by license, redistribution prohibited"},
 /*  3 */ {0, {64,8,80,373}, MESSAGE, "Copyright (c) 1989-1998 Electric Editor Incorporated"},
 /*  4 */ {0, {120,8,136,209}, MESSAGE, "Written by Steven M. Rubin"},
 /*  5 */ {0, {8,8,24,295}, MESSAGE, "The Electric(tm) Design System"},
 /*  6 */ {0, {32,8,48,246}, MESSAGE, "Version XXXX"},
 /*  7 */ {0, {16,376,48,408}, ICON|INACTIVE, (char *)us_icon130},
 /*  8 */ {0, {48,376,80,408}, ICON|INACTIVE, (char *)us_icon129},
 /*  9 */ {0, {16,408,48,440}, ICON|INACTIVE, (char *)us_icon131},
 /* 10 */ {0, {48,408,80,440}, ICON|INACTIVE, (char *)us_icon132},
 /* 11 */ {0, {144,136,264,445}, SCROLL, ""},
 /* 12 */ {0, {120,216,138,404}, BUTTON, "And a Cast of Thousands"}
};
DIALOG us_aboutdialog = {{50,75,323,528}, 0, 12, us_aboutdialogitems};

/* GNU About Electric */
DIALOGITEM us_aboutgnudialogitems[] =
{
 /*  1 */ {0, {28,320,52,400}, BUTTON, "Continue"},
 /*  2 */ {0, {300,12,316,356}, MESSAGE, "Electric comes with ABSOLUTELY NO WARRANTY"},
 /*  3 */ {0, {64,8,80,373}, MESSAGE, "Copyright (c) 1998 Electric Editor Incorporated"},
 /*  4 */ {0, {96,8,112,221}, MESSAGE, "Written by Steven M. Rubin"},
 /*  5 */ {0, {8,8,24,295}, MESSAGE, "The Electric(tm) Design System"},
 /*  6 */ {0, {32,8,48,246}, MESSAGE, "Version XXXX"},
 /*  7 */ {0, {16,420,48,452}, ICON|INACTIVE, (char *)us_icon130},
 /*  8 */ {0, {48,420,80,452}, ICON|INACTIVE, (char *)us_icon129},
 /*  9 */ {0, {16,452,48,484}, ICON|INACTIVE, (char *)us_icon131},
 /* 10 */ {0, {48,452,80,484}, ICON|INACTIVE, (char *)us_icon132},
 /* 11 */ {0, {120,8,293,487}, SCROLL, ""},
 /* 12 */ {0, {96,232,114,420}, BUTTON, "And a Cast of Thousands"},
 /* 13 */ {0, {324,12,340,330}, MESSAGE, "This is free software, and you are welcome to"},
 /* 14 */ {0, {300,358,318,487}, BUTTON, "Warranty details"},
 /* 15 */ {0, {336,358,354,487}, BUTTON, "Copying details"},
 /* 16 */ {0, {344,12,360,309}, MESSAGE, "redistribute it under certain conditions"}
};
DIALOG us_aboutgnudialog = {{50,75,419,573}, 0, 16, us_aboutgnudialogitems};

/* Array */
DIALOGITEM us_arraydialogitems[] =
{
 /*  1 */ {0, {160,360,184,424}, BUTTON, "OK"},
 /*  2 */ {0, {160,32,184,96}, BUTTON, "Cancel"},
 /*  3 */ {0, {12,160,28,205}, EDITTEXT, "1"},
 /*  4 */ {0, {52,160,68,205}, EDITTEXT, "1"},
 /*  5 */ {0, {96,160,112,235}, EDITTEXT, "0"},
 /*  6 */ {0, {124,160,140,235}, EDITTEXT, "0"},
 /*  7 */ {0, {164,140,180,318}, CHECK, "Generate array indices"},
 /*  8 */ {0, {4,216,20,393}, CHECK, "Flip alternate columns"},
 /*  9 */ {0, {44,216,60,376}, CHECK, "Flip alternate rows"},
 /* 10 */ {0, {12,36,28,151}, MESSAGE, "X repeat factor:"},
 /* 11 */ {0, {52,36,68,151}, MESSAGE, "Y repeat factor:"},
 /* 12 */ {0, {96,4,112,154}, MESSAGE, "X edge overlap:"},
 /* 13 */ {0, {124,4,140,154}, MESSAGE, "Y centerline distance:"},
 /* 14 */ {0, {100,244,116,425}, RADIO, "Space by edge overlap"},
 /* 15 */ {0, {120,244,136,455}, RADIO, "Space by centerline distance"},
 /* 16 */ {0, {20,216,36,425}, CHECK, "Stagger alternate columns"},
 /* 17 */ {0, {60,216,76,400}, CHECK, "Stagger alternate rows"}
};
DIALOG us_arraydialog = {{50,75,245,533}, "Array Current Node", 17, us_arraydialogitems};

/* New node options */
DIALOGITEM us_defnodedialogitems[] =
{
 /*  1 */ {0, {248,456,272,520}, BUTTON, "OK"},
 /*  2 */ {0, {208,456,232,520}, BUTTON, "Cancel"},
 /*  3 */ {0, {80,200,96,310}, EDITTEXT, ""},
 /*  4 */ {0, {140,16,156,240}, RADIO, "Expand new facet instances"},
 /*  5 */ {0, {140,260,156,499}, RADIO, "Unexpand new facet instances"},
 /*  6 */ {0, {80,15,96,197}, MESSAGE, "X size of new primitives:"},
 /*  7 */ {0, {100,15,116,197}, MESSAGE, "Y size of new primitives:"},
 /*  8 */ {0, {100,200,116,310}, EDITTEXT, ""},
 /*  9 */ {0, {8,12,24,222}, RADIO, "Defaults for primitive node:"},
 /* 10 */ {0, {8,224,24,434}, POPUP, ""},
 /* 11 */ {0, {184,328,200,508}, CHECK, "Tiny facets hashed out"},
 /* 12 */ {0, {36,12,52,222}, RADIO, "Defaults for facet instance:"},
 /* 13 */ {0, {36,224,52,434}, POPUP, ""},
 /* 14 */ {0, {184,16,200,316}, CHECK, "Disallow modification of existing facets"},
 /* 15 */ {0, {232,16,248,278}, CHECK, "Check facet dates during creation"},
 /* 16 */ {0, {256,16,272,222}, MESSAGE, "Orientation of all new nodes:"},
 /* 17 */ {0, {256,232,272,297}, EDITTEXT, ""},
 /* 18 */ {0, {256,320,272,425}, CHECK, "Transposed"},
 /* 19 */ {0, {64,16,65,520}, DIVIDELINE, ""},
 /* 20 */ {0, {128,16,129,520}, DIVIDELINE, ""},
 /* 21 */ {0, {168,16,169,520}, DIVIDELINE, ""},
 /* 22 */ {0, {208,16,224,330}, CHECK, "Disallow modification of locked primitives"}
};
DIALOG us_defnodedialog = {{50,75,334,612}, "New Node Options", 22, us_defnodedialogitems};

/* ALS Clock */
DIALOGITEM us_alsclockdialogitems[] =
{
 /*  1 */ {0, {8,312,32,376}, BUTTON, "OK"},
 /*  2 */ {0, {40,312,64,376}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,8,26,101}, RADIO, "Frequency:"},
 /*  4 */ {0, {24,8,42,101}, RADIO, "Period:"},
 /*  5 */ {0, {64,8,82,101}, RADIO, "Custom:"},
 /*  6 */ {0, {16,208,32,283}, EDITTEXT, ""},
 /*  7 */ {0, {16,112,32,199}, MESSAGE, "Freq/Period:"},
 /*  8 */ {0, {96,256,112,370}, RADIO, "Gate Strength"},
 /*  9 */ {0, {200,232,216,369}, RADIO, "Undefined Phase"},
 /* 10 */ {0, {88,8,104,151}, MESSAGE, "Random Distribution:"},
 /* 11 */ {0, {88,160,104,223}, EDITTEXT, ""},
 /* 12 */ {0, {112,256,128,367}, RADIO, "VDD Strength"},
 /* 13 */ {0, {80,256,96,377}, RADIO, "Node Strength"},
 /* 14 */ {0, {184,232,200,328}, RADIO, "High Phase"},
 /* 15 */ {0, {256,272,280,363}, BUTTON, "Delete Phase"},
 /* 16 */ {0, {136,8,251,221}, SCROLL|INACTIVE, ""},
 /* 17 */ {0, {144,224,160,288}, MESSAGE, "Duration:"},
 /* 18 */ {0, {224,272,248,363}, BUTTON, "Add Phase"},
 /* 19 */ {0, {264,8,280,197}, MESSAGE, "Phase Cycles (0 for infinite):"},
 /* 20 */ {0, {264,200,280,247}, EDITTEXT, ""},
 /* 21 */ {0, {144,296,160,369}, EDITTEXT, ""},
 /* 22 */ {0, {120,8,136,99}, MESSAGE, "Phase List:"},
 /* 23 */ {0, {168,232,184,327}, RADIO, "Low Phase"}
};
DIALOG us_alsclockdialog = {{50,75,341,456}, "Clock Specification", 23, us_alsclockdialogitems};

/* Copy from library */
DIALOGITEM us_copyfacetdialogitems[] =
{
 /*  1 */ {0, {136,332,160,404}, BUTTON, "OK"},
 /*  2 */ {0, {72,332,96,404}, BUTTON, "Cancel"},
 /*  3 */ {0, {32,16,192,314}, SCROLL, ""},
 /*  4 */ {0, {8,8,24,177}, MESSAGE, "Copy facet from library:"},
 /*  5 */ {0, {8,176,24,407}, POPUP, ""}
};
DIALOG us_copyfacetdialog = {{50,75,249,491}, "Cross-Library Copy", 5, us_copyfacetdialogitems};

/* New arc options */
DIALOGITEM us_defarcdialogitems[] =
{
 /*  1 */ {0, {192,312,216,384}, BUTTON, "OK"},
 /*  2 */ {0, {192,72,216,144}, BUTTON, "Cancel"},
 /*  3 */ {0, {15,150,31,430}, POPUP, ""},
 /*  4 */ {0, {15,15,31,145}, RADIO, "Defaults for arc:"},
 /*  5 */ {0, {40,15,56,175}, RADIO, "Defaults for all arcs"},
 /*  6 */ {0, {160,368,176,423}, BUTTON, "Set pin"},
 /*  7 */ {0, {80,16,96,73}, CHECK, "Rigid"},
 /*  8 */ {0, {80,112,96,214}, CHECK, "Fixed-angle"},
 /*  9 */ {0, {80,224,96,299}, CHECK, "Slidable"},
 /* 10 */ {0, {104,16,120,95}, CHECK, "Negated"},
 /* 11 */ {0, {104,112,120,205}, CHECK, "Directional"},
 /* 12 */ {0, {104,224,120,344}, CHECK, "Ends extended"},
 /* 13 */ {0, {40,260,60,428}, BUTTON, "Reset to initial defaults"},
 /* 14 */ {0, {136,72,152,160}, EDITTEXT, ""},
 /* 15 */ {0, {136,16,152,64}, MESSAGE, "Width:"},
 /* 16 */ {0, {136,184,152,232}, MESSAGE, "Angle:"},
 /* 17 */ {0, {136,240,152,304}, EDITTEXT, ""},
 /* 18 */ {0, {160,16,176,47}, MESSAGE, "Pin:"},
 /* 19 */ {0, {160,48,176,358}, MESSAGE, ""}
};
DIALOG us_defarcdialog = {{50,75,278,509}, "New Arc Options", 19, us_defarcdialogitems};

/* DRC error */
DIALOGITEM us_drcerrdialogitems[] =
{
 /*  1 */ {0, {88,40,112,104}, BUTTON, "OK"},
 /*  2 */ {0, {120,208,144,336}, BUTTON, "Stop Checking"},
 /*  3 */ {0, {120,8,144,136}, BUTTON, "Ignore this error"},
 /*  4 */ {0, {88,208,112,336}, BUTTON, "Continue Silently"},
 /*  5 */ {0, {8,8,80,336}, MESSAGE, ""}
};
DIALOG us_drcerrdialog = {{50,75,202,419}, "DRC Violation", 5, us_drcerrdialogitems};

/* Layer Patterns */
unsigned char us_icon300[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0210, 0210, 0210, 0210, 0104, 0104, 021, 021, 042, 042, 042, 042, 021, 021, 0104, 0104,
	0210, 0210, 0210, 0210, 0104, 0104, 021, 021, 042, 042, 042, 042, 021, 021, 0104, 0104,
	0210, 0210, 0210, 0210, 0104, 0104, 021, 021, 042, 042, 042, 042, 021, 021, 0104, 0104,
	0210, 0210, 0210, 0210, 0104, 0104, 021, 021, 042, 042, 042, 042, 021, 021, 0104, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon301[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0314, 0314, 0377, 0377, 0314, 0314, 0, 0, 063, 063, 0377, 0377, 063, 063, 0, 0,
	0314, 0314, 0377, 0377, 0314, 0314, 0, 0, 063, 063, 0377, 0377, 063, 063, 0, 0,
	0314, 0314, 0377, 0377, 0314, 0314, 0, 0, 063, 063, 0377, 0377, 063, 063, 0, 0,
	0314, 0314, 0377, 0377, 0314, 0314, 0, 0, 063, 063, 0377, 0377, 063, 063, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon302[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0125, 0125, 0140, 0140, 0125, 0125, 0220, 0220, 0125, 0125, 0220, 0220, 0125, 0125, 0140, 0140,
	0125, 0125, 06, 06, 0125, 0125, 011, 011, 0125, 0125, 011, 011, 0125, 0125, 06, 06,
	0125, 0125, 0140, 0140, 0125, 0125, 0220, 0220, 0125, 0125, 0220, 0220, 0125, 0125, 0140, 0140,
	0125, 0125, 06, 06, 0125, 0125, 011, 011, 0125, 0125, 011, 011, 0, 0, 06, 06,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon303[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	042, 042, 0104, 0104, 0, 0, 021, 021, 0210, 0210, 0104, 0104, 0, 0, 021, 021,
	042, 042, 0104, 0104, 0, 0, 021, 021, 0210, 0210, 0104, 0104, 0, 0, 021, 021,
	042, 042, 0104, 0104, 0, 0, 021, 021, 0210, 0210, 0104, 0104, 0, 0, 021, 021,
	042, 042, 0104, 0104, 0, 0, 021, 021, 0210, 0210, 0104, 0104, 0, 0, 021, 021,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon304[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	020, 020, 04, 04, 040, 040, 02, 02, 0100, 0100, 01, 01, 0200, 0200, 0200, 0200,
	01, 01, 0100, 0100, 02, 02, 040, 040, 04, 04, 020, 020, 010, 010, 010, 010,
	020, 020, 04, 04, 040, 040, 02, 02, 0100, 0100, 01, 01, 0200, 0200, 0200, 0200,
	01, 01, 0100, 0100, 02, 02, 040, 040, 04, 04, 020, 020, 010, 010, 010, 010,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon305[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0100, 0100, 020, 0, 0200, 0200, 0, 040, 01, 01, 0100, 0, 02, 02, 0, 0200,
	01, 01, 0, 01, 0200, 0200, 02, 0, 0100, 0100, 0, 04, 040, 040, 010, 0,
	0100, 0100, 0, 020, 0200, 0200, 040, 0, 01, 01, 0, 0100, 02, 02, 0200, 0,
	01, 01, 01, 0, 0200, 0200, 0, 02, 0100, 0100, 04, 0, 040, 040, 0, 010,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon306[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	010, 0, 0, 0, 0, 04, 03, 03, 02, 0, 0204, 0204, 0, 01, 03, 03,
	0, 0200, 0, 0, 0100, 0, 060, 060, 0, 040, 0110, 0110, 020, 0, 060, 060,
	0, 010, 0, 0, 04, 0, 03, 03, 0, 02, 0204, 0204, 01, 0, 03, 03,
	0200, 0, 0, 0, 0, 0100, 060, 060, 040, 0, 0110, 0110, 0, 020, 060, 060,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon307[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	034, 034, 0, 0, 076, 076, 0314, 0314, 066, 066, 0, 0, 076, 076, 0314, 0314,
	034, 034, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	034, 034, 0, 0, 076, 076, 0314, 0314, 066, 066, 0, 0, 076, 076, 0314, 0314,
	034, 034, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon308[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 042, 042, 021, 021, 0210, 0210, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 042, 042, 021, 021, 0210, 0210, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 042, 042, 021, 021, 0210, 0210, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 042, 042, 021, 021, 0210, 0210, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon309[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 042, 042, 042, 042, 0104, 0104, 0125, 0125, 0210, 0210, 042, 042,
	0, 0, 0, 0, 042, 042, 042, 042, 0104, 0104, 0125, 0125, 0210, 0210, 042, 042,
	0, 0, 0, 0, 042, 042, 042, 042, 0104, 0104, 0125, 0125, 0210, 0210, 042, 042,
	0, 0, 0, 0, 042, 042, 042, 042, 0104, 0104, 0125, 0125, 0210, 0210, 042, 042,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
unsigned char us_icon310[] =
{
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0377, 0377, 0, 0, 0377, 0377, 0, 0, 0377, 0377, 0, 0, 0377, 0377,
	0, 0, 0377, 0377, 0, 0, 0377, 0377, 0, 0, 0377, 0377, 0, 0, 0377, 0377,
	0, 0, 0377, 0377, 0, 0, 0377, 0377, 0, 0, 0377, 0377, 0, 0, 0377, 0377,
	0, 0, 0377, 0377, 0, 0, 0377, 0377, 0, 0, 0377, 0377, 0, 0, 0377, 0377,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
};
UINTSML us_predefpats[] =
{
	0x8888,  /* X   X   X   X    */
	0x4444,  /*  X   X   X   X   */
	0x2222,  /*   X   X   X   X  */
	0x1111,  /*    X   X   X   X */
	0x8888,  /* X   X   X   X    */
	0x4444,  /*  X   X   X   X   */
	0x2222,  /*   X   X   X   X  */
	0x1111,  /*    X   X   X   X */

	0x8888,  /* X   X   X   X    */
	0x1111,  /*    X   X   X   X */
	0x2222,  /*   X   X   X   X  */
	0x4444,  /*  X   X   X   X   */
	0x8888,  /* X   X   X   X    */
	0x1111,  /*    X   X   X   X */
	0x2222,  /*   X   X   X   X  */
	0x4444,  /*  X   X   X   X   */

	0xCCCC,  /* XX  XX  XX  XX   */
	0xCCCC,  /* XX  XX  XX  XX   */
	0x3333,  /*   XX  XX  XX  XX */
	0x3333,  /*   XX  XX  XX  XX */
	0xCCCC,  /* XX  XX  XX  XX   */
	0xCCCC,  /* XX  XX  XX  XX   */
	0x3333,  /*   XX  XX  XX  XX */
	0x3333,  /*   XX  XX  XX  XX */

	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0x0000,  /*                  */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0x0000,  /*                  */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0x0000,  /*                  */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0x0000,  /*                  */

	0xAAAA,  /* X X X X X X X X  */
	0xAAAA,  /* X X X X X X X X  */
	0xAAAA,  /* X X X X X X X X  */
	0xAAAA,  /* X X X X X X X X  */
	0xAAAA,  /* X X X X X X X X  */
	0xAAAA,  /* X X X X X X X X  */
	0xAAAA,  /* X X X X X X X X  */
	0xAAAA,  /* X X X X X X X X  */

	0x6060,  /*  XX      XX      */
	0x9090,  /* X  X    X  X     */
	0x9090,  /* X  X    X  X     */
	0x6060,  /*  XX      XX      */
	0x0606,  /*      XX      XX  */
	0x0909,  /*     X  X    X  X */
	0x0909,  /*     X  X    X  X */
	0x0606,  /*      XX      XX  */

	0x2222,  /*   X   X   X   X  */
	0x0000,  /*                  */
	0x8888,  /* X   X   X   X    */
	0x0000,  /*                  */
	0x2222,  /*   X   X   X   X  */
	0x0000,  /*                  */
	0x8888,  /* X   X   X   X    */
	0x0000,  /*                  */

	0x4444,  /*  X   X   X   X   */
	0x1111,  /*    X   X   X   X */
	0x4444,  /*  X   X   X   X   */
	0x1111,  /*    X   X   X   X */
	0x4444,  /*  X   X   X   X   */
	0x1111,  /*    X   X   X   X */
	0x4444,  /*  X   X   X   X   */
	0x1111,  /*    X   X   X   X */

	0x1010,  /*    X       X     */
	0x2020,  /*   X       X      */
	0x4040,  /*  X       X       */
	0x8080,  /* X       X        */
	0x0101,  /*        X       X */
	0x0202,  /*       X       X  */
	0x0404,  /*      X       X   */
	0x0808,  /*     X       X    */

	0x0808,  /*     X       X    */
	0x0404,  /*      X       X   */
	0x0202,  /*       X       X  */
	0x0101,  /*        X       X */
	0x8080,  /* X       X        */
	0x4040,  /*  X       X       */
	0x2020,  /*   X       X      */
	0x1010,  /*    X       X     */

	0x4040,  /*  X       X       */
	0x8080,  /* X       X        */
	0x0101,  /*        X       X */
	0x0202,  /*       X       X  */
	0x0101,  /*        X       X */
	0x8080,  /* X       X        */
	0x4040,  /*  X       X       */
	0x2020,  /*   X       X      */

	0x1000,  /*    X             */
	0x0020,  /*           X      */
	0x4000,  /*  X               */
	0x0080,  /*         X        */
	0x0001,  /*                X */
	0x0200,  /*       X          */
	0x0004,  /*              X   */
	0x0800,  /*     X            */

	0x0800,  /*     X            */
	0x0004,  /*              X   */
	0x0200,  /*       X          */
	0x0001,  /*                X */
	0x0080,  /*         X        */
	0x4000,  /*  X               */
	0x0020,  /*           X      */
	0x1000,  /*    X             */

	0x0000,  /*                  */
	0x0303,  /*       XX      XX */
	0x4848,  /*  X  X    X  X    */
	0x0303,  /*       XX      XX */
	0x0000,  /*                  */
	0x3030,  /*   XX      XX     */
	0x8484,  /* X    X  X    X   */
	0x3030,  /*   XX      XX     */

	0x1C1C,  /*    XXX     XXX   */
	0x3E3E,  /*   XXXXX   XXXXX  */
	0x3636,  /*   XX XX   XX XX  */
	0x3E3E,  /*   XXXXX   XXXXX  */
	0x1C1C,  /*    XXX     XXX   */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */

	0x0000,  /*                  */
	0xCCCC,  /* XX  XX  XX  XX   */
	0x0000,  /*                  */
	0xCCCC,  /* XX  XX  XX  XX   */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */

	0x0000,  /*                  */
	0x0000,  /*                  */
	0x2222,  /*   X   X   X   X  */
	0x8888,  /* X   X   X   X    */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x2222,  /*   X   X   X   X  */
	0x8888,  /* X   X   X   X    */

	0x0000,  /*                  */
	0x0000,  /*                  */
	0x1111,  /*    X   X   X   X */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x1111,  /*    X   X   X   X */
	0x0000,  /*                  */

	0x0000,  /*                  */
	0x2222,  /*   X   X   X   X  */
	0x4444,  /*  X   X   X   X   */
	0x8888,  /* X   X   X   X    */
	0x0000,  /*                  */
	0x2222,  /*   X   X   X   X  */
	0x4444,  /*  X   X   X   X   */
	0x8888,  /* X   X   X   X    */

	0x0000,  /*                  */
	0x2222,  /*   X   X   X   X  */
	0x5555,  /*  X X X X X X X X */
	0x2222,  /*   X   X   X   X  */
	0x0000,  /*                  */
	0x2222,  /*   X   X   X   X  */
	0x5555,  /*  X X X X X X X X */
	0x2222,  /*   X   X   X   X  */

	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */
	0x0000,  /*                  */

	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0xFFFF,  /* XXXXXXXXXXXXXXXX */
	0xFFFF   /* XXXXXXXXXXXXXXXX */
};
DIALOGITEM us_patterndialogitems[] =
{
 /*  1 */ {0, {176,296,200,360}, BUTTON, "OK"},
 /*  2 */ {0, {136,296,160,360}, BUTTON, "Cancel"},
 /*  3 */ {0, {4,8,20,184}, MESSAGE, "Stipple Pattern for Layer:"},
 /*  4 */ {0, {4,184,20,368}, POPUP, ""},
 /*  5 */ {0, {84,16,212,272}, USERDRAWN, ""},
 /*  6 */ {0, {64,184,80,336}, CHECK, "Outline Pattern"},
 /*  7 */ {0, {64,8,80,160}, CHECK, "Use Stipple Pattern"},
 /*  8 */ {0, {28,8,60,40}, ICON, (char *)us_icon300},
 /*  9 */ {0, {28,40,60,72}, ICON, (char *)us_icon301},
 /* 10 */ {0, {28,72,60,104}, ICON, (char *)us_icon302},
 /* 11 */ {0, {28,104,60,136}, ICON, (char *)us_icon303},
 /* 12 */ {0, {28,136,60,168}, ICON, (char *)us_icon304},
 /* 13 */ {0, {28,168,60,200}, ICON, (char *)us_icon305},
 /* 14 */ {0, {28,200,60,232}, ICON, (char *)us_icon306},
 /* 15 */ {0, {28,232,60,264}, ICON, (char *)us_icon307},
 /* 16 */ {0, {28,264,60,296}, ICON, (char *)us_icon308},
 /* 17 */ {0, {28,296,60,328}, ICON, (char *)us_icon309},
 /* 18 */ {0, {28,328,60,360}, ICON, (char *)us_icon310}
};
DIALOG us_patterndialog = {{50,75,266,453}, "Edit Stipple Patterns", 18, us_patterndialogitems};

/* Artwork Color/Layer */
DIALOGITEM us_artworkdialogitems[] =
{
 /*  1 */ {0, {168,340,192,404}, BUTTON, "OK"},
 /*  2 */ {0, {168,244,192,308}, BUTTON, "Cancel"},
 /*  3 */ {0, {120,292,136,419}, RADIO, "Outlined Pattern"},
 /*  4 */ {0, {32,16,160,272}, USERDRAWN, ""},
 /*  5 */ {0, {56,292,72,388}, RADIO, "Solid color"},
 /*  6 */ {0, {168,24,184,77}, MESSAGE, "Color:"},
 /*  7 */ {0, {88,292,104,388}, RADIO, "Use Pattern"},
 /*  8 */ {0, {0,16,32,48}, ICON, (char *)us_icon300},
 /*  9 */ {0, {0,48,32,80}, ICON, (char *)us_icon301},
 /* 10 */ {0, {0,80,32,112}, ICON, (char *)us_icon302},
 /* 11 */ {0, {0,112,32,144}, ICON, (char *)us_icon303},
 /* 12 */ {0, {0,144,32,176}, ICON, (char *)us_icon304},
 /* 13 */ {0, {0,176,32,208}, ICON, (char *)us_icon305},
 /* 14 */ {0, {0,208,32,240}, ICON, (char *)us_icon306},
 /* 15 */ {0, {0,240,32,272}, ICON, (char *)us_icon307},
 /* 16 */ {0, {0,272,32,304}, ICON, (char *)us_icon308},
 /* 17 */ {0, {0,304,32,336}, ICON, (char *)us_icon309},
 /* 18 */ {0, {0,336,32,368}, ICON, (char *)us_icon310},
 /* 19 */ {0, {168,80,184,214}, POPUP, "Overlappable 1"}
};
DIALOG us_artworkdialog = {{50,75,253,498}, "Set Look of Highlighted", 19, us_artworkdialogitems};

/* Technologies */
DIALOGITEM us_techselectdialogitems[] =
{
 /*  1 */ {0, {96,216,120,280}, BUTTON, "OK"},
 /*  2 */ {0, {24,216,48,280}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,8,153,193}, SCROLL, ""},
 /*  4 */ {0, {160,8,192,292}, MESSAGE, ""}
};
DIALOG us_techselectdialog = {{50,75,250,373}, "Change Current Technology", 4, us_techselectdialogitems};

/* Dependent Libraries */
DIALOGITEM us_dependentlibdialogitems[] =
{
 /*  1 */ {0, {208,368,232,432}, BUTTON, "OK"},
 /*  2 */ {0, {208,256,232,320}, BUTTON, "Cancel"},
 /*  3 */ {0, {32,8,177,174}, SCROLL, ""},
 /*  4 */ {0, {8,8,24,153}, MESSAGE, "Dependent Libraries:"},
 /*  5 */ {0, {208,8,224,165}, MESSAGE, "Libraries are examined"},
 /*  6 */ {0, {40,192,64,256}, BUTTON, "Remove"},
 /*  7 */ {0, {88,192,112,256}, BUTTON, "<< Add"},
 /*  8 */ {0, {128,280,144,427}, MESSAGE, "Library (if not in list):"},
 /*  9 */ {0, {152,280,168,432}, EDITTEXT, ""},
 /* 10 */ {0, {8,272,24,361}, MESSAGE, "All Libraries:"},
 /* 11 */ {0, {224,8,240,123}, MESSAGE, "from bottom up"},
 /* 12 */ {0, {32,272,118,438}, SCROLL, ""},
 /* 13 */ {0, {184,8,200,67}, MESSAGE, "Current:"},
 /* 14 */ {0, {184,72,200,254}, MESSAGE, ""}
};
DIALOG us_dependentlibdialog = {{50,75,296,524}, "Dependent Library Selection", 14, us_dependentlibdialogitems};

/* Library paths */
DIALOGITEM us_librarypathdialogitems[] =
{
 /*  1 */ {0, {76,312,100,376}, BUTTON, "OK"},
 /*  2 */ {0, {76,32,100,96}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,16,24,220}, MESSAGE, "Location of library files:"},
 /*  4 */ {0, {32,8,64,400}, EDITTEXT, ""}
};
DIALOG us_librarypathdialog = {{50,75,159,485}, "Current Library Path", 4, us_librarypathdialogitems};

/* Help */
DIALOGITEM us_helpdialogitems[] =
{
 /*  1 */ {0, {288,376,312,440}, BUTTON, "OK"},
 /*  2 */ {0, {8,32,24,91}, MESSAGE, "Topics:"},
 /*  3 */ {0, {8,192,280,636}, SCROLL, ""},
 /*  4 */ {0, {24,8,309,177}, SCROLL, ""}
};
DIALOG us_helpdialog = {{50,75,378,719}, "Help", 4, us_helpdialogitems};

/* Technology Variables */
DIALOGITEM us_techvarsdialogitems[] =
{
 /*  1 */ {0, {208,472,232,536}, BUTTON, "OK"},
 /*  2 */ {0, {208,376,232,440}, BUTTON, "Cancel"},
 /*  3 */ {0, {24,8,143,264}, SCROLL, ""},
 /*  4 */ {0, {176,16,192,55}, MESSAGE, "Type:"},
 /*  5 */ {0, {176,56,192,142}, MESSAGE, ""},
 /*  6 */ {0, {152,104,168,536}, MESSAGE, ""},
 /*  7 */ {0, {24,280,143,536}, SCROLL, ""},
 /*  8 */ {0, {8,16,24,240}, MESSAGE, "Current Variables on Technology:"},
 /*  9 */ {0, {8,288,24,419}, MESSAGE, "Possible Variables:"},
 /* 10 */ {0, {208,280,232,344}, BUTTON, "<< Copy"},
 /* 11 */ {0, {208,24,232,88}, BUTTON, "Remove"},
 /* 12 */ {0, {176,216,192,533}, EDITTEXT, ""},
 /* 13 */ {0, {208,136,232,237}, BUTTON, "Edit Strings"},
 /* 14 */ {0, {176,168,192,212}, MESSAGE, "Value:"},
 /* 15 */ {0, {152,16,168,98}, MESSAGE, "Description:"}
};
DIALOG us_techvarsdialog = {{50,75,293,622}, "Technology Variables", 15, us_techvarsdialogitems};

/* SPICE Options */
DIALOGITEM us_spiceoptdialogitems[] =
{
 /*  1 */ {0, {48,420,72,480}, BUTTON, "OK"},
 /*  2 */ {0, {8,420,32,480}, BUTTON, "Cancel"},
 /*  3 */ {0, {56,8,72,188}, POPUP, "Execute Deck"},
 /*  4 */ {0, {8,96,24,187}, POPUP, "Spice 2"},
 /*  5 */ {0, {300,216,316,375}, RADIO, "Use Model from File:"},
 /*  6 */ {0, {284,216,300,426}, RADIO, "Derive Model from Circuitry"},
 /*  7 */ {0, {32,96,48,140}, POPUP, "1"},
 /*  8 */ {0, {348,256,364,295}, BUTTON, "Set"},
 /*  9 */ {0, {316,224,348,480}, MESSAGE, ""},
 /* 10 */ {0, {32,240,48,372}, CHECK, "Use Node Names"},
 /* 11 */ {0, {8,240,24,359}, CHECK, "Use Parasitics"},
 /* 12 */ {0, {8,8,24,93}, MESSAGE, "File Format:"},
 /* 13 */ {0, {32,8,48,93}, MESSAGE, "SPICE Level:"},
 /* 14 */ {0, {120,16,136,200}, RADIO, "Use Built-in Model Cards"},
 /* 15 */ {0, {144,16,160,213}, RADIO, "Use Model Cards from File:"},
 /* 16 */ {0, {144,216,176,480}, MESSAGE, ""},
 /* 17 */ {0, {192,16,208,140}, RADIO, "No Trailer Cards"},
 /* 18 */ {0, {216,16,232,202}, RADIO, "Include Trailer from File:"},
 /* 19 */ {0, {216,208,248,480}, MESSAGE, ""},
 /* 20 */ {0, {96,8,112,209}, MESSAGE, ""},
 /* 21 */ {0, {160,32,176,163}, BUTTON, "Set Model Card File"},
 /* 22 */ {0, {232,32,248,163}, BUTTON, "Set Trailer Card File"},
 /* 23 */ {0, {284,8,380,206}, SCROLL, ""},
 /* 24 */ {0, {268,8,284,80}, MESSAGE, "For Facet:"},
 /* 25 */ {0, {120,216,136,403}, BUTTON, "Edit Built-in Model Cards"},
 /* 26 */ {0, {84,8,85,480}, DIVIDELINE, ""},
 /* 27 */ {0, {256,8,257,480}, DIVIDELINE, ""}
};
DIALOG us_spiceoptdialog = {{50,75,436,568}, "SPICE Options", 27, us_spiceoptdialogitems};

/* Verilog Options */
DIALOGITEM us_verilogoptdialogitems[] =
{
 /*  1 */ {0, {12,408,36,466}, BUTTON, "OK"},
 /*  2 */ {0, {12,324,36,382}, BUTTON, "Cancel"},
 /*  3 */ {0, {64,216,80,375}, RADIO, "Use Model from File:"},
 /*  4 */ {0, {48,216,64,426}, RADIO, "Derive Model from Circuitry"},
 /*  5 */ {0, {112,256,128,295}, BUTTON, "Set"},
 /*  6 */ {0, {80,224,112,480}, MESSAGE, ""},
 /*  7 */ {0, {8,8,24,180}, CHECK, "Use ASSIGN Construct"},
 /*  8 */ {0, {48,8,144,206}, SCROLL, ""},
 /*  9 */ {0, {32,8,48,80}, MESSAGE, "For Facet:"}
};
DIALOG us_verilogoptdialog = {{50,75,200,563}, "Verilog Options", 9, us_verilogoptdialogitems};

/* Printing Options */
DIALOGITEM us_printingoptdialogitems[] =
{
 /*  1 */ {0, {8,356,32,414}, BUTTON, "OK"},
 /*  2 */ {0, {40,356,64,414}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,148,24,344}, RADIO, "Plot only Highlighted Area"},
 /*  4 */ {0, {8,8,24,142}, RADIO, "Plot Entire Facet"},
 /*  5 */ {0, {72,104,88,220}, CHECK, "Encapsulated"},
 /*  6 */ {0, {36,8,52,163}, CHECK, "Plot Date In Corner"},
 /*  7 */ {0, {240,108,256,166}, RADIO, "HPGL"},
 /*  8 */ {0, {240,180,256,254}, RADIO, "HPGL/2"},
 /*  9 */ {0, {260,20,276,187}, RADIO, "HPGL/2 plot fills page"},
 /* 10 */ {0, {280,20,296,177}, RADIO, "HPGL/2 plot fixed at:"},
 /* 11 */ {0, {280,180,296,240}, EDITTEXT, ""},
 /* 12 */ {0, {280,244,296,406}, MESSAGE, "internal units per pixel"},
 /* 13 */ {0, {196,20,212,172}, CHECK, "Synchronize to file:"},
 /* 14 */ {0, {196,172,228,418}, MESSAGE, ""},
 /* 15 */ {0, {176,20,192,108}, MESSAGE, "EPS Scale:"},
 /* 16 */ {0, {176,124,192,164}, EDITTEXT, "2"},
 /* 17 */ {0, {156,8,172,80}, MESSAGE, "For facet:"},
 /* 18 */ {0, {156,80,172,388}, MESSAGE, ""},
 /* 19 */ {0, {236,8,237,418}, DIVIDELINE, ""},
 /* 20 */ {0, {72,8,88,96}, MESSAGE, "PostScript:"},
 /* 21 */ {0, {72,240,88,360}, CHECK, "Color"},
 /* 22 */ {0, {68,8,69,418}, DIVIDELINE, ""},
 /* 23 */ {0, {240,8,256,98}, MESSAGE, "HPGL Level:"},
 /* 24 */ {0, {96,20,112,78}, RADIO, "Printer"},
 /* 25 */ {0, {116,20,132,78}, RADIO, "Plotter"},
 /* 26 */ {0, {96,88,112,148}, MESSAGE, "Width:"},
 /* 27 */ {0, {96,152,112,192}, EDITTEXT, "2"},
 /* 28 */ {0, {116,88,132,148}, MESSAGE, "Width:"},
 /* 29 */ {0, {116,152,132,192}, EDITTEXT, "2"},
 /* 30 */ {0, {96,204,112,264}, MESSAGE, "Height:"},
 /* 31 */ {0, {96,268,112,308}, EDITTEXT, "2"},
 /* 32 */ {0, {136,20,152,240}, CHECK, "Rotate plot 90 degrees"},
 /* 33 */ {0, {136,244,152,304}, MESSAGE, "Margin:"},
 /* 34 */ {0, {136,308,152,348}, EDITTEXT, "2"}
};
DIALOG us_printingoptdialog = {{50,75,361,501}, "Printing Options", 34, us_printingoptdialogitems};

/* File Progress */
DIALOGITEM us_progressdialogitems[] =
{
 /*  1 */ {0, {32,8,49,230}, PROGRESS, ""},
 /*  2 */ {0, {8,8,24,230}, MESSAGE, "Reading file..."}
};
DIALOG us_progressdialog = {{50,75,112,312}, 0, 2, us_progressdialogitems};

/* Resistance */
DIALOGITEM us_resistancedialogitems[] =
{
 /*  1 */ {0, {40,192,64,256}, BUTTON, "OK"},
 /*  2 */ {0, {40,16,64,80}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,24,24,118}, EDITTEXT, ""},
 /*  4 */ {0, {8,128,24,239}, POPUP, "Ohms"},
 /*  5 */ {0, {40,104,64,168}, BUTTON, "More..."}
};
DIALOG us_resistancedialog = {{50,75,124,345}, "Resistance", 5, us_resistancedialogitems};

/* Capacitance */
DIALOGITEM us_capacitancedialogitems[] =
{
 /*  1 */ {0, {40,176,64,240}, BUTTON, "OK"},
 /*  2 */ {0, {40,16,64,80}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,16,24,110}, EDITTEXT, ""},
 /*  4 */ {0, {8,120,24,246}, POPUP, "Milli-farads"},
 /*  5 */ {0, {40,96,64,160}, BUTTON, "More..."}
};
DIALOG us_capacitancedialog = {{50,75,121,330}, "Capacitance", 5, us_capacitancedialogitems};

/* Inductance */
DIALOGITEM us_inductancedialogitems[] =
{
 /*  1 */ {0, {40,168,64,232}, BUTTON, "OK"},
 /*  2 */ {0, {40,8,64,72}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,16,24,110}, EDITTEXT, ""},
 /*  4 */ {0, {8,120,24,237}, POPUP, "Henrys"},
 /*  5 */ {0, {40,88,64,152}, BUTTON, "More..."}
};
DIALOG us_inductancedialog = {{50,75,126,317}, "Inductance", 5, us_inductancedialogitems};

/* VCCS Transconductance */
DIALOGITEM us_vccsdialogitems[] =
{
 /*  1 */ {0, {40,176,64,240}, BUTTON, "OK"},
 /*  2 */ {0, {40,16,64,80}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,16,24,110}, EDITTEXT, ""},
 /*  4 */ {0, {8,120,24,247}, POPUP, "Siemens"},
 /*  5 */ {0, {40,96,64,160}, BUTTON, "More..."}
};
DIALOG us_vccsdialog = {{50,75,125,329}, "VCCS Transconductance", 5, us_vccsdialogitems};

/* Area */
DIALOGITEM us_areadialogitems[] =
{
 /*  1 */ {0, {40,184,64,248}, BUTTON, "OK"},
 /*  2 */ {0, {40,8,64,72}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,80,24,174}, EDITTEXT, ""},
 /*  4 */ {0, {40,96,64,160}, BUTTON, "More..."}
};
DIALOG us_areadialog = {{50,75,124,333}, "Area", 4, us_areadialogitems};

/* Width/Length */
DIALOGITEM us_widlendialogitems[] =
{
 /*  1 */ {0, {88,184,112,248}, BUTTON, "OK"},
 /*  2 */ {0, {88,8,112,72}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,108,24,202}, EDITTEXT, ""},
 /*  4 */ {0, {8,8,24,59}, MESSAGE, "Width:"},
 /*  5 */ {0, {32,108,48,202}, EDITTEXT, ""},
 /*  6 */ {0, {32,8,48,60}, MESSAGE, "Length:"},
 /*  7 */ {0, {56,108,72,202}, EDITTEXT, ""},
 /*  8 */ {0, {56,8,72,96}, MESSAGE, "SPICE name:"},
 /*  9 */ {0, {88,96,112,160}, BUTTON, "More"}
};
DIALOG us_widlendialog = {{50,75,170,332}, "Transistor Information", 9, us_widlendialogitems};

/* Gain */
DIALOGITEM us_gaindialogitems[] =
{
 /*  1 */ {0, {40,176,64,240}, BUTTON, "OK"},
 /*  2 */ {0, {40,16,64,80}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,88,24,213}, EDITTEXT, ""},
 /*  4 */ {0, {8,40,24,83}, MESSAGE, "Gain:"},
 /*  5 */ {0, {40,96,64,160}, BUTTON, "More..."}
};
DIALOG us_gaindialog = {{50,75,122,334}, "Gain", 5, us_gaindialogitems};

/* Source Information */
DIALOGITEM us_sourcedialogitems[] =
{
 /*  1 */ {0, {72,268,96,336}, BUTTON, "OK"},
 /*  2 */ {0, {72,20,96,88}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,112,24,264}, POPUP, "Source Type"},
 /*  4 */ {0, {36,8,52,100}, MESSAGE, "SPICE Card:"},
 /*  5 */ {0, {8,8,24,100}, MESSAGE, "Source type:"},
 /*  6 */ {0, {36,112,52,348}, EDITTEXT, ""},
 /*  7 */ {0, {72,144,96,212}, BUTTON, "More..."}
};
DIALOG us_sourcedialog = {{75,75,186,440}, "Source Information", 7, us_sourcedialogitems};


/* Window Views */
DIALOGITEM us_windowviewdialogitems[] =
{
 /*  1 */ {0, {256,56,280,166}, BUTTON, "Restore View"},
 /*  2 */ {0, {216,8,240,72}, BUTTON, "Done"},
 /*  3 */ {0, {32,8,208,234}, SCROLL, ""},
 /*  4 */ {0, {8,96,24,229}, EDITTEXT, ""},
 /*  5 */ {0, {216,120,240,230}, BUTTON, "Save This View"},
 /*  6 */ {0, {8,8,24,90}, MESSAGE, "View name:"}
};
DIALOG us_windowviewdialog = {{50,75,342,316}, "Window Views", 6, us_windowviewdialogitems};

/* Create To */
DIALOGITEM us_createtodialogitems[] =
{
 /*  1 */ {0, {64,96,88,160}, BUTTON, "OK"},
 /*  2 */ {0, {64,8,88,72}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,48,24,142}, EDITTEXT, ""},
 /*  4 */ {0, {8,20,24,42}, MESSAGE, "X:"},
 /*  5 */ {0, {32,48,48,142}, EDITTEXT, ""},
 /*  6 */ {0, {32,20,48,42}, MESSAGE, "Y:"}
};
DIALOG us_createtodialog = {{50,75,147,244}, "Create At Location", 6, us_createtodialogitems};

/* Port Display Options */
DIALOGITEM us_portdisplaydialogitems[] =
{
 /*  1 */ {0, {100,92,124,156}, BUTTON, "OK"},
 /*  2 */ {0, {100,8,124,72}, BUTTON, "Cancel"},
 /*  3 */ {0, {8,8,24,155}, RADIO, "Full Port Names"},
 /*  4 */ {0, {28,8,44,155}, RADIO, "Short Port Names"},
 /*  5 */ {0, {48,8,64,155}, RADIO, "Ports as Crosses"},
 /*  6 */ {0, {68,8,84,155}, RADIO, "No Ports Shown"}
};
DIALOG us_portdisplaydialog = {{133,131,270,304}, "Port Display Options", 6, us_portdisplaydialogitems};

/* Drawing Options */
DIALOGITEM us_drawingoptdialogitems[] =
{
 /*  1 */ {0, {64,244,88,308}, BUTTON, "OK"},
 /*  2 */ {0, {64,32,88,96}, BUTTON, "Cancel"},
 /*  3 */ {0, {12,8,28,125}, MESSAGE, "Company Name:"},
 /*  4 */ {0, {12,128,28,328}, EDITTEXT, ""},
 /*  5 */ {0, {36,8,52,125}, MESSAGE, "Designer  Name:"},
 /*  6 */ {0, {36,128,52,328}, EDITTEXT, ""}
};
DIALOG us_drawingoptdialog = {{50,75,149,417}, "Drawing Options", 6, us_drawingoptdialogitems};

#if SCAID
/* Silicon Compiler Options */
DIALOGITEM us_silcompdialogitems[] =
{
 /*  1 */ {0, {428,272,452,330}, BUTTON, "OK"},
 /*  2 */ {0, {428,40,452,98}, BUTTON, "Cancel"},
 /*  3 */ {0, {60,208,76,388}, POPUP, "Vertical arc"},
 /*  4 */ {0, {8,208,24,388}, POPUP, "Horizontal arc"},
 /*  5 */ {0, {8,8,24,180}, MESSAGE, "Horizontal routing arc:"},
 /*  6 */ {0, {60,8,76,180}, MESSAGE, "Vertical routing arc:"},
 /*  7 */ {0, {32,8,48,174}, MESSAGE, "Horizontal wire width:"},
 /*  8 */ {0, {32,208,48,282}, EDITTEXT, "2.5"},
 /*  9 */ {0, {84,8,100,174}, MESSAGE, "Vertical wire width:"},
 /* 10 */ {0, {84,208,100,282}, EDITTEXT, "2.5"},
 /* 11 */ {0, {120,8,136,174}, MESSAGE, "Power wire width:"},
 /* 12 */ {0, {120,208,136,282}, EDITTEXT, "2.5"},
 /* 13 */ {0, {144,8,160,174}, MESSAGE, "Main power wire width:"},
 /* 14 */ {0, {144,208,160,282}, EDITTEXT, "2.5"},
 /* 15 */ {0, {184,12,200,203}, MESSAGE, "P-Well height (0 for none):"},
 /* 16 */ {0, {184,208,200,282}, EDITTEXT, "2.5"},
 /* 17 */ {0, {208,12,224,203}, MESSAGE, "P-Well offset from bottom:"},
 /* 18 */ {0, {208,208,224,282}, EDITTEXT, "2.5"},
 /* 19 */ {0, {248,12,264,203}, MESSAGE, "Via size:"},
 /* 20 */ {0, {248,208,264,282}, EDITTEXT, "2.5"},
 /* 21 */ {0, {272,12,288,203}, MESSAGE, "Minimum metal spacing:"},
 /* 22 */ {0, {272,208,288,282}, EDITTEXT, "2.5"},
 /* 23 */ {0, {312,12,328,203}, MESSAGE, "Routing: feed-through size:"},
 /* 24 */ {0, {312,208,328,282}, EDITTEXT, "2.5"},
 /* 25 */ {0, {336,12,352,203}, MESSAGE, "Routing: min. port distance:"},
 /* 26 */ {0, {336,208,352,282}, EDITTEXT, "2.5"},
 /* 27 */ {0, {360,12,376,203}, MESSAGE, "Routing: min. active dist.:"},
 /* 28 */ {0, {360,208,376,282}, EDITTEXT, "2.5"},
 /* 29 */ {0, {400,12,416,203}, MESSAGE, "Number of rows of cells:"},
 /* 30 */ {0, {400,208,416,282}, EDITTEXT, "5"}
};
DIALOG us_silcompdialog = {{50,75,512,467}, "Silicon Compiler Options", 30, us_silcompdialogitems};
#endif

/* Color Mixing */
DIALOGITEM us_colormixdialogitems[] =
{
 /*  1 */ {0, {204,404,228,472}, BUTTON, "OK"},
 /*  2 */ {0, {204,324,228,392}, BUTTON, "Cancel"},
 /*  3 */ {0, {244,8,260,24}, USERDRAWN, ""},
 /*  4 */ {0, {244,36,260,472}, RADIO, "Entry 1"},
 /*  5 */ {0, {264,8,280,24}, USERDRAWN, ""},
 /*  6 */ {0, {264,36,280,472}, RADIO, "Entry 2"},
 /*  7 */ {0, {284,8,300,24}, USERDRAWN, ""},
 /*  8 */ {0, {284,36,300,472}, RADIO, "Entry 3"},
 /*  9 */ {0, {304,8,320,24}, USERDRAWN, ""},
 /* 10 */ {0, {304,36,320,472}, RADIO, "Entry 4"},
 /* 11 */ {0, {324,8,340,24}, USERDRAWN, ""},
 /* 12 */ {0, {324,36,340,472}, RADIO, "Entry 5"},
 /* 13 */ {0, {344,8,360,24}, USERDRAWN, ""},
 /* 14 */ {0, {344,36,360,472}, RADIO, "Entry 6"},
 /* 15 */ {0, {364,8,380,24}, USERDRAWN, ""},
 /* 16 */ {0, {364,36,380,472}, RADIO, "Entry 7"},
 /* 17 */ {0, {384,8,400,24}, USERDRAWN, ""},
 /* 18 */ {0, {384,36,400,472}, RADIO, "Entry 8"},
 /* 19 */ {0, {404,8,420,24}, USERDRAWN, ""},
 /* 20 */ {0, {404,36,420,472}, RADIO, "Entry 9"},
 /* 21 */ {0, {424,8,440,24}, USERDRAWN, ""},
 /* 22 */ {0, {424,36,440,472}, RADIO, "Entry 10"},
 /* 23 */ {0, {444,8,460,24}, USERDRAWN, ""},
 /* 24 */ {0, {444,36,460,472}, RADIO, "Entry 11"},
 /* 25 */ {0, {464,8,480,24}, USERDRAWN, ""},
 /* 26 */ {0, {464,36,480,472}, RADIO, "Entry 12"},
 /* 27 */ {0, {484,8,500,24}, USERDRAWN, ""},
 /* 28 */ {0, {484,36,500,472}, RADIO, "Entry 13"},
 /* 29 */ {0, {504,8,520,24}, USERDRAWN, ""},
 /* 30 */ {0, {504,36,520,472}, RADIO, "Entry 14"},
 /* 31 */ {0, {524,8,540,24}, USERDRAWN, ""},
 /* 32 */ {0, {524,36,540,472}, RADIO, "Entry 15"},
 /* 33 */ {0, {544,8,560,24}, USERDRAWN, ""},
 /* 34 */ {0, {544,36,560,472}, RADIO, "Entry 16"},
 /* 35 */ {0, {32,8,236,212}, USERDRAWN, ""},
 /* 36 */ {0, {32,228,236,308}, USERDRAWN, ""},
 /* 37 */ {0, {8,16,24,144}, MESSAGE, "Hue/Saturation:"},
 /* 38 */ {0, {8,228,24,308}, MESSAGE, "Intensity:"},
 /* 39 */ {0, {28,356,44,472}, RADIO, "Primaries"},
 /* 40 */ {0, {52,356,68,472}, RADIO, "Specials"},
 /* 41 */ {0, {76,356,92,472}, RADIO, "Layer 1"},
 /* 42 */ {0, {100,356,116,472}, RADIO, "Layer 2"},
 /* 43 */ {0, {124,356,140,472}, RADIO, "Layer 3"},
 /* 44 */ {0, {148,356,164,472}, RADIO, "Layer 4"},
 /* 45 */ {0, {172,356,188,472}, RADIO, "Layer 5"},
 /* 46 */ {0, {4,356,20,436}, MESSAGE, "Palettes:"}
};
DIALOG us_colormixdialog = {{75,75,642,555}, "Color Mixing", 46, us_colormixdialogitems};

/* Annular Ring */
DIALOGITEM us_annringdialogitems[] =
{
 /*  1 */ {0, {268,176,292,240}, BUTTON, "OK"},
 /*  2 */ {0, {268,20,292,84}, BUTTON, "Cancel"},
 /*  3 */ {0, {164,12,180,160}, MESSAGE, "Inner Radius:"},
 /*  4 */ {0, {164,164,180,244}, EDITTEXT, ""},
 /*  5 */ {0, {188,12,204,156}, MESSAGE, "Outer Radius:"},
 /*  6 */ {0, {188,164,204,244}, EDITTEXT, ""},
 /*  7 */ {0, {212,12,228,160}, MESSAGE, "Number of segments:"},
 /*  8 */ {0, {212,164,228,244}, EDITTEXT, "32"},
 /*  9 */ {0, {236,12,252,160}, MESSAGE, "Number of degrees:"},
 /* 10 */ {0, {236,164,252,244}, EDITTEXT, "360"},
 /* 11 */ {0, {8,8,24,172}, MESSAGE, "Layer to use for ring:"},
 /* 12 */ {0, {28,8,156,244}, SCROLL, ""}
};
DIALOG us_annringdialog = {{75,75,376,330}, "Annulus Construction", 12, us_annringdialogitems};

/* prototypes for local routines */
INTSML us_patternstroke(INTBIG, INTBIG);
void us_redrawpattern(RECTAREA*);
void us_writephases(float[], INTSML[], INTSML);
INTSML us_topofpins(char**);
char *us_nextpins(void);
INTSML us_topoftechs(char**);
char *us_nexttechs(void);
void us_defarcload(ARCPROTO*, NODEPROTO**, INTBIG);
void us_loadnode(NODEPROTO*);
void us_stufftechdescript(void);
void us_showliblist(char**, INTSML);
void us_setcurrenttechvar(TECHVAR*);
void us_movedialogtonode(DIALOG*, GEOM*);
INTSML us_nullup(INTBIG, INTBIG);
void us_nullvoid(void);
INTSML us_nullchar(INTBIG, INTBIG, INTSML);
void us_colormixreload(void);
char *us_colormixentryname(char *overlayernames[], INTSML ind);
void us_colormixbuildindex(INTSML layer1, INTSML layer2, INTSML layer3, INTSML layer4, INTSML layer5);
void us_colormixdrawpalette(RECTAREA *ra);
void us_colormixtogglemarker(void);
void us_colormixdrawsquare(INTBIG index);

/****************************** DIALOG CODE ******************************/

INTSML us_nulldloglist(char **c) { return(0); }
char *us_nulldlogitem(void) { return(0); }
void us_nulldlogdone(void) {}
INTSML us_nullup(INTBIG x, INTBIG y)  { return(0); }
void us_nullvoid(void) {}
INTSML us_nullchar(INTBIG x, INTBIG y, INTSML ch) { return(0); }

/*
 * special case for the "About Electric" menu
 * version number        = 6 (stat text)
 * authors               = 12 (button)
 * restrictions (nonGNU) = 13 (button)
 * warranty (GNU)        = 14 (button)
 * copying (GNU)         = 15 (button)
 */
void us_aboutdlog(char *licline)
{
	char line[256], date[30];
	INTSML itemHit, i;

#if EGNU
	/* show the GNU "about" dialog */
	if (DiaInitDialog(&us_aboutgnudialog) != 0) return;
	DiaInitTextDialog(11, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1,
		SCSMALLFONT|SCHORIZBAR);
#else
	/* show the commercial "about" dialog */
	if (DiaInitDialog(&us_aboutdialog) != 0) return;
	DiaInitTextDialog(11, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1, 0);
#endif

	/* show the version and copyright information */
	(void)strcpy(line, "Version ");
	(void)strcat(line, el_version);
	DiaSetText(6, line);
	strcpy(date, timetostring(getcurrenttime()));
	date[24] = 0;
	(void)sprintf(line, "Copyright (c) 1989-%s Electric Editor Incorporated", &date[20]);
	DiaSetText(3, line);

	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK) break;
		if (itemHit == 12)
		{
			DiaLoadTextDialog(11, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
			for(i=0; us_castofthousands[i] != 0; i++) DiaStuffLine(11, us_castofthousands[i]);
			DiaSelectLine(11, -1);
			continue;
		}
		if (itemHit == 14)
		{
			DiaLoadTextDialog(11, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
			for(i=0; us_gnuwarranty[i] != 0; i++) DiaStuffLine(11, us_gnuwarranty[i]);
			DiaSelectLine(11, -1);
			continue;
		}
		if (itemHit == 15)
		{
			DiaLoadTextDialog(11, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
			for(i=0; us_gnucopying[i] != 0; i++) DiaStuffLine(11, us_gnucopying[i]);
			DiaSelectLine(11, -1);
			continue;
		}
	}
	DiaDoneDialog();
}

/*
 * special case for the "array" menu
 * X repeat factor = 3 (edit text)
 * Y repeat factor = 4 (edit text)
 * X spacing       = 5 (edit text)
 * Y spacing       = 6 (edit text)
 * Flip in X       = 8 (check box)
 * Flip in Y       = 9 (check box)
 * Add names       = 7 (check box)
 * X spacing label = 12 (stat text)
 * Y spacing label = 13 (stat text)
 * Space by edge   = 14 (radio button)
 * Space by center = 15 (radio button)
 * Stagger in X    = 16 (check box)
 * Stagger in Y    = 17 (check box)
 */
INTSML us_arraydlog(char *paramstart[])
{
	REGISTER INTSML itemHit;
	REGISTER INTBIG xcentdist, ycentdist, xsize, ysize;
	INTBIG xoverlap, yoverlap, plx, ply, phx, phy;
	REGISTER NODEINST *ni;
	XARRAY trans;

	/* display the array dialog box */
	if (DiaInitDialog(&us_arraydialog) != 0) return(0);
	DiaSetText(3, "1");
	DiaSetText(4, "1");
	DiaSetText(5, "0");
	DiaSetText(6, "0");
	DiaSetControl(14, 1);
	DiaSetText(12, "X edge overlap:");
	DiaSetText(13, "Y edge overlap:");
	ni = (NODEINST *)us_getobject(OBJNODEINST, 0);
	if (ni == NONODEINST) xsize = ysize = 0; else
	{
		makeangle(ni->rotation, ni->transpose, trans);
		nodesizeoffset(ni, &plx, &ply, &phx, &phy);
		xform(ni->highx-ni->lowx - plx - phx, ni->highy-ni->lowy - ply - phy, &xoverlap, &yoverlap, trans);
		xsize = abs(xoverlap);   ysize = abs(yoverlap);
	}
	xoverlap = yoverlap = 0;
	xcentdist = xsize;   ycentdist = ysize;

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL) break;
		if (itemHit == OK && DiaValidEntry(3) && DiaValidEntry(4) && DiaValidEntry(5) &&
			DiaValidEntry(6)) break;
		if (itemHit == 7 || itemHit == 8 || itemHit == 9 || itemHit == 16 || itemHit == 17)
			DiaSetControl(itemHit, (INTSML)(1-DiaGetControl(itemHit)));
		if (itemHit == 14 || itemHit == 15)
		{
			DiaSetControl(14, 0);
			DiaSetControl(15, 0);
			DiaSetControl(itemHit, 1);
			if (itemHit == 14)
			{
				DiaSetText(12, "X edge overlap:");
				DiaSetText(13, "Y edge overlap:");
				xcentdist = atola(DiaGetText(5));
				ycentdist = atola(DiaGetText(6));
				DiaSetText(5, latoa(xoverlap));
				DiaSetText(6, latoa(yoverlap));
			} else
			{
				DiaSetText(12, "X centerline distance:");
				DiaSetText(13, "Y centerline distance:");
				xoverlap = atola(DiaGetText(5));
				yoverlap = atola(DiaGetText(6));
				DiaSetText(5, latoa(xcentdist));
				DiaSetText(6, latoa(ycentdist));
			}
			continue;
		}
	}

	paramstart[0] = "";
	if (itemHit != CANCEL)
	{
		(void)initinfstr();
		(void)addstringtoinfstr(DiaGetText(3));
		if (DiaGetControl(8) != 0) (void)addtoinfstr('f');
		if (DiaGetControl(16) != 0) (void)addtoinfstr('s');
		(void)addtoinfstr(' ');
		(void)addstringtoinfstr(DiaGetText(4));
		if (DiaGetControl(9) != 0) (void)addtoinfstr('f');
		if (DiaGetControl(17) != 0) (void)addtoinfstr('s');
		(void)addtoinfstr(' ');
		xoverlap = atola(DiaGetText(5));
		yoverlap = atola(DiaGetText(6));
		if (DiaGetControl(15) != 0)
		{
			xoverlap = xsize - xoverlap;
			yoverlap = ysize - yoverlap;
		}
		(void)addstringtoinfstr(latoa(xoverlap));
		(void)addtoinfstr(' ');
		(void)addstringtoinfstr(latoa(yoverlap));
		if (DiaGetControl(7) == 0) (void)addstringtoinfstr(" no-names");
		paramstart[0] = returninfstr();
	}
	DiaDoneDialog();
	return(1);
}

/*
 * special case for the "artwork primitive color&pattern" menu
 * Pattern squares = 4 (user item)
 * Color           = 19 (popup)
 * Solid           = 5 (radio button)
 * Use Pattern     = 7 (radio button)
 * Outline pattern = 3 (radio button)
 * Predefined pats = 8-18
 */
static RECTAREA us_strokerect;
static INTBIG us_origpattern[8];
static INTSML us_strokeup;

void us_redrawpattern(RECTAREA *bigr)
{
	INTSML j, k, bits;
	RECTAREA r;

	for(j=0; j<8; j++)
	{
		bits = us_origpattern[j] & 0xFFFF;
		for(k=0; k<16; k++)
		{
			r.left = us_strokerect.left + k*16;   r.right = r.left + 17;
			r.top = us_strokerect.top + j*16;     r.bottom = r.top + 17;
			if ((bits & (1<<(15-k))) != 0) DiaDrawRect(4, &r, 1); else DiaFrameRect(4, &r);
		}
	}
}

INTSML us_patternstroke(INTBIG ox, INTBIG oy)
{
	INTSML x, y;
	REGISTER INTSML j, k, bits;
	RECTAREA r;

	DiaGetMouse(&x, &y);
	j = (y - us_strokerect.top) / 16;  if (j < 0) j = 0;  if (j > 7) j = 7;
	k = (x - us_strokerect.left) / 16;  if (k < 0) k = 0;  if (k > 15) k = 15;
	r.left = us_strokerect.left + k*16;   r.right = r.left + 17;
	r.top = us_strokerect.top + j*16;     r.bottom = r.top + 17;
	bits = us_origpattern[j] & 0xFFFF;
	if (us_strokeup == 0)
	{
		DiaFrameRect(4, &r);
		bits &= ~(1<<(15-k));
	} else
	{
		DiaDrawRect(4, &r, 1);
		bits |= 1<<(15-k);
	}
	us_origpattern[j] = bits;
	return(0);
}

INTSML us_artlookdlog(char *paramstart[])
{
	RECTAREA r;
	INTBIG addr, type;
	UINTSML spattern[8];
	REGISTER NODEINST *ni;
	REGISTER ARCINST *ai;
	REGISTER VARIABLE *colorvar, *patternvar;
	INTSML itemHit, i, j, k, bits, err, x, y;
	HIGHLIGHT *high;
	static char *colornames[25] = {"Overlappable 1", "Overlappable 2", "Overlappable 3",
		"Overlappable 4", "Overlappable 5", "White", "Black", "Gray", "Light Gray",
		"Dark Gray", "Red", "Light Red", "Dark Red", "Green", "Light Green", "Dark Green",
		"Blue", "Light Blue", "Dark Blue", "Cyan", "Magenta", "Yellow", "Orange",
		"Purple", "Brown"};
	static INTSML valuelist[25] =
	{
		COLORT1,		/* overlappable 1 */
		COLORT2,		/* overlappable 2 */
		COLORT3,		/* overlappable 3 */
		COLORT4,		/* overlappable 4 */
		COLORT5,		/* overlappable 5 */
		WHITE,			/* white */
		BLACK,			/* black */
		GRAY,			/* gray */
		LGRAY,			/* light gray */
		DGRAY,			/* dark gray */
		RED,			/* red */
		LRED,			/* light red */
		DRED,			/* dark red */
		GREEN,			/* green */
		LGREEN,			/* light green */
		DGREEN,			/* dark green */
		BLUE,			/* blue */
		LBLUE,			/* light blue */
		DBLUE,			/* dark blue */
		CYAN,			/* cyan */
		MAGENTA,		/* magenta */
		YELLOW,			/* yellow */
		ORANGE,			/* orange */
		PURPLE,			/* purple */
		BROWN			/* brown */
	};

	/* make sure there is an artwork primitive highlighted */
	high = us_getonehighlight();
	if (high == NOHIGHLIGHT) return(0);
	err = 0;
	if ((high->status&HIGHTYPE) != HIGHFROM) err = 1; else
	{
		if (high->fromgeom->entrytype == OBJNODEINST)
		{
			ni = high->fromgeom->entryaddr.ni;
			if (ni->proto->index == 0 || ni->proto->tech != art_tech) err = 1;
			addr = (INTBIG)ni;
			type = VNODEINST;
		} else
		{
			ai = high->fromgeom->entryaddr.ai;
			if (ai->proto->tech != art_tech) err = 1;
			addr = (INTBIG)ai;
			type = VARCINST;
		}
	}
	if (err != 0)
	{
		us_abortcommand("First find a single node or arc in the Artwork technology");
		return(0);
	}

	/* display the artwork dialog box */
	if (DiaInitDialog(&us_artworkdialog) != 0) return(0);
	DiaSetPopup(19, 25, colornames);
	DiaItemRect(4, &us_strokerect);
	DiaRedispRoutine(4, us_redrawpattern);
	DiaFrameRect(4, &us_strokerect);

	/* set existing conditions */
	colorvar = getvalkey(addr, type, VINTEGER, art_colorkey);
	if (colorvar != NOVARIABLE)
	{
		for(i=0; i<25; i++) if (valuelist[i] == colorvar->addr)
		{
			DiaSetPopupEntry(19, i);
			break;
		}
	}
	for(i=0; i<8; i++) us_origpattern[i] = 0;
	patternvar = getvalkey(addr, type, -1, art_patternkey);
	if (patternvar != NOVARIABLE && getlength(patternvar) == 8)
	{
		if ((patternvar->type&VTYPE) == VINTEGER)
		{
			for(i=0; i<8; i++) us_origpattern[i] = ((UINTBIG *)patternvar->addr)[i];
			DiaSetControl(7, 1);
		} else if ((patternvar->type&VTYPE) == VSHORT)
		{
			for(i=0; i<8; i++) us_origpattern[i] = ((UINTSML *)patternvar->addr)[i];
			DiaSetControl(3, 1);
		}
	} else DiaSetControl(5, 1);
	us_redrawpattern(&us_strokerect);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK) break;
		if (itemHit == 4)
		{
			DiaGetMouse(&x, &y);
			j = (y - us_strokerect.top) / 16;  if (j < 0) j = 0;  if (j > 7) j = 7;
			k = (x - us_strokerect.left) / 16;  if (k < 0) k = 0;  if (k > 15) k = 15;
			bits = us_origpattern[j] & 0xFFFF;
			if ((bits & (1<<(15-k))) != 0) us_strokeup = 0; else us_strokeup = 1;
			trackcursor(0, us_nullup, us_nullvoid, us_patternstroke, us_nullchar,
				us_nullvoid, TRACKNORMAL);
			continue;
		}
		if (itemHit == 5 || itemHit == 7 || itemHit == 3)
		{
			DiaSetControl(5, 0);
			DiaSetControl(7, 0);
			DiaSetControl(3, 0);
			DiaSetControl(itemHit, 1);
			continue;
		}
		if (itemHit >= 8 && itemHit <= 18)
		{
			DiaGetMouse(&x, &y);
			DiaItemRect(itemHit, &r);
			j = (r.top+r.bottom)/2;
			if (y < j-8 || y > j+8) continue;
			i = (itemHit-8) * 2;
			if (x > (r.left+r.right)/2) i++;
			i *= 8;
			for(j=0; j<8; j++) us_origpattern[j] = us_predefpats[i++] & 0xFFFF;
			us_redrawpattern(&us_strokerect);
			continue;
		}
	}

	if (itemHit != CANCEL)
	{
		/* prepare for change */
		us_pushhighlight();
		us_clearhighlightcount();
		startobjectchange(addr, type);

		/* make the change */
		if (DiaGetControl(5) != 0)
		{
			if (patternvar != NOVARIABLE) (void)delvalkey(addr, type, art_patternkey);
		} else if (DiaGetControl(7) != 0)
		{
			(void)setvalkey(addr, type, art_patternkey, (INTBIG)us_origpattern,
				VINTEGER|VISARRAY|(8<<VLENGTHSH));
		} else
		{
			for(i=0; i<8; i++) spattern[i] = (UINTSML)us_origpattern[i];
			(void)setvalkey(addr, type, art_patternkey, (INTBIG)spattern, VSHORT|VISARRAY|(8<<VLENGTHSH));
		}
		i = DiaGetPopupEntry(19);
		if (valuelist[i] == 014)
		{
			/* black is the default */
			if (colorvar != NOVARIABLE) (void)delvalkey(addr, type, art_colorkey);
		} else (void)setvalkey(addr, type, art_colorkey, valuelist[i], VINTEGER);

		/* complete change */
		endobjectchange(addr, type);
		(void)us_pophighlight(0);
	}
	DiaDoneDialog();
	paramstart[0] = "";
	return(1);
}

/*
 * special case for the "layer pattern" menu
 * Name of layer   = 4 (popup)
 * Pattern squares = 5 (user item)
 * Outline pattern = 6 (check box)
 * Use pattern     = 7 (check box)
 * Predefined pats = 8-18 (icon)
 */
INTSML us_patterndlog(char *paramstart[])
{
	INTSML itemHit, curlayer, i, j, k, bits, *origbits, *orignature, x, y, dispstyle;
	RECTAREA r;
	REGISTER char **layernames;
	GRAPHICS *desc;

	if (us_needwindow()) return(0);

	/* get memory to save state */
	origbits = (INTSML *)emalloc(el_curtech->layercount * 8 * SIZEOFINTSML, us_aid->cluster);
	if (origbits == 0) return(0);
	orignature = (INTSML *)emalloc(el_curtech->layercount * SIZEOFINTSML, us_aid->cluster);
	if (orignature == 0) return(0);
	dispstyle = us_getdispstyle(el_curwindowpart);
	for(i=0; i<el_curtech->layercount; i++)
	{
		orignature[i] = (el_curtech->layers[i])->style[dispstyle];
		for(j=0; j<8; j++) origbits[i*8+j] = (el_curtech->layers[i])->raster[j];
	}
	curlayer = 0;

	/* display the pattern dialog box */
	if (DiaInitDialog(&us_patterndialog) != 0)
	{
		efree((char *)origbits);
		efree((char *)orignature);
		return(0);
	}
	DiaItemRect(5, &us_strokerect);
	DiaRedispRoutine(5, us_redrawpattern);
	DiaFrameRect(5, &us_strokerect);

	/* setup list of layer names */
	layernames = (char **)emalloc(el_curtech->layercount * (sizeof (char *)), el_tempcluster);
	for(i=0; i<el_curtech->layercount; i++)
		allocstring(&layernames[i], layername(el_curtech, i), el_tempcluster);
	DiaSetPopup(4, el_curtech->layercount, layernames);
	for(i=0; i<el_curtech->layercount; i++)
		efree(layernames[i]);
	efree((char *)layernames);

	/* setup initial layer: number 0 */
	curlayer = 0;
	DiaSetPopupEntry(4, curlayer);
	desc = el_curtech->layers[curlayer];
	if ((desc->style[us_getdispstyle(el_curwindowpart)]&NATURE) == PATTERNED)
	{
		DiaUnDimItem(6);
		DiaSetControl(7, 1);
		if ((desc->style[dispstyle]&OUTLINEPAT) != 0) DiaSetControl(6, 1);
	} else DiaDimItem(6);
	for(j=0; j<8; j++) us_origpattern[j] = desc->raster[j] & 0xFFFF;
	us_redrawpattern(&us_strokerect);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL) break;
		if (itemHit == OK) break;
		if (itemHit == 7)
		{
			/* the "Use Stipple" box */
			if (DiaGetControl(7) == 0)
			{
				DiaSetControl(7, 1);
				DiaUnDimItem(6);
				desc->style[dispstyle] = (desc->style[dispstyle] & ~NATURE) | PATTERNED;
			} else
			{
				DiaSetControl(7, 0);
				DiaSetControl(6, 0);
				DiaDimItem(6);
				desc->style[dispstyle] = (desc->style[dispstyle] & ~NATURE) | SOLIDC;
			}
			continue;
		}
		if (itemHit == 6)
		{
			/* the "Outline Pattern" box */
			if (DiaGetControl(6) == 0)
			{
				DiaSetControl(6, 1);
				desc->style[dispstyle] |= OUTLINEPAT;
			} else
			{
				DiaSetControl(6, 0);
				desc->style[dispstyle] &= ~OUTLINEPAT;
			}
			continue;
		}
		if (itemHit == 4)
		{
			/* the layer popup */
			curlayer = DiaGetPopupEntry(4);
			desc = el_curtech->layers[curlayer];
			DiaSetControl(7, 0);
			DiaUnDimItem(6);
			DiaSetControl(6, 0);
			if ((desc->style[dispstyle]&NATURE) == PATTERNED)
			{
				DiaSetControl(7, 1);
				if ((desc->style[dispstyle]&OUTLINEPAT) != 0) DiaSetControl(6, 1);
			} else DiaDimItem(6);
			for(j=0; j<8; j++) us_origpattern[j] = desc->raster[j] & 0xFFFF;
			us_redrawpattern(&us_strokerect);
			continue;
		}
		if (itemHit == 5)
		{
			DiaGetMouse(&x, &y);
			j = (y - us_strokerect.top) / 16;  if (j < 0) j = 0;  if (j > 7) j = 7;
			k = (x - us_strokerect.left) / 16;  if (k < 0) k = 0;  if (k > 15) k = 15;
			bits = desc->raster[j] & 0xFFFF;
			if ((bits & (1<<(15-k))) != 0) us_strokeup = 0; else us_strokeup = 1;
			trackcursor(0, us_nullup, us_nullvoid, us_patternstroke,
				us_nullchar, us_nullvoid, TRACKNORMAL);
			for(j=0; j<8; j++) desc->raster[j] = (UINTSML)us_origpattern[j];
			continue;
		}
		if (itemHit >= 8 && itemHit <= 18)
		{
			DiaGetMouse(&x, &y);
			DiaItemRect(itemHit, &r);
			j = (r.top+r.bottom)/2;
			if (y < j-8 || y > j+8) continue;
			i = (itemHit-8) * 2;
			if (x > (r.left+r.right)/2) i++;
			i *= 8;
			for(j=0; j<8; j++)
			{
				bits = us_predefpats[i++] & 0xFFFF;
				desc->raster[j] = bits;
				us_origpattern[j] = bits;
			}
			us_redrawpattern(&us_strokerect);
			continue;
		}
	}

	if (itemHit == CANCEL)
	{
		for(i=0; i<el_curtech->layercount; i++)
		{
			(el_curtech->layers[i])->style[dispstyle] = orignature[i];
			for(j=0; j<8; j++) (el_curtech->layers[i])->raster[j] = origbits[i*8+j];
		}
	}
	efree((char *)origbits);
	efree((char *)orignature);
	DiaDoneDialog();
	paramstart[0] = "";
	return(1);
}

/*
 * special case for the "als clock" dialog
 */
#define	MAXPHASES 20
INTSML us_alsclockdlog(char *paramstart[])
{
	INTSML itemHit, retval, i, j;
	char *line;
	float durval[MAXPHASES];
	INTSML levval[MAXPHASES], phases;
	static char *retdur[MAXPHASES];
	static INTSML first = 0;

	/* display the ALS clock dialog box */
	if (DiaInitDialog(&us_alsclockdialog) != 0) return(0);
	DiaInitTextDialog(16, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1, 0);

	/* setup complex clock specification */
	DiaSetText(11, "0.0");	/* random */
	DiaSetControl(8, 1);	/* gate strength */
	DiaSetControl(14, 1);	/* level */
	DiaSetText(20, "0");	/* infinite cycles */

	/* now disable complex clock specification */
	DiaSetControl(3, 1);										/* frequency */
	DiaDimItem(10);   DiaDimItem(11);   DiaNoEditControl(11);	/* random */
	DiaDimItem(13);   DiaDimItem(8);    DiaDimItem(12);			/* strength */
	DiaDimItem(23);   DiaDimItem(14);   DiaDimItem(9);			/* level */
	DiaDimItem(17);   DiaDimItem(21);   DiaNoEditControl(21);	/* duration */
	DiaDimItem(18);   DiaDimItem(15);							/* add/delete */
	DiaDimItem(22);												/* list header */
	DiaDimItem(19);   DiaDimItem(20);   DiaNoEditControl(20);	/* cycles */
	DiaUnDimItem(7);  DiaUnDimItem(6);  DiaEditControl(6);		/* freq/per */

	/* loop until done */
	phases = 0;
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;
		if (itemHit == 3 || itemHit == 4 || itemHit == 5)
		{
			DiaSetControl(3, 0);   DiaSetControl(4, 0);   DiaSetControl(5, 0);
			DiaSetControl(itemHit, 1);
			if (itemHit == 5)
			{
				DiaUnDimItem(10);   DiaUnDimItem(11);   DiaEditControl(11);	/* random */
				DiaUnDimItem(13);   DiaUnDimItem(8);    DiaUnDimItem(12);	/* strength */
				DiaUnDimItem(23);   DiaUnDimItem(14);   DiaUnDimItem(9);	/* level */
				DiaUnDimItem(17);   DiaUnDimItem(21);   DiaEditControl(21);	/* duration */
				DiaUnDimItem(18);   DiaUnDimItem(15);						/* add/delete */
				DiaUnDimItem(22);											/* list header */
				DiaUnDimItem(19);   DiaUnDimItem(20);   DiaEditControl(20);	/* cycles */
				DiaDimItem(7);      DiaDimItem(6);      DiaNoEditControl(6);/* freq/per */
			} else
			{
				DiaDimItem(10);   DiaDimItem(11);   DiaNoEditControl(11);	/* random */
				DiaDimItem(13);   DiaDimItem(8);    DiaDimItem(12);			/* strength */
				DiaDimItem(23);   DiaDimItem(14);   DiaDimItem(9);			/* level */
				DiaDimItem(17);   DiaDimItem(21);   DiaNoEditControl(21);	/* duration */
				DiaDimItem(18);   DiaDimItem(15);							/* add/delete */
				DiaDimItem(22);												/* list header */
				DiaDimItem(19);   DiaDimItem(20);   DiaNoEditControl(20);	/* cycles */
				DiaUnDimItem(7);  DiaUnDimItem(6);  DiaEditControl(6);		/* freq/per */
			}
			continue;
		}
		if (itemHit == 13 || itemHit == 8 || itemHit == 12)
		{
			DiaSetControl(13, 0);   DiaSetControl(8, 0);   DiaSetControl(12, 0);
			DiaSetControl(itemHit, 1);
			continue;
		}
		if (itemHit == 23 || itemHit == 14 || itemHit == 9)
		{
			DiaSetControl(23, 0);   DiaSetControl(14, 0);   DiaSetControl(9, 0);
			DiaSetControl(itemHit, 1);
			continue;
		}
		if (itemHit == 18)
		{
			/* add phase */
			if (phases >= MAXPHASES) continue;
			line = DiaGetText(21);
			durval[phases] = (float)atof(line);
			if (DiaGetControl(23) != 0) levval[phases] = 0; else
				if (DiaGetControl(14) != 0) levval[phases] = 1; else levval[phases] = 2;
			phases++;
			us_writephases(durval, levval, phases);
			continue;
		}
		if (itemHit == 15)
		{
			/* delete phase */
			if (phases <= 0) continue;
			j = DiaGetCurLine(16);
			for(i=j; i<phases; i++)
			{
				durval[i] = durval[i+1];
				levval[i] = levval[i+1];
			}
			phases--;
			us_writephases(durval, levval, phases);
			continue;
		}
	}
	retval = 0;
	if (itemHit == OK && DiaGetControl(3) != 0)
	{

		paramstart[0] = "frequency";
		paramstart[1] = us_putintoinfstr(DiaGetText(6));
		retval = 2;
	} else if (itemHit == OK && DiaGetControl(4) != 0)
	{
		paramstart[0] = "period";
		paramstart[1] = us_putintoinfstr(DiaGetText(6));
		retval = 2;
	} else if (itemHit == OK && DiaGetControl(5) != 0)
	{
		paramstart[0] = "custom";
		paramstart[1] = us_putintoinfstr(DiaGetText(11));
		if (DiaGetControl(13) != 0) paramstart[2] = "1"; else
			if (DiaGetControl(8) != 0) paramstart[2] = "2"; else
				paramstart[2] = "3";
		paramstart[3] = us_putintoinfstr(DiaGetText(20));
		retval = 4;
		if (first == 0) for(i=0; i<MAXPHASES; i++) retdur[i] = 0;
		first++;
		for(i=0; i<phases; i++)
		{
			if (retdur[i] != 0) efree(retdur[i]);
			retdur[i] = (char *)emalloc(50, us_aid->cluster);
			if (retdur[i] == 0) break;
			(void)sprintf(retdur[i], "%e", durval[i]);
			paramstart[retval++] = (levval[i]==0 ? "low" : (levval[i]==1 ? "high" : "undefined"));
			paramstart[retval++] = retdur[i];
		}
	}
	DiaDoneDialog();
	return(retval);
}

void us_writephases(float durval[], INTSML levval[], INTSML phases)
{
	INTSML i;
	char lne[50];

	DiaLoadTextDialog(16, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
	for(i=0; i<phases; i++)
	{
		(void)sprintf(lne, "%s for %e",
			(levval[i]==0 ? "low" : (levval[i]==1 ? "high" : "undefined")), durval[i]);
		DiaStuffLine(16, lne);
	}
	if (phases <= 0) DiaSelectLine(16, -1); else DiaSelectLine(16, 0);
}

/*
 * special case for the "copyfacet" dialog
 * Library name = 5 (static text)
 * Facet list   = 3 (user item)
 */
INTSML us_copyfacetdlog(char *prompt, char *paramstart[])
{
	INTSML itemHit, libcount, i;
	REGISTER LIBRARY *lib, *olib;
	REGISTER char **liblist;

	/* see how many libraries should be in the popup */
	libcount = 0;
	for(olib = el_curlib; olib != NOLIBRARY; olib = olib->nextlibrary) libcount++;

	/* determine the initial library */
	lib = el_curlib;
	if (libcount > 1) lib = lib->nextlibrary;
	if (*prompt == '!')
	{
		olib = getlibrary(&prompt[1]);
		if (olib != NOLIBRARY)
		{
			libcount = 1;
			lib = olib;
		}
	}

	/* load up list of libraries */
	liblist = (char **)emalloc(libcount * (sizeof (char *)), el_tempcluster);
	if (liblist == 0) return(0);
	if (libcount == 1) liblist[0] = lib->libname; else
	{
		for(olib = el_curlib->nextlibrary, i=0; olib != NOLIBRARY;
			olib = olib->nextlibrary)
				liblist[i++] = olib->libname;
		libcount = i;
	}

	/* display the copyfacet dialog box */
	if (DiaInitDialog(&us_copyfacetdialog) != 0)
	{
		efree((char *)liblist);
		return(0);
	}
	DiaSetPopup(5, libcount, liblist);

	olib = el_curlib;   el_curlib = lib;
	DiaInitTextDialog(3, us_topoffacets, us_nextparse, us_nulldlogdone, 0,
		SCSELMOUSE|SCSELKEY|SCDOUBLEQUIT);
	el_curlib = olib;

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;
		if (itemHit == 5)
		{
			i = DiaGetPopupEntry(5);
			for(lib = el_curlib; lib != NOLIBRARY; lib = lib->nextlibrary)
				if (strcmp(lib->libname, liblist[i]) == 0) break;
			if (lib == NOLIBRARY) continue;
			olib = el_curlib;
			el_curlib = lib;
			DiaLoadTextDialog(3, us_topoffacets, us_nextparse, us_nulldlogdone, 0);
			el_curlib = olib;
		}
	}

	paramstart[0] = "";
	if (itemHit != CANCEL)
	{
		(void)initinfstr();
		(void)addstringtoinfstr(lib->libname);
		(void)addtoinfstr(':');
		(void)addstringtoinfstr(DiaGetScrollLine(3, DiaGetCurLine(3)));
		paramstart[0] = returninfstr();
	}
	DiaDoneDialog();
	efree((char *)liblist);
	return(1);
}

/*
 * special case for the "defarc" menu
 * defaults for specific type = 4 (radio button)
 * defaults for all types     = 5 (radio button)
 * specific arc               = 3 (stat text)
 * reset to initial state     = 13 (button)
 * rigid                      = 7 (check button)
 * fixed-angle                = 8 (check button)
 * slidable                   = 9 (check button)
 * negated                    = 10 (check button)
 * directional                = 11 (check button)
 * ends extended              = 12 (check button)
 * width                      = 14 (edit text)
 * width title                = 15 (stat text)
 * angle title                = 16 (stat text)
 * angle                      = 17 (edit text)
 * default pin title          = 18 (stat text)
 * default pin                = 19 (stat text)
 * set pin                    = 6 (button)
 */
static ARCPROTO *us_thisap;
static NODEPROTO *us_posprims;
INTSML us_defarcdlog(char *paramstart[])
{
	INTSML itemHit;
	REGISTER INTBIG allstyle, i, j, origallstyle, bits;
	REGISTER VARIABLE *var;
	char **arcnames;
	REGISTER ARCPROTO *ap, **arcs;
	REGISTER NODEPROTO **pins, *np;
	extern DIALOG us_listdialog;

	/* display the default arc dialog box */
	if (DiaInitDialog(&us_defarcdialog) != 0) return(0);

	/* remember all state */
	var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_arcstyle);
	if (var != NOVARIABLE) allstyle = var->addr; else
		allstyle = WANTFIXANG;
	origallstyle = allstyle;
	for(i=0, ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto) i++;
	pins = (NODEPROTO **)emalloc(i * (sizeof (NODEPROTO *)), el_tempcluster);
	arcs = (ARCPROTO **)emalloc(i * (sizeof (ARCPROTO *)), el_tempcluster);
	arcnames = (char **)emalloc(i * (sizeof (char *)), el_tempcluster);
	if (pins == 0 || arcs == 0 || arcnames == 0) return(0);
	for(i=0, ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto, i++)
	{
		var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, us_arcstyle);
		if (var != NOVARIABLE) ap->temp1 = var->addr; else
			ap->temp1 = ap->userbits;
		ap->temp2 = defaultarcwidth(ap);
		pins[i] = getpinproto(ap);
		arcs[i] = ap;
		arcnames[i] = ap->protoname;
	}

	/* initially load for first arc in technology */
	us_thisap = us_curarcproto;
	us_defarcload(us_thisap, pins, allstyle);
	DiaSetControl(4, 1);
	DiaSetPopup(3, (INTSML)i, arcnames);
	efree((char *)arcnames);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;
		if (itemHit == 7 || itemHit == 8 || itemHit == 9 ||
			itemHit == 10 || itemHit == 11 || itemHit == 12)
		{
			j = DiaGetControl(itemHit);
			DiaSetControl(itemHit, (INTSML)(1-j));
			if (DiaGetControl(4) == 0) i = allstyle; else
				i = us_thisap->temp1;
			switch (itemHit)
			{
				case 7:
					if (j == 0) i |= WANTFIX; else i &= ~WANTFIX;
					break;
				case 8:
					if (j == 0) i |= WANTFIXANG; else i &= ~WANTFIXANG;
					break;
				case 9:
					if (j != 0) i |= WANTCANTSLIDE; else i &= ~WANTCANTSLIDE;
					break;
				case 10:
					if (j == 0) i |= WANTNEGATED; else i &= ~WANTNEGATED;
					break;
				case 11:
					if (j == 0) i |= WANTDIRECTIONAL; else i &= ~WANTDIRECTIONAL;
					break;
				case 12:
					if (j != 0) i |= WANTNOEXTEND; else i &= ~WANTNOEXTEND;
					break;
			}
			if (DiaGetControl(4) == 0) allstyle = i; else
				us_thisap->temp1 = i;
			continue;
		}
		if (itemHit == 4)
		{
			us_defarcload(us_thisap, pins, allstyle);
			DiaSetControl(4, 1);
			DiaSetControl(5, 0);
			continue;
		}
		if (itemHit == 5)
		{
			us_defarcload(NOARCPROTO, pins, allstyle);
			DiaSetControl(4, 0);
			DiaSetControl(5, 1);
			continue;
		}
		if (itemHit == 13)
		{
			allstyle = WANTFIXANG;
			DiaSetControl(7, 0);
			DiaSetControl(8, 1);
			DiaSetControl(9, 1);
			DiaSetControl(10, 0);
			DiaSetControl(11, 0);
			DiaSetControl(12, 1);
			continue;
		}
		if (itemHit == 3)
		{
			i = DiaGetPopupEntry(3);
			us_thisap = arcs[i];
			us_defarcload(us_thisap, pins, allstyle);
			continue;
		}
		if (itemHit == 14)
		{
			if (DiaGetControl(4) == 0) continue;
			us_thisap->temp2 = atola(DiaGetText(14));
			continue;
		}
		if (itemHit == 17)
		{
			if (DiaGetControl(4) == 0) continue;
			us_thisap->temp1 = (us_thisap->temp1 & ~AANGLEINC) | ((atoi(DiaGetText(17))%360) << AANGLEINCSH);
			continue;
		}
		if (itemHit == 6)
		{
			if (DiaGetControl(4) == 0) continue;

			if (DiaInitDialog(&us_listdialog) != 0) continue;
			DiaInitTextDialog(3, us_topofpins, us_nextpins, us_nulldlogdone,
				0, SCSELMOUSE|SCSELKEY|SCDOUBLEQUIT);
			DiaSetText(4, "Select a node to use as a pin");

			for(;;)
			{
				itemHit = DiaNextHit();
				if (itemHit == OK || itemHit == CANCEL) break;
			}
			np = getnodeproto(DiaGetScrollLine(3, DiaGetCurLine(3)));
			DiaDoneDialog();
			if (itemHit == CANCEL) continue;

			for(i=0, ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto, i++)
				if (us_thisap == ap) break;
			if (ap != NOARCPROTO) pins[i] = np;
			DiaSetText(19, describenodeproto(np));
			continue;
		}
	}

	if (itemHit != CANCEL)
	{
		for(i=0, ap = el_curtech->firstarcproto; ap != NOARCPROTO;
			ap = ap->nextarcproto, i++)
		{
			var = getvalkey((INTBIG)ap, VARCPROTO, VINTEGER, us_arcstyle);
			if (var != NOVARIABLE) bits = var->addr; else
				bits = ap->userbits;
			if (ap->temp1 != bits)
				(void)setvalkey((INTBIG)ap, VARCPROTO, us_arcstyle, ap->temp1, VINTEGER);
			if (ap->temp2 != defaultarcwidth(ap))
				(void)setvalkey((INTBIG)ap, VARCPROTO, el_arc_default_width,
					arcprotowidthoffset(ap) + ap->temp2, VINTEGER);
			np = getpinproto(ap);
			if (np != pins[i])
				(void)setval((INTBIG)ap, VARCPROTO, "ARC_Default_Pin", (INTBIG)pins[i], VNODEPROTO);
		}
		if (allstyle != origallstyle)
			(void)setvalkey((INTBIG)us_aid, VAID, us_arcstyle, allstyle, VINTEGER);
	}
	DiaDoneDialog();
	efree((char *)pins);
	efree((char *)arcs);
	paramstart[0] = "x";
	return(1);
}

INTSML us_topofpins(char **c)
{
	us_posprims = el_curtech->firstnodeproto;
	return(1);
}

char *us_nextpins(void)
{
	REGISTER char *nextname;
	REGISTER INTSML i;
	REGISTER PORTPROTO *pp;

	for( ; us_posprims != NONODEPROTO; us_posprims = us_posprims->nextnodeproto)
	{
		/* test this pin for validity */
		pp = us_posprims->firstportproto;
		for(i=0; pp->connects[i] != NOARCPROTO; i++)
			if (pp->connects[i] == us_thisap) break;
		if (pp->connects[i] == NOARCPROTO) continue;
		nextname = us_posprims->primname;
		us_posprims = us_posprims->nextnodeproto;
		return(nextname);
	}
	return(0);
}

/*
 * Helper routine for arc options
 */
void us_defarcload(ARCPROTO *ap, NODEPROTO **pins, INTBIG allstyle)
{
	REGISTER NODEPROTO *np;
	REGISTER ARCPROTO *oap;
	REGISTER INTSML i;
	REGISTER INTBIG style;
	char line[20];

	if (ap == NOARCPROTO)
	{
		style = allstyle;
		DiaDimItem(3);
		DiaUnDimItem(13);
		DiaDimItem(15);
		DiaSetText(14, "");
		DiaNoEditControl(14);
		DiaDimItem(16);
		DiaSetText(17, "");
		DiaNoEditControl(17);
		DiaDimItem(18);
		DiaSetText(19, "");
		DiaDimItem(6);
	} else
	{
		style = ap->temp1;
		DiaUnDimItem(3);
		DiaDimItem(13);
		DiaUnDimItem(15);
		DiaSetText(-14, latoa(defaultarcwidth(ap) - arcprotowidthoffset(ap)));
		DiaEditControl(14);
		DiaUnDimItem(16);
		(void)sprintf(line, "%ld", (ap->userbits&AANGLEINC) >> AANGLEINCSH);
		DiaSetText(17, line);
		DiaEditControl(17);
		DiaUnDimItem(18);
		np = NONODEPROTO;
		for(i=0, oap = el_curtech->firstarcproto; oap != NOARCPROTO; oap = oap->nextarcproto, i++)
			if (ap == oap) np = pins[i];
		DiaSetText(19, describenodeproto(np));
		DiaUnDimItem(6);
	}
	DiaSetControl(7, (INTSML)((style&WANTFIX) != 0 ? 1 : 0));
	DiaSetControl(8, (INTSML)((style&WANTFIXANG) != 0 ? 1 : 0));
	DiaSetControl(9, (INTSML)((style&WANTCANTSLIDE) == 0 ? 1 : 0));
	DiaSetControl(10, (INTSML)((style&WANTNEGATED) != 0 ? 1 : 0));
	DiaSetControl(11, (INTSML)((style&WANTDIRECTIONAL) != 0 ? 1 : 0));
	DiaSetControl(12, (INTSML)((style&WANTNOEXTEND) == 0 ? 1 : 0));
}

/*
 * special case for the "defnode" menu
 * X size         = 3 (edit text)
 * Expanded       = 4 (radio button)
 * Unexpanded     = 5 (radio button)
 * X size label   = 6 (stat text)
 * Y size label   = 7 (stat text)
 * Y size         = 8 (edit text)
 * Primitives     = 9 (radio button)
 * Primitive name = 10 (popup)
 * Tiny facets    = 11 (check button)
 * Facets         = 12 (radio button)
 * Facet name     = 13 (popup)
 * Allow facetmod = 14 (check button)
 * Check dates    = 15 (check button)
 * Rotation       = 17 (edit text)
 * Transposed     = 18 (check button)
 * Separator line = 19 (user item)
 * Separator line = 20 (user item)
 * Separator line = 21 (user item)
 * Allow prim mod = 22 (check button)
 */
INTSML us_defnodedlog(char *paramstart[])
{
	INTSML itemHit, i, j, pangle, numprims, numfacets;
	INTBIG plx, ply, phx, phy, lx, pxs, pys, nodesize[2];
	REGISTER NODEPROTO *thisprim, *thisfacet, *np;
	REGISTER VARIABLE *var;
	REGISTER char **primnames, **facetnames;

	/* display the defnode dialog box */
	if (DiaInitDialog(&us_defnodedialog) != 0) return(0);

	/* construct lists of primitives and facets */
	numprims = numfacets = 0;
	for(np = el_curtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
		numprims++;
	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
		numfacets++;
	primnames = (char **)emalloc(numprims * (sizeof (char *)), el_tempcluster);
	if (numfacets != 0)
		facetnames = (char **)emalloc(numfacets * (sizeof (char *)), el_tempcluster);
	numprims = numfacets = 0;
	for(np = el_curtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
		primnames[numprims++] = np->primname;
	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
		(void)allocstring(&facetnames[numfacets++], describenodeproto(np),
			el_tempcluster);
	DiaSetPopup(10, numprims, primnames);
	DiaSetPopup(13, numfacets, facetnames);
	for(i=0; i<numfacets; i++) efree(facetnames[i]);
	if (numfacets != 0) efree((char *)facetnames);
	efree((char *)primnames);

	/* save existing state */
	for(np = el_curtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
	{
		defaultnodesize(np, &pxs, &pys);
		nodeprotosizeoffset(np, &plx, &ply, &phx, &phy);
		np->temp1 = pxs - plx - phx;
		np->temp2 = pys - ply - phy;
	}
	for(i=0,np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto,i++)
	{
		np->temp1 = np->userbits;
		np->temp2 = i;
	}

	/* decide what to display first */
	if (us_curnodeproto == NONODEPROTO)
	{
		thisfacet = el_curlib->firstnodeproto;
		thisprim = el_curtech->firstnodeproto;
		DiaSetControl(9, 1);
		DiaSetControl(12, 0);
		us_loadnode(thisprim);
	} else
	{
		if (us_curnodeproto->index == 0)
		{
			thisfacet = us_curnodeproto;
			thisprim = el_curtech->firstnodeproto;
			DiaSetControl(9, 0);
			DiaSetControl(12, 1);
		} else
		{
			thisfacet = el_curlib->firstnodeproto;
			thisprim = us_curnodeproto;
			DiaSetControl(9, 1);
			DiaSetControl(12, 0);
		}
		us_loadnode(us_curnodeproto);
	}
	DiaSetPopupEntry(10, (INTSML)(thisprim->index-1));
	if (thisfacet != NONODEPROTO)
		DiaSetPopupEntry(13, (INTSML)thisfacet->temp2);

	/* load defaults for all nodes */
	var = getvalkey((INTBIG)us_aid, VAID, VINTEGER, us_placement_angle);
	if (var == NOVARIABLE) pangle = 0; else pangle = (INTSML)var->addr;
	DiaSetText(-17, frtoa(pangle%3600*WHOLE/10));
	DiaSetControl(18, (INTSML)((pangle >= 3600 ? 1 : 0)));

	DiaSetControl(14, (INTSML)((us_useroptions&NOFACETCHANGES) != 0 ? 1 : 0));
	DiaSetControl(22, (INTSML)((us_useroptions&NOPRIMCHANGES) != 0 ? 1 : 0));
	DiaSetControl(15, (INTSML)((us_useroptions&CHECKDATE) != 0 ? 1 : 0));
	DiaSetControl(11, (INTSML)((us_useroptions&DRAWTINYFACETS) == 0 ? 1 : 0));

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;
		if (itemHit == 9)
		{
			DiaSetControl(9, 1);
			DiaSetControl(12, 0);
			us_loadnode(thisprim);
			continue;
		}
		if (itemHit == 10)
		{
			DiaSetControl(9, 1);
			DiaSetControl(12, 0);
			i = DiaGetPopupEntry(10);
			for(np = el_curtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
				if (np->index == i+1) break;
			thisprim = np;
			us_loadnode(thisprim);
			continue;
		}
		if (itemHit == 12)
		{
			if (thisfacet == NONODEPROTO) continue;
			DiaSetControl(9, 0);
			DiaSetControl(12, 1);
			us_loadnode(thisfacet);
			continue;
		}
		if (itemHit == 13)
		{
			DiaSetControl(9, 0);
			DiaSetControl(12, 1);
			i = DiaGetPopupEntry(13);
			for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
				if (np->temp2 == i) break;
			thisfacet = np;
			us_loadnode(thisfacet);
			continue;
		}
		if (itemHit == 3 || itemHit == 8)
		{
			if (DiaGetControl(9) == 0) continue;
			thisprim->temp1 = atola(DiaGetText(3));
			thisprim->temp2 = atola(DiaGetText(8));
			continue;
		}
		if (itemHit == 4)
		{
			DiaSetControl(4, 1);
			DiaSetControl(5, 0);
			thisfacet->temp1 |= WANTNEXPAND;
			continue;
		}
		if (itemHit == 5)
		{
			DiaSetControl(4, 0);
			DiaSetControl(5, 1);
			thisfacet->temp1 &= ~WANTNEXPAND;
			continue;
		}
		if (itemHit == 14 || itemHit == 15 || itemHit == 18 ||
			itemHit == 22 || itemHit == 11)
		{
			DiaSetControl(itemHit, (INTSML)(1-DiaGetControl(itemHit)));
			continue;
		}
	}

	paramstart[0] = "x";
	if (itemHit != CANCEL)
	{
		/* handle primitive size changes */
		for(np = el_curtech->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
		{
			defaultnodesize(np, &pxs, &pys);
			nodeprotosizeoffset(np, &plx, &ply, &phx, &phy);
			if (np->temp1 != pxs - plx - phx ||
				np->temp2 != pys - ply - phy)
			{
				nodesize[0] = np->temp1+plx+phx;
				nodesize[1] = np->temp2+ply+phy;
				(void)setvalkey((INTBIG)np, VNODEPROTO, el_node_default_size,
					(INTBIG)nodesize, VINTEGER|VISARRAY|(2<<VLENGTHSH));
			}
		}

		/* handle facet expansion changes */
		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
			if ((np->temp1&WANTNEXPAND) != (INTBIG)(np->userbits&WANTNEXPAND))
				(void)setval((INTBIG)np, VNODEPROTO, "userbits", np->temp1, VINTEGER);

		/* handle changes to all nodes */
		lx = us_useroptions;
		i = DiaGetControl(14);
		if (i != 0) lx |= NOFACETCHANGES; else lx &= ~NOFACETCHANGES;
		i = DiaGetControl(22);
		if (i != 0) lx |= NOPRIMCHANGES; else lx &= ~NOPRIMCHANGES;
		i = DiaGetControl(15);
		if (i != 0) lx |= CHECKDATE; else lx &= ~CHECKDATE;
		i = DiaGetControl(11);
		if (i == 0) lx |= DRAWTINYFACETS; else lx &= ~DRAWTINYFACETS;
		(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags, lx, VINTEGER);
		j = (atofr(DiaGetText(17))*10/WHOLE) % 3600;
		if (DiaGetControl(18) != 0) j += 3600;
		if (j != pangle)
			(void)setvalkey((INTBIG)us_aid, VAID, us_placement_angle, j, VINTEGER);
	}
	DiaDoneDialog();
	return(1);
}

/*
 * helper routine for defnode dialog
 */
void us_loadnode(NODEPROTO *thisnp)
{
	INTBIG plx, ply, phx, phy, pxs, pys;
	INTSML i, j;

	if (thisnp->index == 0)
	{
		DiaDimItem(6);
		DiaDimItem(7);
		DiaNoEditControl(3);   DiaNoEditControl(8);
		DiaSetText(3, "");   DiaSetText(8, "");
		DiaUnDimItem(4);
		DiaUnDimItem(5);
		if ((thisnp->userbits&WANTNEXPAND) != 0)
		{ i = 4;   j = 5; } else { i = 5;   j = 4; }
		DiaSetControl(i, 1);
		DiaSetControl(j, 0);
	} else
	{
		DiaUnDimItem(6);
		DiaUnDimItem(7);
		DiaDimItem(4);
		DiaDimItem(5);

		defaultnodesize(thisnp, &pxs, &pys);
		nodeprotosizeoffset(thisnp, &plx, &ply, &phx, &phy);
		DiaEditControl(3);   DiaEditControl(8);
		DiaSetText(3, latoa(pxs-plx-phx));
		DiaSetText(8, latoa(pys-ply-phy));
	}
}

/*
 * special case for "DRC error" options
 * 5 = Error message      (stat text)
 * 1 = Acknowledge        (button)
 * 2 = Quit-checking      (button)
 * 3 = Ignore-error       (button)
 * 4 = Continue-silently  (button)
 */
INTSML us_drcerrordlog(char *prompt, char *paramstart[])
{
	INTSML itemHit, oldplease;

	/* display the DRC error dialog box */
	if (DiaInitDialog(&us_drcerrdialog) != 0) return(0);

	/* load the message */
	DiaSetText(5, prompt);

	/* loop until done */
	oldplease = el_pleasestop;
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == 1 || itemHit == 2 || itemHit == 3 || itemHit == 4) break;
	}
	el_pleasestop = oldplease;

	switch (itemHit)
	{
		case 2:  paramstart[0] = "quit-checking";       break;
		case 3:  paramstart[0] = "ignore-error";        break;
		case 4:  paramstart[0] = "continue-silently";   break;
		default: paramstart[0] = "acknowledge";         break;
	}
	DiaDoneDialog();
	return(1);
}

/*
 * the meaning of "us_techlist":
 *  0  list all technologies without modification
 *  1  list all technologies, splitting "schematics" into "digital" and "analog"
 *  2  list all technologies that can be edited
 *  3  list all technologies that can be deleted
 */
int us_techlist;
static TECHNOLOGY *us_postechcomcomp;
INTSML us_topoftechs(char **c) { us_postechcomcomp = el_technologies; return(1); }
char *us_nexttechs(void)
{
	REGISTER char *retname;
	REGISTER TECHNOLOGY *tech;

	for(;;)
	{
		if (us_postechcomcomp == NOTECHNOLOGY)
		{
			us_postechcomcomp = 0;
			if (us_techlist == 1) return("schematic, analog");
		}
		if (us_postechcomcomp == 0) return(0);

		/* get the next technology in the list */
		tech = us_postechcomcomp;
		us_postechcomcomp = us_postechcomcomp->nexttechnology;

		/* adjust the name if requested */
		retname = tech->techname;
		if (tech == sch_tech && us_techlist == 1)
			retname = "schematic, digital";

		/* ignore if requested */
		if (us_techlist == 2 && (tech->userbits&NONSTANDARD) != 0) continue;
		if (us_techlist == 3 && tech == gen_tech) continue;

		/* accept */
		break;
	}
	return(retname);
}

void us_stufftechdescript(void)
{
	REGISTER TECHNOLOGY *t;
	REGISTER char *tech;

	tech = DiaGetScrollLine(3, DiaGetCurLine(3));
	if (namesamen(tech, "schematic", 9) == 0)
	{
		t = sch_tech;
		DiaSetText(4, t->techdescript);
		return;
	}

	for(t = el_technologies; t != NOTECHNOLOGY; t = t->nexttechnology)
		if (strcmp(t->techname, tech) == 0) break;
	if (t == NOTECHNOLOGY) return;
	DiaSetText(4, t->techdescript);
}

/*
 * special case for the "select technology" menu
 * Technology description = 5 (stat text)
 * Technology list        = 3 (user item)
 */
INTSML us_technologydlog(char *prompt, char *paramstart[])
{
	INTSML itemHit;

	/* display the new facet dialog box */
	us_techselectdialog.movable = prompt;

	/* the list of technologies depends on the nature of the operation */
	if (namesame(prompt, "Change current technology") == 0) us_techlist = 1; else
		if (namesame(prompt, "Edit technology") == 0) us_techlist = 2; else
			if (namesame(prompt, "Document technology") == 0) us_techlist = 0; else
				if (namesame(prompt, "Convert to new technology") == 0) us_techlist = 0; else
					if (namesame(prompt, "Delete technology") == 0) us_techlist = 3;

	if (DiaInitDialog(&us_techselectdialog) != 0) return(0);
	DiaInitTextDialog(3, us_topoftechs, us_nexttechs, us_nulldlogdone, 0,
		SCSELMOUSE|SCSELKEY|SCDOUBLEQUIT|SCREPORT);
	us_stufftechdescript();

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK) break;
		if (itemHit == 3)
		{
			us_stufftechdescript();
			continue;
		}
	}

	paramstart[0] = "";
	if (itemHit != CANCEL)
	{
		paramstart[0] = us_putintoinfstr(DiaGetScrollLine(3, DiaGetCurLine(3)));
		if (namesame(paramstart[0], "schematic, digital") == 0) paramstart[0] = "schematic";
	}
	DiaDoneDialog();
	return(1);
}

/*
 * special case for the "dependent libraries" menu
 * Dependent list = 3 (user item)
 * Library list   = 12 (user item)
 * Add lib        = 7 (button)
 * Remove lib     = 6 (button)
 * New name       = 9 (edit text)
 * Current lib    = 14 (stat text)
 */
INTSML us_dependentlibdlog(char *paramstart[])
{
	INTSML itemHit, i, j, liblistlen;
	REGISTER VARIABLE *var;
	char **liblist, **newliblist, *pt;

	/* display the dependent library dialog box */
	if (DiaInitDialog(&us_dependentlibdialog) != 0) return(0);
	DiaSetText(14, el_curlib->libname);
	DiaInitTextDialog(12, topoflibs, nextlibs, us_nulldlogdone, 0, SCSELMOUSE|SCSELKEY);
	DiaInitTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, 0,
		SCSELMOUSE|SCSELKEY);
	var = getval((INTBIG)el_curlib, VLIBRARY, VSTRING|VISARRAY, "EDTEC_dependent_libraries");
	if (var == NOVARIABLE) liblistlen = 0; else
	{
		liblistlen = (INTSML)getlength(var);
		liblist = (char **)emalloc(liblistlen * (sizeof (char *)), el_tempcluster);
		if (liblist == 0) return(0);
		for(i=0; i<liblistlen; i++)
			(void)allocstring(&liblist[i], ((char **)var->addr)[i], el_tempcluster);
	}
	us_showliblist(liblist, liblistlen);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK) break;
		if (itemHit == 6)
		{
			/* remove */
			i = DiaGetCurLine(3);
			if (i < 0 || i >= liblistlen) continue;
			efree(liblist[i]);
			for(j=i; j<liblistlen-1; j++) liblist[j] = liblist[j+1];
			liblistlen--;
			if (liblistlen == 0) efree((char *)liblist);
			us_showliblist(liblist, liblistlen);
			continue;
		}
		if (itemHit == 7)
		{
			/* add */
			pt = DiaGetText(9);
			while (*pt == ' ') pt++;
			if (*pt == 0) pt = DiaGetScrollLine(12, DiaGetCurLine(12));
			i = DiaGetCurLine(3);
			if (i < 0) i = 0;

			/* create a new list */
			newliblist = (char **)emalloc((liblistlen+1) * (sizeof (char *)), el_tempcluster);
			if (newliblist == 0) return(0);
			for(j=0; j<liblistlen; j++) newliblist[j] = liblist[j];
			if (liblistlen != 0) efree((char *)liblist);
			liblist = newliblist;

			for(j=liblistlen; j>i; j--) liblist[j] = liblist[j-1];
			liblistlen++;
			(void)allocstring(&liblist[i], pt, el_tempcluster);
			us_showliblist(liblist, liblistlen);
			DiaSetText(9, "");
			continue;
		}
	}

	if (itemHit != CANCEL)
	{
		if (liblistlen == 0)
		{
			if (var != NOVARIABLE)
				delval((INTBIG)el_curlib, VLIBRARY, "EDTEC_dependent_libraries");
		} else
		{
			(void)setval((INTBIG)el_curlib, VLIBRARY, "EDTEC_dependent_libraries",
				(INTBIG)liblist, VSTRING|VISARRAY|(liblistlen<<VLENGTHSH));
		}
	}
	for(i=0; i<liblistlen; i++) efree(liblist[i]);
	if (liblistlen != 0) efree((char *)liblist);
	DiaDoneDialog();
	return(0);
}

void us_showliblist(char **liblist, INTSML liblistlen)
{
	REGISTER INTSML i;

	DiaLoadTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
	if (liblistlen == 0)
	{
		DiaSelectLine(3, -1);
		return;
	}
	for(i=0; i<liblistlen; i++) DiaStuffLine(3, liblist[i]);
	DiaSelectLine(3, 0);
}

/*
 * special case for the "library paths" menu
 * library file location = 4 (stat text)
 */
INTSML us_librarypathdlog(char *paramstart[])
{
	INTSML itemHit;
	char *pt;

	/* display the library paths dialog box */
	if (DiaInitDialog(&us_librarypathdialog) != 0) return(0);
	DiaSetText(4, el_libdir);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL) break;
		if (itemHit == OK && DiaValidEntry(4)) break;
	}

	paramstart[0] = "";
	if (itemHit != CANCEL)
	{
		pt = DiaGetText(4);
		if (strcmp(pt, el_libdir) != 0) (void)reallocstring(&el_libdir, pt, db_cluster);
	}
	DiaDoneDialog();
	return(1);
}

/*
 * special case for the "help" menu
 * topics       = 4 (user item)
 * help         = 3 (user item)
 */
INTSML us_helpdlog(char *prompt, char *paramstart[])
{
	char *filename, *line, buf[256];
	INTSML itemHit, i;
	FILE *in;

	/* get the help file */
	(void)initinfstr();
	(void)addstringtoinfstr(el_libdir);
	(void)addstringtoinfstr(prompt);
	line = returninfstr();
	in = xopen(line, FILETYPEHELP, "", &filename);
	if (in == NULL)
	{
		us_abortcommand("Cannot find help file: %s", line);
		return(0);
	}

	/* show the "help" dialog */
	if (DiaInitDialog(&us_helpdialog) != 0)
	{
		xclose(in);
		return(0);
	}
	DiaInitTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1,
		SCHORIZBAR|SCSMALLFONT|SCFIXEDWIDTH);
	DiaInitTextDialog(4, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1,
		SCSELMOUSE|SCSELKEY|SCREPORT|SCSMALLFONT);

	/* load the topics list */
	for(;;)
	{
		if (xfgets(buf, 256, in) != 0) break;
		if (buf[0] != '!') continue;
		DiaStuffLine(4, &buf[1]);
	}
	DiaSelectLine(4, -1);

	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK) break;
		if (itemHit == 4)
		{
			line = DiaGetScrollLine(4, DiaGetCurLine(4));
			xseek(in, 0, 0);
			DiaLoadTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
			for(;;)
			{
				if (xfgets(buf, 256, in) != 0) break;
				if (buf[0] != '!') continue;
				if (strcmp(&buf[1], line) == 0) break;
			}
			for(i=0; ; i++)
			{
				if (xfgets(buf, 256, in) != 0) break;
				if (buf[0] == '!') break;
				if (buf[0] == 0 && i == 0) continue;
				DiaStuffLine(3, buf);
			}
			DiaSelectLine(3, -1);
			continue;
		}
	}
	DiaDoneDialog();
	xclose(in);
	paramstart[0] = "";
	return(1);
}

/*
 * special case for the "technology variables" menu
 * Type          =  5 (stat text)
 * Description   =  6 (stat text)
 * Current vars  =  3 (user)
 * Known vars    =  7 (user)
 * Remove        = 11 (button)
 * Copy          = 10 (button)
 * Edit Strings  = 13 (button)
 * the Value     = 12 (edit text)
 */
INTSML us_techvarsdlog(char *paramstart[])
{
	char **varnames, *name, *cmd[5];
	INTSML itemHit, i, j;
	REGISTER VARIABLE *var, *ovar;
	TECHVAR *newvars, *tvar, *ltvar, *t;

	/* show the "technology variables" dialog */
	if (DiaInitDialog(&us_techvarsdialog) != 0) return(0);
	DiaInitTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1,
		SCSELMOUSE|SCREPORT);
	DiaInitTextDialog(7, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1,
		SCSELMOUSE|SCREPORT);

	/* load the known variables list */
	for(i=0; us_knownvars[i].varname != 0; i++) DiaStuffLine(7, us_knownvars[i].varname);
	DiaSelectLine(7, -1);

	/* see what variables are already in the list */
	var = getval((INTBIG)el_curlib, VLIBRARY, VSTRING|VISARRAY, "EDTEC_variable_list");
	newvars = NOTECHVAR;
	if (var != NOVARIABLE)
	{
		j = (INTSML)getlength(var);
		varnames = (char **)var->addr;
		for(i=0; i<j; i++)
		{
			ovar = getval((INTBIG)el_curlib, VLIBRARY, -1, varnames[i]);
			if (ovar == NOVARIABLE) continue;
			DiaStuffLine(3, varnames[i]);
			tvar = (TECHVAR *)emalloc(sizeof (TECHVAR), el_tempcluster);
			if (tvar == 0) break;
			(void)allocstring(&tvar->varname, varnames[i], el_tempcluster);
			tvar->nexttechvar = newvars;
			tvar->changed = 0;
			switch (ovar->type&(VTYPE|VISARRAY))
			{
				case VFLOAT:   tvar->fval = castfloat(ovar->addr);   break;
				case VINTEGER: tvar->ival = ovar->addr;              break;
				case VSTRING:
					(void)allocstring(&tvar->sval, (char *)ovar->addr, el_tempcluster);
					break;
			}
			tvar->vartype = ovar->type;
			newvars = tvar;
		}
	}
	DiaSelectLine(3, -1);

	/* set dialog allowances state */
	us_setcurrenttechvar(newvars);
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL || itemHit == 13) break;

		/* hit in one scroll area turns off highlight in the other */
		if (itemHit == 3)
		{
			DiaSelectLine(7, -1);
			us_setcurrenttechvar(newvars);
		}
		if (itemHit == 7)
		{
			DiaSelectLine(3, -1);
			us_setcurrenttechvar(newvars);
		}

		/* change to the value */
		if (itemHit == 12)
		{
			i = DiaGetCurLine(3);
			if (i < 0) continue;
			name = DiaGetScrollLine(3, i);
			for(t = newvars; t != NOTECHVAR; t = t->nexttechvar)
				if (namesame(t->varname, name) == 0) break;
			if (t == NOTECHVAR) continue;
			switch (t->vartype&(VTYPE|VISARRAY))
			{
				case VINTEGER:
					t->ival = myatoi(DiaGetText(12));
					t->changed++;
					break;
				case VFLOAT:
					t->fval = (float)atof(DiaGetText(12));
					t->changed++;
					break;
				case VSTRING:
					(void)reallocstring(&t->sval, DiaGetText(12), el_tempcluster);
					t->changed++;
					break;
			}
			continue;
		}

		/* the "<< Copy" button */
		if (itemHit == 10)
		{
			i = DiaGetCurLine(7);
			if (i < 0) continue;
			name = DiaGetScrollLine(7, i);
			for(t = newvars; t != NOTECHVAR; t = t->nexttechvar)
				if (namesame(t->varname, name) == 0) break;
			if (t != NOTECHVAR) continue;

			tvar = (TECHVAR *)emalloc(sizeof (TECHVAR), el_tempcluster);
			if (tvar == 0) break;
			(void)allocstring(&tvar->varname, name, el_tempcluster);
			tvar->vartype = us_knownvars[i].vartype;
			tvar->ival = 0;
			tvar->fval = 0.0;
			if ((tvar->vartype&(VTYPE|VISARRAY)) == VSTRING)
				(void)allocstring(&tvar->sval, "", el_tempcluster);
			tvar->changed = 1;
			tvar->nexttechvar = newvars;
			newvars = tvar;
			DiaLoadTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
			for(t = newvars; t != NOTECHVAR; t = t->nexttechvar) DiaStuffLine(3, t->varname);
			DiaSelectLine(3, -1);
			us_setcurrenttechvar(newvars);
			continue;
		}

		/* the "Remove" button */
		if (itemHit == 11)
		{
			i = DiaGetCurLine(3);
			if (i < 0) continue;
			name = DiaGetScrollLine(3, i);

			ltvar = NOTECHVAR;
			for(t = newvars; t != NOTECHVAR; t = t->nexttechvar)
			{
				if (namesame(t->varname, name) == 0) break;
				ltvar = t;
			}
			if (t == NOTECHVAR) continue;
			if (ltvar == NOTECHVAR) newvars = t->nexttechvar; else
				ltvar->nexttechvar = t->nexttechvar;
			if ((t->vartype&(VTYPE|VISARRAY)) == VSTRING) efree(t->sval);
			efree(t->varname);
			efree((char *)t);
			DiaLoadTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
			for(t = newvars; t != NOTECHVAR; t = t->nexttechvar) DiaStuffLine(3, t->varname);
			DiaSelectLine(3, -1);
			us_setcurrenttechvar(newvars);
			continue;
		}
	}
	if (itemHit == 13)
	{
		i = DiaGetCurLine(3);
		if (i < 0) itemHit = OK; else
			name = DiaGetScrollLine(3, i);
	}
	DiaDoneDialog();
	if (itemHit == OK || itemHit == 13)
	{
		j = 0;
		for(t = newvars; t != NOTECHVAR; t = t->nexttechvar) j++;
		if (j > 0)
		{
			varnames = (char **)emalloc(j * (sizeof (char *)), el_tempcluster);
			if (varnames == 0) return(0);
			j = 0;
			for(t = newvars; t != NOTECHVAR; t = t->nexttechvar)
			{
				(void)allocstring(&varnames[j], t->varname, el_tempcluster);
				j++;
				if (t->changed == 0) continue;
				switch (t->vartype&(VTYPE|VISARRAY))
				{
					case VINTEGER:
						(void)setval((INTBIG)el_curlib, VLIBRARY, t->varname, t->ival, VINTEGER);
						break;
					case VFLOAT:
						(void)setval((INTBIG)el_curlib, VLIBRARY, t->varname, castint(t->fval), VFLOAT);
						break;
					case VSTRING:
						(void)setval((INTBIG)el_curlib, VLIBRARY, t->varname, (INTBIG)t->sval, VSTRING);
						break;
					case VSTRING|VISARRAY:
						cmd[0] = "EMPTY";
						(void)setval((INTBIG)el_curlib, VLIBRARY, t->varname,
							(INTBIG)cmd, VSTRING|VISARRAY|(1<<VLENGTHSH));
						break;
				}
			}
			(void)setval((INTBIG)el_curlib, VLIBRARY, "EDTEC_variable_list",
				(INTBIG)varnames, VSTRING|VISARRAY|(j<<VLENGTHSH));
			for(i=0; i<j; i++) efree(varnames[i]);
			efree((char *)varnames);
		} else
		{
			if (getval((INTBIG)el_curlib, VLIBRARY, VSTRING|VISARRAY, "EDTEC_variable_list") != NOVARIABLE)
				(void)delval((INTBIG)el_curlib, VLIBRARY, "EDTEC_variable_list");
		}
	}
	if (itemHit == 13)
	{
		cmd[0] = "textedit";
		(void)initinfstr();
		(void)addstringtoinfstr("lib:~.");
		(void)addstringtoinfstr(name);
		(void)allocstring(&cmd[1], returninfstr(), el_tempcluster);
		cmd[2] = "header";
		(void)initinfstr();
		(void)addstringtoinfstr("Editing technology variable: ");
		(void)addstringtoinfstr(name);
		(void)allocstring(&cmd[3], returninfstr(), el_tempcluster);
		us_var(4, cmd);
		efree(cmd[1]);
		efree(cmd[3]);
	}
	paramstart[0] = "";
	return(1);
}

void us_setcurrenttechvar(TECHVAR *newvars)
{
	TECHVAR *t;
	INTSML i;
	char line[20], *name;

	DiaDimItem(13);      DiaSetText(12, "");   DiaNoEditControl(12);
	DiaDimItem(11);      DiaDimItem(10);
	DiaSetText(5, "");   DiaSetText(6, "");
	i = DiaGetCurLine(3);
	if (i >= 0)
	{
		DiaUnDimItem(11);
		name = DiaGetScrollLine(3, i);
		for(i=0; us_knownvars[i].varname != 0; i++)
			if (namesame(us_knownvars[i].varname, name) == 0) break;
		if (us_knownvars[i].varname != 0) DiaSetText(6, us_knownvars[i].description);
		for(t = newvars; t != NOTECHVAR; t = t->nexttechvar)
			if (namesame(t->varname, name) == 0) break;
		if (t != NOTECHVAR) switch (t->vartype&(VTYPE|VISARRAY))
		{
			case VINTEGER:
				DiaSetText(5, "Integer");
				DiaEditControl(12);
				(void)sprintf(line, "%ld", t->ival);
				DiaSetText(-12, line);
				break;
			case VFLOAT:
				DiaSetText(5, "Real");
				DiaEditControl(12);
				(void)sprintf(line, "%g", t->fval);
				DiaSetText(-12, line);
				break;
			case VSTRING:
				DiaSetText(5, "String");
				DiaEditControl(12);
				DiaSetText(-12, t->sval);
				break;
			case VSTRING|VISARRAY:
				DiaSetText(5, "Strings");
				DiaUnDimItem(13);
				break;
		}
	}

	i = DiaGetCurLine(7);
	if (i >= 0)
	{
		name = DiaGetScrollLine(7, i);
		for(i=0; us_knownvars[i].varname != 0; i++)
			if (namesame(us_knownvars[i].varname, name) == 0) break;
		if (us_knownvars[i].varname != 0)
		{
			DiaSetText(6, us_knownvars[i].description);
			switch (us_knownvars[i].vartype&(VTYPE|VISARRAY))
			{
				case VINTEGER:         DiaSetText(5, "Integer");   break;
				case VFLOAT:           DiaSetText(5, "Real");      break;
				case VSTRING:          DiaSetText(5, "String");    break;
				case VSTRING|VISARRAY: DiaSetText(5, "Strings");   break;
			}
		}
		DiaUnDimItem(10);
	}
}

/*
 * special case for the "SPICE options" menu
 */
INTSML us_spicedlog(char *paramstart[])
{
#if SIMAID & SIMSPICE
	INTSML itemHit, i, level, oldplease, dummy, execute, canexecute;
	REGISTER INTBIG j, l, spice_state;
	char *subparams[3], *pt, header[200], *dummyfile[1];
	static char *formatnames[3] = {"Spice 2", "Spice 3", "Hspice"};
	static char *levelnames[3] = {"1", "2", "3"};
	static char *executenames[5] = {"Don't Run SPICE", "Run SPICE", "Run SPICE Quietly",
		"Run SPICE, Read Output", "Run SPICE Quietly, Read Output"};
	static char qual[50];
	REGISTER VARIABLE *var;
	REGISTER NODEPROTO *np;
	REGISTER WINDOWPART *w;
	REGISTER EDITOR *ed;
	extern COMCOMP us_colorreadp;

	/* Display the SPICE options dialog box */
	if (DiaInitDialog(&us_spiceoptdialog) != 0) return(0);
	DiaSetPopup(3, 5, executenames);
	DiaSetPopup(4, 3, formatnames);
	DiaSetPopup(7, 3, levelnames);

	/* state of the execute flag */
	canexecute = us_graphicshas(CANRUNPROCESS);
	if (canexecute != 0)
	{
		var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_dontrun);
		if (var == NOVARIABLE) execute = 3; else
		{
			switch (var->addr)
			{
				case SIMRUNNO:        execute = 0;   break;
				case SIMRUNYES:       execute = 1;   break;
				case SIMRUNYESQ:      execute = 2;   break;
				case SIMRUNYESPARSE:  execute = 3;   break;
				case SIMRUNYESQPARSE: execute = 4;   break;
			}
		}
		DiaSetPopupEntry(3, execute);
	} else
	{
		DiaDimItem(3);
	}

	/* get the spice level */
	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_spice_level);
	if (var == NOVARIABLE) level = 1; else level = (INTSML)var->addr;
	DiaSetPopupEntry(7, (INTSML)(level-1));

	/* get miscellaneous state */
	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_spice_state);
	if (var != NOVARIABLE) spice_state = var->addr; else spice_state = 0;
	if ((spice_state&SPICENODENAMES) != 0) DiaSetControl(10, 1);
	if ((spice_state&SPICERESISTANCE) != 0) DiaSetControl(11, 1);
	switch (spice_state & SPICETYPE)
	{
		case SPICE2:      DiaSetPopupEntry(4, 0);   DiaDimItem(10);     break;
		case SPICE3:      DiaSetPopupEntry(4, 1);   DiaUnDimItem(10);   break;
		case SPICEHSPICE: DiaSetPopupEntry(4, 2);   DiaUnDimItem(10);   break;
	}

	/* get model and trailer cards */
	(void)initinfstr();
	(void)addstringtoinfstr("For technology: ");
	(void)addstringtoinfstr(el_curtech->techname);
	DiaSetText(20, returninfstr());
	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VSTRING, "SIM_spice_model_file");
	if (var != NOVARIABLE)
	{
		DiaSetText(16, (char *)var->addr);
		DiaSetControl(15, 1);
		DiaUnDimItem(21);
	} else
	{
		DiaSetControl(14, 1);
		DiaDimItem(21);
	}
	var = getval((INTBIG)el_curtech, VTECHNOLOGY, VSTRING, "SIM_spice_trailer_file");
	if (var != NOVARIABLE)
	{
		DiaSetText(19, (char *)var->addr);
		DiaSetControl(18, 1);
		DiaUnDimItem(22);
	} else
	{
		DiaSetControl(17, 1);
		DiaDimItem(22);
	}

	/* list of facets for model description files */
	DiaInitTextDialog(23, us_topoffacets, us_nextparse, us_nulldlogdone,
		0, SCSELMOUSE|SCSELKEY|SCREPORT);
	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
	{
		np->temp1 = 0;
		var = getval((INTBIG)np, VNODEPROTO, VSTRING, "SIM_spice_behave_file");
		if (var != NOVARIABLE)
			(void)allocstring((char **)&np->temp1, (char *)var->addr, el_tempcluster);
	}
	pt = DiaGetScrollLine(23, DiaGetCurLine(23));
	DiaSetControl(6, 1);   DiaSetControl(5, 0);
	DiaSetText(9, "");     DiaDimItem(8);
	np = getnodeproto(pt);
	if (np != NONODEPROTO)
	{
		var = getval((INTBIG)np, VNODEPROTO, VSTRING, "SIM_spice_behave_file");
		if (var != NOVARIABLE)
		{
			DiaSetControl(6, 0);   DiaSetControl(5, 1);
			DiaSetText(9, (char *)var->addr);   DiaUnDimItem(8);
		}
	}

	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL || itemHit == 25) break;

		if (itemHit == 4)
		{
			/* file format button */
			if (DiaGetPopupEntry(4) != 0) DiaUnDimItem(10); else DiaDimItem(10);
			continue;
		}

		if (itemHit == 10 || itemHit == 11)
		{
			/* check boxes */
			DiaSetControl(itemHit, (INTSML)(1-DiaGetControl(itemHit)));
			continue;
		}

		if (itemHit == 14 || itemHit == 15)
		{
			/* model cards button */
			DiaSetControl(14, 0);   DiaSetControl(15, 0);
			DiaSetControl(itemHit, 1);
			if (itemHit == 15)
			{
				DiaUnDimItem(21);   DiaUnDimItem(16);
				itemHit = 21;
			} else
			{
				DiaDimItem(21);   DiaDimItem(16);
				continue;
			}
		}
		if (itemHit == 21)
		{
			/* select model cards */
			oldplease = el_pleasestop;
			i = ttygetparam("spice/SPICE Model File", &us_colorreadp, 1, subparams);
			el_pleasestop = oldplease;
			if (i != 0 && subparams[0][0] != 0) DiaSetText(16, subparams[0]);
			if (*DiaGetText(16) == 0)
			{
				DiaSetControl(14, 1);   DiaSetControl(15, 0);
				DiaDimItem(21);         DiaDimItem(16);
			}
			continue;
		}

		if (itemHit == 17 || itemHit == 18)
		{
			/* trailer cards button */
			DiaSetControl(17, 0);   DiaSetControl(18, 0);
			DiaSetControl(itemHit, 1);
			if (itemHit == 18)
			{
				DiaUnDimItem(22);   DiaUnDimItem(19);
				itemHit = 22;
			} else
			{
				DiaDimItem(22);   DiaDimItem(19);
				continue;
			}
		}

		if (itemHit == 22)
		{
			/* select trailer cards */
			oldplease = el_pleasestop;
			i = ttygetparam("spice/SPICE Trailer File", &us_colorreadp, 1, subparams);
			el_pleasestop = oldplease;
			if (i != 0 && subparams[0][0] != 0) DiaSetText(19, subparams[0]);
			if (*DiaGetText(19) == 0)
			{
				DiaSetControl(17, 1);   DiaSetControl(18, 0);
				DiaDimItem(22);         DiaDimItem(19);
			}
			continue;
		}

		if (itemHit == 23)
		{
			/* selection of facets */
			DiaSetControl(6, 1);   DiaSetControl(5, 0);
			DiaSetText(9, "");     DiaDimItem(8);
			pt = DiaGetScrollLine(23, DiaGetCurLine(23));
			np = getnodeproto(pt);
			if (np != NONODEPROTO && np->temp1 != 0)
			{
				DiaSetControl(6, 0);   DiaSetControl(5, 1);
				DiaSetText(9, (char *)np->temp1);   DiaUnDimItem(8);
			}
			continue;
		}

		if (itemHit == 6 || itemHit == 5)
		{
			/* model for facet */
			DiaSetControl(6, 0);   DiaSetControl(5, 0);
			DiaSetControl(itemHit, 1);
			if (itemHit == 5)
			{
				DiaUnDimItem(8);   DiaUnDimItem(9);
				itemHit = 8;
			} else
			{
				DiaDimItem(8);   DiaDimItem(9);
				DiaSetText(9, "");
				pt = DiaGetScrollLine(23, DiaGetCurLine(23));
				np = getnodeproto(pt);
				if (np != NONODEPROTO)
				{
					if (np->temp1 != 0) efree((char *)np->temp1);
					np->temp1 = 0;
				}
				continue;
			}
		}

		if (itemHit == 8)
		{
			/* set model for facet */
			pt = DiaGetScrollLine(23, DiaGetCurLine(23));
			np = getnodeproto(pt);
			if (np == NONODEPROTO) continue;
			oldplease = el_pleasestop;
			i = ttygetparam("spice/Facet's Model File", &us_colorreadp, 1, subparams);
			el_pleasestop = oldplease;
			if (i != 0 && subparams[0][0] != 0)
			{
				DiaSetText(9, subparams[0]);
				if (np->temp1 != 0) efree((char *)np->temp1);
				(void)allocstring((char **)&np->temp1, subparams[0], el_tempcluster);
			} else
			{
				DiaSetControl(6, 1);   DiaSetControl(5, 0);
				DiaDimItem(8);         DiaDimItem(9);
			}
			continue;
		}
	}

	if (itemHit != CANCEL)  /* now update the values */
	{
		if (canexecute != 0)
		{
			i = DiaGetPopupEntry(3);
			if (i != execute)
			{
				switch (i)
				{
					case 0: execute = SIMRUNNO;          break;
					case 1: execute = SIMRUNYES;         break;
					case 2: execute = SIMRUNYESQ;        break;
					case 3: execute = SIMRUNYESPARSE;    break;
					case 4: execute = SIMRUNYESQPARSE;   break;
				}
				(void)setvalkey((INTBIG)sim_aid, VAID, sim_dontrun, execute, VINTEGER);
			}
		}

		level = DiaGetPopupEntry(7) + 1;
		(void)setvalkey((INTBIG)sim_aid, VAID, sim_spice_level, level, VINTEGER);

		if (DiaGetControl(10) != 0) spice_state |= SPICENODENAMES; else
			spice_state &= ~SPICENODENAMES;
		if (DiaGetControl(11) != 0) spice_state |= SPICERESISTANCE; else
			spice_state &= ~SPICERESISTANCE;
		switch (DiaGetPopupEntry(4))
		{
			case 0: spice_state = (spice_state & ~SPICETYPE) | SPICE2;        break;
			case 1: spice_state = (spice_state & ~SPICETYPE) | SPICE3;        break;
			case 2: spice_state = (spice_state & ~SPICETYPE) | SPICEHSPICE;   break;
		}
		(void)setvalkey((INTBIG)sim_aid, VAID, sim_spice_state, spice_state, VINTEGER);

		if (DiaGetControl(15) != 0)
		{
			/* set model cards */
			(void)setval((INTBIG)el_curtech, VTECHNOLOGY, "SIM_spice_model_file",
				(INTBIG)DiaGetText(16), VSTRING);
		} else
		{
			/* remove model cards */
			if (getval((INTBIG)el_curtech, VTECHNOLOGY, VSTRING, "SIM_spice_model_file") != NOVARIABLE)
				(void)delval((INTBIG)el_curtech, VTECHNOLOGY, "SIM_spice_model_file");
		}

		if (DiaGetControl(18) != 0)
		{
			/* set trailer cards */
			(void)setval((INTBIG)el_curtech, VTECHNOLOGY, "SIM_spice_trailer_file",
				(INTBIG)DiaGetText(19), VSTRING);
		} else
		{
			/* remove trailer cards */
			if (getval((INTBIG)el_curtech, VTECHNOLOGY, VSTRING, "SIM_spice_trailer_file") != NOVARIABLE)
				(void)delval((INTBIG)el_curtech, VTECHNOLOGY, "SIM_spice_trailer_file");
		}
		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
		{
			var = getval((INTBIG)np, VNODEPROTO, VSTRING, "SIM_spice_behave_file");
			if (var != NOVARIABLE)
			{
				if (np->temp1 == 0)
					(void)delval((INTBIG)np, VNODEPROTO, "SIM_spice_behave_file"); else
				{
					if (strcmp((char *)np->temp1, (char *)var->addr) != 0)
						(void)setval((INTBIG)np, VNODEPROTO, "SIM_spice_behave_file", (INTBIG)np->temp1, VSTRING);
				}
			} else if (np->temp1 != 0)
				(void)setval((INTBIG)np, VNODEPROTO, "SIM_spice_behave_file", (INTBIG)np->temp1, VSTRING);
			if (np->temp1 != 0) efree((char *)np->temp1);
		}
	}
	DiaDoneDialog();
	if (itemHit == 25)
	{
		/* now edit the model cards */
		sprintf(qual, "SIM_spice_header_level%d", level);
		sprintf(header, "Level %d SPICE Model cards for %s", level, el_curtech->techname);

		var = getval((INTBIG)el_curtech, VTECHNOLOGY, -1, qual);
		if (var == NOVARIABLE)
		{
			dummyfile[0] = "";
			var = setval((INTBIG)el_curtech, VTECHNOLOGY, qual, (INTBIG)dummyfile,
				VSTRING|VISARRAY|(1<<VLENGTHSH));
			if (var == NOVARIABLE)
			{
				us_abortcommand("Cannot create %s on the technology", qual);
				return(0);
			}
		} else
			var->type &= ~VDONTSAVE;

		/* get a new window, put an editor in it */
		w = us_wantnewwindow(0);
		if (w == NOWINDOWPART) return(0);
		if (us_makeeditor(w, header, &dummy, &dummy) == NOWINDOWPART) return(0);
		ed = w->editor;
		ed->editobjqual = qual;
		ed->editobjaddr = (char *)el_curtech;
		ed->editobjtype = VTECHNOLOGY;
		ed->editobjvar = var;
		us_suspendgraphics(w);

		l = (INTSML)getlength(var);
		for(j=0; j<l; j++)
		{
			(void)initinfstr();
			(void)addstringtoinfstr(describevariable(var, (INTSML)j, -1));
			us_addline(w, j, returninfstr());
		}
		us_resumegraphics(w);
		w->changehandler = us_varchanges;
	}
	paramstart[0] = "x";	/* passed back to menu handler */
	return(1);
#else
	ttyputerr("No SPICE simulation");
	return(1);
#endif
}

/*
 * special case for the "Verilog options" menu
 */
INTSML us_verilogdlog(char *paramstart[])
{
#if SIMAID & SIMVERILOG
	INTSML itemHit, i, oldplease;
	INTBIG verilog_state;
	char *subparams[3], *pt;
	REGISTER VARIABLE *var;
	REGISTER NODEPROTO *np;
	extern COMCOMP us_colorreadp;

	/* Display the Verilog options dialog box */
	if (DiaInitDialog(&us_verilogoptdialog) != 0) return(0);

	/* get miscellaneous state */
	var = getvalkey((INTBIG)sim_aid, VAID, VINTEGER, sim_verilog_state);
	if (var != NOVARIABLE) verilog_state = var->addr; else verilog_state = 0;
	if ((verilog_state&VERILOGUSEASSIGN) != 0) DiaSetControl(7, 1);

	/* list of facets for model description files */
	DiaInitTextDialog(8, us_topoffacets, us_nextparse, us_nulldlogdone,
		0, SCSELMOUSE|SCSELKEY|SCREPORT);
	for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
	{
		np->temp1 = 0;
		var = getval((INTBIG)np, VNODEPROTO, VSTRING, "SIM_verilog_behave_file");
		if (var != NOVARIABLE)
			(void)allocstring((char **)&np->temp1, (char *)var->addr, el_tempcluster);
	}
	pt = DiaGetScrollLine(8, DiaGetCurLine(8));
	DiaSetControl(4, 1);   DiaSetControl(3, 0);
	DiaSetText(6, "");     DiaDimItem(5);
	np = getnodeproto(pt);
	if (np != NONODEPROTO)
	{
		var = getval((INTBIG)np, VNODEPROTO, VSTRING, "SIM_verilog_behave_file");
		if (var != NOVARIABLE)
		{
			DiaSetControl(4, 0);   DiaSetControl(3, 1);
			DiaSetText(6, (char *)var->addr);   DiaUnDimItem(5);
		}
	}

	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;

		if (itemHit == 7)
		{
			/* use ASSIGN statement */
			DiaSetControl(itemHit, (INTSML)(1-DiaGetControl(itemHit)));
			continue;
		}

		if (itemHit == 8)
		{
			/* selection of facets */
			DiaSetControl(4, 1);   DiaSetControl(3, 0);
			DiaSetText(6, "");     DiaDimItem(5);
			pt = DiaGetScrollLine(8, DiaGetCurLine(8));
			np = getnodeproto(pt);
			if (np != NONODEPROTO && np->temp1 != 0)
			{
				DiaSetControl(4, 0);   DiaSetControl(3, 1);
				DiaSetText(6, (char *)np->temp1);   DiaUnDimItem(5);
			}
			continue;
		}

		if (itemHit == 3 || itemHit == 4)
		{
			/* model for facet */
			DiaSetControl(3, 0);   DiaSetControl(4, 0);
			DiaSetControl(itemHit, 1);
			if (itemHit == 3)
			{
				DiaUnDimItem(5);   DiaUnDimItem(6);
				itemHit = 5;
			} else
			{
				DiaDimItem(5);   DiaDimItem(6);
				DiaSetText(6, "");
				pt = DiaGetScrollLine(8, DiaGetCurLine(8));
				np = getnodeproto(pt);
				if (np != NONODEPROTO)
				{
					if (np->temp1 != 0) efree((char *)np->temp1);
					np->temp1 = 0;
				}
				continue;
			}
		}

		if (itemHit == 5)
		{
			/* set model for facet */
			pt = DiaGetScrollLine(8, DiaGetCurLine(8));
			np = getnodeproto(pt);
			if (np == NONODEPROTO) continue;
			oldplease = el_pleasestop;
			i = ttygetparam("verilog/Facet's Model File", &us_colorreadp, 1, subparams);
			el_pleasestop = oldplease;
			if (i != 0 && subparams[0][0] != 0)
			{
				DiaSetText(6, subparams[0]);
				if (np->temp1 != 0) efree((char *)np->temp1);
				(void)allocstring((char **)&np->temp1, subparams[0], el_tempcluster);
			} else
			{
				DiaSetControl(4, 1);   DiaSetControl(3, 0);
				DiaDimItem(5);         DiaDimItem(6);
			}
			continue;
		}
	}

	if (itemHit != CANCEL)  /* now update the values */
	{
		if (DiaGetControl(7) != 0) verilog_state |= VERILOGUSEASSIGN; else
			verilog_state &= ~VERILOGUSEASSIGN;
		(void)setvalkey((INTBIG)sim_aid, VAID, sim_verilog_state, verilog_state, VINTEGER);

		for(np = el_curlib->firstnodeproto; np != NONODEPROTO; np = np->nextnodeproto)
		{
			var = getval((INTBIG)np, VNODEPROTO, VSTRING, "SIM_verilog_behave_file");
			if (var != NOVARIABLE)
			{
				if (np->temp1 == 0)
					(void)delval((INTBIG)np, VNODEPROTO, "SIM_verilog_behave_file"); else
				{
					if (strcmp((char *)np->temp1, (char *)var->addr) != 0)
						(void)setval((INTBIG)np, VNODEPROTO, "SIM_verilog_behave_file",
							(INTBIG)np->temp1, VSTRING);
				}
			} else if (np->temp1 != 0)
				(void)setval((INTBIG)np, VNODEPROTO, "SIM_verilog_behave_file",
					(INTBIG)np->temp1, VSTRING);
			if (np->temp1 != 0) efree((char *)np->temp1);
		}
	}
	DiaDoneDialog();
	paramstart[0] = "x";	/* passed back to menu handler */
	return(1);
#else
	ttyputerr("No Verilog simulation");
	return(1);
#endif
}

/*
 * special case for the "print options" menu
 * plot entire facet       = 4 (radio)
 * focus on highlighted    = 3 (radio)
 * encapsulated postscript = 5 (check box)
 * date in corner          = 6 (check box)
 * HPGL                    = 7 (radio)
 * HPGL/2                  = 8 (radio)
 * HPGL/2 plot fills page  = 9 (radio)
 * HPGL/2 plot fixed at    = 10 (radio)
 * HPGL/2 plot scale       = 11 (edit text)
 * synchronize to file     = 13 (check box)
 * EPS scale label         = 15 (stat text)
 * EPS scale               = 16 (edit text)
 * Facet                   = 18 (stat text)
 * Divider                 = 19 (stat text)
 * Color postscript        = 21 (check box)
 * Divider                 = 22 (stat text)
 * Printer                 = 24 (radio)
 * Plotter                 = 25 (radio)
 * Printer width           = 27 (edit text)
 * Plotter width           = 29 (edit text)
 * Printer height          = 31 (edit text)
 * Rotate output           = 32 (check)
 * Print margin            = 34 (edit text)
 */
INTSML us_plotoptionsdlog(char *paramstart[])
{
	INTSML itemHit;
	REGISTER INTBIG scale, i, oldplease, state, wid, hei;
	REGISTER VARIABLE *var;
	REGISTER NODEPROTO *np;
	REGISTER char *pt;
	char buf[50], *subparams[3];
	extern COMCOMP us_colorwritep;

	/* display the print options dialog box */
	if (DiaInitDialog(&us_printingoptdialog) != 0) return(0);
	var = getvalkey((INTBIG)io_aid, VAID, VINTEGER, io_state);
	if (var != NOVARIABLE) state = var->addr; else state = 0;
	if ((state&PLOTDATES) != 0) DiaSetControl(6, 1);
	if ((state&PLOTFOCUS) != 0) DiaSetControl(3, 1); else
		DiaSetControl(4, 1);
	if ((state&EPSPSCRIPT) != 0) DiaSetControl(5, 1);
	if ((state&PSCOLOR) != 0) DiaSetControl(21, 1);
	if ((state&PSROTATE) != 0) DiaSetControl(32, 1);
	var = getval((INTBIG)io_aid, VAID, VFRACT, "IO_postscript_width");
	if (var == NOVARIABLE) wid = muldiv(DEFAULTPSWIDTH, WHOLE, 75); else
		wid = var->addr;
	DiaSetText(27, frtoa(wid));
	DiaSetText(29, frtoa(wid));
	var = getval((INTBIG)io_aid, VAID, VFRACT, "IO_postscript_height");
	if (var == NOVARIABLE) hei = muldiv(DEFAULTPSHEIGHT, WHOLE, 75); else
		hei = var->addr;
	DiaSetText(31, frtoa(hei));
	var = getval((INTBIG)io_aid, VAID, VFRACT, "IO_postscript_margin");
	if (var == NOVARIABLE) i = muldiv(DEFAULTPSMARGIN, WHOLE, 75); else
		i = var->addr;
	DiaSetText(34, frtoa(i));
	if ((state&PSPLOTTER) != 0)
	{
		DiaSetControl(25, 1);
		DiaDimItem(26);
		DiaDimItem(27);
		DiaDimItem(30);
		DiaDimItem(31);
	} else
	{
		DiaSetControl(24, 1);
		DiaDimItem(28);
		DiaDimItem(29);
	}
	np = el_curlib->curnodeproto;
	DiaDimItem(15);
	DiaDimItem(16);
	if (np == NONODEPROTO)
	{
		DiaDimItem(13);
		DiaDimItem(17);
	} else
	{
		DiaSetText(18, describenodeproto(np));
		DiaUnDimItem(17);
		if ((state&EPSPSCRIPT) != 0)
		{
			DiaUnDimItem(15);
			DiaUnDimItem(16);
			var = getvalkey((INTBIG)np, VNODEPROTO, VFRACT, io_postscriptepsscale);
			if (var != NOVARIABLE)
			{
				DiaSetText(16, frtoa(var->addr));
			}
		}
		DiaUnDimItem(13);
		var = getvalkey((INTBIG)np, VNODEPROTO, VSTRING, io_postscriptfilename);
		if (var != NOVARIABLE)
		{
			DiaSetControl(13, 1);
			DiaSetText(14, (char *)var->addr);
		}
	}
	if ((state&HPGL2) != 0)
	{
		DiaSetControl(8, 1);
		DiaUnDimItem(9);   DiaUnDimItem(10);   DiaUnDimItem(12);
		DiaEditControl(11);
		var = getval((INTBIG)io_aid, VAID, VINTEGER, "IO_hpgl2_scale");
		if (var == NOVARIABLE)
		{
			DiaSetControl(9, 1);
			DiaSetText(11, "20");
		} else
		{
			DiaSetControl(10, 1);
			(void)sprintf(buf, "%ld", var->addr);
			DiaSetText(11, buf);
		}
	} else
	{
		DiaSetControl(7, 1);
		DiaSetControl(9, 1);
		DiaSetText(11, "20");
		DiaDimItem(9);   DiaDimItem(10);   DiaDimItem(12);
		DiaNoEditControl(11);
	}

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK) break;
		if (itemHit == 5 || itemHit == 6 || itemHit == 13 || itemHit == 21 || itemHit == 32)
		{
			i = 1 - DiaGetControl(itemHit);
			DiaSetControl(itemHit, (INTSML)i);
			if (itemHit == 5)
			{
				if (i == 0)
				{
					DiaDimItem(15);
					DiaDimItem(16);
				} else
				{
					DiaUnDimItem(15);
					DiaUnDimItem(16);
				}
			}
			if (itemHit == 13)
			{
				if (i != 0)
				{
					/* select a file name to synchronize with this facet */
					oldplease = el_pleasestop;
					i = ttygetparam("ps/PostScript file", &us_colorwritep, 1, subparams);
					el_pleasestop = (INTSML)oldplease;
					if (i != 0 && subparams[0][0] != 0)
					{
						DiaUnDimItem(14);
						DiaSetText(14, subparams[0]);
					} else
					{
						DiaSetControl(13, 0);
					}
				} else
				{
					DiaDimItem(14);
				}
			}
			continue;
		}
		if (itemHit == 3 || itemHit == 4)
		{
			DiaSetControl(3, 0);
			DiaSetControl(4, 0);
			DiaSetControl(itemHit, 1);
			continue;
		}
		if (itemHit == 7)
		{
			DiaSetControl(7, 1);   DiaSetControl(8, 0);
			DiaDimItem(9);   DiaDimItem(10);   DiaDimItem(12);
			DiaNoEditControl(11);
			continue;
		}
		if (itemHit == 8)
		{
			DiaSetControl(7, 0);   DiaSetControl(8, 1);
			DiaUnDimItem(9);   DiaUnDimItem(10);   DiaUnDimItem(12);
			DiaEditControl(11);
			continue;
		}
		if (itemHit == 9 || itemHit == 10)
		{
			DiaSetControl(9, 0);
			DiaSetControl(10, 0);
			DiaSetControl(itemHit, 1);
			continue;
		}
		if (itemHit == 24 || itemHit == 25)
		{
			DiaSetControl(24, 0);
			DiaSetControl(25, 0);
			DiaSetControl(itemHit, 1);
			if (itemHit == 25)
			{
				DiaUnDimItem(28);
				DiaUnDimItem(29);
				DiaDimItem(26);
				DiaDimItem(27);
				DiaDimItem(30);
				DiaDimItem(31);
			} else
			{
				DiaUnDimItem(26);
				DiaUnDimItem(27);
				DiaUnDimItem(30);
				DiaUnDimItem(31);
				DiaDimItem(28);
				DiaDimItem(29);
			}
			continue;
		}
	}

	paramstart[0] = "";
	if (itemHit != CANCEL)
	{
		if (DiaGetControl(3) != 0) state |= PLOTFOCUS; else state &= ~PLOTFOCUS;
		if (DiaGetControl(5) != 0) state |= EPSPSCRIPT; else state &= ~EPSPSCRIPT;
		if (DiaGetControl(21) != 0) state |= PSCOLOR; else state &= ~PSCOLOR;
		if (DiaGetControl(32) != 0) state |= PSROTATE; else state &= ~PSROTATE;
		if (DiaGetControl(6) != 0) state |= PLOTDATES; else state &= ~PLOTDATES;
		if (DiaGetControl(8) != 0) state |= HPGL2; else state &= ~HPGL2;
		if (DiaGetControl(24) != 0)
		{
			/* printed */
			state &= ~PSPLOTTER;
			pt = DiaGetText(27);
			(void)setval((INTBIG)io_aid, VAID, "IO_postscript_width", atofr(pt), VFRACT);
			pt = DiaGetText(31);
			(void)setval((INTBIG)io_aid, VAID, "IO_postscript_height", atofr(pt), VFRACT);
		} else
		{
			state |= PSPLOTTER;
			pt = DiaGetText(29);
			(void)setval((INTBIG)io_aid, VAID, "IO_postscript_width", atofr(pt), VFRACT);
		}
		(void)setvalkey((INTBIG)io_aid, VAID, io_state, state, VINTEGER);
		pt = DiaGetText(34);
		(void)setval((INTBIG)io_aid, VAID, "IO_postscript_margin", atofr(pt), VFRACT);
		if (np != NONODEPROTO)
		{
			if (DiaGetControl(13) != 0)
			{
				/* add a synchronization file */
				pt = DiaGetText(14);
				(void)setvalkey((INTBIG)np, VNODEPROTO, io_postscriptfilename,
					(INTBIG)pt, VSTRING);
			} else
			{
				/* remove a synchronization file */
				if (getvalkey((INTBIG)np, VNODEPROTO, VSTRING, io_postscriptfilename) != NOVARIABLE)
					delvalkey((INTBIG)np, VNODEPROTO, io_postscriptfilename);
			}
			if (DiaGetControl(5) != 0)
			{
				pt = DiaGetText(16);
				(void)setvalkey((INTBIG)np, VNODEPROTO, io_postscriptepsscale,
					atofr(pt), VFRACT);
			}
		}
		if ((state&HPGL2) != 0)
		{
			if (DiaGetControl(9) != 0)
			{
				if (getval((INTBIG)io_aid, VAID, VINTEGER, "IO_hpgl2_scale") != NOVARIABLE)
					(void)delval((INTBIG)io_aid, VAID, "IO_hpgl2_scale");
			} else
			{
				scale = myatoi(DiaGetText(11));
				if (scale <= 0) scale = 1;
				(void)setval((INTBIG)io_aid, VAID, "IO_hpgl2_scale", scale, VINTEGER);
			}
		}
	}
	DiaDoneDialog();
	return(1);
}

/*
 * routine to move dialog "dia" to a place close to object "geom" in the current window
 */
void us_movedialogtonode(DIALOG *dia, GEOM *geom)
{
	REGISTER INTBIG x, y, wid, hei;
	INTSML swid, shei;

	if (geom == NOGEOM) return;
	if (el_curwindowpart == NOWINDOWPART) return;
	wid = dia->windowRect.right - dia->windowRect.left;
	hei = dia->windowRect.bottom - dia->windowRect.top;

	/* see which side the dialog goes on */
	x = applyxscale(el_curwindowpart, geom->highx-el_curwindowpart->screenlx) + el_curwindowpart->uselx;
	us_getwindowsize(el_curwindowpart->frame, &swid, &shei);
	if (x + wid > swid)
	{
		/* attach on left side */
		x = applyxscale(el_curwindowpart, geom->lowx-el_curwindowpart->screenlx) + el_curwindowpart->uselx;
		dia->windowRect.left = (INTSML)(x - wid);   dia->windowRect.right = (INTSML)x;
	} else
	{
		/* attach on right side */
		dia->windowRect.left = (INTSML)x;   dia->windowRect.right = (INTSML)(x + wid);
	}

	y = applyyscale(el_curwindowpart, geom->highy-el_curwindowpart->screenly) + el_curwindowpart->usely;
	if (shei-y-hei <= 39)
	{
		/* attach on bottom side */
		y = applyyscale(el_curwindowpart, geom->lowy-el_curwindowpart->screenly) + el_curwindowpart->usely;
		dia->windowRect.bottom = (INTSML)(shei - y + hei);
		dia->windowRect.top = (INTSML)(shei - y);
	} else
	{
		/* attach on top side */
		dia->windowRect.bottom = (INTSML)(shei - y);
		dia->windowRect.top = (INTSML)(shei - y - hei);
	}
}

/*
 * special case for the "resistance" menu
 * resistance value   = 3 (edit)
 * units              = 4 (popup)
 * More...            = 5 (button)
 */
INTSML us_resistancedlog(char *prompt, char *paramstart[], char *initial)
{
	INTSML itemHit, i;
	static char *resnames[] = {"Ohms", "Kilo-ohms", "Mega-ohms", "Giga-Ohms"};
	REGISTER HIGHLIGHT *high;
	char line[70];

	/* if an initial value is given, search for highlighted node and move dialog to it */
	if (initial != 0)
	{
		high = us_getonehighlight();
		if (high != NOHIGHLIGHT) us_movedialogtonode(&us_resistancedialog, high->fromgeom);
	}

	/* display the resistance dialog box */
	if (namesame(prompt, "ccvs") == 0) (void)strcpy(line, "CCVS transresistance"); else
		(void)sprintf(line, "%s resistance", prompt);
	us_resistancedialog.movable = line;
	if (initial != 0) us_resistancedialog.items = 5; else us_resistancedialog.items = 4;
	if (DiaInitDialog(&us_resistancedialog) != 0) return(0);
	DiaSetPopup(4, 4, resnames);
	if (initial == 0) DiaSetText(3, "100"); else
	{
		i = strlen(initial);
		if (i > 0 && namesame(&initial[i-1], "K") == 0)
		{
			DiaSetPopupEntry(4, 1);
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'K';
		} else if (i > 2 && namesame(&initial[i-3], "MEG") == 0)
		{
			DiaSetPopupEntry(4, 2);
			initial[i-3] = 0;
			DiaSetText(3, initial);
			initial[i-3] = 'M';
		} else if (i > 0 && namesame(&initial[i-1], "G") == 0)
		{
			DiaSetPopupEntry(4, 3);
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'G';
		} else DiaSetText(3, initial);
	}

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK || itemHit == 5) break;
	}

	(void)initinfstr();
	(void)addstringtoinfstr(DiaGetText(3));
	i = DiaGetPopupEntry(4);
	switch (i)
	{
		case 1: (void)addstringtoinfstr("K");     break;
		case 2: (void)addstringtoinfstr("MEG");   break;
		case 3: (void)addstringtoinfstr("G");     break;
	}
	paramstart[0] = returninfstr();
	DiaDoneDialog();
	if (itemHit == OK) return(1);
	if (itemHit == 5) (void)us_showdlog(paramstart, 0);
	return(0);
}

/*
 * special case for the "capacitance" menu
 * capacitance value   = 3 (edit)
 * units               = 4 (popup)
 * More...             = 5 (button)
 */
INTSML us_capacitancedlog(char *paramstart[], char *initial)
{
	INTSML itemHit, i;
	static char *capnames[] = {"Femto-farads", "Pico-farads", "Micro-farads", "Milli-farads",
		"Farads"};
	REGISTER HIGHLIGHT *high;

	/* if an initial value is given, search for highlighted node and move dialog to it */
	if (initial != 0)
	{
		high = us_getonehighlight();
		if (high != NOHIGHLIGHT) us_movedialogtonode(&us_capacitancedialog, high->fromgeom);
	}

	/* display the capacitance dialog box */
	if (initial != 0) us_capacitancedialog.items = 5; else us_capacitancedialog.items = 4;
	if (DiaInitDialog(&us_capacitancedialog) != 0) return(0);
	DiaSetPopup(4, 5, capnames);
	if (initial == 0)
	{
		DiaSetText(3, "100");
		DiaSetPopupEntry(4, 3);
	} else
	{
		i = strlen(initial);
		if (i > 0 && namesame(&initial[i-1], "F") == 0)
		{
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'F';
		} else if (i > 0 && namesame(&initial[i-1], "P") == 0)
		{
			DiaSetPopupEntry(4, 1);
			initial[i-3] = 0;
			DiaSetText(3, initial);
			initial[i-3] = 'P';
		} else if (i > 0 && namesame(&initial[i-1], "U") == 0)
		{
			DiaSetPopupEntry(4, 2);
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'U';
		} else if (i > 0 && namesame(&initial[i-1], "M") == 0)
		{
			DiaSetPopupEntry(4, 3);
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'M';
		} else
		{
			DiaSetPopupEntry(4, 4);
			DiaSetText(3, initial);
		}
	}

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK || itemHit == 5) break;
	}

	(void)initinfstr();
	(void)addstringtoinfstr(DiaGetText(3));
	i = DiaGetPopupEntry(4);
	switch (i)
	{
		case 0: (void)addstringtoinfstr("F");   break;
		case 1: (void)addstringtoinfstr("P");   break;
		case 2: (void)addstringtoinfstr("U");   break;
		case 3: (void)addstringtoinfstr("M");   break;
	}
	paramstart[0] = returninfstr();
	DiaDoneDialog();
	if (itemHit == OK) return(1);
	if (itemHit == 5) (void)us_showdlog(paramstart, 0);
	return(0);
}

/*
 * special case for the "inductance" menu
 * inductance value   = 3 (edit)
 * units              = 4 (popup)
 * More...            = 5 (button)
 */
INTSML us_inductancedlog(char *paramstart[], char *initial)
{
	INTSML itemHit, i;
	static char *indnames[] = {"Micro-henrys", "Milli-henrys", "Henrys"};
	REGISTER HIGHLIGHT *high;

	/* if an initial value is given, search for highlighted node and move dialog to it */
	if (initial != 0)
	{
		high = us_getonehighlight();
		if (high != NOHIGHLIGHT) us_movedialogtonode(&us_inductancedialog, high->fromgeom);
	}

	/* display the inductance dialog box */
	if (initial != 0) us_inductancedialog.items = 5; else us_inductancedialog.items = 4;
	if (DiaInitDialog(&us_inductancedialog) != 0) return(0);
	DiaSetPopup(4, 3, indnames);
	if (initial == 0)
	{
		DiaSetText(3, "100");
		DiaSetPopupEntry(4, 2);
	} else
	{
		i = strlen(initial);
		if (i > 0 && namesame(&initial[i-1], "U") == 0)
		{
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'U';
		} else if (i > 0 && namesame(&initial[i-1], "M") == 0)
		{
			DiaSetPopupEntry(4, 1);
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'M';
		} else
		{
			DiaSetPopupEntry(4, 2);
			DiaSetText(3, initial);
		}
	}

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK || itemHit == 5) break;
	}

	(void)initinfstr();
	(void)addstringtoinfstr(DiaGetText(3));
	i = DiaGetPopupEntry(4);
	switch (i)
	{
		case 0: (void)addstringtoinfstr("U");   break;
		case 1: (void)addstringtoinfstr("M");   break;
	}
	paramstart[0] = returninfstr();
	DiaDoneDialog();
	if (itemHit == OK) return(1);
	if (itemHit == 5) (void)us_showdlog(paramstart, 0);
	return(0);
}

/*
 * special case for the "VCCS Transconductance" menu
 * siemens value       = 3 (edit)
 * units               = 4 (popup)
 * More...             = 5 (button)
 */
INTSML us_vccsdlog(char *paramstart[], char *initial)
{
	INTSML itemHit, i;
	static char *sienames[] = {"Micro-siemens", "Milli-siemens", "Siemens"};
	REGISTER HIGHLIGHT *high;

	/* if an initial value is given, search for highlighted node and move dialog to it */
	if (initial != 0)
	{
		high = us_getonehighlight();
		if (high != NOHIGHLIGHT) us_movedialogtonode(&us_vccsdialog, high->fromgeom);
	}

	/* display the siemens dialog box */
	if (initial != 0) us_vccsdialog.items = 5; else us_vccsdialog.items = 4;
	if (DiaInitDialog(&us_vccsdialog) != 0) return(0);
	DiaSetPopup(4, 3, sienames);
	if (initial == 0)
	{
		DiaSetText(3, "100");
		DiaSetPopupEntry(4, 2);
	} else
	{
		i = strlen(initial);
		if (i > 0 && namesame(&initial[i-1], "U") == 0)
		{
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'U';
		} else if (i > 0 && namesame(&initial[i-1], "M") == 0)
		{
			DiaSetPopupEntry(4, 1);
			initial[i-1] = 0;
			DiaSetText(3, initial);
			initial[i-1] = 'M';
		} else
		{
			DiaSetPopupEntry(4, 2);
			DiaSetText(3, initial);
		}
	}

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK || itemHit == 5) break;
	}

	(void)initinfstr();
	(void)addstringtoinfstr(DiaGetText(3));
	i = DiaGetPopupEntry(4);
	switch (i)
	{
		case 0: (void)addstringtoinfstr("U");   break;
		case 1: (void)addstringtoinfstr("M");   break;
	}
	paramstart[0] = returninfstr();
	DiaDoneDialog();
	if (itemHit == OK) return(1);
	if (itemHit == 5) (void)us_showdlog(paramstart, 0);
	return(0);
}

/*
 * special case for the "area" menu
 * area value           = 3 (edit)
 * More...              = 4 (button)
 */
INTSML us_areadlog(char *prompt, char *paramstart[], char *initial)
{
	INTSML itemHit;
	static char line[80];
	REGISTER HIGHLIGHT *high;

	/* if an initial value is given, search for highlighted node and move dialog to it */
	if (initial != 0)
	{
		high = us_getonehighlight();
		if (high != NOHIGHLIGHT) us_movedialogtonode(&us_areadialog, high->fromgeom);
	}

	/* display the area dialog box */
	(void)sprintf(line, "%s area", prompt);
	us_areadialog.movable = line;
	if (initial != 0) us_areadialog.items = 4; else us_areadialog.items = 3;
	if (DiaInitDialog(&us_areadialog) != 0) return(0);
	if (initial == 0) DiaSetText(3, "10"); else
		DiaSetText(3, initial);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK || itemHit == 4) break;
	}

	strcpy(line, DiaGetText(3));
	paramstart[0] = line;
	DiaDoneDialog();
	if (itemHit == OK) return(1);
	if (itemHit == 4) (void)us_showdlog(paramstart, 0);
	return(0);
}

/*
 * special case for the "gain" menu
 * area value           = 3 (edit)
 * units                = 4 (popup)
 * More...              = 5 (button)
 */
INTSML us_gaindlog(char *prompt, char *paramstart[], char *initial)
{
	INTSML itemHit;
	static char line[50];
	REGISTER HIGHLIGHT *high;

	/* if an initial value is given, search for highlighted node and move dialog to it */
	if (initial != 0)
	{
		high = us_getonehighlight();
		if (high != NOHIGHLIGHT) us_movedialogtonode(&us_gaindialog, high->fromgeom);
	}

	/* display the gain dialog box */
	(void)sprintf(line, "%s gain", prompt);
	us_gaindialog.movable = line;
	if (initial != 0) us_gaindialog.items = 5; else us_gaindialog.items = 4;
	if (DiaInitDialog(&us_gaindialog) != 0) return(0);
	if (initial == 0) DiaSetText(3, "10"); else DiaSetText(3, initial);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK || itemHit == 5) break;
	}

	paramstart[0] = us_putintoinfstr(DiaGetText(3));
	DiaDoneDialog();
	if (itemHit == OK) return(1);
	if (itemHit == 5) (void)us_showdlog(paramstart, 0);
	return(0);
}

/*
 * special case for the "source" menu
 * source type          = 3 (popup)
 * SPICE card           = 6 (edit text)
 * More...              = 7 (button)
 */
INTSML us_sourcedlog(char *paramstart[], char *initial)
{
	INTSML itemHit, sourcetype;
	char *extra;
	REGISTER NODEINST *ni;
	enum {kSourceUnknown=0, kSourceVoltage, kSourceCurrent, kSourceCurrentMeter,
		kSourceTransient, kSourceDC, kSourceAC, kSourceNodeSet, kSourceExtension,
		kSourceBulk, kNodeSpecial};
	static char *sourcetypes[] = {"Unknown", "Voltage Source", "Current Source",
		"Current Meter", "Transient Analysis", "DC Analysis", "AC Analysis",
		"Node Set", "Extension", "Bulk", "Special"};

	/* if an initial value is given, search for highlighted node and move dialog to it */
	ni = (NODEINST *)us_getobject(OBJNODEINST, 1);
	if (ni == NONODEINST)
	{
		us_abortcommand("Select a source node first");
		return(0);
	}
	if (initial != 0)
		us_movedialogtonode(&us_sourcedialog, ni->geom);

	/* display the gain dialog box */
	if (DiaInitDialog(&us_sourcedialog) != 0) return(0);

	switch (nodefunction(ni, &extra))
	{
		case NPSOURCE:   sourcetype = kSourceUnknown;        break;
		case NPSOURCEV:  sourcetype = kSourceVoltage;        break;
		case NPSOURCEC:  sourcetype = kSourceCurrent;        break;
		case NPSOURCECM: sourcetype = kSourceCurrentMeter;   break;
		case NPSOURCET:  sourcetype = kSourceTransient;      break;
		case NPSOURCEDC: sourcetype = kSourceDC;             break;
		case NPSOURCEAC: sourcetype = kSourceAC;             break;
		case NPSOURCEN:  sourcetype = kSourceNodeSet;        break;
		case NPSOURCEX:  sourcetype = kSourceExtension;      break;
		case NPSOURCEB:  sourcetype = kSourceBulk;           break;
		case NPSOURCES:  sourcetype = kNodeSpecial;          break;
	}

	if (initial != 0) DiaSetText(-6, extra);
	DiaSetPopup(3, 10, sourcetypes);
	DiaSetPopupEntry(3, sourcetype);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK || itemHit == 7) break;
	}

	(void)initinfstr();
	switch (DiaGetPopupEntry(3))
	{
		case kSourceUnknown:
		case kSourceVoltage:      (void)addstringtoinfstr("v/");   break;
		case kSourceCurrent:      (void)addstringtoinfstr("c/");   break;
		case kSourceCurrentMeter: (void)addstringtoinfstr("cm/");  break;
		case kSourceTransient:    (void)addstringtoinfstr("t/");   break;
		case kSourceDC:           (void)addstringtoinfstr("vd/");  break;
		case kSourceAC:           (void)addstringtoinfstr("a/");   break;
		case kSourceNodeSet:      (void)addstringtoinfstr("n/");   break;
		case kSourceExtension:    (void)addstringtoinfstr("x/");   break;
		case kSourceBulk:         (void)addstringtoinfstr("b/");   break;
		case kNodeSpecial:        (void)addstringtoinfstr("s/");   break;
	}
	(void)addstringtoinfstr(DiaGetText(6));
	paramstart[0] = returninfstr();
	DiaDoneDialog();
	if (itemHit == OK) return(1);
	if (itemHit == 7) (void)us_showdlog(paramstart, 0);
	return(0);
}

/*
 * special case for the "width/length" menu
 * width value      = 3 (edit)
 * length value     = 5 (edit)
 * More...          = 9 (button)
 * SPICE name       = 7 (edit)
 */
INTSML us_widlendlog(char *paramstart[], char *initial)
{
	INTSML itemHit;
	REGISTER char *pt, *ptex, *start;
	static char line[90];
	REGISTER HIGHLIGHT *high;

	/* if an initial value is given, search for highlighted node and move dialog to it */
	if (initial != 0)
	{
		high = us_getonehighlight();
		if (high != NOHIGHLIGHT) us_movedialogtonode(&us_widlendialog, high->fromgeom);
	}

	/* display the width/length dialog box */
	if (initial != 0) us_widlendialog.items = 9; else us_widlendialog.items = 8;
	if (DiaInitDialog(&us_widlendialog) != 0) return(0);
	if (initial == 0)
	{
		DiaSetText(3, "2");
		DiaSetText(5, "2");
		DiaSetText(7, "");
	} else
	{
		for(pt = initial; *pt != 0 && *pt != '/'; pt++) ;
		if (*pt == '/')
		{
			*pt = 0;
			DiaSetText(3, initial);
			*pt++ = '/';
			start = pt;
			for( ; *pt != 0 && *pt != '/'; pt++) ;
			if (*pt == '/')
			{
				*pt = 0;
				DiaSetText(5, start);
				*pt++ = '/';
				DiaSetText(7, pt);
			} else
			{
				DiaSetText(5, start);
				DiaSetText(7, "");
			}
		} else
		{
			DiaSetText(3, initial);
			DiaSetText(5, initial);
			DiaSetText(7, "");
		}
	}

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK || itemHit == 9) break;
	}

	strcpy(line, DiaGetText(3));
	pt = DiaGetText(5);
	while (*pt == ' ' || *pt == '\t') pt++;
	ptex = DiaGetText(7);
	while (*ptex == ' ' || *ptex == '\t') ptex++;

	if (*pt != 0 || *ptex != 0)
	{
		strcat(line, "/");
		strcat(line, pt);
	}
	if (*ptex != 0)
	{
		strcat(line, "/");
		strcat(line, ptex);
	}
	paramstart[0] = line;
	DiaDoneDialog();
	if (itemHit == OK) return(1);
	if (itemHit == 9) (void)us_showdlog(paramstart, 0);
	return(0);
}

/*
 * special case for the "Window View" dialog
 * restore view     = 1 (button)
 * save view        = 5 (button)
 * view list        = 3 (scroll)
 * new view name    = 4 (edit text)
 */
INTSML us_windowviewdlog(char *paramstart[])
{
	INTSML itemHit, i;
	REGISTER VARIABLE *var;
	char *par[3], *pt;

	/* display the window view dialog box */
	if (DiaInitDialog(&us_windowviewdialog) != 0) return(0);
	DiaInitTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, 0,
		SCSELMOUSE | SCSELKEY | SCDOUBLEQUIT);
	for(i=0; i<us_aid->numvar; i++)
	{
		var = &us_aid->firstvar[i];
		pt = makename(var->key);
		if (namesamen(pt, "USER_windowview_", 16) == 0) DiaStuffLine(3, &pt[16]);
	}
	DiaSelectLine(3, -1);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL) break;
		if (itemHit == 1)
		{
			/* restore selected view */
			par[0] = "name";
			i = DiaGetCurLine(3);
			if (i < 0) continue;
			pt = DiaGetScrollLine(3, i);
			(void)allocstring(&par[1], pt, el_tempcluster);
			break;
		}

		if (itemHit == 5)
		{
			/* save selected view */
			if (DiaValidEntry(4) == 0) continue;
			par[0] = "save";
			par[1] = DiaGetText(4);
			us_window(2, par);
			DiaLoadTextDialog(3, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, -1);
			for(i=0; i<us_aid->numvar; i++)
			{
				var = &us_aid->firstvar[i];
				pt = makename(var->key);
				if (namesamen(pt, "USER_windowview_", 16) == 0) DiaStuffLine(3, &pt[16]);
			}
			DiaSelectLine(3, -1);
			continue;
		}
	}

	DiaDoneDialog();
	if (itemHit == 1)
	{
		us_window(2, par);
		efree(par[1]);
	}
	return(0);
}

/*
 * special case for the "Create To" dialog
 * X coordinate     = 3 (edit text)
 * Y coordinate     = 5 (edit text)
 */
INTSML us_createtodlog(char *paramstart[])
{
	INTSML itemHit;
	INTBIG x, y;

	/* determine default location (use snap point if there is one) */
	if (us_getonesnappoint(&x, &y) == 0) x = y = 0;

	/* get coordinates from dialog */
	if (DiaInitDialog(&us_createtodialog) != 0) return(0);
	DiaSetText(3, latoa(x));
	DiaSetText(5, latoa(y));
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK) break;
	}
	paramstart[0] = us_putintoinfstr(DiaGetText(3));
	paramstart[1] = us_putintoinfstr(DiaGetText(5));
	DiaDoneDialog();
	if (itemHit == CANCEL) return(0);
	return(2);
}

/*
 * special case for the "Port Display" dialog
 * Full Port Names     = 3 (button)
 * Short Port Names    = 4 (button)
 * Ports as Crosses    = 5 (button)
 * No Ports Shown      = 6 (button)
 */
INTSML us_portdisplaydlog(char *paramstart[])
{
	INTSML itemHit;
	INTBIG labels;
	WINDOWPART *w;

	/* display the port labels dialog */
	if (us_needwindow()) return(0);
	if (DiaInitDialog(&us_portdisplaydialog) != 0) return(0);
	switch (us_useroptions&PORTLABELS)
	{
		case PORTSFULL:  DiaSetControl(3, 1);   break;
		case PORTSSHORT: DiaSetControl(4, 1);   break;
		case PORTSCROSS: DiaSetControl(5, 1);   break;
		case PORTSOFF:   DiaSetControl(6, 1);   break;
	}
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK) break;
		if (itemHit == 3 || itemHit == 4 || itemHit == 5 || itemHit == 6)
		{
			DiaSetControl(3, 0);
			DiaSetControl(4, 0);
			DiaSetControl(5, 0);
			DiaSetControl(6, 0);
			DiaSetControl(itemHit, 1);
			continue;
		}
	}
	if (DiaGetControl(3) != 0) labels = PORTSFULL; else
		if (DiaGetControl(4) != 0) labels = PORTSSHORT; else
			if (DiaGetControl(5) != 0) labels = PORTSCROSS; else
				labels = PORTSOFF;
	DiaDoneDialog();
	if (itemHit == OK)
	{
		(void)setvalkey((INTBIG)us_aid, VAID, us_optionflags,
			(us_useroptions & ~PORTLABELS) | labels, VINTEGER);
		us_pushhighlight();
		us_clearhighlightcount();
		for(w = el_topwindowpart; w != NOWINDOWPART; w = w->nextwindowpart)
		{
			startobjectchange((INTBIG)w, VWINDOWPART);
			if (w->redisphandler != 0) (*w->redisphandler)(w);
			endobjectchange((INTBIG)w, VWINDOWPART);
		}
		(void)us_pophighlight(0);
	}
	return(0);
}

/*
 * special case for the "Drawing Options" dialog
 * Company Name      = 4 (edit text)
 * Designer Name     = 6 (edit text)
 */
INTSML us_frameoptionsdlog(char *paramstart[])
{
	INTSML itemHit;
	REGISTER VARIABLE *var;
	REGISTER char *pt;

	/* show the drawing options dialog */
	if (DiaInitDialog(&us_drawingoptdialog) != 0) return(0);
	var = getval((INTBIG)us_aid, VAID, VSTRING, "USER_drawing_company_name");
	if (var != NOVARIABLE) DiaSetText(4, (char *)var->addr);
	var = getval((INTBIG)us_aid, VAID, VSTRING, "USER_drawing_designer_name");
	if (var != NOVARIABLE) DiaSetText(6, (char *)var->addr);
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == CANCEL || itemHit == OK) break;
	}
	if (itemHit == OK)
	{
		pt = DiaGetText(4);
		while (*pt == ' ' || *pt == '\t') pt++;
		if (*pt == 0)
		{
			/* remove company information */
			if (var != NOVARIABLE) delval((INTBIG)us_aid, VAID, "USER_drawing_company_name");
		} else
		{
			(void)setval((INTBIG)us_aid, VAID, "USER_drawing_company_name", (INTBIG)pt, VSTRING);
		}

		pt = DiaGetText(6);
		while (*pt == ' ' || *pt == '\t') pt++;
		if (*pt == 0)
		{
			/* remove designer information */
			if (var != NOVARIABLE) delval((INTBIG)us_aid, VAID, "USER_drawing_designer_name");
		} else
		{
			(void)setval((INTBIG)us_aid, VAID, "USER_drawing_designer_name", (INTBIG)pt, VSTRING);
		}
	}
	DiaDoneDialog();
	return(0);
}

/*
 * special case for the "Silicon Compiler Options" menu
 * Vertical arc list           =  3 (popup)
 * Horizontal arc list         =  4 (popup)
 * Horizontal arc width        =  8 (edit text)
 * Vertical arc width          = 10 (edit text)
 * Power arc width             = 12 (edit text)
 * Main power arc width        = 14 (edit text)
 * P-Well height               = 16 (edit text)
 * P-Well offset               = 18 (edit text)
 * Via size                    = 20 (edit text)
 * Minimum spacing             = 22 (edit text)
 * Routing feed-through size   = 24 (edit text)
 * Routing minimum port dist   = 26 (edit text)
 * Routing minimum active dist = 28 (edit text)
 * Number of rows of cells     = 30 (edit text)
 */
INTSML us_silcompdlog(char *paramstart[])
{
#if SCAID
	INTSML itemHit, numarcnames, horizindex, vertindex, i;
	extern AIDENTRY *ro_aid;
	REGISTER ARCPROTO *ap, *aphoriz, *apvert;
	char **arcnames, numstring[20];

	/* gather list of arcs */
	numarcnames = 0;
	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
		numarcnames++;
	arcnames = (char **)emalloc(numarcnames * (sizeof (char *)), el_tempcluster);
	if (arcnames == 0) return(1);
	numarcnames = 0;
	horizindex = vertindex = 0;
	aphoriz = (ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_HORIZ_ARC);
	apvert = (ARCPROTO *)ScGetParameter(SC_PARAM_MAKE_VERT_ARC);
	for(ap = el_curtech->firstarcproto; ap != NOARCPROTO; ap = ap->nextarcproto)
	{
		arcnames[numarcnames] = ap->protoname;
		if (aphoriz == ap) horizindex = numarcnames;
		if (apvert == ap) vertindex = numarcnames;
		numarcnames++;
	}

	/* display the silicon compiler options dialog box */
	if (DiaInitDialog(&us_silcompdialog) != 0) return(0);
	DiaSetPopup(3, numarcnames, arcnames);
	DiaSetPopup(4, numarcnames, arcnames);
	DiaSetPopupEntry(3, vertindex);
	DiaSetPopupEntry(4, horizindex);

	DiaSetText(8, latoa(ScGetParameter(SC_PARAM_MAKE_L1_WIDTH)));
	DiaSetText(10, latoa(ScGetParameter(SC_PARAM_MAKE_L2_WIDTH)));
	DiaSetText(12, latoa(ScGetParameter(SC_PARAM_MAKE_PWR_WIDTH)));
	DiaSetText(14, latoa(ScGetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH)));
	DiaSetText(16, latoa(ScGetParameter(SC_PARAM_MAKE_PWELL_SIZE)));
	DiaSetText(18, latoa(ScGetParameter(SC_PARAM_MAKE_PWELL_OFFSET)));
	DiaSetText(20, latoa(ScGetParameter(SC_PARAM_MAKE_VIA_SIZE)));
	DiaSetText(22, latoa(ScGetParameter(SC_PARAM_MAKE_MIN_SPACING)));
	DiaSetText(24, latoa(ScGetParameter(SC_PARAM_ROUTE_FEEDTHRU_SIZE)));
	DiaSetText(26, latoa(ScGetParameter(SC_PARAM_ROUTE_PORT_X_MIN_DIST)));
	DiaSetText(28, latoa(ScGetParameter(SC_PARAM_ROUTE_ACTIVE_DIST)));
	sprintf(numstring, "%ld", ScGetParameter(SC_PARAM_PLACE_NUM_ROWS));
	DiaSetText(30, numstring);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;
	}

	if (itemHit != CANCEL)
	{
		i = DiaGetPopupEntry(3);
		ScSetParameter(SC_PARAM_MAKE_VERT_ARC, (INTBIG)getarcproto(arcnames[i]));
		i = DiaGetPopupEntry(4);
		ScSetParameter(SC_PARAM_MAKE_HORIZ_ARC, (INTBIG)getarcproto(arcnames[i]));
		ScSetParameter(SC_PARAM_MAKE_L1_WIDTH, atola(DiaGetText(8)));
		ScSetParameter(SC_PARAM_MAKE_L2_WIDTH, atola(DiaGetText(10)));
		ScSetParameter(SC_PARAM_MAKE_PWR_WIDTH, atola(DiaGetText(12)));
		ScSetParameter(SC_PARAM_MAKE_MAIN_PWR_WIDTH, atola(DiaGetText(14)));
		ScSetParameter(SC_PARAM_MAKE_PWELL_SIZE, atola(DiaGetText(16)));
		ScSetParameter(SC_PARAM_MAKE_PWELL_OFFSET, atola(DiaGetText(18)));
		ScSetParameter(SC_PARAM_MAKE_VIA_SIZE, atola(DiaGetText(20)));
		ScSetParameter(SC_PARAM_MAKE_MIN_SPACING, atola(DiaGetText(22)));
		ScSetParameter(SC_PARAM_ROUTE_FEEDTHRU_SIZE, atola(DiaGetText(24)));
		ScSetParameter(SC_PARAM_ROUTE_PORT_X_MIN_DIST, atola(DiaGetText(26)));
		ScSetParameter(SC_PARAM_ROUTE_ACTIVE_DIST, atola(DiaGetText(28)));
		ScSetParameter(SC_PARAM_PLACE_NUM_ROWS, atoi(DiaGetText(30)));
	}
	efree((char *)arcnames);
	DiaDoneDialog();
	paramstart[0] = "";
	return(1);
#else
	ttyputerr("No silicon compiler available");
	return(1);
#endif
}

#define	DEGTORAD    (EPI/180.0)
#define INTENSITYDIVISIONS 20
#define WHEELRADIUS        96
#define WHEELEDGE          (WHEELRADIUS + WHEELRADIUS/16)

INTBIG us_colormixredmap[256], us_colormixgreenmap[256], us_colormixbluemap[256];
INTBIG us_colormixindex[16];
INTBIG us_colormixcurindex;
float us_colormixtheta, us_colormixr, us_colormixinten;
char *us_colormixnames[5];

/*
 * special case for the "Color Mixing" dialog
 * Color patches for palettes  = 3,5,7,9,11,13,15,17,19,21,23,25,27,29,31,33 (user)
 * Buttons for color palette   = 4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34 (radio)
 * Hue/Saturation wheel        = 35 (user)
 * Intensity slider            = 36 (user)
 * Primaries palette selection = 39 (radio)
 * Specials palette selection  = 40 (radio)
 * Layer 1 palette selection   = 41 (radio)
 * Layer 2 palette selection   = 42 (radio)
 * Layer 3 palette selection   = 43 (radio)
 * Layer 4 palette selection   = 44 (radio)
 * Layer 5 palette selection   = 45 (radio)
 */
INTSML us_colormixdlog(char *overlayernames[])
{
	INTSML itemHit, i, x, y;
	INTBIG r, g, b;
	REGISTER INTBIG cx, cy;
	REGISTER VARIABLE *varred, *vargreen, *varblue;
	RECTAREA ra;

	varred = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_red);
	vargreen = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_green);
	varblue = getvalkey((INTBIG)us_aid, VAID, VINTEGER|VISARRAY, us_colormap_blue);
	if (varred == NOVARIABLE || vargreen == NOVARIABLE || varblue == NOVARIABLE) return(0);
	for(i=0; i<256; i++)
	{
		us_colormixredmap[i] = ((INTBIG *)varred->addr)[i];
		us_colormixgreenmap[i] = ((INTBIG *)vargreen->addr)[i];
		us_colormixbluemap[i] = ((INTBIG *)varblue->addr)[i];
	}

	/* display the color mixing dialog box */
	us_colormixdialogitems[40].msg = overlayernames[0];
	us_colormixdialogitems[41].msg = overlayernames[1];
	us_colormixdialogitems[42].msg = overlayernames[2];
	us_colormixdialogitems[43].msg = overlayernames[3];
	us_colormixdialogitems[44].msg = overlayernames[4];
	if (DiaInitDialog(&us_colormixdialog) != 0) return(0);
	for(i=0; i<5; i++) us_colormixnames[i] = overlayernames[i];
	DiaSetControl(39, 1);
	DiaSetControl(4, 1);
	us_colormixdrawpalette(&ra);
	DiaRedispRoutine(35, us_colormixdrawpalette);

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;
		if (itemHit >= 3 && itemHit <= 34)
		{
			/* hit on one of the 16 colors */
			us_colormixtogglemarker();
			for(i=4; i<=34; i += 2) DiaSetControl(i, 0);
			i = (itemHit + 1) / 2 * 2;
			DiaSetControl(i, 1);
			us_colormixtogglemarker();
			continue;
		}
		if (itemHit >= 39 && itemHit <= 45)
		{
			/* hit on one of the 7 palette sets */
			us_colormixtogglemarker();
			for(i=39; i<=45; i++) DiaSetControl(i, 0);
			DiaSetControl(itemHit, 1);
			us_colormixreload();
			us_colormixtogglemarker();
			continue;
		}
		if (itemHit == 35)
		{
			/* hit in the hue/saturation wheel */
			DiaGetMouse(&x, &y);
			DiaItemRect(35, &ra);
			cx = (ra.left + ra.right) / 2;
			cy = (ra.top + ra.bottom) / 2;
			us_colormixtogglemarker();
			us_colormixtheta = (float)((figureangle(cx, cy, x, y) + 5) / 10);
			if (us_colormixtheta < 0.0) us_colormixtheta += 360.0;
			us_colormixr = (float)sqrt((float)((y-cy)*(y-cy) + (x-cx)*(x-cx)));
			if (us_colormixr > WHEELEDGE) us_colormixr = WHEELEDGE;
			us_hsvtorgb(us_colormixtheta / 360.0f, us_colormixr / WHEELEDGE, us_colormixinten, &r,
				&g, &b);
			us_colormixredmap[us_colormixindex[us_colormixcurindex]] = r;
			us_colormixgreenmap[us_colormixindex[us_colormixcurindex]] = g;
			us_colormixbluemap[us_colormixindex[us_colormixcurindex]] = b;
			us_colormixtogglemarker();
			us_colormixdrawsquare(us_colormixcurindex);
			continue;
		}
		if (itemHit == 36)
		{
			/* hit in the intensity slider */
			DiaGetMouse(&x, &y);
			DiaItemRect(36, &ra);
			cx = (ra.left + ra.right) / 2;
			cy = (ra.top + ra.bottom) / 2;
			us_colormixtogglemarker();
			us_colormixinten = (float)(ra.bottom - y) / (float)(ra.bottom - ra.top);
			us_hsvtorgb(us_colormixtheta / 360.0f, us_colormixr / WHEELEDGE, us_colormixinten, &r,
				&g, &b);
			us_colormixredmap[us_colormixindex[us_colormixcurindex]] = r;
			us_colormixgreenmap[us_colormixindex[us_colormixcurindex]] = g;
			us_colormixbluemap[us_colormixindex[us_colormixcurindex]] = b;
			us_colormixtogglemarker();
			us_colormixdrawsquare(us_colormixcurindex);
			continue;
		}
	}

	if (itemHit != CANCEL)
	{
		/* load the color map with the new values */
		startobjectchange((INTBIG)us_aid, VAID);
		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_red, (INTBIG)us_colormixredmap,
			VINTEGER|VISARRAY|(256<<VLENGTHSH));
		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_green, (INTBIG)us_colormixgreenmap,
			VINTEGER|VISARRAY|(256<<VLENGTHSH));
		(void)setvalkey((INTBIG)us_aid, VAID, us_colormap_blue, (INTBIG)us_colormixbluemap,
			VINTEGER|VISARRAY|(256<<VLENGTHSH));
		endobjectchange((INTBIG)us_aid, VAID);
	}
	DiaDoneDialog();
	return(0);
}

/* Routine to draw the hue/saturation wheel and the intensity slider */
void us_colormixdrawpalette(RECTAREA *ra)
{
	REGISTER INTBIG theta, inc, rr, cx, cy, i, col, spacing;
	INTBIG r, g, b, x[4], y[4];
	RECTAREA rect;
	float intermed, intertwo;

	/* draw hue/saturation wheel */
	DiaItemRect(35, &rect);
	cx = (rect.left + rect.right) / 2;
	cy = (rect.top + rect.bottom) / 2;
	for(theta=0; theta<360; theta+=60)
	{
		for(inc=0; inc<60; inc+=20)
			for(rr = 0; rr < WHEELRADIUS/2; rr += WHEELRADIUS/8)
		{
			intermed = (float) theta + inc;
			intertwo = (float) rr + WHEELRADIUS/8;
			x[0] = (INTBIG)(((float)rr) * cos(intermed*DEGTORAD)) + cx;
			y[0] = (INTBIG)(((float)rr) * sin(intermed*DEGTORAD)) + cy;
			x[1] = (INTBIG)(intertwo * cos(intermed*DEGTORAD)) + cx;
			y[1] = (INTBIG)(intertwo * sin(intermed*DEGTORAD)) + cy;
			intermed += 21.0;
			x[2] = (INTBIG)(intertwo * cos(intermed*DEGTORAD)) + cx;
			y[2] = (INTBIG)(intertwo * sin(intermed*DEGTORAD)) + cy;
			x[3] = (INTBIG)(((float)rr) * cos(intermed*DEGTORAD)) + cx;
			y[3] = (INTBIG)(((float)rr) * sin(intermed*DEGTORAD)) + cy;
			us_hsvtorgb(((float)(theta+inc+10)) / 360.0f,
				((float)rr+WHEELRADIUS/16) / WHEELRADIUS, 1.0f, &r, &g, &b);
			DiaFillPoly(35, x, y, 4, r, g, b);
		}
		for(inc=0; inc<60; inc+=10)
			for(rr = WHEELRADIUS/8; rr < WHEELRADIUS; rr += WHEELRADIUS/8)
		{
			intermed = (float) theta + inc;
			intertwo = (float) rr + WHEELRADIUS/8;
			x[0] = (INTBIG)(((float)rr)* cos(intermed*DEGTORAD)) + cx;
			y[0] = (INTBIG)(((float)rr)* sin(intermed*DEGTORAD)) + cy;
			x[1] = (INTBIG)(intertwo * cos(intermed*DEGTORAD)) + cx;
			y[1] = (INTBIG)(intertwo * sin(intermed*DEGTORAD)) + cy;
			intermed += 12.0;
			x[2] = (INTBIG)(intertwo * cos(intermed*DEGTORAD)) + cx;
			y[2] = (INTBIG)(intertwo * sin(intermed*DEGTORAD)) + cy;
			x[3] = (INTBIG)(((float)rr) * cos(intermed*DEGTORAD)) + cx;
			y[3] = (INTBIG)(((float)rr) * sin(intermed*DEGTORAD)) + cy;
			us_hsvtorgb(((float)(theta+inc+5)) / 360.0f,
				((float)rr+WHEELRADIUS/16) / WHEELRADIUS, 1.0f, &r, &g, &b);
			DiaFillPoly(35, x, y, 4, r, g, b);
		}
	}

	/* draw the intensity slider */
	DiaItemRect(36, &rect);
	rect.left--;   rect.right++;
	rect.top--;    rect.bottom++;
	DiaFrameRect(36, &rect);
	rect.left++;   rect.right--;
	rect.top++;    rect.bottom--;
	spacing = (rect.bottom - rect.top) / INTENSITYDIVISIONS;
	for(i=0; i<INTENSITYDIVISIONS; i++)
	{
		x[0] = rect.left;   y[0] = rect.bottom - i*spacing;
		x[1] = rect.left;   y[1] = rect.bottom - (i+1)*spacing;
		x[2] = rect.right;  y[2] = rect.bottom - (i+1)*spacing;
		x[3] = rect.right;  y[3] = rect.bottom - i*spacing;
		col = i * 255 / INTENSITYDIVISIONS;
		DiaFillPoly(36, x, y, 4, col, col, col);
	}

	/* draw the current color marker */
	us_colormixtogglemarker();
	us_colormixreload();
}

/*
 * Routine to draw an "x" on the hue/saturation wheel and the intensity slider
 * to indicate the current color.
 */
void us_colormixtogglemarker(void)
{
	REGISTER INTBIG r, g, b, cx, cy, x, y;
	RECTAREA rect;

	/* get the current color */
	for(us_colormixcurindex=0; us_colormixcurindex<16; us_colormixcurindex++)
		if (DiaGetControl((INTSML)(us_colormixcurindex*2+4)) != 0) break;
	r = us_colormixredmap[us_colormixindex[us_colormixcurindex]];
	g = us_colormixgreenmap[us_colormixindex[us_colormixcurindex]];
	b = us_colormixbluemap[us_colormixindex[us_colormixcurindex]];
	us_rgbtohsv((INTSML)r, (INTSML)g, (INTSML)b, &us_colormixtheta, &us_colormixr, &us_colormixinten);
	us_colormixtheta *= 360.0;
	us_colormixr *= WHEELEDGE;

	/* show the position in the hue/saturation area */
	DiaItemRect(35, &rect);
	cx = (rect.left + rect.right) / 2;
	cy = (rect.top + rect.bottom) / 2;
	x = (INTBIG)(us_colormixr * cos(us_colormixtheta * DEGTORAD)) + cx;
	y = (INTBIG)(us_colormixr * sin(us_colormixtheta * DEGTORAD)) + cy;
	DiaDrawLine(35, x-5, y-5, x+5, y+5, DLMODEINVERT);
	DiaDrawLine(35, x-5, y+5, x+5, y-5, DLMODEINVERT);

	/* show the position in the intensity area */
	DiaItemRect(36, &rect);
	cx = (rect.left + rect.right) / 2;
	y = rect.bottom - (INTBIG)(us_colormixinten * (float)(rect.bottom - rect.top));
	DiaDrawLine(36, cx-5, y-5, cx+5, y+5, DLMODEINVERT);
	DiaDrawLine(36, cx-5, y+5, cx+5, y-5, DLMODEINVERT);
}

/*
 * Routine to reload the 16 color entries according to the selected palette set.
 */
void us_colormixreload(void)
{
	INTBIG i;

	if (DiaGetControl(39) != 0)
	{
		us_colormixindex[0]  = ALLOFF;
		us_colormixindex[1]  = LAYERT1;
		us_colormixindex[2]  = LAYERT2;
		us_colormixindex[3]  = LAYERT3;
		us_colormixindex[4]  = LAYERT4;
		us_colormixindex[5]  = LAYERT5;
		us_colormixindex[6]  = LAYERT1 | LAYERT2;
		us_colormixindex[7]  = LAYERT1 | LAYERT3;
		us_colormixindex[8]  = LAYERT1 | LAYERT4;
		us_colormixindex[9]  = LAYERT1 | LAYERT5;
		us_colormixindex[10] = LAYERT2 | LAYERT3;
		us_colormixindex[11] = LAYERT2 | LAYERT4;
		us_colormixindex[12] = LAYERT2 | LAYERT5;
		us_colormixindex[13] = LAYERT3 | LAYERT4;
		us_colormixindex[14] = LAYERT3 | LAYERT5;
		us_colormixindex[15] = LAYERT4 | LAYERT5;
	}
	if (DiaGetControl(40) != 0)
	{
		us_colormixindex[0]  = ALLOFF;
		us_colormixindex[1]  = GRID;
		us_colormixindex[2]  = HIGHLIT;
		us_colormixindex[3]  = el_colfacettxt;
		us_colormixindex[4]  = el_colfacet;
		us_colormixindex[5]  = el_colwinbor;
		us_colormixindex[6]  = el_colhwinbor;
		us_colormixindex[7]  = el_colmenbor;
		us_colormixindex[8]  = el_colhmenbor;
		us_colormixindex[9]  = el_colmentxt;
		us_colormixindex[10] = el_colmengly;
		us_colormixindex[11] = el_colcursor;
		us_colormixindex[12] = 0354;
		us_colormixindex[13] = 0364;
		us_colormixindex[14] = 0374;
		us_colormixindex[15] = ALLOFF;
	}
	if (DiaGetControl(41) != 0)
		us_colormixbuildindex(LAYERT1, LAYERT2, LAYERT3, LAYERT4, LAYERT5);
	if (DiaGetControl(42) != 0)
		us_colormixbuildindex(LAYERT2, LAYERT1, LAYERT3, LAYERT4, LAYERT5);
	if (DiaGetControl(43) != 0)
		us_colormixbuildindex(LAYERT3, LAYERT1, LAYERT2, LAYERT4, LAYERT5);
	if (DiaGetControl(44) != 0)
		us_colormixbuildindex(LAYERT4, LAYERT1, LAYERT2, LAYERT3, LAYERT5);
	if (DiaGetControl(45) != 0)
		us_colormixbuildindex(LAYERT5, LAYERT1, LAYERT2, LAYERT3, LAYERT4);
	for(i=0; i<16; i++)
	{
		DiaSetText((INTSML)(i*2+4), us_colormixentryname(us_colormixnames, (INTSML)us_colormixindex[i]));
		us_colormixdrawsquare(i);
	}
}

/*
 * Routine to build the entries desired given the five layers "layer1-5".
 */
void us_colormixbuildindex(INTSML layer1, INTSML layer2, INTSML layer3, INTSML layer4, INTSML layer5)
{
	us_colormixindex[0]  = layer1;
	us_colormixindex[1]  = layer1 | layer2;
	us_colormixindex[2]  = layer1 |          layer3;
	us_colormixindex[3]  = layer1 | layer2 | layer3;
	us_colormixindex[4]  = layer1 |                   layer4;
	us_colormixindex[5]  = layer1 | layer2 |          layer4;
	us_colormixindex[6]  = layer1 |          layer3 | layer4;
	us_colormixindex[7]  = layer1 | layer2 | layer3 | layer4;
	us_colormixindex[8]  = layer1 |                            layer5;
	us_colormixindex[9]  = layer1 | layer2 |                   layer5;
	us_colormixindex[10] = layer1 |          layer3 |          layer5;
	us_colormixindex[11] = layer1 | layer2 | layer3 |          layer5;
	us_colormixindex[12] = layer1 |                   layer4 | layer5;
	us_colormixindex[13] = layer1 | layer2 |          layer4 | layer5;
	us_colormixindex[14] = layer1 |          layer3 | layer4 | layer5;
	us_colormixindex[15] = layer1 | layer2 | layer3 | layer4 | layer5;
}

/*
 * Routine to redraw color square "index" from the current settings.
 */
void us_colormixdrawsquare(INTBIG index)
{
	RECTAREA r;
	INTBIG x[4], y[4];

	DiaItemRect((INTSML)(index*2+3), &r);
	x[0] = r.left;   y[0] = r.top;
	x[1] = r.left;   y[1] = r.bottom;
	x[2] = r.right;  y[2] = r.bottom;
	x[3] = r.right;  y[3] = r.top;
	r.left--;   r.right++;
	r.top--;    r.bottom++;
	DiaFrameRect((INTSML)(index*2+3), &r);
	DiaFillPoly((INTSML)(index*2+3), x, y, 4, us_colormixredmap[us_colormixindex[index]],
		us_colormixgreenmap[us_colormixindex[index]], us_colormixbluemap[us_colormixindex[index]]);
}

/*
 * Routine to construct the name of color map entry "ind", given the transparent layer names in "overlayernames".
 */
char *us_colormixentryname(char *overlayernames[], INTSML ind)
{
	INTSML gotname;

	if (ind == ALLOFF) return("Background");
	if (ind == GRID) return("Grid");
	if (ind == HIGHLIT) return("Highlight");
	if (ind == 0354) return("Extra 1");
	if (ind == 0364) return("Extra 2");
	if (ind == 0374) return("Extra 3");
	if (ind == el_colfacettxt) return("Facet Name");
	if (ind == el_colfacet) return("Facet Outline");
	if (ind == el_colwinbor) return("Window Border");
	if (ind == el_colhwinbor) return("Current Window Border");
	if (ind == el_colmenbor) return("Component Menu Border");
	if (ind == el_colhmenbor) return("Highlighted Component Menu Border");
	if (ind == el_colmentxt) return("Text in Component Menu");
	if (ind == el_colmengly) return("Glyphs in Component Menu");
	if (ind == el_colcursor) return("Cursor");
	(void)initinfstr();
	gotname = 0;
	if ((ind&LAYERT1) != 0)
	{
		if (gotname != 0) (void)addstringtoinfstr(", ");
		(void)addstringtoinfstr(overlayernames[0]);
		gotname = 1;
	}
	if ((ind&LAYERT2) != 0)
	{
		if (gotname != 0) (void)addstringtoinfstr(", ");
		(void)addstringtoinfstr(overlayernames[1]);
		gotname = 1;
	}
	if ((ind&LAYERT3) != 0)
	{
		if (gotname != 0) (void)addstringtoinfstr(", ");
		(void)addstringtoinfstr(overlayernames[2]);
		gotname = 1;
	}
	if ((ind&LAYERT4) != 0)
	{
		if (gotname != 0) (void)addstringtoinfstr(", ");
		(void)addstringtoinfstr(overlayernames[3]);
		gotname = 1;
	}
	if ((ind&LAYERT5) != 0)
	{
		if (gotname != 0) (void)addstringtoinfstr(", ");
		(void)addstringtoinfstr(overlayernames[4]);
	}
	return(returninfstr());
}

/*
 * special case for the "Annular ring" dialog
 * inner radius       = 4 (edit text)
 * outer radius       = 6 (edit text)
 * number of segments = 8 (edit text)
 * number of degrees  = 10 (edit text)
 * layer to use       = 12 (scroll)
 */
INTSML us_annularringdlog(char *paramstart[])
{
	INTSML itemHit, i, selectedlayer;
	REGISTER INTBIG lx, hx, ly, hy, cx, cy;
	REGISTER NODEINST *ni;
	REGISTER NODEPROTO *layer, *parent;
	char inner[20], outer[20], segs[20], degrees[20], *pars[6];
	static POLYGON *poly = NOPOLYGON;
	HIGHLIGHT newhigh;

	parent = us_needfacet();
	if (parent == NONODEPROTO) return(0);

	/* get polygon */
	if (poly == NOPOLYGON) poly = allocpolygon(4, us_aid->cluster);

	/* display the window view dialog box */
	if (DiaInitDialog(&us_annringdialog) != 0) return(0);
	DiaInitTextDialog(12, us_nulldloglist, us_nulldlogitem, us_nulldlogdone, 0,
		SCSELMOUSE);
	for(i=0; i<el_curtech->layercount; i++)
		DiaStuffLine(12, layername(el_curtech, i));
	DiaSelectLine(12, 0);
	DiaSetText(8, "32");
	DiaSetText(10, "360");

	/* loop until done */
	for(;;)
	{
		itemHit = DiaNextHit();
		if (itemHit == OK || itemHit == CANCEL) break;
	}

	DiaDoneDialog();
	if (itemHit == OK)
	{
		/* figure out which pure-layer node to create */
		selectedlayer = DiaGetCurLine(12);
		for(layer = el_curtech->firstnodeproto; layer != NONODEPROTO; layer = layer->nextnodeproto)
		{
			if (((layer->userbits&NFUNCTION) >> NFUNCTIONSH) != NPNODE) continue;
			ni = dummynode();
			ni->proto = layer;
			ni->lowx = ni->highx = 0;
			ni->lowy = ni->highy = 0;
			i = nodepolys(ni);
			if (i != 1) continue;
			shapenodepoly(ni, 0, poly);
			if (poly->layer == selectedlayer) break;
		}
		if (layer == NONODEPROTO) return(0);

		/* create the pure-layer node */
		cx = (el_curwindowpart->screenlx + el_curwindowpart->screenhx) / 2;
		cy = (el_curwindowpart->screenly + el_curwindowpart->screenhy) / 2;
		lx = cx - (layer->highx - layer->lowx) / 2;
		hx = lx + layer->highx - layer->lowx;
		ly = cy - (layer->highy - layer->lowy) / 2;
		hy = ly + layer->highy - layer->lowy;
		ni = newnodeinst(layer, lx, hx, ly, hy, 0, 0, parent);
		if (ni == NONODEINST) return(0);
		endobjectchange((INTBIG)ni, VNODEINST);

		/* highlight the pure-layer node */
		us_clearhighlightcount();
		newhigh.status = HIGHFROM;
		newhigh.facet = parent;
		newhigh.fromgeom = ni->geom;
		newhigh.fromport = NOPORTPROTO;
		newhigh.frompoint = 0;
		(void)us_addhighlight(&newhigh);

		/* turn it into an annular ring */
		strcpy(inner, DiaGetText(4));
		strcpy(outer, DiaGetText(6));
		strcpy(segs, DiaGetText(8));
		strcpy(degrees, DiaGetText(10));
		pars[0] = "trace";
		pars[1] = "construct-annulus";
		pars[2] = inner;
		pars[3] = outer;
		pars[4] = segs;
		pars[5] = degrees;
		us_node(6, pars);
	}
	return(0);
}
